Class: Orb::Models::AdjustmentInterval::Adjustment::TieredPercentageDiscount
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::AdjustmentInterval::Adjustment::TieredPercentageDiscount
- Defined in:
- lib/orb/models/adjustment_interval.rb,
sig/orb/models/adjustment_interval.rbs
Defined Under Namespace
Instance Attribute Summary collapse
- #adjustment_type ⇒ Symbol, :tiered_percentage_discount
- #applies_to_price_ids ⇒ Array<String> deprecated Deprecated.
-
#filters ⇒ Array<Orb::Models::AdjustmentInterval::Adjustment::TieredPercentageDiscount::Filter>
The filters that determine which prices to apply this adjustment to.
- #id ⇒ String
-
#is_invoice_level ⇒ Boolean
True for adjustments that apply to an entire invoice, false for adjustments that apply to only one price.
-
#plan_phase_order ⇒ Integer?
The plan phase in which this adjustment is active.
-
#reason ⇒ String?
The reason for the adjustment.
-
#replaces_adjustment_id ⇒ String?
The adjustment id this adjustment replaces.
-
#tiers ⇒ Array<Orb::Models::AdjustmentInterval::Adjustment::TieredPercentageDiscount::Tier>
The ordered, contiguous bands of cumulative eligible spend, each discounted at its own percentage (progressive fill-a-tier), applied to the prices this adjustment covers in a given billing period.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
82 |
# File 'sig/orb/models/adjustment_interval.rbs', line 82 def initialize: ( |
Instance Attribute Details
#adjustment_type ⇒ Symbol, :tiered_percentage_discount
72 |
# File 'lib/orb/models/adjustment_interval.rb', line 72 required :adjustment_type, const: :tiered_percentage_discount |
#applies_to_price_ids ⇒ Array<String>
The price IDs that this adjustment applies to.
80 |
# File 'lib/orb/models/adjustment_interval.rb', line 80 required :applies_to_price_ids, Orb::Internal::Type::ArrayOf[String] |
#filters ⇒ Array<Orb::Models::AdjustmentInterval::Adjustment::TieredPercentageDiscount::Filter>
The filters that determine which prices to apply this adjustment to.
86 87 |
# File 'lib/orb/models/adjustment_interval.rb', line 86 required :filters, -> { Orb::Internal::Type::ArrayOf[Orb::AdjustmentInterval::Adjustment::TieredPercentageDiscount::Filter] } |
#id ⇒ String
67 |
# File 'lib/orb/models/adjustment_interval.rb', line 67 required :id, String |
#is_invoice_level ⇒ Boolean
True for adjustments that apply to an entire invoice, false for adjustments that apply to only one price.
94 |
# File 'lib/orb/models/adjustment_interval.rb', line 94 required :is_invoice_level, Orb::Internal::Type::Boolean |
#plan_phase_order ⇒ Integer?
The plan phase in which this adjustment is active.
100 |
# File 'lib/orb/models/adjustment_interval.rb', line 100 required :plan_phase_order, Integer, nil?: true |
#reason ⇒ String?
The reason for the adjustment.
106 |
# File 'lib/orb/models/adjustment_interval.rb', line 106 required :reason, String, nil?: true |
#replaces_adjustment_id ⇒ String?
The adjustment id this adjustment replaces. This adjustment will take the place of the replaced adjustment in plan version migrations.
113 |
# File 'lib/orb/models/adjustment_interval.rb', line 113 required :replaces_adjustment_id, String, nil?: true |
#tiers ⇒ Array<Orb::Models::AdjustmentInterval::Adjustment::TieredPercentageDiscount::Tier>
The ordered, contiguous bands of cumulative eligible spend, each discounted at its own percentage (progressive fill-a-tier), applied to the prices this adjustment covers in a given billing period.
121 122 |
# File 'lib/orb/models/adjustment_interval.rb', line 121 required :tiers, -> { Orb::Internal::Type::ArrayOf[Orb::AdjustmentInterval::Adjustment::TieredPercentageDiscount::Tier] } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/adjustment_interval.rb', line 199
|
Instance Method Details
#to_hash ⇒ {
94 |
# File 'sig/orb/models/adjustment_interval.rbs', line 94 def to_hash: -> { |