Class: Orb::Models::AggregatedCost

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/aggregated_cost.rb,
sig/orb/models/aggregated_cost.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(per_price_costs:, subtotal:, timeframe_end:, timeframe_start:, total:) ⇒ Object

Parameters:

  • per_price_costs (Array<Orb::Models::PerPriceCost>)
  • subtotal (String)

    Total costs for the timeframe, excluding any minimums and discounts.

  • timeframe_end (Time)
  • timeframe_start (Time)
  • total (String)

    Total costs for the timeframe, including any minimums and discounts.



# File 'lib/orb/models/aggregated_cost.rb', line 33

Instance Attribute Details

#per_price_costsArray<Orb::Models::PerPriceCost>

Parameters:

Returns:



9
# File 'lib/orb/models/aggregated_cost.rb', line 9

required :per_price_costs, -> { Orb::Internal::Type::ArrayOf[Orb::PerPriceCost] }

#subtotalString

Total costs for the timeframe, excluding any minimums and discounts.

Parameters:

  • value (String)

Returns:

  • (String)


15
# File 'lib/orb/models/aggregated_cost.rb', line 15

required :subtotal, String

#timeframe_endTime

Parameters:

  • value (Time)

Returns:

  • (Time)


20
# File 'lib/orb/models/aggregated_cost.rb', line 20

required :timeframe_end, Time

#timeframe_startTime

Parameters:

  • value (Time)

Returns:

  • (Time)


25
# File 'lib/orb/models/aggregated_cost.rb', line 25

required :timeframe_start, Time

#totalString

Total costs for the timeframe, including any minimums and discounts.

Parameters:

  • value (String)

Returns:

  • (String)


31
# File 'lib/orb/models/aggregated_cost.rb', line 31

required :total, String

Instance Method Details

#to_hash{

Returns:

  • ({)


31
# File 'sig/orb/models/aggregated_cost.rbs', line 31

def to_hash: -> {