Class: Orb::Models::Alert::BalanceAlertStatus
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Alert::BalanceAlertStatus
- Defined in:
- lib/orb/models/alert.rb,
sig/orb/models/alert.rbs
Instance Attribute Summary collapse
-
#in_alert ⇒ Boolean
Whether the alert is currently in-alert or not.
-
#threshold_value ⇒ Float
The value of the threshold that defines the alert status.
Instance Method Summary collapse
-
#initialize ⇒ BalanceAlertStatus
constructor
A new instance of BalanceAlertStatus.
- #to_hash ⇒ { in_alert: bool, threshold_value: Float }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ BalanceAlertStatus
Returns a new instance of BalanceAlertStatus.
159 |
# File 'sig/orb/models/alert.rbs', line 159
def initialize: (in_alert: bool, threshold_value: Float) -> void
|
Instance Attribute Details
#in_alert ⇒ Boolean
Whether the alert is currently in-alert or not.
221 |
# File 'lib/orb/models/alert.rb', line 221 required :in_alert, Orb::Internal::Type::Boolean |
#threshold_value ⇒ Float
The value of the threshold that defines the alert status.
227 |
# File 'lib/orb/models/alert.rb', line 227 required :threshold_value, Float |
Instance Method Details
#to_hash ⇒ { in_alert: bool, threshold_value: Float }
161 |
# File 'sig/orb/models/alert.rbs', line 161
def to_hash: -> { in_alert: bool, threshold_value: Float }
|