Class: Orb::Models::Alert::Plan
Overview
Instance Attribute Summary collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
116
|
# File 'sig/orb/models/alert.rbs', line 116
def initialize: (
|
Instance Attribute Details
#external_plan_id ⇒ String?
An optional user-defined ID for this plan resource, used throughout the system
as an alias for this Plan. Use this field to identify a plan by an existing
identifier in your system.
172
|
# File 'lib/orb/models/alert.rb', line 172
required :external_plan_id, String, nil?: true
|
#id ⇒ String?
164
|
# File 'lib/orb/models/alert.rb', line 164
required :id, String, nil?: true
|
#name ⇒ String?
177
|
# File 'lib/orb/models/alert.rb', line 177
required :name, String, nil?: true
|
#plan_version ⇒ String
182
|
# File 'lib/orb/models/alert.rb', line 182
required :plan_version, String
|
Instance Method Details
#to_hash ⇒ {
123
|
# File 'sig/orb/models/alert.rbs', line 123
def to_hash: -> {
|