Class: Orb::Models::AlertCreateForCustomerParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::AlertCreateForCustomerParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/orb/models/alert_create_for_customer_params.rb,
sig/orb/models/alert_create_for_customer_params.rbs
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#currency ⇒ String
The case sensitive currency or custom pricing unit to use for this alert.
- #customer_id ⇒ String
-
#thresholds ⇒ Array<Orb::Models::Threshold>?
The thresholds that define the values at which the alert will be triggered.
-
#type ⇒ Symbol, Orb::Models::AlertCreateForCustomerParams::Type
The type of alert to create.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(customer_id:, currency:, type:, thresholds: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(customer_id:, currency:, type:, thresholds: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/orb/models/alert_create_for_customer_params.rb', line 33
|
Instance Attribute Details
#currency ⇒ String
The case sensitive currency or custom pricing unit to use for this alert.
19 |
# File 'lib/orb/models/alert_create_for_customer_params.rb', line 19 required :currency, String |
#customer_id ⇒ String
13 |
# File 'lib/orb/models/alert_create_for_customer_params.rb', line 13 required :customer_id, String |
#thresholds ⇒ Array<Orb::Models::Threshold>?
The thresholds that define the values at which the alert will be triggered.
31 |
# File 'lib/orb/models/alert_create_for_customer_params.rb', line 31 optional :thresholds, -> { Orb::Internal::Type::ArrayOf[Orb::Threshold] }, nil?: true |
#type ⇒ Symbol, Orb::Models::AlertCreateForCustomerParams::Type
The type of alert to create. This must be a valid alert type.
25 |
# File 'lib/orb/models/alert_create_for_customer_params.rb', line 25 required :type, enum: -> { Orb::AlertCreateForCustomerParams::Type } |
Instance Method Details
#to_hash ⇒ {
32 |
# File 'sig/orb/models/alert_create_for_customer_params.rbs', line 32
def to_hash: -> {
|