Class: Orb::Models::AlertCreateForSubscriptionParams::ThresholdOverride

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/alert_create_for_subscription_params.rb,
sig/orb/models/alert_create_for_subscription_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(group_values:, thresholds:) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::AlertCreateForSubscriptionParams::ThresholdOverride for more details.

Per-group threshold override on a grouped cost alert.

  • An empty thresholds list silences alerts for this group (never fires).
  • A non-empty list fully replaces the default thresholds for this group.

Parameters:

  • group_values (Array<String>)

    The values of the grouping keys that identify this group. The list length must m

  • thresholds (Array<Orb::Models::Threshold>)

    The thresholds to apply to this group. An empty list silences alerts for this gr



# File 'lib/orb/models/alert_create_for_subscription_params.rb', line 174

Instance Attribute Details

#group_valuesArray<String>

The values of the grouping keys that identify this group. The list length must match the alert's grouping_keys, and values appear in the same order as grouping_keys.

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


165
# File 'lib/orb/models/alert_create_for_subscription_params.rb', line 165

required :group_values, Orb::Internal::Type::ArrayOf[String]

#thresholdsArray<Orb::Models::Threshold>

The thresholds to apply to this group. An empty list silences alerts for this group. A non-empty list fully replaces the default thresholds for this group.

Parameters:

Returns:



172
# File 'lib/orb/models/alert_create_for_subscription_params.rb', line 172

required :thresholds, -> { Orb::Internal::Type::ArrayOf[Orb::Threshold] }

Instance Method Details

#to_hash{

Returns:

  • ({)


137
# File 'sig/orb/models/alert_create_for_subscription_params.rbs', line 137

def to_hash: -> {