Class: Orb::Models::AlertUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/orb/models/alert_update_params.rb,
sig/orb/models/alert_update_params.rbs

Overview

See Also:

  • Orb::Resources::Alerts#update

Defined Under Namespace

Classes: PriceFilter, ThresholdOverride

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



24
# File 'sig/orb/models/alert_update_params.rbs', line 24

def initialize: (

Instance Attribute Details

#alert_configuration_idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/orb/models/alert_update_params.rb', line 13

required :alert_configuration_id, String

#price_filtersArray<Orb::Models::AlertUpdateParams::PriceFilter>?

Replaces the price filters on a grouped cost alert; an empty list clears them. Only applicable to cost alerts with grouping_keys. Omit to leave unchanged.

Parameters:

  • value (::Array[Orb::AlertUpdateParams::PriceFilter], nil)

Returns:



26
27
28
# File 'lib/orb/models/alert_update_params.rb', line 26

optional :price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::AlertUpdateParams::PriceFilter] },
nil?: true

#threshold_overridesArray<Orb::Models::AlertUpdateParams::ThresholdOverride>?

Replaces the per-group threshold overrides on a grouped cost alert; an empty list clears them. Only applicable to cost alerts with grouping_keys. Omit to leave unchanged.

Parameters:

  • value (::Array[Orb::AlertUpdateParams::ThresholdOverride], nil)

Returns:



36
37
38
# File 'lib/orb/models/alert_update_params.rb', line 36

optional :threshold_overrides,
-> { Orb::Internal::Type::ArrayOf[Orb::AlertUpdateParams::ThresholdOverride] },
nil?: true

#thresholdsArray<Orb::Models::Threshold>

The thresholds that define the values at which the alert will be triggered.

Parameters:

Returns:



19
# File 'lib/orb/models/alert_update_params.rb', line 19

required :thresholds, -> { Orb::Internal::Type::ArrayOf[Orb::Threshold] }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/orb/models/alert_update_params.rb', line 105

Instance Method Details

#to_hash{

Returns:

  • ({)


32
# File 'sig/orb/models/alert_update_params.rbs', line 32

def to_hash: -> {