Class: Orb::Models::AlertUpdateParams::ThresholdOverride
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::AlertUpdateParams::ThresholdOverride
- Defined in:
- lib/orb/models/alert_update_params.rb,
sig/orb/models/alert_update_params.rbs
Instance Attribute Summary collapse
-
#group_values ⇒ Array<String>
The values of the grouping keys that identify this group.
-
#thresholds ⇒ Array<Orb::Models::Threshold>
The thresholds to apply to this group.
Instance Method Summary collapse
-
#initialize(group_values:, thresholds:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ThresholdOverride for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(group_values:, thresholds:) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::AlertUpdateParams::ThresholdOverride for more details.
Per-group threshold override on a grouped cost alert.
- An empty
thresholdslist silences alerts for this group (never fires). - A non-empty list fully replaces the default thresholds for this group.
|
|
# File 'lib/orb/models/alert_update_params.rb', line 126
|
Instance Attribute Details
#group_values ⇒ Array<String>
The values of the grouping keys that identify this group. The list length must match the alert's grouping_keys, and values appear in the same order as grouping_keys.
117 |
# File 'lib/orb/models/alert_update_params.rb', line 117 required :group_values, Orb::Internal::Type::ArrayOf[String] |
#thresholds ⇒ Array<Orb::Models::Threshold>
The thresholds to apply to this group. An empty list silences alerts for this group. A non-empty list fully replaces the default thresholds for this group.
124 |
# File 'lib/orb/models/alert_update_params.rb', line 124 required :thresholds, -> { Orb::Internal::Type::ArrayOf[Orb::Threshold] } |
Instance Method Details
#to_hash ⇒ {
106 |
# File 'sig/orb/models/alert_update_params.rbs', line 106
def to_hash: -> {
|