Class: Orb::Models::AmountDiscountInterval::Filter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::AmountDiscountInterval::Filter
- Defined in:
- lib/orb/models/amount_discount_interval.rb,
sig/orb/models/amount_discount_interval.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#field ⇒ Symbol, Orb::Models::AmountDiscountInterval::Filter::Field
The property of the price to filter on.
-
#operator ⇒ Symbol, Orb::Models::AmountDiscountInterval::Filter::Operator
Should prices that match the filter be included or excluded.
-
#values ⇒ Array<String>
The IDs or values that match this filter.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(field:, operator:, values:) ⇒ Object
|
|
# File 'lib/orb/models/amount_discount_interval.rb', line 83
|
Instance Attribute Details
#field ⇒ Symbol, Orb::Models::AmountDiscountInterval::Filter::Field
The property of the price to filter on.
69 |
# File 'lib/orb/models/amount_discount_interval.rb', line 69 required :field, enum: -> { Orb::AmountDiscountInterval::Filter::Field } |
#operator ⇒ Symbol, Orb::Models::AmountDiscountInterval::Filter::Operator
Should prices that match the filter be included or excluded.
75 |
# File 'lib/orb/models/amount_discount_interval.rb', line 75 required :operator, enum: -> { Orb::AmountDiscountInterval::Filter::Operator } |
#values ⇒ Array<String>
The IDs or values that match this filter.
81 |
# File 'lib/orb/models/amount_discount_interval.rb', line 81 required :values, Orb::Internal::Type::ArrayOf[String] |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/amount_discount_interval.rb', line 102
|
Instance Method Details
#to_hash ⇒ {
74 |
# File 'sig/orb/models/amount_discount_interval.rbs', line 74
def to_hash: -> {
|