Class: Orb::Models::BackfillReflectedWebhookEvent::Backfill
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::BackfillReflectedWebhookEvent::Backfill
- Defined in:
- lib/orb/models/backfill_reflected_webhook_event.rb,
sig/orb/models/backfill_reflected_webhook_event.rbs
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#close_time ⇒ Time?
If in the future, the time at which the backfill will automatically close.
- #created_at ⇒ Time
-
#customer_id ⇒ String?
The Orb-generated ID of the customer to which this backfill is scoped.
-
#deprecation_filter ⇒ String?
A boolean computed property used to filter the set of events to deprecate.
-
#events_ingested ⇒ Integer
The number of events ingested in this backfill.
- #id ⇒ String
-
#replace_existing_events ⇒ Boolean
If
true, existing events in the backfill's timeframe will be replaced with the newly ingested events associated with the backfill. -
#reverted_at ⇒ Time?
The time at which this backfill was reverted.
-
#status ⇒ Symbol, Orb::Models::BackfillReflectedWebhookEvent::Backfill::Status
The status of the backfill.
- #timeframe_end ⇒ Time
- #timeframe_start ⇒ Time
Instance Method Summary collapse
-
#initialize(id:, close_time:, created_at:, customer_id:, events_ingested:, replace_existing_events:, reverted_at:, status:, timeframe_end:, timeframe_start:, deprecation_filter: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Backfill for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, close_time:, created_at:, customer_id:, events_ingested:, replace_existing_events:, reverted_at:, status:, timeframe_end:, timeframe_start:, deprecation_filter: nil) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::BackfillReflectedWebhookEvent::Backfill for more details.
A backfill represents an update to historical usage data, adding or replacing events in a timeframe.
|
|
# File 'lib/orb/models/backfill_reflected_webhook_event.rb', line 122
|
Instance Attribute Details
#close_time ⇒ Time?
If in the future, the time at which the backfill will automatically close. If in the past, the time at which the backfill was closed.
64 |
# File 'lib/orb/models/backfill_reflected_webhook_event.rb', line 64 required :close_time, Time, nil?: true |
#created_at ⇒ Time
69 |
# File 'lib/orb/models/backfill_reflected_webhook_event.rb', line 69 required :created_at, Time |
#customer_id ⇒ String?
The Orb-generated ID of the customer to which this backfill is scoped. If
null, this backfill is scoped to all customers.
76 |
# File 'lib/orb/models/backfill_reflected_webhook_event.rb', line 76 required :customer_id, String, nil?: true |
#deprecation_filter ⇒ String?
A boolean computed property used to filter the set of events to deprecate
120 |
# File 'lib/orb/models/backfill_reflected_webhook_event.rb', line 120 optional :deprecation_filter, String, nil?: true |
#events_ingested ⇒ Integer
The number of events ingested in this backfill.
82 |
# File 'lib/orb/models/backfill_reflected_webhook_event.rb', line 82 required :events_ingested, Integer |
#id ⇒ String
57 |
# File 'lib/orb/models/backfill_reflected_webhook_event.rb', line 57 required :id, String |
#replace_existing_events ⇒ Boolean
If true, existing events in the backfill's timeframe will be replaced with the
newly ingested events associated with the backfill. If false, newly ingested
events will be added to the existing events.
90 |
# File 'lib/orb/models/backfill_reflected_webhook_event.rb', line 90 required :replace_existing_events, Orb::Internal::Type::Boolean |
#reverted_at ⇒ Time?
The time at which this backfill was reverted.
96 |
# File 'lib/orb/models/backfill_reflected_webhook_event.rb', line 96 required :reverted_at, Time, nil?: true |
#status ⇒ Symbol, Orb::Models::BackfillReflectedWebhookEvent::Backfill::Status
The status of the backfill.
102 |
# File 'lib/orb/models/backfill_reflected_webhook_event.rb', line 102 required :status, enum: -> { Orb::BackfillReflectedWebhookEvent::Backfill::Status } |
#timeframe_end ⇒ Time
107 |
# File 'lib/orb/models/backfill_reflected_webhook_event.rb', line 107 required :timeframe_end, Time |
#timeframe_start ⇒ Time
112 |
# File 'lib/orb/models/backfill_reflected_webhook_event.rb', line 112 required :timeframe_start, Time |
Instance Method Details
#to_hash ⇒ {
91 |
# File 'sig/orb/models/backfill_reflected_webhook_event.rbs', line 91
def to_hash: -> {
|