Class: Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/orb/models/beta/external_plan_id_create_plan_version_params.rb,
sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs
Overview
Defined Under Namespace
Classes: AddAdjustment, AddPrice, RemoveAdjustment, RemovePrice, ReplaceAdjustment, ReplacePrice
Instance Attribute Summary collapse
-
#add_adjustments ⇒ Array<Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::AddAdjustment>?
Additional adjustments to be added to the plan.
-
#add_prices ⇒ Array<Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::AddPrice>?
Additional prices to be added to the plan.
- #external_plan_id ⇒ String
-
#remove_adjustments ⇒ Array<Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::RemoveAdjustment>?
Adjustments to be removed from the plan.
-
#remove_prices ⇒ Array<Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::RemovePrice>?
Prices to be removed from the plan.
-
#replace_adjustments ⇒ Array<Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplaceAdjustment>?
Adjustments to be replaced with additional adjustments on the plan.
-
#replace_prices ⇒ Array<Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice>?
Prices to be replaced with additional prices on the plan.
-
#set_as_default ⇒ Boolean?
Set this new plan version as the default.
-
#version ⇒ Integer
New version number.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(Orb::Models::NewPercentageDiscount, Orb::Models::NewUsageDiscount, Orb::Models::NewAmountDiscount, Orb::Models::NewMinimum, Orb::Models::NewMaximum, Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplaceAdjustment::Adjustment::TieredPercentageDiscount)
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(price_id:, plan_phase_order: nil) ⇒ Object
|
|
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 2983
|
Instance Attribute Details
#add_adjustments ⇒ Array<Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::AddAdjustment>?
Additional adjustments to be added to the plan.
26 27 28 29 30 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 26 optional :add_adjustments, -> { Orb::Internal::Type::ArrayOf[Orb::Beta::ExternalPlanIDCreatePlanVersionParams::AddAdjustment] }, nil?: true |
#add_prices ⇒ Array<Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::AddPrice>?
Additional prices to be added to the plan.
36 37 38 39 40 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 36 optional :add_prices, -> { Orb::Internal::Type::ArrayOf[Orb::Beta::ExternalPlanIDCreatePlanVersionParams::AddPrice] }, nil?: true |
#external_plan_id ⇒ String
14 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 14 required :external_plan_id, String |
#remove_adjustments ⇒ Array<Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::RemoveAdjustment>?
Adjustments to be removed from the plan.
46 47 48 49 50 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 46 optional :remove_adjustments, -> { Orb::Internal::Type::ArrayOf[Orb::Beta::ExternalPlanIDCreatePlanVersionParams::RemoveAdjustment] }, nil?: true |
#remove_prices ⇒ Array<Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::RemovePrice>?
Prices to be removed from the plan.
56 57 58 59 60 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 56 optional :remove_prices, -> { Orb::Internal::Type::ArrayOf[Orb::Beta::ExternalPlanIDCreatePlanVersionParams::RemovePrice] }, nil?: true |
#replace_adjustments ⇒ Array<Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplaceAdjustment>?
Adjustments to be replaced with additional adjustments on the plan.
66 67 68 69 70 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 66 optional :replace_adjustments, -> { Orb::Internal::Type::ArrayOf[Orb::Beta::ExternalPlanIDCreatePlanVersionParams::ReplaceAdjustment] }, nil?: true |
#replace_prices ⇒ Array<Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice>?
Prices to be replaced with additional prices on the plan.
76 77 78 79 80 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 76 optional :replace_prices, -> { Orb::Internal::Type::ArrayOf[Orb::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice] }, nil?: true |
#set_as_default ⇒ Boolean?
Set this new plan version as the default
86 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 86 optional :set_as_default, Orb::Internal::Type::Boolean, nil?: true |
#version ⇒ Integer
New version number.
20 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 20 required :version, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 354
|
.variants ⇒ Array(Orb::Models::NewPercentageDiscount, Orb::Models::NewUsageDiscount, Orb::Models::NewAmountDiscount, Orb::Models::NewMinimum, Orb::Models::NewMaximum, Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplaceAdjustment::Adjustment::TieredPercentageDiscount)
|
|
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 359
|
Instance Method Details
#to_hash ⇒ {
53 |
# File 'sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs', line 53
def to_hash: -> {
|