Class: Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::AddPrice::Price::EventOutput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::AddPrice::Price::EventOutput
- Defined in:
- lib/orb/models/beta/external_plan_id_create_plan_version_params.rb,
sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs
Defined Under Namespace
Modules: Cadence Classes: EventOutputConfig
Instance Attribute Summary collapse
-
#billable_metric_id ⇒ String?
The id of the billable metric for the price.
-
#billed_in_advance ⇒ Boolean?
If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.
-
#billing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
For custom cadence: specifies the duration of the billing period in days or months.
-
#cadence ⇒ Symbol, Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::AddPrice::Price::EventOutput::Cadence
The cadence to bill for this price on.
-
#conversion_rate ⇒ Float?
The per unit conversion rate of the price currency to the invoicing currency.
-
#conversion_rate_config ⇒ Orb::Models::UnitConversionRateConfig, ...
The configuration for the rate of the price currency to the invoicing currency.
-
#currency ⇒ String?
An ISO 4217 currency string, or custom pricing unit identifier, in which this price is billed.
-
#dimensional_price_configuration ⇒ Orb::Models::NewDimensionalPriceConfiguration?
For dimensional price: specifies a price group and dimension values.
-
#event_output_config ⇒ Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::AddPrice::Price::EventOutput::EventOutputConfig
Configuration for event_output pricing.
-
#external_price_id ⇒ String?
An alias for the price.
-
#fixed_price_quantity ⇒ Float?
If the Price represents a fixed cost, this represents the quantity of units applied.
-
#invoice_grouping_key ⇒ String?
The property used to group this price on an invoice.
-
#invoicing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
Within each billing cycle, specifies the cadence at which invoices are produced.
-
#item_id ⇒ String
The id of the item the price will be associated with.
-
#license_type_id ⇒ String?
The ID of the license type to associate with this price.
-
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource.
-
#model_type ⇒ Symbol, :event_output
The pricing model type.
-
#name ⇒ String
The name of the price.
-
#reference_id ⇒ String?
A transient ID that can be used to reference this price when adding adjustments in the same API call.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(cadence:, event_output_config:, item_id:, name:, billable_metric_id: nil, billed_in_advance: nil, billing_cycle_configuration: nil, conversion_rate: nil, conversion_rate_config: nil, currency: nil, dimensional_price_configuration: nil, external_price_id: nil, fixed_price_quantity: nil, invoice_grouping_key: nil, invoicing_cycle_configuration: nil, license_type_id: nil, metadata: nil, reference_id: nil, model_type: :event_output) ⇒ Object
constructor
Some parameter documentations has been truncated, see EventOutput for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cadence:, event_output_config:, item_id:, name:, billable_metric_id: nil, billed_in_advance: nil, billing_cycle_configuration: nil, conversion_rate: nil, conversion_rate_config: nil, currency: nil, dimensional_price_configuration: nil, external_price_id: nil, fixed_price_quantity: nil, invoice_grouping_key: nil, invoicing_cycle_configuration: nil, license_type_id: nil, metadata: nil, reference_id: nil, model_type: :event_output) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::AddPrice::Price::EventOutput for more details.
|
|
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 2900
|
Instance Attribute Details
#billable_metric_id ⇒ String?
The id of the billable metric for the price. Only needed if the price is usage-based.
2808 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 2808 optional :billable_metric_id, String, nil?: true |
#billed_in_advance ⇒ Boolean?
If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.
2815 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 2815 optional :billed_in_advance, Orb::Internal::Type::Boolean, nil?: true |
#billing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
For custom cadence: specifies the duration of the billing period in days or months.
2822 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 2822 optional :billing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true |
#cadence ⇒ Symbol, Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::AddPrice::Price::EventOutput::Cadence
The cadence to bill for this price on.
2775 2776 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 2775 required :cadence, enum: -> { Orb::Beta::ExternalPlanIDCreatePlanVersionParams::AddPrice::Price::EventOutput::Cadence } |
#conversion_rate ⇒ Float?
The per unit conversion rate of the price currency to the invoicing currency.
2828 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 2828 optional :conversion_rate, Float, nil?: true |
#conversion_rate_config ⇒ Orb::Models::UnitConversionRateConfig, ...
The configuration for the rate of the price currency to the invoicing currency.
2834 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 2834 optional :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true |
#currency ⇒ String?
An ISO 4217 currency string, or custom pricing unit identifier, in which this price is billed.
2841 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 2841 optional :currency, String, nil?: true |
#dimensional_price_configuration ⇒ Orb::Models::NewDimensionalPriceConfiguration?
For dimensional price: specifies a price group and dimension values
2847 2848 2849 2850 2851 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 2847 optional :dimensional_price_configuration, -> { Orb::NewDimensionalPriceConfiguration }, nil?: true |
#event_output_config ⇒ Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::AddPrice::Price::EventOutput::EventOutputConfig
Configuration for event_output pricing
2782 2783 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 2782 required :event_output_config, -> { Orb::Beta::ExternalPlanIDCreatePlanVersionParams::AddPrice::Price::EventOutput::EventOutputConfig } |
#external_price_id ⇒ String?
An alias for the price.
2857 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 2857 optional :external_price_id, String, nil?: true |
#fixed_price_quantity ⇒ Float?
If the Price represents a fixed cost, this represents the quantity of units applied.
2864 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 2864 optional :fixed_price_quantity, Float, nil?: true |
#invoice_grouping_key ⇒ String?
The property used to group this price on an invoice
2870 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 2870 optional :invoice_grouping_key, String, nil?: true |
#invoicing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
Within each billing cycle, specifies the cadence at which invoices are produced. If unspecified, a single invoice is produced per billing cycle.
2877 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 2877 optional :invoicing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true |
#item_id ⇒ String
The id of the item the price will be associated with.
2789 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 2789 required :item_id, String |
#license_type_id ⇒ String?
The ID of the license type to associate with this price.
2883 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 2883 optional :license_type_id, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource. Individual keys can be removed
by setting the value to null, and the entire metadata mapping can be cleared
by setting metadata to null.
2891 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 2891 optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true |
#model_type ⇒ Symbol, :event_output
The pricing model type
2795 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 2795 required :model_type, const: :event_output |
#name ⇒ String
The name of the price.
2801 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 2801 required :name, String |
#reference_id ⇒ String?
A transient ID that can be used to reference this price when adding adjustments in the same API call.
2898 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 2898 optional :reference_id, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 2956
|
Instance Method Details
#to_hash ⇒ {
2012 |
# File 'sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs', line 2012
def to_hash: -> {
|