Class: Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::AddPrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::ThresholdDiscountGroup

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/beta/external_plan_id_create_plan_version_params.rb,
sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



906
# File 'sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs', line 906

def initialize: (

Instance Attribute Details

#above_threshold_discount_percentageString

Discount rate applied to spend above the threshold.

Parameters:

  • value (String)

Returns:

  • (String)


1266
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 1266

required :above_threshold_discount_percentage, String

#below_threshold_discount_percentageString

Discount rate applied to spend at or below the threshold. Set to 0 for no baseline discount.

Parameters:

  • value (String)

Returns:

  • (String)


1273
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 1273

required :below_threshold_discount_percentage, String

#cell_coordinatesString

Semicolon-separated list of matrix cell coordinates targeted by this group. Each coordinate is first,second when the matrix has two dimensions, or just first for a single-dimension matrix. Example: blue,circle;green,triangle.

Parameters:

  • value (String)

Returns:

  • (String)


1281
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 1281

required :cell_coordinates, String

#descriptionString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1291
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 1291

optional :description, String, nil?: true

#threshold_amountString

Parameters:

  • value (String)

Returns:

  • (String)


1286
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 1286

required :threshold_amount, String

Instance Method Details

#to_hash{

Returns:

  • ({)


914
# File 'sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs', line 914

def to_hash: -> {