Class: Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::RemovePrice
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::RemovePrice
- Defined in:
- lib/orb/models/beta/external_plan_id_create_plan_version_params.rb,
sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs
Instance Attribute Summary collapse
-
#plan_phase_order ⇒ Integer?
The phase to remove this price from.
-
#price_id ⇒ String
The id of the price to remove from the plan.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
2110 |
# File 'sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs', line 2110
def initialize: (
|
Instance Attribute Details
#plan_phase_order ⇒ Integer?
The phase to remove this price from.
3033 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3033 optional :plan_phase_order, Integer, nil?: true |
#price_id ⇒ String
The id of the price to remove from the plan.
3027 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3027 required :price_id, String |
Instance Method Details
#to_hash ⇒ { price_id: String, plan_phase_order: Integer? }
2115 |
# File 'sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs', line 2115
def to_hash: -> { price_id: String, plan_phase_order: Integer? }
|