Class: Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice
- Defined in:
- lib/orb/models/beta/external_plan_id_create_plan_version_params.rb,
sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs
Defined Under Namespace
Modules: Price Classes: LicenseAllocationPrice
Constant Summary collapse
- Orb =
Instance Attribute Summary collapse
-
#allocation_price ⇒ Orb::Models::NewAllocationPrice?
The allocation price to add to the plan.
-
#license_allocation_price ⇒ Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::LicenseAllocationPrice?
The license allocation price to add to the plan.
-
#plan_phase_order ⇒ Integer?
The phase to replace this price from.
-
#price ⇒ Orb::Models::NewPlanUnitPrice, ...
New plan price request body params.
-
#replaces_price_id ⇒ String
The id of the price on the plan to replace in the plan.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(replaces_price_id:, allocation_price: nil, license_allocation_price: nil, plan_phase_order: nil, price: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(replaces_price_id:, allocation_price: nil, license_allocation_price: nil, plan_phase_order: nil, price: nil) ⇒ Object
|
|
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3341
|
Instance Attribute Details
#allocation_price ⇒ Orb::Models::NewAllocationPrice?
The allocation price to add to the plan.
3315 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3315 optional :allocation_price, -> { Orb::NewAllocationPrice }, nil?: true |
#license_allocation_price ⇒ Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::LicenseAllocationPrice?
The license allocation price to add to the plan.
3321 3322 3323 3324 3325 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3321 optional :license_allocation_price, -> { Orb::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::LicenseAllocationPrice }, nil?: true |
#plan_phase_order ⇒ Integer?
The phase to replace this price from.
3331 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3331 optional :plan_phase_order, Integer, nil?: true |
#price ⇒ Orb::Models::NewPlanUnitPrice, ...
New plan price request body params.
3337 3338 3339 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3337 optional :price, union: -> { Orb::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::Price }, nil?: true |
#replaces_price_id ⇒ String
The id of the price on the plan to replace in the plan.
3309 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3309 required :replaces_price_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3591
|
Instance Method Details
#to_hash ⇒ {
2355 |
# File 'sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs', line 2355
def to_hash: -> {
|