Class: Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::Price::CumulativeGroupedAllocation::CumulativeGroupedAllocationConfig

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/beta/external_plan_id_create_plan_version_params.rb,
sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs

Overview

See Also:

  • Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::Price::CumulativeGroupedAllocation#cumulative_grouped_allocation_config

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



4196
# File 'sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs', line 4196

def initialize: (

Instance Attribute Details

#cumulative_allocation ⇒ String

The overall allocation across all groups

Parameters:

  • value (String)

Returns:

  • (String)


6080
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 6080

required :cumulative_allocation, String

#group_allocation ⇒ String

The allocation per individual group

Parameters:

  • value (String)

Returns:

  • (String)


6086
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 6086

required :group_allocation, String

#grouping_key ⇒ String

The event property used to group usage before applying allocations

Parameters:

  • value (String)

Returns:

  • (String)


6092
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 6092

required :grouping_key, String

#unit_amount ⇒ String

The amount to charge for each unit outside of the allocation

Parameters:

  • value (String)

Returns:

  • (String)


6098
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 6098

required :unit_amount, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


4203
# File 'sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs', line 4203

def to_hash: -> {