Class: Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::Price::EventOutput::EventOutputConfig

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/beta/external_plan_id_create_plan_version_params.rb,
sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs

Overview

See Also:

  • Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::Price::EventOutput#event_output_config

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(unit_rating_key:, default_unit_rate: nil, grouping_key: nil) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::Price::EventOutput::EventOutputConfig for more details.

Configuration for event_output pricing

Parameters:

  • unit_rating_key (String)

    The key in the event data to extract the unit rate from.

  • default_unit_rate (String, nil) (defaults to: nil)

    If provided, this amount will be used as the unit rate when an event does not ha

  • grouping_key (String, nil) (defaults to: nil)

    An optional key in the event data to group by (e.g., event ID). All events will



# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 5933

Instance Attribute Details

#default_unit_rateString?

If provided, this amount will be used as the unit rate when an event does not have a value for the unit_rating_key. If not provided, events missing a unit rate will be ignored.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


5924
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 5924

optional :default_unit_rate, String, nil?: true

#grouping_keyString?

An optional key in the event data to group by (e.g., event ID). All events will also be grouped by their unit rate.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


5931
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 5931

optional :grouping_key, String, nil?: true

#unit_rating_keyString

The key in the event data to extract the unit rate from.

Parameters:

  • value (String)

Returns:

  • (String)


5916
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 5916

required :unit_rating_key, String

Instance Method Details

#to_hash{

Returns:

  • ({)


4137
# File 'sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs', line 4137

def to_hash: -> {