Class: Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig
- Defined in:
- lib/orb/models/beta/external_plan_id_create_plan_version_params.rb,
sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs
Overview
Defined Under Namespace
Classes: MatrixValue, ThresholdDiscountGroup
Instance Attribute Summary collapse
-
#default_unit_amount ⇒ String
Unit price used for usage that does not match any defined matrix cell.
-
#first_dimension ⇒ String
First matrix dimension key.
-
#matrix_values ⇒ Array<Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::MatrixValue>
Per-cell unit prices.
-
#second_dimension ⇒ String?
Optional second matrix dimension key.
- #threshold_discount_groups ⇒ Array<Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::ThresholdDiscountGroup>?
Instance Method Summary collapse
- #initialize(first_dimension_value:, unit_amount:, second_dimension_value: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(first_dimension_value:, unit_amount:, second_dimension_value: nil) ⇒ Object
|
|
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 4205
|
Instance Attribute Details
#default_unit_amount ⇒ String
Unit price used for usage that does not match any defined matrix cell.
4141 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 4141 required :default_unit_amount, String |
#first_dimension ⇒ String
First matrix dimension key.
4147 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 4147 required :first_dimension, String |
#matrix_values ⇒ Array<Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::MatrixValue>
Per-cell unit prices.
4153 4154 4155 4156 4157 4158 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 4153 required :matrix_values, -> do Orb::Internal::Type::ArrayOf[ Orb::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::MatrixValue ] end |
#second_dimension ⇒ String?
Optional second matrix dimension key.
4164 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 4164 optional :second_dimension, String, nil?: true |
#threshold_discount_groups ⇒ Array<Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::ThresholdDiscountGroup>?
4169 4170 4171 4172 4173 4174 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 4169 optional :threshold_discount_groups, -> do Orb::Internal::Type::ArrayOf[ Orb::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::ThresholdDiscountGroup ] end |
Instance Method Details
#to_hash ⇒ {
2913 |
# File 'sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs', line 2913
def to_hash: -> {
|