Class: Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/beta/external_plan_id_create_plan_version_params.rb,
sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(allocation:, default_unit_amount:, dimensions:, tiers:) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig for more details.

Configuration for tiered_matrix_with_allocation pricing

Parameters:



5051
5052
5053
5054
5055
5056
5057
5058
5059
5060
5061
5062
5063
5064
5065
5066
5067
5068
5069
5070
5071
5072
5073
5074
5075
5076
5077
5078
5079
5080
5081
5082
5083
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 5051

class Tier < Orb::Internal::Type::BaseModel
  # @!attribute dimension_values
  #   The matrix cell this tier applies to, as one or two dimension values
  #
  #   @return [Array<String>]
  required :dimension_values, Orb::Internal::Type::ArrayOf[String]

  # @!attribute tier_lower_bound
  #   Exclusive tier starting value. The tier runs up to and including the next bound
  #   configured for the same matrix cell.
  #
  #   @return [String]
  required :tier_lower_bound, String

  # @!attribute unit_amount
  #   Per unit amount
  #
  #   @return [String]
  required :unit_amount, String

  # @!method initialize(dimension_values:, tier_lower_bound:, unit_amount:)
  #   Some parameter documentations has been truncated, see
  #   {Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier}
  #   for more details.
  #
  #   Configuration for a single tier scoped to one matrix cell
  #
  #   @param dimension_values [Array<String>] The matrix cell this tier applies to, as one or two dimension values
  #
  #   @param tier_lower_bound [String] Exclusive tier starting value. The tier runs up to and including the next bound
  #
  #   @param unit_amount [String] Per unit amount
end

Instance Attribute Details

#dimension_values ⇒ Array<String>

The matrix cell this tier applies to, as one or two dimension values

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


5056
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 5056

required :dimension_values, Orb::Internal::Type::ArrayOf[String]

#tier_lower_bound ⇒ String

Exclusive tier starting value. The tier runs up to and including the next bound configured for the same matrix cell.

Parameters:

  • value (String)

Returns:

  • (String)


5063
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 5063

required :tier_lower_bound, String

#unit_amount ⇒ String

Per unit amount

Parameters:

  • value (String)

Returns:

  • (String)


5069
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 5069

required :unit_amount, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


3487
# File 'sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs', line 3487

def to_hash: -> {