Class: Orb::Models::BetaCreatePlanVersionParams::AddPrice::LicenseAllocationPrice::LicenseAllocation

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/beta_create_plan_version_params.rb,
sig/orb/models/beta_create_plan_version_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



437
# File 'sig/orb/models/beta_create_plan_version_params.rbs', line 437

def initialize: (

Instance Attribute Details

#amountString

The amount of credits granted per active license per cadence.

Parameters:

  • value (String)

Returns:

  • (String)


585
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 585

required :amount, String

#currencyString

The currency of the license allocation.

Parameters:

  • value (String)

Returns:

  • (String)


591
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 591

required :currency, String

#write_off_overageBoolean?

When True, overage beyond the allocation is written off.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


597
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 597

optional :write_off_overage, Orb::Internal::Type::Boolean, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


443
# File 'sig/orb/models/beta_create_plan_version_params.rbs', line 443

def to_hash: -> {