Class: Orb::Models::BetaCreatePlanVersionParams::AddPrice::Price::GroupedWithMinMaxThresholds::GroupedWithMinMaxThresholdsConfig

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/beta_create_plan_version_params.rb,
sig/orb/models/beta_create_plan_version_params.rbs

Overview

See Also:

  • Orb::Models::BetaCreatePlanVersionParams::AddPrice::Price::GroupedWithMinMaxThresholds#grouped_with_min_max_thresholds_config

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



1223
# File 'sig/orb/models/beta_create_plan_version_params.rbs', line 1223

def initialize: (

Instance Attribute Details

#grouping_keyString

The event property used to group before applying thresholds

Parameters:

  • value (String)

Returns:

  • (String)


1702
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 1702

required :grouping_key, String

#maximum_chargeString

The maximum amount to charge each group

Parameters:

  • value (String)

Returns:

  • (String)


1708
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 1708

required :maximum_charge, String

#minimum_chargeString

The minimum amount to charge each group, regardless of usage

Parameters:

  • value (String)

Returns:

  • (String)


1714
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 1714

required :minimum_charge, String

#per_unit_rateString

The base price charged per group

Parameters:

  • value (String)

Returns:

  • (String)


1720
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 1720

required :per_unit_rate, String

Instance Method Details

#to_hash{

Returns:

  • ({)


1230
# File 'sig/orb/models/beta_create_plan_version_params.rbs', line 1230

def to_hash: -> {