Class: Orb::Models::BetaCreatePlanVersionParams::AddPrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::BetaCreatePlanVersionParams::AddPrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig
- Defined in:
- lib/orb/models/beta_create_plan_version_params.rb,
sig/orb/models/beta_create_plan_version_params.rbs
Overview
Defined Under Namespace
Classes: MatrixValue, ThresholdDiscountGroup
Instance Attribute Summary collapse
-
#default_unit_amount ⇒ String
Unit price used for usage that does not match any defined matrix cell.
-
#first_dimension ⇒ String
First matrix dimension key.
-
#matrix_values ⇒ Array<Orb::Models::BetaCreatePlanVersionParams::AddPrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::MatrixValue>
Per-cell unit prices.
-
#second_dimension ⇒ String?
Optional second matrix dimension key.
- #threshold_discount_groups ⇒ Array<Orb::Models::BetaCreatePlanVersionParams::AddPrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::ThresholdDiscountGroup>?
Instance Method Summary collapse
- #initialize(first_dimension_value:, unit_amount:, second_dimension_value: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(first_dimension_value:, unit_amount:, second_dimension_value: nil) ⇒ Object
|
|
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 1218
|
Instance Attribute Details
#default_unit_amount ⇒ String
Unit price used for usage that does not match any defined matrix cell.
1154 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 1154 required :default_unit_amount, String |
#first_dimension ⇒ String
First matrix dimension key.
1160 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 1160 required :first_dimension, String |
#matrix_values ⇒ Array<Orb::Models::BetaCreatePlanVersionParams::AddPrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::MatrixValue>
Per-cell unit prices.
1166 1167 1168 1169 1170 1171 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 1166 required :matrix_values, -> do Orb::Internal::Type::ArrayOf[ Orb::BetaCreatePlanVersionParams::AddPrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::MatrixValue ] end |
#second_dimension ⇒ String?
Optional second matrix dimension key.
1177 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 1177 optional :second_dimension, String, nil?: true |
#threshold_discount_groups ⇒ Array<Orb::Models::BetaCreatePlanVersionParams::AddPrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::ThresholdDiscountGroup>?
1182 1183 1184 1185 1186 1187 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 1182 optional :threshold_discount_groups, -> do Orb::Internal::Type::ArrayOf[ Orb::BetaCreatePlanVersionParams::AddPrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::ThresholdDiscountGroup ] end |
Instance Method Details
#to_hash ⇒ {
842 |
# File 'sig/orb/models/beta_create_plan_version_params.rbs', line 842
def to_hash: -> {
|