Class: Orb::Models::BetaCreatePlanVersionParams::AddPrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/beta_create_plan_version_params.rb,
sig/orb/models/beta_create_plan_version_params.rbs

Overview

See Also:

  • Orb::Models::BetaCreatePlanVersionParams::AddPrice::Price::TieredMatrixWithAllocation#tiered_matrix_with_allocation_config

Defined Under Namespace

Classes: Tier

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



1011
# File 'sig/orb/models/beta_create_plan_version_params.rbs', line 1011

def initialize: (

Instance Attribute Details

#allocation ⇒ String

Usage allocation, pooled across all matrix cells

Parameters:

  • value (String)

Returns:

  • (String)


1432
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 1432

required :allocation, String

#default_unit_amount ⇒ String

Per unit rate for usage whose matrix cell has no configured tiers

Parameters:

  • value (String)

Returns:

  • (String)


1438
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 1438

required :default_unit_amount, String

#dimensions ⇒ Array<String>

One or two event property values to evaluate matrix cells by

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


1444
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 1444

required :dimensions, Orb::Internal::Type::ArrayOf[String]

#tiers ⇒ Array<Orb::Models::BetaCreatePlanVersionParams::AddPrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier>

Graduated tiers keyed by matrix cell; usage in a cell is tiered only against its own rows

Parameters:

  • value (::Array[Orb::BetaCreatePlanVersionParams::AddPrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier])

Returns:



1451
1452
1453
1454
1455
1456
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 1451

required :tiers,
-> do
  Orb::Internal::Type::ArrayOf[
    Orb::BetaCreatePlanVersionParams::AddPrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier
  ]
end

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


1018
# File 'sig/orb/models/beta_create_plan_version_params.rbs', line 1018

def to_hash: -> {