Class: Orb::Models::BetaCreatePlanVersionParams::RemoveAdjustment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::BetaCreatePlanVersionParams::RemoveAdjustment
- Defined in:
- lib/orb/models/beta_create_plan_version_params.rb,
sig/orb/models/beta_create_plan_version_params.rbs
Instance Attribute Summary collapse
-
#adjustment_id ⇒ String
The id of the adjustment to remove from on the plan.
-
#plan_phase_order ⇒ Integer?
The phase to remove this adjustment from.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
2086 |
# File 'sig/orb/models/beta_create_plan_version_params.rbs', line 2086
def initialize: (
|
Instance Attribute Details
#adjustment_id ⇒ String
The id of the adjustment to remove from on the plan.
2964 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 2964 required :adjustment_id, String |
#plan_phase_order ⇒ Integer?
The phase to remove this adjustment from.
2970 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 2970 optional :plan_phase_order, Integer, nil?: true |
Instance Method Details
#to_hash ⇒ { adjustment_id: String, plan_phase_order: Integer? }
2091 |
# File 'sig/orb/models/beta_create_plan_version_params.rbs', line 2091
def to_hash: -> { adjustment_id: String, plan_phase_order: Integer? }
|