Class: Orb::Models::BetaCreatePlanVersionParams::ReplaceAdjustment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::BetaCreatePlanVersionParams::ReplaceAdjustment
- Defined in:
- lib/orb/models/beta_create_plan_version_params.rb,
sig/orb/models/beta_create_plan_version_params.rbs
Defined Under Namespace
Modules: Adjustment
Constant Summary collapse
- Orb =
Instance Attribute Summary collapse
-
#adjustment ⇒ Orb::Models::NewPercentageDiscount, ...
The definition of a new adjustment to create and add to the plan.
-
#plan_phase_order ⇒ Integer?
The phase to replace this adjustment from.
-
#replaces_adjustment_id ⇒ String
The id of the adjustment on the plan to replace in the plan.
Instance Method Summary collapse
- #initialize(adjustment:, replaces_adjustment_id:, plan_phase_order: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(adjustment:, replaces_adjustment_id:, plan_phase_order: nil) ⇒ Object
|
|
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3274
|
Instance Attribute Details
#adjustment ⇒ Orb::Models::NewPercentageDiscount, ...
The definition of a new adjustment to create and add to the plan.
3260 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3260 required :adjustment, union: -> { Orb::BetaCreatePlanVersionParams::ReplaceAdjustment::Adjustment } |
#plan_phase_order ⇒ Integer?
The phase to replace this adjustment from.
3272 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3272 optional :plan_phase_order, Integer, nil?: true |
#replaces_adjustment_id ⇒ String
The id of the adjustment on the plan to replace in the plan.
3266 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3266 required :replaces_adjustment_id, String |
Instance Method Details
#to_hash ⇒ {
2309 |
# File 'sig/orb/models/beta_create_plan_version_params.rbs', line 2309
def to_hash: -> {
|