Class: Orb::Models::BetaCreatePlanVersionParams::ReplacePrice::Price::GroupedWithMinMaxThresholds
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::BetaCreatePlanVersionParams::ReplacePrice::Price::GroupedWithMinMaxThresholds
- Defined in:
- lib/orb/models/beta_create_plan_version_params.rb,
sig/orb/models/beta_create_plan_version_params.rbs
Defined Under Namespace
Modules: Cadence Classes: GroupedWithMinMaxThresholdsConfig
Instance Attribute Summary collapse
-
#billable_metric_id ⇒ String?
The id of the billable metric for the price.
-
#billed_in_advance ⇒ Boolean?
If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.
-
#billing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
For custom cadence: specifies the duration of the billing period in days or months.
-
#cadence ⇒ Symbol, Orb::Models::BetaCreatePlanVersionParams::ReplacePrice::Price::GroupedWithMinMaxThresholds::Cadence
The cadence to bill for this price on.
-
#conversion_rate ⇒ Float?
The per unit conversion rate of the price currency to the invoicing currency.
-
#conversion_rate_config ⇒ Orb::Models::UnitConversionRateConfig, ...
The configuration for the rate of the price currency to the invoicing currency.
-
#currency ⇒ String?
An ISO 4217 currency string, or custom pricing unit identifier, in which this price is billed.
-
#dimensional_price_configuration ⇒ Orb::Models::NewDimensionalPriceConfiguration?
For dimensional price: specifies a price group and dimension values.
-
#external_price_id ⇒ String?
An alias for the price.
-
#fixed_price_quantity ⇒ Float?
If the Price represents a fixed cost, this represents the quantity of units applied.
-
#grouped_with_min_max_thresholds_config ⇒ Orb::Models::BetaCreatePlanVersionParams::ReplacePrice::Price::GroupedWithMinMaxThresholds::GroupedWithMinMaxThresholdsConfig
Configuration for grouped_with_min_max_thresholds pricing.
-
#invoice_grouping_key ⇒ String?
The property used to group this price on an invoice.
-
#invoicing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
Within each billing cycle, specifies the cadence at which invoices are produced.
-
#item_id ⇒ String
The id of the item the price will be associated with.
-
#license_type_id ⇒ String?
The ID of the license type to associate with this price.
-
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource.
-
#model_type ⇒ Symbol, :grouped_with_min_max_thresholds
The pricing model type.
-
#name ⇒ String
The name of the price.
-
#reference_id ⇒ String?
A transient ID that can be used to reference this price when adding adjustments in the same API call.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(cadence:, grouped_with_min_max_thresholds_config:, item_id:, name:, billable_metric_id: nil, billed_in_advance: nil, billing_cycle_configuration: nil, conversion_rate: nil, conversion_rate_config: nil, currency: nil, dimensional_price_configuration: nil, external_price_id: nil, fixed_price_quantity: nil, invoice_grouping_key: nil, invoicing_cycle_configuration: nil, license_type_id: nil, metadata: nil, reference_id: nil, model_type: :grouped_with_min_max_thresholds) ⇒ Object
constructor
Some parameter documentations has been truncated, see GroupedWithMinMaxThresholds for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cadence:, grouped_with_min_max_thresholds_config:, item_id:, name:, billable_metric_id: nil, billed_in_advance: nil, billing_cycle_configuration: nil, conversion_rate: nil, conversion_rate_config: nil, currency: nil, dimensional_price_configuration: nil, external_price_id: nil, fixed_price_quantity: nil, invoice_grouping_key: nil, invoicing_cycle_configuration: nil, license_type_id: nil, metadata: nil, reference_id: nil, model_type: :grouped_with_min_max_thresholds) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::BetaCreatePlanVersionParams::ReplacePrice::Price::GroupedWithMinMaxThresholds for more details.
|
|
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4557
|
Instance Attribute Details
#billable_metric_id ⇒ String?
The id of the billable metric for the price. Only needed if the price is usage-based.
4465 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4465 optional :billable_metric_id, String, nil?: true |
#billed_in_advance ⇒ Boolean?
If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.
4472 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4472 optional :billed_in_advance, Orb::Internal::Type::Boolean, nil?: true |
#billing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
For custom cadence: specifies the duration of the billing period in days or months.
4479 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4479 optional :billing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true |
#cadence ⇒ Symbol, Orb::Models::BetaCreatePlanVersionParams::ReplacePrice::Price::GroupedWithMinMaxThresholds::Cadence
The cadence to bill for this price on.
4432 4433 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4432 required :cadence, enum: -> { Orb::BetaCreatePlanVersionParams::ReplacePrice::Price::GroupedWithMinMaxThresholds::Cadence } |
#conversion_rate ⇒ Float?
The per unit conversion rate of the price currency to the invoicing currency.
4485 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4485 optional :conversion_rate, Float, nil?: true |
#conversion_rate_config ⇒ Orb::Models::UnitConversionRateConfig, ...
The configuration for the rate of the price currency to the invoicing currency.
4491 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4491 optional :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true |
#currency ⇒ String?
An ISO 4217 currency string, or custom pricing unit identifier, in which this price is billed.
4498 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4498 optional :currency, String, nil?: true |
#dimensional_price_configuration ⇒ Orb::Models::NewDimensionalPriceConfiguration?
For dimensional price: specifies a price group and dimension values
4504 4505 4506 4507 4508 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4504 optional :dimensional_price_configuration, -> { Orb::NewDimensionalPriceConfiguration }, nil?: true |
#external_price_id ⇒ String?
An alias for the price.
4514 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4514 optional :external_price_id, String, nil?: true |
#fixed_price_quantity ⇒ Float?
If the Price represents a fixed cost, this represents the quantity of units applied.
4521 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4521 optional :fixed_price_quantity, Float, nil?: true |
#grouped_with_min_max_thresholds_config ⇒ Orb::Models::BetaCreatePlanVersionParams::ReplacePrice::Price::GroupedWithMinMaxThresholds::GroupedWithMinMaxThresholdsConfig
Configuration for grouped_with_min_max_thresholds pricing
4439 4440 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4439 required :grouped_with_min_max_thresholds_config, -> { Orb::BetaCreatePlanVersionParams::ReplacePrice::Price::GroupedWithMinMaxThresholds::GroupedWithMinMaxThresholdsConfig } |
#invoice_grouping_key ⇒ String?
The property used to group this price on an invoice
4527 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4527 optional :invoice_grouping_key, String, nil?: true |
#invoicing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
Within each billing cycle, specifies the cadence at which invoices are produced. If unspecified, a single invoice is produced per billing cycle.
4534 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4534 optional :invoicing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true |
#item_id ⇒ String
The id of the item the price will be associated with.
4446 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4446 required :item_id, String |
#license_type_id ⇒ String?
The ID of the license type to associate with this price.
4540 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4540 optional :license_type_id, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource. Individual keys can be removed
by setting the value to null, and the entire metadata mapping can be cleared
by setting metadata to null.
4548 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4548 optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true |
#model_type ⇒ Symbol, :grouped_with_min_max_thresholds
The pricing model type
4452 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4452 required :model_type, const: :grouped_with_min_max_thresholds |
#name ⇒ String
The name of the price.
4458 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4458 required :name, String |
#reference_id ⇒ String?
A transient ID that can be used to reference this price when adding adjustments in the same API call.
4555 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4555 optional :reference_id, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4613
|
Instance Method Details
#to_hash ⇒ {
3214 |
# File 'sig/orb/models/beta_create_plan_version_params.rbs', line 3214
def to_hash: -> {
|