Class: Orb::Models::BetaCreatePlanVersionParams::ReplacePrice::Price::GroupedWithMinMaxThresholds::GroupedWithMinMaxThresholdsConfig

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/beta_create_plan_version_params.rb,
sig/orb/models/beta_create_plan_version_params.rbs

Overview

See Also:

  • Orb::Models::BetaCreatePlanVersionParams::ReplacePrice::Price::GroupedWithMinMaxThresholds#grouped_with_min_max_thresholds_config

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



4016
# File 'sig/orb/models/beta_create_plan_version_params.rbs', line 4016

def initialize: (

Instance Attribute Details

#grouping_key ⇒ String

The event property used to group before applying thresholds

Parameters:

  • value (String)

Returns:

  • (String)


5773
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 5773

required :grouping_key, String

#maximum_charge ⇒ String

The maximum amount to charge each group

Parameters:

  • value (String)

Returns:

  • (String)


5779
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 5779

required :maximum_charge, String

#minimum_charge ⇒ String

The minimum amount to charge each group, regardless of usage

Parameters:

  • value (String)

Returns:

  • (String)


5785
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 5785

required :minimum_charge, String

#per_unit_rate ⇒ String

The base price charged per group

Parameters:

  • value (String)

Returns:

  • (String)


5791
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 5791

required :per_unit_rate, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


4023
# File 'sig/orb/models/beta_create_plan_version_params.rbs', line 4023

def to_hash: -> {