Class: Orb::Models::BetaCreatePlanVersionParams::ReplacePrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::ThresholdDiscountGroup

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/beta_create_plan_version_params.rb,
sig/orb/models/beta_create_plan_version_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



2948
# File 'sig/orb/models/beta_create_plan_version_params.rbs', line 2948

def initialize: (

Instance Attribute Details

#above_threshold_discount_percentageString

Discount rate applied to spend above the threshold.

Parameters:

  • value (String)

Returns:

  • (String)


4146
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4146

required :above_threshold_discount_percentage, String

#below_threshold_discount_percentageString

Discount rate applied to spend at or below the threshold. Set to 0 for no baseline discount.

Parameters:

  • value (String)

Returns:

  • (String)


4153
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4153

required :below_threshold_discount_percentage, String

#cell_coordinatesString

Semicolon-separated list of matrix cell coordinates targeted by this group. Each coordinate is first,second when the matrix has two dimensions, or just first for a single-dimension matrix. Example: blue,circle;green,triangle.

Parameters:

  • value (String)

Returns:

  • (String)


4161
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4161

required :cell_coordinates, String

#descriptionString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


4171
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4171

optional :description, String, nil?: true

#threshold_amountString

Parameters:

  • value (String)

Returns:

  • (String)


4166
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 4166

required :threshold_amount, String

Instance Method Details

#to_hash{

Returns:

  • ({)


2956
# File 'sig/orb/models/beta_create_plan_version_params.rbs', line 2956

def to_hash: -> {