Class: Orb::Models::BillableMetricEditedWebhookEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/billable_metric_edited_webhook_event.rb,
sig/orb/models/billable_metric_edited_webhook_event.rbs

Defined Under Namespace

Modules: Type Classes: Properties

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(description: nil, metadata: nil, name: nil) ⇒ Object

metadata values are non-null on the wire, as on the price event.

Parameters:

  • description (String, nil) (defaults to: nil)
  • metadata (Hash{Symbol=>String}, nil) (defaults to: nil)
  • name (String, nil) (defaults to: nil)


# File 'lib/orb/models/billable_metric_edited_webhook_event.rb', line 37

Instance Attribute Details

#billable_metric ⇒ Orb::Models::BillableMetric

The Metric resource represents a calculation of a quantity based on events. Metrics are defined by the query that transforms raw usage events into meaningful values for your customers.

Parameters:

Returns:



18
# File 'lib/orb/models/billable_metric_edited_webhook_event.rb', line 18

required :billable_metric, -> { Orb::BillableMetric }

#created_at ⇒ Time

The time at which this event was created, to the second.

Parameters:

  • value (Time)

Returns:

  • (Time)


24
# File 'lib/orb/models/billable_metric_edited_webhook_event.rb', line 24

required :created_at, Time

#id ⇒ String

The ID of this webhook event.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/orb/models/billable_metric_edited_webhook_event.rb', line 10

required :id, String

#properties ⇒ Orb::Models::BillableMetricEditedWebhookEvent::Properties

Parameters:

  • value (Orb::BillableMetricEditedWebhookEvent::Properties)

Returns:



29
# File 'lib/orb/models/billable_metric_edited_webhook_event.rb', line 29

required :properties, -> { Orb::BillableMetricEditedWebhookEvent::Properties }

#type ⇒ Symbol, Orb::Models::BillableMetricEditedWebhookEvent::Type

The event this payload describes.

Parameters:

  • value (Orb::Models::BillableMetricEditedWebhookEvent::type_)

Returns:



35
# File 'lib/orb/models/billable_metric_edited_webhook_event.rb', line 35

required :type, enum: -> { Orb::BillableMetricEditedWebhookEvent::Type }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


31
# File 'sig/orb/models/billable_metric_edited_webhook_event.rbs', line 31

def to_hash: -> {