Class: Orb::Models::ChangedSubscriptionResources::CreatedInvoice::CreditNote

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/changed_subscription_resources.rb,
sig/orb/models/changed_subscription_resources.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



318
# File 'sig/orb/models/changed_subscription_resources.rbs', line 318

def initialize: (

Instance Attribute Details

#credit_note_number ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


612
# File 'lib/orb/models/changed_subscription_resources.rb', line 612

required :credit_note_number, String

#id ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


607
# File 'lib/orb/models/changed_subscription_resources.rb', line 607

required :id, String

#memo ⇒ String?

An optional memo supplied on the credit note.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


618
# File 'lib/orb/models/changed_subscription_resources.rb', line 618

required :memo, String, nil?: true

#reason ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


623
# File 'lib/orb/models/changed_subscription_resources.rb', line 623

required :reason, String

#total ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


628
# File 'lib/orb/models/changed_subscription_resources.rb', line 628

required :total, String

#type ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


633
# File 'lib/orb/models/changed_subscription_resources.rb', line 633

required :type, String

#voided_at ⇒ Time?

If the credit note has a status of void, this gives a timestamp when the credit note was voided.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


640
# File 'lib/orb/models/changed_subscription_resources.rb', line 640

required :voided_at, Time, nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


328
# File 'sig/orb/models/changed_subscription_resources.rbs', line 328

def to_hash: -> {