Class: Orb::Models::ChangedSubscriptionResources::CreatedInvoice::CustomerBalanceTransaction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::ChangedSubscriptionResources::CreatedInvoice::CustomerBalanceTransaction
- Defined in:
- lib/orb/models/changed_subscription_resources.rb,
sig/orb/models/changed_subscription_resources.rbs
Defined Under Namespace
Instance Attribute Summary collapse
- #action ⇒ Symbol, Orb::Models::ChangedSubscriptionResources::CreatedInvoice::CustomerBalanceTransaction::Action
-
#amount ⇒ String
The value of the amount changed in the transaction.
-
#created_at ⇒ Time
The creation time of this transaction.
- #credit_note ⇒ Orb::Models::CreditNoteTiny?
-
#description ⇒ String?
An optional description provided for manual customer balance adjustments.
-
#ending_balance ⇒ String
The new value of the customer's balance prior to the transaction, in the customer's currency.
-
#id ⇒ String
A unique id for this transaction.
- #invoice ⇒ Orb::Models::InvoiceTiny?
-
#starting_balance ⇒ String
The original value of the customer's balance prior to the transaction, in the customer's currency.
- #type ⇒ Symbol, Orb::Models::ChangedSubscriptionResources::CreatedInvoice::CustomerBalanceTransaction::Type
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, action:, amount:, created_at:, credit_note:, description:, ending_balance:, invoice:, starting_balance:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CustomerBalanceTransaction for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, action:, amount:, created_at:, credit_note:, description:, ending_balance:, invoice:, starting_balance:, type:) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::ChangedSubscriptionResources::CreatedInvoice::CustomerBalanceTransaction for more details.
|
|
# File 'lib/orb/models/changed_subscription_resources.rb', line 712
|
Instance Attribute Details
#action ⇒ Symbol, Orb::Models::ChangedSubscriptionResources::CreatedInvoice::CustomerBalanceTransaction::Action
661 662 |
# File 'lib/orb/models/changed_subscription_resources.rb', line 661 required :action, enum: -> { Orb::ChangedSubscriptionResources::CreatedInvoice::CustomerBalanceTransaction::Action } |
#amount ⇒ String
The value of the amount changed in the transaction.
668 |
# File 'lib/orb/models/changed_subscription_resources.rb', line 668 required :amount, String |
#created_at ⇒ Time
The creation time of this transaction.
674 |
# File 'lib/orb/models/changed_subscription_resources.rb', line 674 required :created_at, Time |
#credit_note ⇒ Orb::Models::CreditNoteTiny?
679 |
# File 'lib/orb/models/changed_subscription_resources.rb', line 679 required :credit_note, -> { Orb::CreditNoteTiny }, nil?: true |
#description ⇒ String?
An optional description provided for manual customer balance adjustments.
685 |
# File 'lib/orb/models/changed_subscription_resources.rb', line 685 required :description, String, nil?: true |
#ending_balance ⇒ String
The new value of the customer's balance prior to the transaction, in the customer's currency.
692 |
# File 'lib/orb/models/changed_subscription_resources.rb', line 692 required :ending_balance, String |
#id ⇒ String
A unique id for this transaction.
656 |
# File 'lib/orb/models/changed_subscription_resources.rb', line 656 required :id, String |
#invoice ⇒ Orb::Models::InvoiceTiny?
697 |
# File 'lib/orb/models/changed_subscription_resources.rb', line 697 required :invoice, -> { Orb::InvoiceTiny }, nil?: true |
#starting_balance ⇒ String
The original value of the customer's balance prior to the transaction, in the customer's currency.
704 |
# File 'lib/orb/models/changed_subscription_resources.rb', line 704 required :starting_balance, String |
#type ⇒ Symbol, Orb::Models::ChangedSubscriptionResources::CreatedInvoice::CustomerBalanceTransaction::Type
709 710 |
# File 'lib/orb/models/changed_subscription_resources.rb', line 709 required :type, enum: -> { Orb::ChangedSubscriptionResources::CreatedInvoice::CustomerBalanceTransaction::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/changed_subscription_resources.rb', line 752
|
Instance Method Details
#to_hash ⇒ {
382 |
# File 'sig/orb/models/changed_subscription_resources.rbs', line 382
def to_hash: -> {
|