Class: Orb::Models::CreditBlockAccountingSyncSucceededWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::CreditBlockAccountingSyncSucceededWebhookEvent
- Defined in:
- lib/orb/models/credit_block_accounting_sync_succeeded_webhook_event.rb,
sig/orb/models/credit_block_accounting_sync_succeeded_webhook_event.rbs
Defined Under Namespace
Modules: Type Classes: AccountingSyncRecord, Block, Properties
Instance Attribute Summary collapse
- #accounting_sync_record ⇒ Orb::Models::CreditBlockAccountingSyncSucceededWebhookEvent::AccountingSyncRecord
-
#block ⇒ Orb::Models::CreditBlockAccountingSyncSucceededWebhookEvent::Block
The Credit Block resource models prepaid credits within Orb.
-
#created_at ⇒ Time
The time at which this event was created, to the second.
-
#id ⇒ String
The ID of this webhook event.
- #properties ⇒ Orb::Models::CreditBlockAccountingSyncSucceededWebhookEvent::Properties
-
#type ⇒ Symbol, Orb::Models::CreditBlockAccountingSyncSucceededWebhookEvent::Type
The event this payload describes.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(connection_type:) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(connection_type:) ⇒ Object
|
|
# File 'lib/orb/models/credit_block_accounting_sync_succeeded_webhook_event.rb', line 41
|
Instance Attribute Details
#accounting_sync_record ⇒ Orb::Models::CreditBlockAccountingSyncSucceededWebhookEvent::AccountingSyncRecord
15 16 |
# File 'lib/orb/models/credit_block_accounting_sync_succeeded_webhook_event.rb', line 15 required :accounting_sync_record, -> { Orb::CreditBlockAccountingSyncSucceededWebhookEvent::AccountingSyncRecord } |
#block ⇒ Orb::Models::CreditBlockAccountingSyncSucceededWebhookEvent::Block
The Credit Block resource models prepaid credits within Orb.
22 |
# File 'lib/orb/models/credit_block_accounting_sync_succeeded_webhook_event.rb', line 22 required :block, -> { Orb::CreditBlockAccountingSyncSucceededWebhookEvent::Block } |
#created_at ⇒ Time
The time at which this event was created, to the second.
28 |
# File 'lib/orb/models/credit_block_accounting_sync_succeeded_webhook_event.rb', line 28 required :created_at, Time |
#id ⇒ String
The ID of this webhook event.
10 |
# File 'lib/orb/models/credit_block_accounting_sync_succeeded_webhook_event.rb', line 10 required :id, String |
#properties ⇒ Orb::Models::CreditBlockAccountingSyncSucceededWebhookEvent::Properties
33 |
# File 'lib/orb/models/credit_block_accounting_sync_succeeded_webhook_event.rb', line 33 required :properties, -> { Orb::CreditBlockAccountingSyncSucceededWebhookEvent::Properties } |
#type ⇒ Symbol, Orb::Models::CreditBlockAccountingSyncSucceededWebhookEvent::Type
The event this payload describes.
39 |
# File 'lib/orb/models/credit_block_accounting_sync_succeeded_webhook_event.rb', line 39 required :type, enum: -> { Orb::CreditBlockAccountingSyncSucceededWebhookEvent::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/credit_block_accounting_sync_succeeded_webhook_event.rb', line 128
|
Instance Method Details
#to_hash ⇒ {
35 |
# File 'sig/orb/models/credit_block_accounting_sync_succeeded_webhook_event.rbs', line 35
def to_hash: -> {
|