Class: Orb::Models::CreditBlockListInvoicesResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/credit_block_list_invoices_response.rb,
sig/orb/models/credit_block_list_invoices_response.rbs

Overview

See Also:

  • Orb::Resources::CreditBlocks#list_invoices

Defined Under Namespace

Classes: Block, Invoice

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, subscription_id: nil) ⇒ Object

The subscription commitment whose true-up rolled forward into this credit block. Present only when credit_block_source is commitment.

Parameters:

  • id (String)

    The ID of the subscription commitment this block was rolled forward from.

  • subscription_id (String, nil) (defaults to: nil)

    The subscription the commitment belongs to.



# File 'lib/orb/models/credit_block_list_invoices_response.rb', line 19

Instance Attribute Details

#blockOrb::Models::CreditBlockListInvoicesResponse::Block

The Credit Block resource models prepaid credits within Orb.



11
# File 'lib/orb/models/credit_block_list_invoices_response.rb', line 11

required :block, -> { Orb::Models::CreditBlockListInvoicesResponse::Block }

#invoicesArray<Orb::Models::CreditBlockListInvoicesResponse::Invoice>



16
17
# File 'lib/orb/models/credit_block_list_invoices_response.rb', line 16

required :invoices,
-> { Orb::Internal::Type::ArrayOf[Orb::Models::CreditBlockListInvoicesResponse::Invoice] }

Instance Method Details

#to_hash{

Returns:

  • ({)


19
# File 'sig/orb/models/credit_block_list_invoices_response.rbs', line 19

def to_hash: -> {