Class: Orb::Models::CreditBlockListInvoicesResponse::Block::CreditCommitment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::CreditBlockListInvoicesResponse::Block::CreditCommitment
- Defined in:
- lib/orb/models/credit_block_list_invoices_response.rb,
sig/orb/models/credit_block_list_invoices_response.rbs
Overview
Instance Attribute Summary collapse
-
#id ⇒ String
The ID of the subscription commitment this block was rolled forward from.
-
#subscription_id ⇒ String?
The subscription the commitment belongs to.
Instance Method Summary collapse
-
#initialize ⇒ CreditCommitment
constructor
A new instance of CreditCommitment.
- #to_hash ⇒ { id: String, subscription_id: String? }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ CreditCommitment
Returns a new instance of CreditCommitment.
278 |
# File 'sig/orb/models/credit_block_list_invoices_response.rbs', line 278
def initialize: (id: String, ?subscription_id: String?) -> void
|
Instance Attribute Details
#id ⇒ String
The ID of the subscription commitment this block was rolled forward from.
341 |
# File 'lib/orb/models/credit_block_list_invoices_response.rb', line 341 required :id, String |
#subscription_id ⇒ String?
The subscription the commitment belongs to.
347 |
# File 'lib/orb/models/credit_block_list_invoices_response.rb', line 347 optional :subscription_id, String, nil?: true |
Instance Method Details
#to_hash ⇒ { id: String, subscription_id: String? }
280 |
# File 'sig/orb/models/credit_block_list_invoices_response.rbs', line 280
def to_hash: -> { id: String, subscription_id: String? }
|