Class: Orb::Models::CreditBlockRetrieveResponse::CreditCommitment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::CreditBlockRetrieveResponse::CreditCommitment
- Defined in:
- lib/orb/models/credit_block_retrieve_response.rb,
sig/orb/models/credit_block_retrieve_response.rbs
Overview
Instance Attribute Summary collapse
-
#id ⇒ String
The ID of the subscription commitment this block was rolled forward from.
-
#subscription_id ⇒ String?
The subscription the commitment belongs to.
Instance Method Summary collapse
-
#initialize(id:, subscription_id: nil) ⇒ CreditCommitment
constructor
The subscription commitment whose true-up rolled forward into this credit block.
- #to_hash ⇒ { id: String, subscription_id: String? }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, subscription_id: nil) ⇒ CreditCommitment
The subscription commitment whose true-up rolled forward into this credit block.
Present only when credit_block_source is commitment.
|
|
# File 'lib/orb/models/credit_block_retrieve_response.rb', line 322
|
Instance Attribute Details
#id ⇒ String
The ID of the subscription commitment this block was rolled forward from.
314 |
# File 'lib/orb/models/credit_block_retrieve_response.rb', line 314 required :id, String |
#subscription_id ⇒ String?
The subscription the commitment belongs to.
320 |
# File 'lib/orb/models/credit_block_retrieve_response.rb', line 320 optional :subscription_id, String, nil?: true |
Instance Method Details
#to_hash ⇒ { id: String, subscription_id: String? }
259 |
# File 'sig/orb/models/credit_block_retrieve_response.rbs', line 259
def to_hash: -> { id: String, subscription_id: String? }
|