Class: Orb::Models::CreditNoteAccountingSyncFailedWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::CreditNoteAccountingSyncFailedWebhookEvent
- Defined in:
- lib/orb/models/credit_note_accounting_sync_failed_webhook_event.rb,
sig/orb/models/credit_note_accounting_sync_failed_webhook_event.rbs
Defined Under Namespace
Modules: Type Classes: AccountingSyncRecord, Properties
Instance Attribute Summary collapse
- #accounting_sync_record ⇒ Orb::Models::CreditNoteAccountingSyncFailedWebhookEvent::AccountingSyncRecord
-
#created_at ⇒ Time
The time at which this event was created, to the second.
-
#credit_note ⇒ Orb::Models::CreditNote
The Credit Note resource represents a credit that has been applied to a particular invoice.
-
#id ⇒ String
The ID of this webhook event.
- #properties ⇒ Orb::Models::CreditNoteAccountingSyncFailedWebhookEvent::Properties
-
#type ⇒ Symbol, Orb::Models::CreditNoteAccountingSyncFailedWebhookEvent::Type
The event this payload describes.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(connection_type:, failure_reason:) ⇒ Object
|
|
# File 'lib/orb/models/credit_note_accounting_sync_failed_webhook_event.rb', line 42
|
Instance Attribute Details
#accounting_sync_record ⇒ Orb::Models::CreditNoteAccountingSyncFailedWebhookEvent::AccountingSyncRecord
15 16 |
# File 'lib/orb/models/credit_note_accounting_sync_failed_webhook_event.rb', line 15 required :accounting_sync_record, -> { Orb::CreditNoteAccountingSyncFailedWebhookEvent::AccountingSyncRecord } |
#created_at ⇒ Time
The time at which this event was created, to the second.
22 |
# File 'lib/orb/models/credit_note_accounting_sync_failed_webhook_event.rb', line 22 required :created_at, Time |
#credit_note ⇒ Orb::Models::CreditNote
The Credit Note resource represents a credit that has been applied to a particular invoice.
29 |
# File 'lib/orb/models/credit_note_accounting_sync_failed_webhook_event.rb', line 29 required :credit_note, -> { Orb::CreditNote } |
#id ⇒ String
The ID of this webhook event.
10 |
# File 'lib/orb/models/credit_note_accounting_sync_failed_webhook_event.rb', line 10 required :id, String |
#properties ⇒ Orb::Models::CreditNoteAccountingSyncFailedWebhookEvent::Properties
34 |
# File 'lib/orb/models/credit_note_accounting_sync_failed_webhook_event.rb', line 34 required :properties, -> { Orb::CreditNoteAccountingSyncFailedWebhookEvent::Properties } |
#type ⇒ Symbol, Orb::Models::CreditNoteAccountingSyncFailedWebhookEvent::Type
The event this payload describes.
40 |
# File 'lib/orb/models/credit_note_accounting_sync_failed_webhook_event.rb', line 40 required :type, enum: -> { Orb::CreditNoteAccountingSyncFailedWebhookEvent::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/credit_note_accounting_sync_failed_webhook_event.rb', line 126
|
Instance Method Details
#to_hash ⇒ {
35 |
# File 'sig/orb/models/credit_note_accounting_sync_failed_webhook_event.rbs', line 35
def to_hash: -> {
|