Class: Orb::Models::CreditNoteIssuedWebhookEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/credit_note_issued_webhook_event.rb,
sig/orb/models/credit_note_issued_webhook_event.rbs

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, credit_note:, properties:, type:) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::CreditNoteIssuedWebhookEvent for more details.

Issued when a credit note is created.

Parameters:



# File 'lib/orb/models/credit_note_issued_webhook_event.rb', line 36

Instance Attribute Details

#created_at ⇒ Time

The time at which this event was created, to the second.

Parameters:

  • value (Time)

Returns:

  • (Time)


16
# File 'lib/orb/models/credit_note_issued_webhook_event.rb', line 16

required :created_at, Time

#credit_note ⇒ Orb::Models::CreditNote

The Credit Note resource represents a credit that has been applied to a particular invoice.

Parameters:

Returns:



23
# File 'lib/orb/models/credit_note_issued_webhook_event.rb', line 23

required :credit_note, -> { Orb::CreditNote }

#id ⇒ String

The ID of this webhook event.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/orb/models/credit_note_issued_webhook_event.rb', line 10

required :id, String

#properties ⇒ Object

Parameters:

  • value (top)

Returns:

  • (Object)


28
# File 'lib/orb/models/credit_note_issued_webhook_event.rb', line 28

required :properties, Orb::Internal::Type::Unknown

#type ⇒ Symbol, Orb::Models::CreditNoteIssuedWebhookEvent::Type

The event this payload describes.

Parameters:

  • value (Orb::Models::CreditNoteIssuedWebhookEvent::type_)

Returns:



34
# File 'lib/orb/models/credit_note_issued_webhook_event.rb', line 34

required :type, enum: -> { Orb::CreditNoteIssuedWebhookEvent::Type }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


31
# File 'sig/orb/models/credit_note_issued_webhook_event.rbs', line 31

def to_hash: -> {