Class: Orb::Models::CreditNoteMarkedAsVoidWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::CreditNoteMarkedAsVoidWebhookEvent
- Defined in:
- lib/orb/models/credit_note_marked_as_void_webhook_event.rb,
sig/orb/models/credit_note_marked_as_void_webhook_event.rbs
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The time at which this event was created, to the second.
-
#credit_note ⇒ Orb::Models::CreditNote
The Credit Note resource represents a credit that has been applied to a particular invoice.
-
#id ⇒ String
The ID of this webhook event.
- #properties ⇒ Object
-
#type ⇒ Symbol, Orb::Models::CreditNoteMarkedAsVoidWebhookEvent::Type
The event this payload describes.
Instance Method Summary collapse
-
#initialize(id:, created_at:, credit_note:, properties:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CreditNoteMarkedAsVoidWebhookEvent for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, credit_note:, properties:, type:) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::CreditNoteMarkedAsVoidWebhookEvent for more details.
Issued when a credit note is marked as void.
|
|
# File 'lib/orb/models/credit_note_marked_as_void_webhook_event.rb', line 36
|
Instance Attribute Details
#created_at ⇒ Time
The time at which this event was created, to the second.
16 |
# File 'lib/orb/models/credit_note_marked_as_void_webhook_event.rb', line 16 required :created_at, Time |
#credit_note ⇒ Orb::Models::CreditNote
The Credit Note resource represents a credit that has been applied to a particular invoice.
23 |
# File 'lib/orb/models/credit_note_marked_as_void_webhook_event.rb', line 23 required :credit_note, -> { Orb::CreditNote } |
#id ⇒ String
The ID of this webhook event.
10 |
# File 'lib/orb/models/credit_note_marked_as_void_webhook_event.rb', line 10 required :id, String |
#properties ⇒ Object
28 |
# File 'lib/orb/models/credit_note_marked_as_void_webhook_event.rb', line 28 required :properties, Orb::Internal::Type::Unknown |
#type ⇒ Symbol, Orb::Models::CreditNoteMarkedAsVoidWebhookEvent::Type
The event this payload describes.
34 |
# File 'lib/orb/models/credit_note_marked_as_void_webhook_event.rb', line 34 required :type, enum: -> { Orb::CreditNoteMarkedAsVoidWebhookEvent::Type } |
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/orb/models/credit_note_marked_as_void_webhook_event.rbs', line 31
def to_hash: -> {
|