Class: Orb::Models::CustomerAccountingSyncSucceededWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::CustomerAccountingSyncSucceededWebhookEvent
- Defined in:
- lib/orb/models/customer_accounting_sync_succeeded_webhook_event.rb,
sig/orb/models/customer_accounting_sync_succeeded_webhook_event.rbs
Defined Under Namespace
Modules: Type Classes: AccountingSyncRecord, Properties
Instance Attribute Summary collapse
- #accounting_sync_record ⇒ Orb::Models::CustomerAccountingSyncSucceededWebhookEvent::AccountingSyncRecord
-
#created_at ⇒ Time
The time at which this event was created, to the second.
-
#customer ⇒ Orb::Models::Customer
A customer is a buyer of your products, and the other party to the billing relationship.
-
#id ⇒ String
The ID of this webhook event.
- #properties ⇒ Orb::Models::CustomerAccountingSyncSucceededWebhookEvent::Properties
-
#type ⇒ Symbol, Orb::Models::CustomerAccountingSyncSucceededWebhookEvent::Type
The event this payload describes.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(connection_type:) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(connection_type:) ⇒ Object
|
|
# File 'lib/orb/models/customer_accounting_sync_succeeded_webhook_event.rb', line 58
|
Instance Attribute Details
#accounting_sync_record ⇒ Orb::Models::CustomerAccountingSyncSucceededWebhookEvent::AccountingSyncRecord
15 16 |
# File 'lib/orb/models/customer_accounting_sync_succeeded_webhook_event.rb', line 15 required :accounting_sync_record, -> { Orb::CustomerAccountingSyncSucceededWebhookEvent::AccountingSyncRecord } |
#created_at ⇒ Time
The time at which this event was created, to the second.
22 |
# File 'lib/orb/models/customer_accounting_sync_succeeded_webhook_event.rb', line 22 required :created_at, Time |
#customer ⇒ Orb::Models::Customer
A customer is a buyer of your products, and the other party to the billing relationship.
In Orb, customers are assigned system generated identifiers automatically, but
it's often desirable to have these match existing identifiers in your system. To
avoid having to denormalize Orb ID information, you can pass in an
external_customer_id with your own identifier. See
Customer ID Aliases for further
information about how these aliases work in Orb.
In addition to having an identifier in your system, a customer may exist in a
payment provider solution like Stripe. Use the payment_provider_id and the
payment_provider enum field to express this mapping.
A customer also has a timezone (from the standard IANA timezone database), which defaults to your account's timezone. See Timezone localization for information on what this timezone parameter influences within Orb.
45 |
# File 'lib/orb/models/customer_accounting_sync_succeeded_webhook_event.rb', line 45 required :customer, -> { Orb::Customer } |
#id ⇒ String
The ID of this webhook event.
10 |
# File 'lib/orb/models/customer_accounting_sync_succeeded_webhook_event.rb', line 10 required :id, String |
#properties ⇒ Orb::Models::CustomerAccountingSyncSucceededWebhookEvent::Properties
50 |
# File 'lib/orb/models/customer_accounting_sync_succeeded_webhook_event.rb', line 50 required :properties, -> { Orb::CustomerAccountingSyncSucceededWebhookEvent::Properties } |
#type ⇒ Symbol, Orb::Models::CustomerAccountingSyncSucceededWebhookEvent::Type
The event this payload describes.
56 |
# File 'lib/orb/models/customer_accounting_sync_succeeded_webhook_event.rb', line 56 required :type, enum: -> { Orb::CustomerAccountingSyncSucceededWebhookEvent::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/customer_accounting_sync_succeeded_webhook_event.rb', line 136
|
Instance Method Details
#to_hash ⇒ {
35 |
# File 'sig/orb/models/customer_accounting_sync_succeeded_webhook_event.rbs', line 35
def to_hash: -> {
|