Class: Orb::Models::CustomerBalanceTransactionCreatedWebhookEvent::Properties::BalanceTransaction

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/customer_balance_transaction_created_webhook_event.rb,
sig/orb/models/customer_balance_transaction_created_webhook_event.rbs

Overview

See Also:

  • Orb::Models::CustomerBalanceTransactionCreatedWebhookEvent::Properties#balance_transaction

Defined Under Namespace

Modules: Action, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, action:, amount:, created_at:, credit_note:, description:, ending_balance:, invoice:, starting_balance:, type:) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::CustomerBalanceTransactionCreatedWebhookEvent::Properties::BalanceTransaction for more details.

Parameters:



# File 'lib/orb/models/customer_balance_transaction_created_webhook_event.rb', line 141

Instance Attribute Details

#action ⇒ Symbol, Orb::Models::CustomerBalanceTransactionCreatedWebhookEvent::Properties::BalanceTransaction::Action

Parameters:

  • value (Orb::Models::CustomerBalanceTransactionCreatedWebhookEvent::Properties::BalanceTransaction::action)

Returns:



90
91
# File 'lib/orb/models/customer_balance_transaction_created_webhook_event.rb', line 90

required :action,
enum: -> { Orb::CustomerBalanceTransactionCreatedWebhookEvent::Properties::BalanceTransaction::Action }

#amount ⇒ String

The value of the amount changed in the transaction.

Parameters:

  • value (String)

Returns:

  • (String)


97
# File 'lib/orb/models/customer_balance_transaction_created_webhook_event.rb', line 97

required :amount, String

#created_at ⇒ Time

The creation time of this transaction.

Parameters:

  • value (Time)

Returns:

  • (Time)


103
# File 'lib/orb/models/customer_balance_transaction_created_webhook_event.rb', line 103

required :created_at, Time

#credit_note ⇒ Orb::Models::CreditNoteTiny?

Parameters:

Returns:



108
# File 'lib/orb/models/customer_balance_transaction_created_webhook_event.rb', line 108

required :credit_note, -> { Orb::CreditNoteTiny }, nil?: true

#description ⇒ String?

An optional description provided for manual customer balance adjustments.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


114
# File 'lib/orb/models/customer_balance_transaction_created_webhook_event.rb', line 114

required :description, String, nil?: true

#ending_balance ⇒ String

The new value of the customer's balance prior to the transaction, in the customer's currency.

Parameters:

  • value (String)

Returns:

  • (String)


121
# File 'lib/orb/models/customer_balance_transaction_created_webhook_event.rb', line 121

required :ending_balance, String

#id ⇒ String

A unique id for this transaction.

Parameters:

  • value (String)

Returns:

  • (String)


85
# File 'lib/orb/models/customer_balance_transaction_created_webhook_event.rb', line 85

required :id, String

#invoice ⇒ Orb::Models::InvoiceTiny?

Parameters:

Returns:



126
# File 'lib/orb/models/customer_balance_transaction_created_webhook_event.rb', line 126

required :invoice, -> { Orb::InvoiceTiny }, nil?: true

#starting_balance ⇒ String

The original value of the customer's balance prior to the transaction, in the customer's currency.

Parameters:

  • value (String)

Returns:

  • (String)


133
# File 'lib/orb/models/customer_balance_transaction_created_webhook_event.rb', line 133

required :starting_balance, String

#type ⇒ Symbol, Orb::Models::CustomerBalanceTransactionCreatedWebhookEvent::Properties::BalanceTransaction::Type

Parameters:

  • value (Orb::Models::CustomerBalanceTransactionCreatedWebhookEvent::Properties::BalanceTransaction::type_)

Returns:



138
139
# File 'lib/orb/models/customer_balance_transaction_created_webhook_event.rb', line 138

required :type,
enum: -> { Orb::CustomerBalanceTransactionCreatedWebhookEvent::Properties::BalanceTransaction::Type }

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/orb/models/customer_balance_transaction_created_webhook_event.rb', line 182

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


103
# File 'sig/orb/models/customer_balance_transaction_created_webhook_event.rbs', line 103

def to_hash: -> {