Class: Orb::Models::CustomerCreatePortalSessionByExternalIDParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/orb/models/customer_create_portal_session_by_external_id_params.rb,
sig/orb/models/customer_create_portal_session_by_external_id_params.rbs

Overview

See Also:

  • Orb::Resources::Customers#create_portal_session_by_external_id

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(external_customer_id:, expires_in_minutes: nil, invalidate_existing: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::CustomerCreatePortalSessionByExternalIDParams for more details.

Parameters:

  • external_customer_id (String)
  • expires_in_minutes (Integer) (defaults to: nil)

    Duration in minutes until the portal session expires. Defaults to 60. Maximum 18

  • invalidate_existing (Boolean) (defaults to: nil)

    When true (default), creating this session soft-deletes any other active portal

  • request_options (Orb::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/orb/models/customer_create_portal_session_by_external_id_params.rb', line 31

Instance Attribute Details

#expires_in_minutesInteger?

Duration in minutes until the portal session expires. Defaults to 60. Maximum 180.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


20
# File 'lib/orb/models/customer_create_portal_session_by_external_id_params.rb', line 20

optional :expires_in_minutes, Integer

#external_customer_idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/orb/models/customer_create_portal_session_by_external_id_params.rb', line 13

required :external_customer_id, String

#invalidate_existingBoolean?

When true (default), creating this session soft-deletes any other active portal sessions for the customer. Set to false to allow concurrent sessions — useful when minting portal links for multiple authenticated end-users at once. The customer's permanent portal link (if any) is never invalidated by this.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


29
# File 'lib/orb/models/customer_create_portal_session_by_external_id_params.rb', line 29

optional :invalidate_existing, Orb::Internal::Type::Boolean

Instance Method Details

#to_hash{

Returns:

  • ({)


32
# File 'sig/orb/models/customer_create_portal_session_by_external_id_params.rbs', line 32

def to_hash: -> {