Class: Orb::Models::CustomerCreditBalanceDepletedWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::CustomerCreditBalanceDepletedWebhookEvent
- Defined in:
- lib/orb/models/customer_credit_balance_depleted_webhook_event.rb,
sig/orb/models/customer_credit_balance_depleted_webhook_event.rbs
Defined Under Namespace
Modules: Type Classes: Properties
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The time at which this event was created, to the second.
-
#customer ⇒ Orb::Models::Customer
A customer is a buyer of your products, and the other party to the billing relationship.
-
#id ⇒ String
The ID of this webhook event.
- #properties ⇒ Orb::Models::CustomerCreditBalanceDepletedWebhookEvent::Properties
-
#type ⇒ Symbol, Orb::Models::CustomerCreditBalanceDepletedWebhookEvent::Type
The event this payload describes.
Instance Method Summary collapse
-
#initialize(id:, display_name:, name:, symbol:) ⇒ Object
constructor
A currency or custom credit unit, as embedded in webhook payloads.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, display_name:, name:, symbol:) ⇒ Object
A currency or custom credit unit, as embedded in webhook payloads.
|
|
# File 'lib/orb/models/customer_credit_balance_depleted_webhook_event.rb', line 52
|
Instance Attribute Details
#created_at ⇒ Time
The time at which this event was created, to the second.
16 |
# File 'lib/orb/models/customer_credit_balance_depleted_webhook_event.rb', line 16 required :created_at, Time |
#customer ⇒ Orb::Models::Customer
A customer is a buyer of your products, and the other party to the billing relationship.
In Orb, customers are assigned system generated identifiers automatically, but
it's often desirable to have these match existing identifiers in your system. To
avoid having to denormalize Orb ID information, you can pass in an
external_customer_id with your own identifier. See
Customer ID Aliases for further
information about how these aliases work in Orb.
In addition to having an identifier in your system, a customer may exist in a
payment provider solution like Stripe. Use the payment_provider_id and the
payment_provider enum field to express this mapping.
A customer also has a timezone (from the standard IANA timezone database), which defaults to your account's timezone. See Timezone localization for information on what this timezone parameter influences within Orb.
39 |
# File 'lib/orb/models/customer_credit_balance_depleted_webhook_event.rb', line 39 required :customer, -> { Orb::Customer } |
#id ⇒ String
The ID of this webhook event.
10 |
# File 'lib/orb/models/customer_credit_balance_depleted_webhook_event.rb', line 10 required :id, String |
#properties ⇒ Orb::Models::CustomerCreditBalanceDepletedWebhookEvent::Properties
44 |
# File 'lib/orb/models/customer_credit_balance_depleted_webhook_event.rb', line 44 required :properties, -> { Orb::CustomerCreditBalanceDepletedWebhookEvent::Properties } |
#type ⇒ Symbol, Orb::Models::CustomerCreditBalanceDepletedWebhookEvent::Type
The event this payload describes.
50 |
# File 'lib/orb/models/customer_credit_balance_depleted_webhook_event.rb', line 50 required :type, enum: -> { Orb::CustomerCreditBalanceDepletedWebhookEvent::Type } |
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/orb/models/customer_credit_balance_depleted_webhook_event.rbs', line 31
def to_hash: -> {
|