Class: Orb::Models::CustomerCreditBalanceDepletedWebhookEvent::Properties::AlertConfiguration::Threshold

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/customer_credit_balance_depleted_webhook_event.rb,
sig/orb/models/customer_credit_balance_depleted_webhook_event.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Threshold

Returns a new instance of Threshold.

Parameters:

  • value: (String)


193
# File 'sig/orb/models/customer_credit_balance_depleted_webhook_event.rbs', line 193

def initialize: (value: String) -> void

Instance Attribute Details

#value ⇒ String

The value at which an alert will fire. For credit balance alerts, the alert will fire at or below this value. For usage and cost alerts, the alert will fire at or above this value.

Parameters:

  • value (String)

Returns:

  • (String)


328
# File 'lib/orb/models/customer_credit_balance_depleted_webhook_event.rb', line 328

required :value, String

Instance Method Details

#to_hash ⇒ { value: String }

Returns:

  • ({ value: String })


195
# File 'sig/orb/models/customer_credit_balance_depleted_webhook_event.rbs', line 195

def to_hash: -> { value: String }