Class: Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration
- Defined in:
- lib/orb/models/customer_credit_balance_dropped_webhook_event.rb,
sig/orb/models/customer_credit_balance_dropped_webhook_event.rbs
Overview
Defined Under Namespace
Modules: Type Classes: BalanceAlertStatus, LicenseType, Metric, Plan, PriceFilter, Threshold, ThresholdOverride
Instance Attribute Summary collapse
-
#balance_alert_status ⇒ Array<Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::BalanceAlertStatus>?
The current status of the alert.
-
#created_at ⇒ Time
The creation time of the resource in Orb.
-
#currency ⇒ String?
The name of the currency the credit balance or invoice cost is denominated in.
-
#customer ⇒ Orb::Models::CustomerMinified?
The customer the alert applies to.
-
#enabled ⇒ Boolean
Whether the alert is enabled or disabled.
-
#grouping_keys ⇒ Array<String>?
The property keys to group cost alerts by.
-
#id ⇒ String
Also referred to as alert_id in this documentation.
-
#license_type ⇒ Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::LicenseType?
Minified license type for alert serialization.
-
#metric ⇒ Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::Metric?
The metric the alert applies to.
-
#plan ⇒ Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::Plan?
The plan the alert applies to.
-
#price_filters ⇒ Array<Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::PriceFilter>?
Filters scoping which prices are included in spend and grouped cost alert evaluation.
-
#subscription ⇒ Orb::Models::SubscriptionMinified?
The subscription the alert applies to.
-
#threshold_overrides ⇒ Array<Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::ThresholdOverride>?
Per-group threshold overrides.
-
#thresholds ⇒ Array<Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::Threshold>?
The thresholds that define the conditions under which the alert will be triggered.
-
#type ⇒ Symbol, Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::Type
The type of alert.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:) ⇒ Object
constructor
Minified license type for alert serialization.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:) ⇒ Object
Minified license type for alert serialization.
|
|
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 232
|
Instance Attribute Details
#balance_alert_status ⇒ Array<Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::BalanceAlertStatus>?
The current status of the alert. This field is only present for credit balance alerts.
185 186 187 188 189 |
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 185 optional :balance_alert_status, -> { Orb::Internal::Type::ArrayOf[Orb::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::BalanceAlertStatus] }, nil?: true |
#created_at ⇒ Time
The creation time of the resource in Orb.
118 |
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 118 required :created_at, Time |
#currency ⇒ String?
The name of the currency the credit balance or invoice cost is denominated in.
124 |
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 124 required :currency, String, nil?: true |
#customer ⇒ Orb::Models::CustomerMinified?
The customer the alert applies to.
130 |
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 130 required :customer, -> { Orb::CustomerMinified }, nil?: true |
#enabled ⇒ Boolean
Whether the alert is enabled or disabled.
136 |
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 136 required :enabled, Orb::Internal::Type::Boolean |
#grouping_keys ⇒ Array<String>?
The property keys to group cost alerts by. Only present for cost alerts with grouping enabled.
196 |
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 196 optional :grouping_keys, Orb::Internal::Type::ArrayOf[String], nil?: true |
#id ⇒ String
Also referred to as alert_id in this documentation.
112 |
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 112 required :id, String |
#license_type ⇒ Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::LicenseType?
Minified license type for alert serialization.
202 203 204 205 206 |
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 202 optional :license_type, -> { Orb::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::LicenseType }, nil?: true |
#metric ⇒ Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::Metric?
The metric the alert applies to.
142 143 144 145 146 |
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 142 required :metric, -> { Orb::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::Metric }, nil?: true |
#plan ⇒ Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::Plan?
The plan the alert applies to.
152 153 154 |
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 152 required :plan, -> { Orb::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::Plan }, nil?: true |
#price_filters ⇒ Array<Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::PriceFilter>?
Filters scoping which prices are included in spend and grouped cost alert evaluation. Alerts use the price_id, item_id, and price_type fields only; the alert's pricing unit is reported by currency.
214 215 216 217 218 |
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 214 optional :price_filters, -> { Orb::Internal::Type::ArrayOf[Orb::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::PriceFilter] }, nil?: true |
#subscription ⇒ Orb::Models::SubscriptionMinified?
The subscription the alert applies to.
160 |
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 160 required :subscription, -> { Orb::SubscriptionMinified }, nil?: true |
#threshold_overrides ⇒ Array<Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::ThresholdOverride>?
Per-group threshold overrides. Each override maps a specific combination of grouping_keys values to a replacement threshold list. Only present for grouped cost alerts that have at least one override.
226 227 228 229 230 |
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 226 optional :threshold_overrides, -> { Orb::Internal::Type::ArrayOf[Orb::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::ThresholdOverride] }, nil?: true |
#thresholds ⇒ Array<Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::Threshold>?
The thresholds that define the conditions under which the alert will be triggered.
167 168 169 170 171 |
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 167 required :thresholds, -> { Orb::Internal::Type::ArrayOf[Orb::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::Threshold] }, nil?: true |
#type ⇒ Symbol, Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::Type
The type of alert. This must be a valid alert type.
177 178 |
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 177 required :type, enum: -> { Orb::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 361
|
Instance Method Details
#to_hash ⇒ {
133 |
# File 'sig/orb/models/customer_credit_balance_dropped_webhook_event.rbs', line 133
def to_hash: -> {
|