Class: Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::Plan

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/customer_credit_balance_dropped_webhook_event.rb,
sig/orb/models/customer_credit_balance_dropped_webhook_event.rbs

Overview

See Also:

  • Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration#plan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



178
# File 'sig/orb/models/customer_credit_balance_dropped_webhook_event.rbs', line 178

def initialize: (

Instance Attribute Details

#external_plan_id ⇒ String?

An optional user-defined ID for this plan resource, used throughout the system as an alias for this Plan. Use this field to identify a plan by an existing identifier in your system.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


299
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 299

required :external_plan_id, String, nil?: true

#id ⇒ String?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


291
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 291

required :id, String, nil?: true

#name ⇒ String?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


304
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 304

required :name, String, nil?: true

#plan_version ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


309
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 309

required :plan_version, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


185
# File 'sig/orb/models/customer_credit_balance_dropped_webhook_event.rbs', line 185

def to_hash: -> {