Class: Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::Threshold
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::Threshold
- Defined in:
- lib/orb/models/customer_credit_balance_dropped_webhook_event.rb,
sig/orb/models/customer_credit_balance_dropped_webhook_event.rbs
Instance Attribute Summary collapse
-
#value ⇒ String
The value at which an alert will fire.
Instance Method Summary collapse
-
#initialize ⇒ Threshold
constructor
A new instance of Threshold.
- #to_hash ⇒ { value: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Threshold
Returns a new instance of Threshold.
198 |
# File 'sig/orb/models/customer_credit_balance_dropped_webhook_event.rbs', line 198
def initialize: (value: String) -> void
|
Instance Attribute Details
#value ⇒ String
The value at which an alert will fire. For credit balance alerts, the alert will fire at or below this value. For usage and cost alerts, the alert will fire at or above this value.
334 |
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 334 required :value, String |
Instance Method Details
#to_hash ⇒ { value: String }
200 |
# File 'sig/orb/models/customer_credit_balance_dropped_webhook_event.rbs', line 200
def to_hash: -> { value: String }
|