Class: Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::ThresholdOverride::Threshold

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/customer_credit_balance_dropped_webhook_event.rb,
sig/orb/models/customer_credit_balance_dropped_webhook_event.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(group_values:, thresholds:, group_keys: nil) ⇒ Threshold

Some parameter documentations has been truncated, see Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::ThresholdOverride for more details.

A per-group threshold override on a grouped cost alert.

An empty thresholds list means the group is silenced (never fires). A non-empty list fully replaces the default thresholds for that group.

Parameters:



499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 499

class Threshold < Orb::Internal::Type::BaseModel
  # @!attribute value
  #   The value at which an alert will fire. For credit balance alerts, the alert will
  #   fire at or below this value. For usage and cost alerts, the alert will fire at
  #   or above this value.
  #
  #   @return [String]
  required :value, String

  # @!method initialize(value:)
  #   Some parameter documentations has been truncated, see
  #   {Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::ThresholdOverride::Threshold}
  #   for more details.
  #
  #   Thresholds are used to define the conditions under which an alert will be
  #   triggered.
  #
  #   @param value [String] The value at which an alert will fire. For credit balance alerts, the alert will
end

Instance Attribute Details

#value ⇒ String

The value at which an alert will fire. For credit balance alerts, the alert will fire at or below this value. For usage and cost alerts, the alert will fire at or above this value.

Parameters:

  • value (String)

Returns:

  • (String)


506
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 506

required :value, String

Instance Method Details

#to_hash ⇒ { value: String }

Returns:

  • ({ value: String })


335
# File 'sig/orb/models/customer_credit_balance_dropped_webhook_event.rbs', line 335

def to_hash: -> { value: String }