Class: Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration
- Defined in:
- lib/orb/models/customer_credit_balance_recovered_webhook_event.rb,
sig/orb/models/customer_credit_balance_recovered_webhook_event.rbs
Overview
Defined Under Namespace
Modules: Type Classes: BalanceAlertStatus, LicenseType, Metric, Plan, PriceFilter, Threshold, ThresholdOverride
Instance Attribute Summary collapse
-
#balance_alert_status ⇒ Array<Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::BalanceAlertStatus>?
The current status of the alert.
-
#created_at ⇒ Time
The creation time of the resource in Orb.
-
#currency ⇒ String?
The name of the currency the credit balance or invoice cost is denominated in.
-
#customer ⇒ Orb::Models::CustomerMinified?
The customer the alert applies to.
-
#enabled ⇒ Boolean
Whether the alert is enabled or disabled.
-
#grouping_keys ⇒ Array<String>?
The property keys to group cost alerts by.
-
#id ⇒ String
Also referred to as alert_id in this documentation.
-
#license_type ⇒ Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::LicenseType?
Minified license type for alert serialization.
-
#metric ⇒ Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::Metric?
The metric the alert applies to.
-
#plan ⇒ Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::Plan?
The plan the alert applies to.
-
#price_filters ⇒ Array<Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::PriceFilter>?
Filters scoping which prices are included in spend and grouped cost alert evaluation.
-
#subscription ⇒ Orb::Models::SubscriptionMinified?
The subscription the alert applies to.
-
#threshold_overrides ⇒ Array<Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::ThresholdOverride>?
Per-group threshold overrides.
-
#thresholds ⇒ Array<Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::Threshold>?
The thresholds that define the conditions under which the alert will be triggered.
-
#type ⇒ Symbol, Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::Type
The type of alert.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:) ⇒ Object
constructor
Minified license type for alert serialization.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:) ⇒ Object
Minified license type for alert serialization.
|
|
# File 'lib/orb/models/customer_credit_balance_recovered_webhook_event.rb', line 226
|
Instance Attribute Details
#balance_alert_status ⇒ Array<Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::BalanceAlertStatus>?
The current status of the alert. This field is only present for credit balance alerts.
179 180 181 182 183 |
# File 'lib/orb/models/customer_credit_balance_recovered_webhook_event.rb', line 179 optional :balance_alert_status, -> { Orb::Internal::Type::ArrayOf[Orb::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::BalanceAlertStatus] }, nil?: true |
#created_at ⇒ Time
The creation time of the resource in Orb.
110 |
# File 'lib/orb/models/customer_credit_balance_recovered_webhook_event.rb', line 110 required :created_at, Time |
#currency ⇒ String?
The name of the currency the credit balance or invoice cost is denominated in.
116 |
# File 'lib/orb/models/customer_credit_balance_recovered_webhook_event.rb', line 116 required :currency, String, nil?: true |
#customer ⇒ Orb::Models::CustomerMinified?
The customer the alert applies to.
122 |
# File 'lib/orb/models/customer_credit_balance_recovered_webhook_event.rb', line 122 required :customer, -> { Orb::CustomerMinified }, nil?: true |
#enabled ⇒ Boolean
Whether the alert is enabled or disabled.
128 |
# File 'lib/orb/models/customer_credit_balance_recovered_webhook_event.rb', line 128 required :enabled, Orb::Internal::Type::Boolean |
#grouping_keys ⇒ Array<String>?
The property keys to group cost alerts by. Only present for cost alerts with grouping enabled.
190 |
# File 'lib/orb/models/customer_credit_balance_recovered_webhook_event.rb', line 190 optional :grouping_keys, Orb::Internal::Type::ArrayOf[String], nil?: true |
#id ⇒ String
Also referred to as alert_id in this documentation.
104 |
# File 'lib/orb/models/customer_credit_balance_recovered_webhook_event.rb', line 104 required :id, String |
#license_type ⇒ Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::LicenseType?
Minified license type for alert serialization.
196 197 198 199 200 |
# File 'lib/orb/models/customer_credit_balance_recovered_webhook_event.rb', line 196 optional :license_type, -> { Orb::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::LicenseType }, nil?: true |
#metric ⇒ Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::Metric?
The metric the alert applies to.
134 135 136 137 138 |
# File 'lib/orb/models/customer_credit_balance_recovered_webhook_event.rb', line 134 required :metric, -> { Orb::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::Metric }, nil?: true |
#plan ⇒ Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::Plan?
The plan the alert applies to.
144 145 146 147 148 |
# File 'lib/orb/models/customer_credit_balance_recovered_webhook_event.rb', line 144 required :plan, -> { Orb::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::Plan }, nil?: true |
#price_filters ⇒ Array<Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::PriceFilter>?
Filters scoping which prices are included in spend and grouped cost alert evaluation. Alerts use the price_id, item_id, and price_type fields only; the alert's pricing unit is reported by currency.
208 209 210 211 212 |
# File 'lib/orb/models/customer_credit_balance_recovered_webhook_event.rb', line 208 optional :price_filters, -> { Orb::Internal::Type::ArrayOf[Orb::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::PriceFilter] }, nil?: true |
#subscription ⇒ Orb::Models::SubscriptionMinified?
The subscription the alert applies to.
154 |
# File 'lib/orb/models/customer_credit_balance_recovered_webhook_event.rb', line 154 required :subscription, -> { Orb::SubscriptionMinified }, nil?: true |
#threshold_overrides ⇒ Array<Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::ThresholdOverride>?
Per-group threshold overrides. Each override maps a specific combination of grouping_keys values to a replacement threshold list. Only present for grouped cost alerts that have at least one override.
220 221 222 223 224 |
# File 'lib/orb/models/customer_credit_balance_recovered_webhook_event.rb', line 220 optional :threshold_overrides, -> { Orb::Internal::Type::ArrayOf[Orb::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::ThresholdOverride] }, nil?: true |
#thresholds ⇒ Array<Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::Threshold>?
The thresholds that define the conditions under which the alert will be triggered.
161 162 163 164 165 |
# File 'lib/orb/models/customer_credit_balance_recovered_webhook_event.rb', line 161 required :thresholds, -> { Orb::Internal::Type::ArrayOf[Orb::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::Threshold] }, nil?: true |
#type ⇒ Symbol, Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::Type
The type of alert. This must be a valid alert type.
171 172 |
# File 'lib/orb/models/customer_credit_balance_recovered_webhook_event.rb', line 171 required :type, enum: -> { Orb::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/customer_credit_balance_recovered_webhook_event.rb', line 355
|
Instance Method Details
#to_hash ⇒ {
128 |
# File 'sig/orb/models/customer_credit_balance_recovered_webhook_event.rbs', line 128
def to_hash: -> {
|