Class: Orb::Models::CustomerEditedWebhookEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/customer_edited_webhook_event.rb,
sig/orb/models/customer_edited_webhook_event.rbs

Defined Under Namespace

Modules: Type Classes: Properties

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(auto_collection: nil, billing_address: nil, default_payment_method_id: nil, email: nil, email_delivery: nil, external_customer_id: nil, metadata: nil, name: nil, payment_provider: nil, payment_provider_id: nil, shipping_address: nil, tax_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::CustomerEditedWebhookEvent::Properties::PreviousAttributes for more details.

metadata values are non-null on the wire (deleting a key removes it from storage); the Optional values only exist on the new half of a metadata FieldChange.

Parameters:

  • auto_collection (Boolean, nil) (defaults to: nil)
  • billing_address (Orb::Models::Address, nil) (defaults to: nil)
  • default_payment_method_id (String, nil) (defaults to: nil)
  • email (String, nil) (defaults to: nil)
  • email_delivery (Boolean, nil) (defaults to: nil)
  • external_customer_id (String, nil) (defaults to: nil)
  • metadata (Hash{Symbol=>String}, nil) (defaults to: nil)
  • name (String, nil) (defaults to: nil)
  • payment_provider (String, nil) (defaults to: nil)
  • payment_provider_id (String, nil) (defaults to: nil)
  • shipping_address (Orb::Models::Address, nil) (defaults to: nil)
  • tax_id (Orb::Models::CustomerTaxID, nil) (defaults to: nil) —

    Tax IDs are commonly required to be displayed on customer invoices, which are ad



# File 'lib/orb/models/customer_edited_webhook_event.rb', line 52

Instance Attribute Details

#created_at ⇒ Time

The time at which this event was created, to the second.

Parameters:

  • value (Time)

Returns:

  • (Time)


16
# File 'lib/orb/models/customer_edited_webhook_event.rb', line 16

required :created_at, Time

#customer ⇒ Orb::Models::Customer

A customer is a buyer of your products, and the other party to the billing relationship.

In Orb, customers are assigned system generated identifiers automatically, but it's often desirable to have these match existing identifiers in your system. To avoid having to denormalize Orb ID information, you can pass in an external_customer_id with your own identifier. See Customer ID Aliases for further information about how these aliases work in Orb.

In addition to having an identifier in your system, a customer may exist in a payment provider solution like Stripe. Use the payment_provider_id and the payment_provider enum field to express this mapping.

A customer also has a timezone (from the standard IANA timezone database), which defaults to your account's timezone. See Timezone localization for information on what this timezone parameter influences within Orb.

Parameters:

Returns:



39
# File 'lib/orb/models/customer_edited_webhook_event.rb', line 39

required :customer, -> { Orb::Customer }

#id ⇒ String

The ID of this webhook event.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/orb/models/customer_edited_webhook_event.rb', line 10

required :id, String

#properties ⇒ Orb::Models::CustomerEditedWebhookEvent::Properties

Parameters:

  • value (Orb::CustomerEditedWebhookEvent::Properties)

Returns:



44
# File 'lib/orb/models/customer_edited_webhook_event.rb', line 44

required :properties, -> { Orb::CustomerEditedWebhookEvent::Properties }

#type ⇒ Symbol, Orb::Models::CustomerEditedWebhookEvent::Type

The event this payload describes.

Parameters:

  • value (Orb::Models::CustomerEditedWebhookEvent::type_)

Returns:



50
# File 'lib/orb/models/customer_edited_webhook_event.rb', line 50

required :type, enum: -> { Orb::CustomerEditedWebhookEvent::Type }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


31
# File 'sig/orb/models/customer_edited_webhook_event.rbs', line 31

def to_hash: -> {