Module: Orb::Models::CustomerUpdateByExternalIDParams::PaymentProvider

Extended by:
Internal::Type::Enum
Defined in:
lib/orb/models/customer_update_by_external_id_params.rb,
sig/orb/models/customer_update_by_external_id_params.rbs

Overview

This is used for creating charges or invoices in an external system via Orb. When not in test mode:

  • the connection must first be configured in the Orb webapp.
  • if the provider is an invoicing provider (stripe_invoice, quickbooks, bill.com, netsuite), any product mappings must first be configured with the Orb team.

Constant Summary collapse

QUICKBOOKS =

Returns:

  • (:quickbooks)
:quickbooks
BILL_COM =

Returns:

  • (:"bill.com")
:"bill.com"
STRIPE_CHARGE =

Returns:

  • (:stripe_charge)
:stripe_charge
STRIPE_INVOICE =

Returns:

  • (:stripe_invoice)
:stripe_invoice
NETSUITE =

Returns:

  • (:netsuite)
:netsuite
ADYEN =

Returns:

  • (:adyen)
:adyen

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Orb::Models::CustomerUpdateByExternalIDParams::payment_provider]

Returns:

  • (::Array[Orb::Models::CustomerUpdateByExternalIDParams::payment_provider])


205
# File 'sig/orb/models/customer_update_by_external_id_params.rbs', line 205

def self?.values: -> ::Array[Orb::Models::CustomerUpdateByExternalIDParams::payment_provider]