Module: Orb::Models::CustomerUpdateByExternalIDParams::TaxConfiguration
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/orb/models/customer_update_by_external_id_params.rb,
sig/orb/models/customer_update_by_external_id_params.rbs
Defined Under Namespace
Classes: Anrok, Numeral, Stripe
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(tax_exempt:, automatic_tax_enabled: nil, tax_provider: :anrok) ⇒ Object
Some parameter documentations has been truncated, see Anrok for more details.
- #self?.variants ⇒ ::Array[Orb::Models::CustomerUpdateByExternalIDParams::tax_configuration]
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(Orb::Models::NewAvalaraTaxConfiguration, Orb::Models::NewTaxJarConfiguration, Orb::Models::NewSphereConfiguration, Orb::Models::CustomerUpdateByExternalIDParams::TaxConfiguration::Numeral, Orb::Models::CustomerUpdateByExternalIDParams::TaxConfiguration::Anrok, Orb::Models::CustomerUpdateByExternalIDParams::TaxConfiguration::Stripe)
|
|
# File 'lib/orb/models/customer_update_by_external_id_params.rb', line 550
|
Instance Method Details
#initialize(tax_exempt:, automatic_tax_enabled: nil, tax_provider: :anrok) ⇒ Object
Some parameter documentations has been truncated, see Anrok for more details.
|
|
# File 'lib/orb/models/customer_update_by_external_id_params.rb', line 478
|
#self?.variants ⇒ ::Array[Orb::Models::CustomerUpdateByExternalIDParams::tax_configuration]
300 |
# File 'sig/orb/models/customer_update_by_external_id_params.rbs', line 300
def self?.variants: -> ::Array[Orb::Models::CustomerUpdateByExternalIDParams::tax_configuration]
|