Class: Orb::Models::CustomerUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::CustomerUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/orb/models/customer_update_params.rb,
sig/orb/models/customer_update_params.rbs
Overview
Defined Under Namespace
Modules: PaymentProvider, TaxConfiguration Classes: PaymentConfiguration
Constant Summary collapse
- Orb =
Instance Attribute Summary collapse
- #accounting_sync_configuration ⇒ Orb::Models::NewAccountingSyncConfiguration?
-
#additional_emails ⇒ Array<String>?
Additional email addresses for this customer.
-
#auto_collection ⇒ Boolean?
Used to determine if invoices for this customer will automatically attempt to charge a saved payment method, if available.
-
#auto_issuance ⇒ Boolean?
Used to determine if invoices for this customer will be automatically issued.
- #billing_address ⇒ Orb::Models::AddressInput?
-
#currency ⇒ String?
An ISO 4217 currency string used for the customer's invoices and balance.
- #customer_id ⇒ String
-
#default_payment_method_id ⇒ String?
The Orb ID of the payment method to set as this customer's default.
-
#email ⇒ String?
A valid customer email, to be used for invoicing and notifications.
- #email_delivery ⇒ Boolean?
-
#external_customer_id ⇒ String?
The external customer ID.
-
#hierarchy ⇒ Orb::Models::CustomerHierarchyConfig?
The hierarchical relationships for this customer.
-
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource.
-
#name ⇒ String?
The full name of the customer.
-
#payment_configuration ⇒ Orb::Models::CustomerUpdateParams::PaymentConfiguration?
Payment configuration for the customer, applicable when using Orb Invoicing with a supported payment provider such as Stripe.
-
#payment_provider ⇒ Symbol, ...
This is used for creating charges or invoices in an external system via Orb.
-
#payment_provider_id ⇒ String?
The ID of this customer in an external payments solution, such as Stripe.
- #reporting_configuration ⇒ Orb::Models::NewReportingConfiguration?
- #shipping_address ⇒ Orb::Models::AddressInput?
- #tax_configuration ⇒ Orb::Models::NewAvalaraTaxConfiguration, ...
-
#tax_id ⇒ Orb::Models::CustomerTaxID?
Tax IDs are commonly required to be displayed on customer invoices, which are added to the headers of invoices.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
75 |
# File 'sig/orb/models/customer_update_params.rbs', line 75
def initialize: (
|
Instance Attribute Details
#accounting_sync_configuration ⇒ Orb::Models::NewAccountingSyncConfiguration?
18 |
# File 'lib/orb/models/customer_update_params.rb', line 18 optional :accounting_sync_configuration, -> { Orb::NewAccountingSyncConfiguration }, nil?: true |
#additional_emails ⇒ Array<String>?
Additional email addresses for this customer. If populated, these email addresses will be CC'd for customer communications. The total number of email addresses (including the primary email) cannot exceed 50.
26 |
# File 'lib/orb/models/customer_update_params.rb', line 26 optional :additional_emails, Orb::Internal::Type::ArrayOf[String], nil?: true |
#auto_collection ⇒ Boolean?
Used to determine if invoices for this customer will automatically attempt to
charge a saved payment method, if available. This parameter defaults to True
when a payment provider is provided on customer creation.
34 |
# File 'lib/orb/models/customer_update_params.rb', line 34 optional :auto_collection, Orb::Internal::Type::Boolean, nil?: true |
#auto_issuance ⇒ Boolean?
Used to determine if invoices for this customer will be automatically issued. If
true, invoices will be automatically issued. If false, invoices will require
manual approval.If null is specified, the customer's auto issuance setting
will be inherited from the account-level setting.
43 |
# File 'lib/orb/models/customer_update_params.rb', line 43 optional :auto_issuance, Orb::Internal::Type::Boolean, nil?: true |
#billing_address ⇒ Orb::Models::AddressInput?
48 |
# File 'lib/orb/models/customer_update_params.rb', line 48 optional :billing_address, -> { Orb::AddressInput }, nil?: true |
#currency ⇒ String?
An ISO 4217 currency string used for the customer's invoices and balance. This can only be set if the customer does not already have a currency configured. If not set at creation or update time, it will be set at subscription creation time.
57 |
# File 'lib/orb/models/customer_update_params.rb', line 57 optional :currency, String, nil?: true |
#customer_id ⇒ String
13 |
# File 'lib/orb/models/customer_update_params.rb', line 13 required :customer_id, String |
#default_payment_method_id ⇒ String?
The Orb ID of the payment method to set as this customer's default. Pass null
to clear the customer's default payment method.
64 |
# File 'lib/orb/models/customer_update_params.rb', line 64 optional :default_payment_method_id, String, nil?: true |
#email ⇒ String?
A valid customer email, to be used for invoicing and notifications.
70 |
# File 'lib/orb/models/customer_update_params.rb', line 70 optional :email, String, nil?: true |
#email_delivery ⇒ Boolean?
75 |
# File 'lib/orb/models/customer_update_params.rb', line 75 optional :email_delivery, Orb::Internal::Type::Boolean, nil?: true |
#external_customer_id ⇒ String?
The external customer ID. This can only be set if the customer has no existing external customer ID. Since this action may change usage quantities for all existing subscriptions, it is disallowed if the customer has issued invoices with usage line items and subject to the same restrictions as backdated subscription creation.
85 |
# File 'lib/orb/models/customer_update_params.rb', line 85 optional :external_customer_id, String, nil?: true |
#hierarchy ⇒ Orb::Models::CustomerHierarchyConfig?
The hierarchical relationships for this customer.
91 |
# File 'lib/orb/models/customer_update_params.rb', line 91 optional :hierarchy, -> { Orb::CustomerHierarchyConfig }, nil?: true |
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource. Individual keys can be removed
by setting the value to null, and the entire metadata mapping can be cleared
by setting metadata to null.
99 |
# File 'lib/orb/models/customer_update_params.rb', line 99 optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true |
#name ⇒ String?
The full name of the customer
105 |
# File 'lib/orb/models/customer_update_params.rb', line 105 optional :name, String, nil?: true |
#payment_configuration ⇒ Orb::Models::CustomerUpdateParams::PaymentConfiguration?
Payment configuration for the customer, applicable when using Orb Invoicing with a supported payment provider such as Stripe.
112 |
# File 'lib/orb/models/customer_update_params.rb', line 112 optional :payment_configuration, -> { Orb::CustomerUpdateParams::PaymentConfiguration }, nil?: true |
#payment_provider ⇒ Symbol, ...
This is used for creating charges or invoices in an external system via Orb. When not in test mode:
- the connection must first be configured in the Orb webapp.
- if the provider is an invoicing provider (
stripe_invoice,quickbooks,bill.com,netsuite), any product mappings must first be configured with the Orb team.
124 |
# File 'lib/orb/models/customer_update_params.rb', line 124 optional :payment_provider, enum: -> { Orb::CustomerUpdateParams::PaymentProvider }, nil?: true |
#payment_provider_id ⇒ String?
The ID of this customer in an external payments solution, such as Stripe. This is used for creating charges or invoices in the external system via Orb.
131 |
# File 'lib/orb/models/customer_update_params.rb', line 131 optional :payment_provider_id, String, nil?: true |
#reporting_configuration ⇒ Orb::Models::NewReportingConfiguration?
136 |
# File 'lib/orb/models/customer_update_params.rb', line 136 optional :reporting_configuration, -> { Orb::NewReportingConfiguration }, nil?: true |
#shipping_address ⇒ Orb::Models::AddressInput?
141 |
# File 'lib/orb/models/customer_update_params.rb', line 141 optional :shipping_address, -> { Orb::AddressInput }, nil?: true |
#tax_configuration ⇒ Orb::Models::NewAvalaraTaxConfiguration, ...
146 |
# File 'lib/orb/models/customer_update_params.rb', line 146 optional :tax_configuration, union: -> { Orb::CustomerUpdateParams::TaxConfiguration }, nil?: true |
#tax_id ⇒ Orb::Models::CustomerTaxID?
Tax IDs are commonly required to be displayed on customer invoices, which are added to the headers of invoices.
Supported Tax ID Countries and Types
| Country | Type | Description |
|---|---|---|
| Albania | al_tin |
Albania Tax Identification Number |
| Andorra | ad_nrt |
Andorran NRT Number |
| Angola | ao_tin |
Angola Tax Identification Number |
| Argentina | ar_cuit |
Argentinian Tax ID Number |
| Armenia | am_tin |
Armenia Tax Identification Number |
| Aruba | aw_tin |
Aruba Tax Identification Number |
| Australia | au_abn |
Australian Business Number (AU ABN) |
| Australia | au_arn |
Australian Taxation Office Reference Number |
| Austria | eu_vat |
European VAT Number |
| Azerbaijan | az_tin |
Azerbaijan Tax Identification Number |
| Bahamas | bs_tin |
Bahamas Tax Identification Number |
| Bahrain | bh_vat |
Bahraini VAT Number |
| Bangladesh | bd_bin |
Bangladesh Business Identification Number |
| Barbados | bb_tin |
Barbados Tax Identification Number |
| Belarus | by_tin |
Belarus TIN Number |
| Belgium | eu_vat |
European VAT Number |
| Benin | bj_ifu |
Benin Tax Identification Number (Identifiant Fiscal Unique) |
| Bolivia | bo_tin |
Bolivian Tax ID |
| Bosnia and Herzegovina | ba_tin |
Bosnia and Herzegovina Tax Identification Number |
| Brazil | br_cnpj |
Brazilian CNPJ Number |
| Brazil | br_cpf |
Brazilian CPF Number |
| Bulgaria | bg_uic |
Bulgaria Unified Identification Code |
| Bulgaria | eu_vat |
European VAT Number |
| Burkina Faso | bf_ifu |
Burkina Faso Tax Identification Number (Numéro d'Identifiant Fiscal Unique) |
| Cambodia | kh_tin |
Cambodia Tax Identification Number |
| Cameroon | cm_niu |
Cameroon Tax Identification Number (Numéro d'Identifiant fiscal Unique) |
| Canada | ca_bn |
Canadian BN |
| Canada | ca_gst_hst |
Canadian GST/HST Number |
| Canada | ca_pst_bc |
Canadian PST Number (British Columbia) |
| Canada | ca_pst_mb |
Canadian PST Number (Manitoba) |
| Canada | ca_pst_sk |
Canadian PST Number (Saskatchewan) |
| Canada | ca_qst |
Canadian QST Number (Québec) |
| Cape Verde | cv_nif |
Cape Verde Tax Identification Number (Número de Identificação Fiscal) |
| Chile | cl_tin |
Chilean TIN |
| China | cn_tin |
Chinese Tax ID |
| Colombia | co_nit |
Colombian NIT Number |
| Congo-Kinshasa | cd_nif |
Congo (DR) Tax Identification Number (Número de Identificação Fiscal) |
| Costa Rica | cr_tin |
Costa Rican Tax ID |
| Croatia | eu_vat |
European VAT Number |
| Croatia | hr_oib |
Croatian Personal Identification Number (OIB) |
| Cyprus | eu_vat |
European VAT Number |
| Czech Republic | eu_vat |
European VAT Number |
| Denmark | eu_vat |
European VAT Number |
| Dominican Republic | do_rcn |
Dominican RCN Number |
| Ecuador | ec_ruc |
Ecuadorian RUC Number |
| Egypt | eg_tin |
Egyptian Tax Identification Number |
| El Salvador | sv_nit |
El Salvadorian NIT Number |
| Estonia | eu_vat |
European VAT Number |
| Ethiopia | et_tin |
Ethiopia Tax Identification Number |
| European Union | eu_oss_vat |
European One Stop Shop VAT Number for non-Union scheme |
| Faroe Islands | fo_vat |
Faroe Islands VAT Number |
| Finland | eu_vat |
European VAT Number |
| France | eu_vat |
European VAT Number |
| Georgia | ge_vat |
Georgian VAT |
| Germany | de_stn |
German Tax Number (Steuernummer) |
| Germany | eu_vat |
European VAT Number |
| Gibraltar | gi_tin |
Gibraltar Tax Identification Number |
| Greece | eu_vat |
European VAT Number |
| Guinea | gn_nif |
Guinea Tax Identification Number (Número de Identificação Fiscal) |
| Hong Kong | hk_br |
Hong Kong BR Number |
| Hungary | eu_vat |
European VAT Number |
| Hungary | hu_tin |
Hungary Tax Number (adószám) |
| Iceland | is_vat |
Icelandic VAT |
| India | in_gst |
Indian GST Number |
| Indonesia | id_npwp |
Indonesian NPWP Number |
| Ireland | eu_vat |
European VAT Number |
| Israel | il_vat |
Israel VAT |
| Italy | eu_vat |
European VAT Number |
| Italy | it_cf |
Italian Codice Fiscale Number |
| Japan | jp_cn |
Japanese Corporate Number (Hōjin Bangō) |
| Japan | jp_rn |
Japanese Registered Foreign Businesses' Registration Number (Tōroku Kokugai Jigyōsha no Tōroku Bangō) |
| Japan | jp_trn |
Japanese Tax Registration Number (Tōroku Bangō) |
| Kazakhstan | kz_bin |
Kazakhstani Business Identification Number |
| Kenya | ke_pin |
Kenya Revenue Authority Personal Identification Number |
| Kyrgyzstan | kg_tin |
Kyrgyzstan Tax Identification Number |
| Laos | la_tin |
Laos Tax Identification Number |
| Latvia | eu_vat |
European VAT Number |
| Liechtenstein | li_uid |
Liechtensteinian UID Number |
| Liechtenstein | li_vat |
Liechtenstein VAT Number |
| Lithuania | eu_vat |
European VAT Number |
| Luxembourg | eu_vat |
European VAT Number |
| Malaysia | my_frp |
Malaysian FRP Number |
| Malaysia | my_itn |
Malaysian ITN |
| Malaysia | my_sst |
Malaysian SST Number |
| Malta | eu_vat |
European VAT Number |
| Mauritania | mr_nif |
Mauritania Tax Identification Number (Número de Identificação Fiscal) |
| Mexico | mx_rfc |
Mexican RFC Number |
| Moldova | md_vat |
Moldova VAT Number |
| Montenegro | me_pib |
Montenegro PIB Number |
| Morocco | ma_vat |
Morocco VAT Number |
| Nepal | np_pan |
Nepal PAN Number |
| Netherlands | eu_vat |
European VAT Number |
| New Zealand | nz_gst |
New Zealand GST Number |
| Nigeria | ng_tin |
Nigerian Tax Identification Number |
| North Macedonia | mk_vat |
North Macedonia VAT Number |
| Northern Ireland | eu_vat |
Northern Ireland VAT Number |
| Norway | no_vat |
Norwegian VAT Number |
| Norway | no_voec |
Norwegian VAT on e-commerce Number |
| Oman | om_vat |
Omani VAT Number |
| Paraguay | py_ruc |
Paraguayan RUC Number |
| Peru | pe_ruc |
Peruvian RUC Number |
| Philippines | ph_tin |
Philippines Tax Identification Number |
| Poland | eu_vat |
European VAT Number |
| Poland | pl_nip |
Polish Tax ID Number |
| Portugal | eu_vat |
European VAT Number |
| Romania | eu_vat |
European VAT Number |
| Romania | ro_tin |
Romanian Tax ID Number |
| Russia | ru_inn |
Russian INN |
| Russia | ru_kpp |
Russian KPP |
| Saudi Arabia | sa_vat |
Saudi Arabia VAT |
| Senegal | sn_ninea |
Senegal NINEA Number |
| Serbia | rs_pib |
Serbian PIB Number |
| Singapore | sg_gst |
Singaporean GST |
| Singapore | sg_uen |
Singaporean UEN |
| Slovakia | eu_vat |
European VAT Number |
| Slovenia | eu_vat |
European VAT Number |
| Slovenia | si_tin |
Slovenia Tax Number (davčna številka) |
| South Africa | za_vat |
South African VAT Number |
| South Korea | kr_brn |
Korean BRN |
| Spain | es_cif |
Spanish NIF Number (previously Spanish CIF Number) |
| Spain | eu_vat |
European VAT Number |
| Sri Lanka | lk_vat |
Sri Lanka VAT Number |
| Suriname | sr_fin |
Suriname FIN Number |
| Sweden | eu_vat |
European VAT Number |
| Switzerland | ch_uid |
Switzerland UID Number |
| Switzerland | ch_vat |
Switzerland VAT Number |
| Taiwan | tw_vat |
Taiwanese VAT |
| Tajikistan | tj_tin |
Tajikistan Tax Identification Number |
| Tanzania | tz_vat |
Tanzania VAT Number |
| Thailand | th_vat |
Thai VAT |
| Turkey | tr_tin |
Turkish Tax Identification Number |
| Uganda | ug_tin |
Uganda Tax Identification Number |
| Ukraine | ua_vat |
Ukrainian VAT |
| United Arab Emirates | ae_trn |
United Arab Emirates TRN |
| United Kingdom | gb_vat |
United Kingdom VAT Number |
| United States | us_ein |
United States EIN |
| Uruguay | uy_ruc |
Uruguayan RUC Number |
| Uzbekistan | uz_tin |
Uzbekistan TIN Number |
| Uzbekistan | uz_vat |
Uzbekistan VAT Number |
| Venezuela | ve_rif |
Venezuelan RIF Number |
| Vietnam | vn_tin |
Vietnamese Tax ID Number |
| Zambia | zm_tin |
Zambia Tax Identification Number |
| Zimbabwe | zw_tin |
Zimbabwe Tax Identification Number |
301 |
# File 'lib/orb/models/customer_update_params.rb', line 301 optional :tax_id, -> { Orb::CustomerTaxID }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/customer_update_params.rb', line 410
|
Instance Method Details
#to_hash ⇒ {
100 |
# File 'sig/orb/models/customer_update_params.rbs', line 100
def to_hash: -> {
|