Class: Orb::Models::CustomerUpdateParams::PaymentConfiguration

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/customer_update_params.rb,
sig/orb/models/customer_update_params.rbs

Defined Under Namespace

Classes: PaymentProvider

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(customer_id:, accounting_sync_configuration: nil, additional_emails: nil, auto_collection: nil, auto_issuance: nil, billing_address: nil, currency: nil, default_payment_method_id: nil, email: nil, email_delivery: nil, external_customer_id: nil, hierarchy: nil, metadata: nil, name: nil, payment_configuration: nil, payment_provider: nil, payment_provider_id: nil, reporting_configuration: nil, shipping_address: nil, tax_configuration: nil, tax_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::CustomerUpdateParams for more details.

Parameters:



351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
# File 'lib/orb/models/customer_update_params.rb', line 351

class PaymentConfiguration < Orb::Internal::Type::BaseModel
  # @!attribute payment_providers
  #   Provider-specific payment configuration.
  #
  #   @return [Array<Orb::Models::CustomerUpdateParams::PaymentConfiguration::PaymentProvider>, nil]
  optional :payment_providers,
           -> { Orb::Internal::Type::ArrayOf[Orb::CustomerUpdateParams::PaymentConfiguration::PaymentProvider] }

  # @!method initialize(payment_providers: nil)
  #   Payment configuration for the customer, applicable when using Orb Invoicing with
  #   a supported payment provider such as Stripe.
  #
  #   @param payment_providers [Array<Orb::Models::CustomerUpdateParams::PaymentConfiguration::PaymentProvider>] Provider-specific payment configuration.

  class PaymentProvider < Orb::Internal::Type::BaseModel
    # @!attribute provider_type
    #   The payment provider to configure.
    #
    #   @return [Symbol, Orb::Models::CustomerUpdateParams::PaymentConfiguration::PaymentProvider::ProviderType]
    required :provider_type,
             enum: -> { Orb::CustomerUpdateParams::PaymentConfiguration::PaymentProvider::ProviderType }

    # @!attribute default_shared_payment_token
    #   The ID of a shared payment token granted by an agent to use as the default
    #   payment instrument for this customer. When set, auto-collection will use this
    #   token instead of the customer's default payment method.
    #
    #   @return [String, nil]
    optional :default_shared_payment_token, String, nil?: true

    # @!attribute excluded_payment_method_types
    #   List of Stripe payment method types to exclude for this customer. Excluded
    #   payment methods will not be available for the customer to select during payment,
    #   and will not be used for auto-collection. If a customer's default payment method
    #   becomes excluded, Orb will attempt to use the next available compatible payment
    #   method for auto-collection.
    #
    #   @return [Array<String>, nil]
    optional :excluded_payment_method_types, Orb::Internal::Type::ArrayOf[String]

    # @!method initialize(provider_type:, default_shared_payment_token: nil, excluded_payment_method_types: nil)
    #   Some parameter documentations has been truncated, see
    #   {Orb::Models::CustomerUpdateParams::PaymentConfiguration::PaymentProvider} for
    #   more details.
    #
    #   @param provider_type [Symbol, Orb::Models::CustomerUpdateParams::PaymentConfiguration::PaymentProvider::ProviderType] The payment provider to configure.
    #
    #   @param default_shared_payment_token [String, nil] The ID of a shared payment token granted by an agent to use as the default payme
    #
    #   @param excluded_payment_method_types [Array<String>] List of Stripe payment method types to exclude for this customer. Excluded payme

    # The payment provider to configure.
    #
    # @see Orb::Models::CustomerUpdateParams::PaymentConfiguration::PaymentProvider#provider_type
    module ProviderType
      extend Orb::Internal::Type::Enum

      STRIPE = :stripe

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end
end

Instance Attribute Details

#payment_providersArray<Orb::Models::CustomerUpdateParams::PaymentConfiguration::PaymentProvider>?

Provider-specific payment configuration.



356
357
# File 'lib/orb/models/customer_update_params.rb', line 356

optional :payment_providers,
-> { Orb::Internal::Type::ArrayOf[Orb::CustomerUpdateParams::PaymentConfiguration::PaymentProvider] }

Instance Method Details

#to_hash{

Returns:

  • ({)


141
# File 'sig/orb/models/customer_update_params.rbs', line 141

def to_hash: -> {