Class: Orb::Models::Customers::BalanceTransactionCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Customers::BalanceTransactionCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/orb/models/customers/balance_transaction_create_params.rb,
sig/orb/models/customers/balance_transaction_create_params.rbs
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
- #amount ⇒ String
- #customer_id ⇒ String
-
#description ⇒ String?
An optional description that can be specified around this entry.
- #type ⇒ Symbol, Orb::Models::Customers::BalanceTransactionCreateParams::Type
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
25 |
# File 'sig/orb/models/customers/balance_transaction_create_params.rbs', line 25
def initialize: (
|
Instance Attribute Details
#amount ⇒ String
19 |
# File 'lib/orb/models/customers/balance_transaction_create_params.rb', line 19 required :amount, String |
#customer_id ⇒ String
14 |
# File 'lib/orb/models/customers/balance_transaction_create_params.rb', line 14 required :customer_id, String |
#description ⇒ String?
An optional description that can be specified around this entry.
30 |
# File 'lib/orb/models/customers/balance_transaction_create_params.rb', line 30 optional :description, String, nil?: true |
#type ⇒ Symbol, Orb::Models::Customers::BalanceTransactionCreateParams::Type
24 |
# File 'lib/orb/models/customers/balance_transaction_create_params.rb', line 24 required :type, enum: -> { Orb::Customers::BalanceTransactionCreateParams::Type } |
Instance Method Details
#to_hash ⇒ {
33 |
# File 'sig/orb/models/customers/balance_transaction_create_params.rbs', line 33
def to_hash: -> {
|