Class: Orb::Models::Customers::CostListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Customers::CostListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/orb/models/customers/cost_list_params.rb,
sig/orb/models/customers/cost_list_params.rbs
Overview
Defined Under Namespace
Modules: ViewMode
Instance Attribute Summary collapse
-
#currency ⇒ String?
The currency or custom pricing unit to use.
- #customer_id ⇒ String
-
#timeframe_end ⇒ Time?
Costs returned are exclusive of
timeframe_end. -
#timeframe_start ⇒ Time?
Costs returned are inclusive of
timeframe_start. -
#view_mode ⇒ Symbol, ...
Controls whether Orb returns cumulative costs since the start of the billing period, or incremental day-by-day costs.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(customer_id:, currency: nil, timeframe_end: nil, timeframe_start: nil, view_mode: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CostListParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(customer_id:, currency: nil, timeframe_end: nil, timeframe_start: nil, view_mode: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::Customers::CostListParams for more details.
|
|
# File 'lib/orb/models/customers/cost_list_params.rb', line 43
|
Instance Attribute Details
#currency ⇒ String?
The currency or custom pricing unit to use.
20 |
# File 'lib/orb/models/customers/cost_list_params.rb', line 20 optional :currency, String, nil?: true |
#customer_id ⇒ String
14 |
# File 'lib/orb/models/customers/cost_list_params.rb', line 14 required :customer_id, String |
#timeframe_end ⇒ Time?
Costs returned are exclusive of timeframe_end.
26 |
# File 'lib/orb/models/customers/cost_list_params.rb', line 26 optional :timeframe_end, Time, nil?: true |
#timeframe_start ⇒ Time?
Costs returned are inclusive of timeframe_start.
32 |
# File 'lib/orb/models/customers/cost_list_params.rb', line 32 optional :timeframe_start, Time, nil?: true |
#view_mode ⇒ Symbol, ...
Controls whether Orb returns cumulative costs since the start of the billing period, or incremental day-by-day costs. If your customer has minimums or discounts, it's strongly recommended that you use the default cumulative behavior.
41 |
# File 'lib/orb/models/customers/cost_list_params.rb', line 41 optional :view_mode, enum: -> { Orb::Customers::CostListParams::ViewMode }, nil?: true |
Instance Method Details
#to_hash ⇒ {
37 |
# File 'sig/orb/models/customers/cost_list_params.rbs', line 37
def to_hash: -> {
|