Module: Orb::Models::Customers::CostListParams::ViewMode

Extended by:
Internal::Type::Enum
Defined in:
lib/orb/models/customers/cost_list_params.rb,
sig/orb/models/customers/cost_list_params.rbs

Overview

Controls whether Orb returns cumulative costs since the start of the billing period, or incremental day-by-day costs. If your customer has minimums or discounts, it's strongly recommended that you use the default cumulative behavior.

Constant Summary collapse

PERIODIC =

Returns:

  • (:periodic)
:periodic
CUMULATIVE =

Returns:

  • (:cumulative)
:cumulative

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/orb/models/customers/cost_list_params.rb', line 69

Instance Method Details

#self?.values::Array[Orb::Models::Customers::CostListParams::view_mode]

Returns:

  • (::Array[Orb::Models::Customers::CostListParams::view_mode])


54
# File 'sig/orb/models/customers/cost_list_params.rbs', line 54

def self?.values: -> ::Array[Orb::Models::Customers::CostListParams::view_mode]