Class: Orb::Models::Customers::CreditListByExternalIDResponse::CreditCommitment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/customers/credit_list_by_external_id_response.rb,
sig/orb/models/customers/credit_list_by_external_id_response.rbs

Overview

See Also:

  • Orb::Models::Customers::CreditListByExternalIDResponse#credit_commitment

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, subscription_id: nil) ⇒ CreditCommitment

The subscription commitment whose true-up rolled forward into this credit block. Present only when credit_block_source is commitment.

Parameters:

  • id (String)

    The ID of the subscription commitment this block was rolled forward from.

  • subscription_id (String, nil) (defaults to: nil)

    The subscription the commitment belongs to.

  • id: (String)
  • subscription_id: (String, nil) (defaults to: nil)


# File 'lib/orb/models/customers/credit_list_by_external_id_response.rb', line 327

Instance Attribute Details

#idString

The ID of the subscription commitment this block was rolled forward from.

Parameters:

  • value (String)

Returns:

  • (String)


319
# File 'lib/orb/models/customers/credit_list_by_external_id_response.rb', line 319

required :id, String

#subscription_idString?

The subscription the commitment belongs to.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


325
# File 'lib/orb/models/customers/credit_list_by_external_id_response.rb', line 325

optional :subscription_id, String, nil?: true

Instance Method Details

#to_hash{ id: String, subscription_id: String? }

Returns:

  • ({ id: String, subscription_id: String? })


255
# File 'sig/orb/models/customers/credit_list_by_external_id_response.rbs', line 255

def to_hash: -> { id: String, subscription_id: String? }