Class: Orb::Models::Customers::CreditListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Customers::CreditListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/orb/models/customers/credit_list_params.rb,
sig/orb/models/customers/credit_list_params.rbs
Overview
Instance Attribute Summary collapse
-
#currency ⇒ String?
The ledger currency or custom pricing unit to use.
-
#cursor ⇒ String?
Cursor for pagination.
- #customer_id ⇒ String
- #effective_date_gt ⇒ Time?
- #effective_date_gte ⇒ Time?
- #effective_date_lt ⇒ Time?
- #effective_date_lte ⇒ Time?
-
#include_all_blocks ⇒ Boolean?
If set to True, all expired and depleted blocks, as well as active block will be returned.
-
#limit ⇒ Integer?
The number of items to fetch.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(customer_id:, currency: nil, cursor: nil, effective_date_gt: nil, effective_date_gte: nil, effective_date_lt: nil, effective_date_lte: nil, include_all_blocks: nil, limit: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CreditListParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(customer_id:, currency: nil, cursor: nil, effective_date_gt: nil, effective_date_gte: nil, effective_date_lt: nil, effective_date_lte: nil, include_all_blocks: nil, limit: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::Customers::CreditListParams for more details.
|
|
# File 'lib/orb/models/customers/credit_list_params.rb', line 62
|
Instance Attribute Details
#currency ⇒ String?
The ledger currency or custom pricing unit to use.
20 |
# File 'lib/orb/models/customers/credit_list_params.rb', line 20 optional :currency, String, nil?: true |
#cursor ⇒ String?
Cursor for pagination. This can be populated by the next_cursor value returned
from the initial request.
27 |
# File 'lib/orb/models/customers/credit_list_params.rb', line 27 optional :cursor, String, nil?: true |
#customer_id ⇒ String
14 |
# File 'lib/orb/models/customers/credit_list_params.rb', line 14 required :customer_id, String |
#effective_date_gt ⇒ Time?
32 |
# File 'lib/orb/models/customers/credit_list_params.rb', line 32 optional :effective_date_gt, Time, nil?: true |
#effective_date_gte ⇒ Time?
37 |
# File 'lib/orb/models/customers/credit_list_params.rb', line 37 optional :effective_date_gte, Time, nil?: true |
#effective_date_lt ⇒ Time?
42 |
# File 'lib/orb/models/customers/credit_list_params.rb', line 42 optional :effective_date_lt, Time, nil?: true |
#effective_date_lte ⇒ Time?
47 |
# File 'lib/orb/models/customers/credit_list_params.rb', line 47 optional :effective_date_lte, Time, nil?: true |
#include_all_blocks ⇒ Boolean?
If set to True, all expired and depleted blocks, as well as active block will be returned.
54 |
# File 'lib/orb/models/customers/credit_list_params.rb', line 54 optional :include_all_blocks, Orb::Internal::Type::Boolean |
#limit ⇒ Integer?
The number of items to fetch. Defaults to 20.
60 |
# File 'lib/orb/models/customers/credit_list_params.rb', line 60 optional :limit, Integer |
Instance Method Details
#to_hash ⇒ {
57 |
# File 'sig/orb/models/customers/credit_list_params.rbs', line 57
def to_hash: -> {
|