Class: Orb::Models::Customers::Credits::LedgerCreateEntryByExternalIDParams::Body::Amendment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Customers::Credits::LedgerCreateEntryByExternalIDParams::Body::Amendment
- Defined in:
- lib/orb/models/customers/credits/ledger_create_entry_by_external_id_params.rb,
sig/orb/models/customers/credits/ledger_create_entry_by_external_id_params.rbs
Instance Attribute Summary collapse
-
#amount ⇒ Float
The number of credits to effect.
-
#block_id ⇒ String
The ID of the block to reverse a decrement from.
-
#currency ⇒ String?
The currency or custom pricing unit to use for this ledger entry.
-
#description ⇒ String?
Optional metadata that can be specified when adding ledger results via the API.
- #entry_type ⇒ Symbol, :amendment
-
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource.
Instance Method Summary collapse
-
#initialize(amount:, block_id:, currency: nil, description: nil, metadata: nil, entry_type: :amendment) ⇒ Object
constructor
Some parameter documentations has been truncated, see Amendment for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, block_id:, currency: nil, description: nil, metadata: nil, entry_type: :amendment) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::Customers::Credits::LedgerCreateEntryByExternalIDParams::Body::Amendment for more details.
|
|
# File 'lib/orb/models/customers/credits/ledger_create_entry_by_external_id_params.rb', line 589
|
Instance Attribute Details
#amount ⇒ Float
The number of credits to effect. Note that this is required for increment, decrement or void operations.
553 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_by_external_id_params.rb', line 553 required :amount, Float |
#block_id ⇒ String
The ID of the block to reverse a decrement from.
559 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_by_external_id_params.rb', line 559 required :block_id, String |
#currency ⇒ String?
The currency or custom pricing unit to use for this ledger entry. If this is a real-world currency, it must match the customer's invoicing currency.
571 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_by_external_id_params.rb', line 571 optional :currency, String, nil?: true |
#description ⇒ String?
Optional metadata that can be specified when adding ledger results via the API. For example, this can be used to note an increment refers to trial credits, or for noting corrections as a result of an incident, etc.
579 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_by_external_id_params.rb', line 579 optional :description, String, nil?: true |
#entry_type ⇒ Symbol, :amendment
564 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_by_external_id_params.rb', line 564 required :entry_type, const: :amendment |
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource. Individual keys can be removed
by setting the value to null, and the entire metadata mapping can be cleared
by setting metadata to null.
587 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_by_external_id_params.rb', line 587 optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true |
Instance Method Details
#to_hash ⇒ {
402 |
# File 'sig/orb/models/customers/credits/ledger_create_entry_by_external_id_params.rbs', line 402
def to_hash: -> {
|