Class: Orb::Models::Customers::Credits::LedgerCreateEntryByExternalIDParams::Body::ExpirationChange

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/customers/credits/ledger_create_entry_by_external_id_params.rb,
sig/orb/models/customers/credits/ledger_create_entry_by_external_id_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



290
# File 'sig/orb/models/customers/credits/ledger_create_entry_by_external_id_params.rbs', line 290

def initialize: (

Instance Attribute Details

#amountFloat?

The number of credits to effect. Note that this is required for increment, decrement, void, or undo operations.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


403
# File 'lib/orb/models/customers/credits/ledger_create_entry_by_external_id_params.rb', line 403

optional :amount, Float, nil?: true

#block_idString?

The ID of the block affected by an expiration_change, used to differentiate between multiple blocks with the same expiry_date.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


410
# File 'lib/orb/models/customers/credits/ledger_create_entry_by_external_id_params.rb', line 410

optional :block_id, String, nil?: true

#currencyString?

The currency or custom pricing unit to use for this ledger entry. If this is a real-world currency, it must match the customer's invoicing currency.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


417
# File 'lib/orb/models/customers/credits/ledger_create_entry_by_external_id_params.rb', line 417

optional :currency, String, nil?: true

#descriptionString?

Optional metadata that can be specified when adding ledger results via the API. For example, this can be used to note an increment refers to trial credits, or for noting corrections as a result of an incident, etc.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


425
# File 'lib/orb/models/customers/credits/ledger_create_entry_by_external_id_params.rb', line 425

optional :description, String, nil?: true

#entry_typeSymbol, :expiration_change

Parameters:

  • value (:expiration_change)

Returns:

  • (Symbol, :expiration_change)


388
# File 'lib/orb/models/customers/credits/ledger_create_entry_by_external_id_params.rb', line 388

required :entry_type, const: :expiration_change

#expiry_dateTime?

An ISO 8601 format date that identifies the origination credit block to expire

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


431
# File 'lib/orb/models/customers/credits/ledger_create_entry_by_external_id_params.rb', line 431

optional :expiry_date, Time, nil?: true

#metadataHash{Symbol=>String, nil}?

User-specified key/value pairs for the resource. Individual keys can be removed by setting the value to null, and the entire metadata mapping can be cleared by setting metadata to null.

Parameters:

  • value (::Hash[Symbol, String?], nil)

Returns:

  • (Hash{Symbol=>String, nil}, nil)


439
# File 'lib/orb/models/customers/credits/ledger_create_entry_by_external_id_params.rb', line 439

optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true

#target_expiry_dateDate

A date (specified in YYYY-MM-DD format) used for expiration change, denoting when credits transferred (as part of a partial block expiration) should expire. This date must be on or after the effective date of the credit block.

Parameters:

  • value (Date)

Returns:

  • (Date)


396
# File 'lib/orb/models/customers/credits/ledger_create_entry_by_external_id_params.rb', line 396

required :target_expiry_date, Date

Instance Method Details

#to_hash{

Returns:

  • ({)


301
# File 'sig/orb/models/customers/credits/ledger_create_entry_by_external_id_params.rbs', line 301

def to_hash: -> {