Module: Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/orb/models/customers/credits/ledger_create_entry_params.rb,
sig/orb/models/customers/credits/ledger_create_entry_params.rbs
Defined Under Namespace
Classes: Amendment, Decrement, ExpirationChange, Increment, Void
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment, Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Decrement, Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::ExpirationChange, Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Void, Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Amendment)
Instance Method Summary collapse
-
#initialize(target_expiry_date:, amount: nil, block_id: nil, currency: nil, description: nil, expiry_date: nil, metadata: nil, entry_type: :expiration_change) ⇒ Object
Some parameter documentations has been truncated, see ExpirationChange for more details.
- #self?.variants ⇒ ::Array[Orb::Models::Customers::Credits::LedgerCreateEntryParams::body]
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 540
|
.variants ⇒ Array(Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment, Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Decrement, Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::ExpirationChange, Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Void, Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Amendment)
|
|
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 326
|
Instance Method Details
#initialize(target_expiry_date:, amount: nil, block_id: nil, currency: nil, description: nil, expiry_date: nil, metadata: nil, entry_type: :expiration_change) ⇒ Object
Some parameter documentations has been truncated, see ExpirationChange for more details.
27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 27 module Body extend Orb::Internal::Type::Union discriminator :entry_type variant :increment, -> { Orb::Customers::Credits::LedgerCreateEntryParams::Body::Increment } variant :decrement, -> { Orb::Customers::Credits::LedgerCreateEntryParams::Body::Decrement } variant :expiration_change, -> { Orb::Customers::Credits::LedgerCreateEntryParams::Body::ExpirationChange } variant :void, -> { Orb::Customers::Credits::LedgerCreateEntryParams::Body::Void } variant :amendment, -> { Orb::Customers::Credits::LedgerCreateEntryParams::Body::Amendment } class Increment < Orb::Internal::Type::BaseModel # @!attribute amount # The number of credits to effect. Note that this is required for increment, # decrement, void, or undo operations. # # @return [Float] required :amount, Float # @!attribute entry_type # # @return [Symbol, :increment] required :entry_type, const: :increment # @!attribute currency # The currency or custom pricing unit to use for this ledger entry. If this is a # real-world currency, it must match the customer's invoicing currency. # # @return [String, nil] optional :currency, String, nil?: true # @!attribute description # Optional metadata that can be specified when adding ledger results via the API. # For example, this can be used to note an increment refers to trial credits, or # for noting corrections as a result of an incident, etc. # # @return [String, nil] optional :description, String, nil?: true # @!attribute effective_date # An ISO 8601 format date that denotes when this credit balance should become # available for use. # # @return [Time, nil] optional :effective_date, Time, nil?: true # @!attribute expiry_date # An ISO 8601 format date that denotes when this credit balance should expire. # # @return [Time, nil] optional :expiry_date, Time, nil?: true # @!attribute filters # Optional filter to specify which items this credit block applies to. If not # specified, the block will apply to all items for the pricing unit. # # @return [Array<Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment::Filter>, nil] optional :filters, -> { Orb::Internal::Type::ArrayOf[Orb::Customers::Credits::LedgerCreateEntryParams::Body::Increment::Filter] }, nil?: true # @!attribute invoice_settings # Passing `invoice_settings` automatically generates an invoice for the newly # added credits. If `invoice_settings` is passed, you must specify # per_unit_cost_basis, as the calculation of the invoice total is done on that # basis. # # @return [Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment::InvoiceSettings, nil] optional :invoice_settings, -> { Orb::Customers::Credits::LedgerCreateEntryParams::Body::Increment::InvoiceSettings }, nil?: true # @!attribute metadata # User-specified key/value pairs for the resource. Individual keys can be removed # by setting the value to `null`, and the entire metadata mapping can be cleared # by setting `metadata` to `null`. # # @return [Hash{Symbol=>String, nil}, nil] optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true # @!attribute per_unit_cost_basis # Can only be specified when entry_type=increment. How much, in the customer's # currency, a customer paid for a single credit in this block # # @return [String, nil] optional :per_unit_cost_basis, String, nil?: true # @!method initialize(amount:, currency: nil, description: nil, effective_date: nil, expiry_date: nil, filters: nil, invoice_settings: nil, metadata: nil, per_unit_cost_basis: nil, entry_type: :increment) # Some parameter documentations has been truncated, see # {Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment} for # more details. # # @param amount [Float] The number of credits to effect. Note that this is required for increment, decre # # @param currency [String, nil] The currency or custom pricing unit to use for this ledger entry. If this is a r # # @param description [String, nil] Optional metadata that can be specified when adding ledger results via the API. # # @param effective_date [Time, nil] An ISO 8601 format date that denotes when this credit balance should become avai # # @param expiry_date [Time, nil] An ISO 8601 format date that denotes when this credit balance should expire. # # @param filters [Array<Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment::Filter>, nil] Optional filter to specify which items this credit block applies to. If not spec # # @param invoice_settings [Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment::InvoiceSettings, nil] Passing `invoice_settings` automatically generates an invoice for the newly adde # # @param metadata [Hash{Symbol=>String, nil}, nil] User-specified key/value pairs for the resource. Individual keys can be removed # # @param per_unit_cost_basis [String, nil] Can only be specified when entry_type=increment. How much, in the customer's cur # # @param entry_type [Symbol, :increment] class Filter < Orb::Internal::Type::BaseModel # @!attribute field # The property of the price the block applies to. Only item_id is supported. # # @return [Symbol, Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment::Filter::Field] required :field, enum: -> { Orb::Customers::Credits::LedgerCreateEntryParams::Body::Increment::Filter::Field } # @!attribute operator # Should prices that match the filter be included or excluded. # # @return [Symbol, Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment::Filter::Operator] required :operator, enum: -> { Orb::Customers::Credits::LedgerCreateEntryParams::Body::Increment::Filter::Operator } # @!attribute values # The IDs or values that match this filter. # # @return [Array<String>] required :values, Orb::Internal::Type::ArrayOf[String] # @!method initialize(field:, operator:, values:) # A PriceFilter that only allows item_id field for block filters. # # @param field [Symbol, Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment::Filter::Field] The property of the price the block applies to. Only item_id is supported. # # @param operator [Symbol, Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment::Filter::Operator] Should prices that match the filter be included or excluded. # # @param values [Array<String>] The IDs or values that match this filter. # The property of the price the block applies to. Only item_id is supported. # # @see Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment::Filter#field module Field extend Orb::Internal::Type::Enum ITEM_ID = :item_id # @!method self.values # @return [Array<Symbol>] end # Should prices that match the filter be included or excluded. # # @see Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment::Filter#operator module Operator extend Orb::Internal::Type::Enum INCLUDES = :includes EXCLUDES = :excludes # @!method self.values # @return [Array<Symbol>] end end # @see Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment#invoice_settings class InvoiceSettings < Orb::Internal::Type::BaseModel # @!attribute auto_collection # Whether the credits purchase invoice should auto collect with the customer's # saved payment method. # # @return [Boolean] required :auto_collection, Orb::Internal::Type::Boolean # @!attribute custom_due_date # An optional custom due date for the invoice. If not set, the due date will be # calculated based on the `net_terms` value. # # @return [Date, Time, nil] optional :custom_due_date, union: -> { Orb::Customers::Credits::LedgerCreateEntryParams::Body::Increment::InvoiceSettings::CustomDueDate }, nil?: true # @!attribute invoice_date # An ISO 8601 format date that denotes when this invoice should be dated in the # customer's timezone. If not provided, the invoice date will default to the # credit block's effective date. # # @return [Date, Time, nil] optional :invoice_date, union: -> { Orb::Customers::Credits::LedgerCreateEntryParams::Body::Increment::InvoiceSettings::InvoiceDate }, nil?: true # @!attribute item_id # The ID of the Item to be used for the invoice line item. If not provided, a # default 'Credits' item will be used. # # @return [String, nil] optional :item_id, String, nil?: true # @!attribute mark_as_paid # If true, the new credits purchase invoice will be marked as paid. # # @return [Boolean, nil] optional :mark_as_paid, Orb::Internal::Type::Boolean # @!attribute memo # An optional memo to display on the invoice. # # @return [String, nil] optional :memo, String, nil?: true # @!attribute net_terms # The net terms determines the due date of the invoice. Due date is calculated # based on the invoice or issuance date, depending on the account's configured due # date calculation method. A value of '0' here represents that the invoice is due # on issue, whereas a value of '30' represents that the customer has 30 days to # pay the invoice. You must set either `net_terms` or `custom_due_date`, but not # both. # # @return [Integer, nil] optional :net_terms, Integer, nil?: true # @!attribute require_successful_payment # If true, the new credit block will require that the corresponding invoice is # paid before it can be drawn down from. # # @return [Boolean, nil] optional :require_successful_payment, Orb::Internal::Type::Boolean # @!method initialize(auto_collection:, custom_due_date: nil, invoice_date: nil, item_id: nil, mark_as_paid: nil, memo: nil, net_terms: nil, require_successful_payment: nil) # Some parameter documentations has been truncated, see # {Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment::InvoiceSettings} # for more details. # # Passing `invoice_settings` automatically generates an invoice for the newly # added credits. If `invoice_settings` is passed, you must specify # per_unit_cost_basis, as the calculation of the invoice total is done on that # basis. # # @param auto_collection [Boolean] Whether the credits purchase invoice should auto collect with the customer's sav # # @param custom_due_date [Date, Time, nil] An optional custom due date for the invoice. If not set, the due date will be ca # # @param invoice_date [Date, Time, nil] An ISO 8601 format date that denotes when this invoice should be dated in the cu # # @param item_id [String, nil] The ID of the Item to be used for the invoice line item. If not provided, a defa # # @param mark_as_paid [Boolean] If true, the new credits purchase invoice will be marked as paid. # # @param memo [String, nil] An optional memo to display on the invoice. # # @param net_terms [Integer, nil] The net terms determines the due date of the invoice. Due date is calculated bas # # @param require_successful_payment [Boolean] If true, the new credit block will require that the corresponding invoice is pai # An optional custom due date for the invoice. If not set, the due date will be # calculated based on the `net_terms` value. # # @see Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment::InvoiceSettings#custom_due_date module CustomDueDate extend Orb::Internal::Type::Union variant Date variant Time # @!method self.variants # @return [Array(Date, Time)] end # An ISO 8601 format date that denotes when this invoice should be dated in the # customer's timezone. If not provided, the invoice date will default to the # credit block's effective date. # # @see Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment::InvoiceSettings#invoice_date module InvoiceDate extend Orb::Internal::Type::Union variant Date variant Time # @!method self.variants # @return [Array(Date, Time)] end end end class Decrement < Orb::Internal::Type::BaseModel # @!attribute amount # The number of credits to effect. Note that this is required for increment, # decrement, void, or undo operations. # # @return [Float] required :amount, Float # @!attribute entry_type # # @return [Symbol, :decrement] required :entry_type, const: :decrement # @!attribute currency # The currency or custom pricing unit to use for this ledger entry. If this is a # real-world currency, it must match the customer's invoicing currency. # # @return [String, nil] optional :currency, String, nil?: true # @!attribute description # Optional metadata that can be specified when adding ledger results via the API. # For example, this can be used to note an increment refers to trial credits, or # for noting corrections as a result of an incident, etc. # # @return [String, nil] optional :description, String, nil?: true # @!attribute metadata # User-specified key/value pairs for the resource. Individual keys can be removed # by setting the value to `null`, and the entire metadata mapping can be cleared # by setting `metadata` to `null`. # # @return [Hash{Symbol=>String, nil}, nil] optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true # @!method initialize(amount:, currency: nil, description: nil, metadata: nil, entry_type: :decrement) # Some parameter documentations has been truncated, see # {Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Decrement} for # more details. # # @param amount [Float] The number of credits to effect. Note that this is required for increment, decre # # @param currency [String, nil] The currency or custom pricing unit to use for this ledger entry. If this is a r # # @param description [String, nil] Optional metadata that can be specified when adding ledger results via the API. # # @param metadata [Hash{Symbol=>String, nil}, nil] User-specified key/value pairs for the resource. Individual keys can be removed # # @param entry_type [Symbol, :decrement] end class ExpirationChange < Orb::Internal::Type::BaseModel # @!attribute entry_type # # @return [Symbol, :expiration_change] required :entry_type, const: :expiration_change # @!attribute target_expiry_date # A date (specified in YYYY-MM-DD format) used for expiration change, denoting # when credits transferred (as part of a partial block expiration) should expire. # This date must be on or after the effective date of the credit block. # # @return [Date] required :target_expiry_date, Date # @!attribute amount # The number of credits to effect. Note that this is required for increment, # decrement, void, or undo operations. # # @return [Float, nil] optional :amount, Float, nil?: true # @!attribute block_id # The ID of the block affected by an expiration_change, used to differentiate # between multiple blocks with the same `expiry_date`. # # @return [String, nil] optional :block_id, String, nil?: true # @!attribute currency # The currency or custom pricing unit to use for this ledger entry. If this is a # real-world currency, it must match the customer's invoicing currency. # # @return [String, nil] optional :currency, String, nil?: true # @!attribute description # Optional metadata that can be specified when adding ledger results via the API. # For example, this can be used to note an increment refers to trial credits, or # for noting corrections as a result of an incident, etc. # # @return [String, nil] optional :description, String, nil?: true # @!attribute expiry_date # An ISO 8601 format date that identifies the origination credit block to expire # # @return [Time, nil] optional :expiry_date, Time, nil?: true # @!attribute metadata # User-specified key/value pairs for the resource. Individual keys can be removed # by setting the value to `null`, and the entire metadata mapping can be cleared # by setting `metadata` to `null`. # # @return [Hash{Symbol=>String, nil}, nil] optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true # @!method initialize(target_expiry_date:, amount: nil, block_id: nil, currency: nil, description: nil, expiry_date: nil, metadata: nil, entry_type: :expiration_change) # Some parameter documentations has been truncated, see # {Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::ExpirationChange} # for more details. # # @param target_expiry_date [Date] A date (specified in YYYY-MM-DD format) used for expiration change, denoting whe # # @param amount [Float, nil] The number of credits to effect. Note that this is required for increment, decre # # @param block_id [String, nil] The ID of the block affected by an expiration_change, used to differentiate betw # # @param currency [String, nil] The currency or custom pricing unit to use for this ledger entry. If this is a r # # @param description [String, nil] Optional metadata that can be specified when adding ledger results via the API. # # @param expiry_date [Time, nil] An ISO 8601 format date that identifies the origination credit block to expire # # @param metadata [Hash{Symbol=>String, nil}, nil] User-specified key/value pairs for the resource. Individual keys can be removed # # @param entry_type [Symbol, :expiration_change] end class Void < Orb::Internal::Type::BaseModel # @!attribute amount # The number of credits to effect. Note that this is required for increment, # decrement, void, or undo operations. # # @return [Float] required :amount, Float # @!attribute block_id # The ID of the block to void. # # @return [String] required :block_id, String # @!attribute entry_type # # @return [Symbol, :void] required :entry_type, const: :void # @!attribute currency # The currency or custom pricing unit to use for this ledger entry. If this is a # real-world currency, it must match the customer's invoicing currency. # # @return [String, nil] optional :currency, String, nil?: true # @!attribute description # Optional metadata that can be specified when adding ledger results via the API. # For example, this can be used to note an increment refers to trial credits, or # for noting corrections as a result of an incident, etc. # # @return [String, nil] optional :description, String, nil?: true # @!attribute metadata # User-specified key/value pairs for the resource. Individual keys can be removed # by setting the value to `null`, and the entire metadata mapping can be cleared # by setting `metadata` to `null`. # # @return [Hash{Symbol=>String, nil}, nil] optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true # @!attribute void_reason # Can only be specified when `entry_type=void`. The reason for the void. # # @return [Symbol, Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Void::VoidReason, nil] optional :void_reason, enum: -> { Orb::Customers::Credits::LedgerCreateEntryParams::Body::Void::VoidReason }, nil?: true # @!method initialize(amount:, block_id:, currency: nil, description: nil, metadata: nil, void_reason: nil, entry_type: :void) # Some parameter documentations has been truncated, see # {Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Void} for more # details. # # @param amount [Float] The number of credits to effect. Note that this is required for increment, decre # # @param block_id [String] The ID of the block to void. # # @param currency [String, nil] The currency or custom pricing unit to use for this ledger entry. If this is a r # # @param description [String, nil] Optional metadata that can be specified when adding ledger results via the API. # # @param metadata [Hash{Symbol=>String, nil}, nil] User-specified key/value pairs for the resource. Individual keys can be removed # # @param void_reason [Symbol, Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Void::VoidReason, nil] Can only be specified when `entry_type=void`. The reason for the void. # # @param entry_type [Symbol, :void] # Can only be specified when `entry_type=void`. The reason for the void. # # @see Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Void#void_reason module VoidReason extend Orb::Internal::Type::Enum REFUND = :refund # @!method self.values # @return [Array<Symbol>] end end class Amendment < Orb::Internal::Type::BaseModel # @!attribute amount # The number of credits to effect. Note that this is required for increment, # decrement or void operations. # # @return [Float] required :amount, Float # @!attribute block_id # The ID of the block to reverse a decrement from. # # @return [String] required :block_id, String # @!attribute entry_type # # @return [Symbol, :amendment] required :entry_type, const: :amendment # @!attribute currency # The currency or custom pricing unit to use for this ledger entry. If this is a # real-world currency, it must match the customer's invoicing currency. # # @return [String, nil] optional :currency, String, nil?: true # @!attribute description # Optional metadata that can be specified when adding ledger results via the API. # For example, this can be used to note an increment refers to trial credits, or # for noting corrections as a result of an incident, etc. # # @return [String, nil] optional :description, String, nil?: true # @!attribute metadata # User-specified key/value pairs for the resource. Individual keys can be removed # by setting the value to `null`, and the entire metadata mapping can be cleared # by setting `metadata` to `null`. # # @return [Hash{Symbol=>String, nil}, nil] optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true # @!method initialize(amount:, block_id:, currency: nil, description: nil, metadata: nil, entry_type: :amendment) # Some parameter documentations has been truncated, see # {Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Amendment} for # more details. # # @param amount [Float] The number of credits to effect. Note that this is required for increment, decre # # @param block_id [String] The ID of the block to reverse a decrement from. # # @param currency [String, nil] The currency or custom pricing unit to use for this ledger entry. If this is a r # # @param description [String, nil] Optional metadata that can be specified when adding ledger results via the API. # # @param metadata [Hash{Symbol=>String, nil}, nil] User-specified key/value pairs for the resource. Individual keys can be removed # # @param entry_type [Symbol, :amendment] end # @!method self.variants # @return [Array(Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment, Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Decrement, Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::ExpirationChange, Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Void, Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Amendment)] end |
#self?.variants ⇒ ::Array[Orb::Models::Customers::Credits::LedgerCreateEntryParams::body]
412 |
# File 'sig/orb/models/customers/credits/ledger_create_entry_params.rbs', line 412
def self?.variants: -> ::Array[Orb::Models::Customers::Credits::LedgerCreateEntryParams::body]
|