Class: Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Amendment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/customers/credits/ledger_create_entry_params.rb,
sig/orb/models/customers/credits/ledger_create_entry_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, block_id:, currency: nil, description: nil, metadata: nil, entry_type: :amendment) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Amendment for more details.

Parameters:

  • amount (Float)

    The number of credits to effect. Note that this is required for increment, decre

  • block_id (String)

    The ID of the block to reverse a decrement from.

  • currency (String, nil) (defaults to: nil)

    The currency or custom pricing unit to use for this ledger entry. If this is a r

  • description (String, nil) (defaults to: nil)

    Optional metadata that can be specified when adding ledger results via the API.

  • metadata (Hash{Symbol=>String, nil}, nil) (defaults to: nil)

    User-specified key/value pairs for the resource. Individual keys can be removed

  • entry_type (Symbol, :amendment) (defaults to: :amendment)


# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 587

Instance Attribute Details

#amountFloat

The number of credits to effect. Note that this is required for increment, decrement or void operations.

Parameters:

  • value (Float)

Returns:

  • (Float)


551
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 551

required :amount, Float

#block_idString

The ID of the block to reverse a decrement from.

Parameters:

  • value (String)

Returns:

  • (String)


557
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 557

required :block_id, String

#currencyString?

The currency or custom pricing unit to use for this ledger entry. If this is a real-world currency, it must match the customer's invoicing currency.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


569
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 569

optional :currency, String, nil?: true

#descriptionString?

Optional metadata that can be specified when adding ledger results via the API. For example, this can be used to note an increment refers to trial credits, or for noting corrections as a result of an incident, etc.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


577
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 577

optional :description, String, nil?: true

#entry_typeSymbol, :amendment

Parameters:

  • value (:amendment)

Returns:

  • (Symbol, :amendment)


562
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 562

required :entry_type, const: :amendment

#metadataHash{Symbol=>String, nil}?

User-specified key/value pairs for the resource. Individual keys can be removed by setting the value to null, and the entire metadata mapping can be cleared by setting metadata to null.

Parameters:

  • value (::Hash[Symbol, String?], nil)

Returns:

  • (Hash{Symbol=>String, nil}, nil)


585
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 585

optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


402
# File 'sig/orb/models/customers/credits/ledger_create_entry_params.rbs', line 402

def to_hash: -> {