Class: Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Decrement
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Decrement
- Defined in:
- lib/orb/models/customers/credits/ledger_create_entry_params.rb,
sig/orb/models/customers/credits/ledger_create_entry_params.rbs
Instance Attribute Summary collapse
-
#amount ⇒ Float
The number of credits to effect.
-
#currency ⇒ String?
The currency or custom pricing unit to use for this ledger entry.
-
#description ⇒ String?
Optional metadata that can be specified when adding ledger results via the API.
- #entry_type ⇒ Symbol, :decrement
-
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
244 |
# File 'sig/orb/models/customers/credits/ledger_create_entry_params.rbs', line 244
def initialize: (
|
Instance Attribute Details
#amount ⇒ Float
The number of credits to effect. Note that this is required for increment, decrement, void, or undo operations.
338 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 338 required :amount, Float |
#currency ⇒ String?
The currency or custom pricing unit to use for this ledger entry. If this is a real-world currency, it must match the customer's invoicing currency.
350 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 350 optional :currency, String, nil?: true |
#description ⇒ String?
Optional metadata that can be specified when adding ledger results via the API. For example, this can be used to note an increment refers to trial credits, or for noting corrections as a result of an incident, etc.
358 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 358 optional :description, String, nil?: true |
#entry_type ⇒ Symbol, :decrement
343 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 343 required :entry_type, const: :decrement |
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource. Individual keys can be removed
by setting the value to null, and the entire metadata mapping can be cleared
by setting metadata to null.
366 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 366 optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true |
Instance Method Details
#to_hash ⇒ {
252 |
# File 'sig/orb/models/customers/credits/ledger_create_entry_params.rbs', line 252
def to_hash: -> {
|