Class: Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::ExpirationChange
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::ExpirationChange
- Defined in:
- lib/orb/models/customers/credits/ledger_create_entry_params.rb,
sig/orb/models/customers/credits/ledger_create_entry_params.rbs
Instance Attribute Summary collapse
-
#amount ⇒ Float?
The number of credits to effect.
-
#block_id ⇒ String?
The ID of the block affected by an expiration_change, used to differentiate between multiple blocks with the same
expiry_date. -
#currency ⇒ String?
The currency or custom pricing unit to use for this ledger entry.
-
#description ⇒ String?
Optional metadata that can be specified when adding ledger results via the API.
- #entry_type ⇒ Symbol, :expiration_change
-
#expiry_date ⇒ Time?
An ISO 8601 format date that identifies the origination credit block to expire.
-
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource.
-
#target_expiry_date ⇒ Date
A date (specified in YYYY-MM-DD format) used for expiration change, denoting when credits transferred (as part of a partial block expiration) should expire.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
290 |
# File 'sig/orb/models/customers/credits/ledger_create_entry_params.rbs', line 290
def initialize: (
|
Instance Attribute Details
#amount ⇒ Float?
The number of credits to effect. Note that this is required for increment, decrement, void, or undo operations.
403 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 403 optional :amount, Float, nil?: true |
#block_id ⇒ String?
The ID of the block affected by an expiration_change, used to differentiate
between multiple blocks with the same expiry_date.
410 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 410 optional :block_id, String, nil?: true |
#currency ⇒ String?
The currency or custom pricing unit to use for this ledger entry. If this is a real-world currency, it must match the customer's invoicing currency.
417 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 417 optional :currency, String, nil?: true |
#description ⇒ String?
Optional metadata that can be specified when adding ledger results via the API. For example, this can be used to note an increment refers to trial credits, or for noting corrections as a result of an incident, etc.
425 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 425 optional :description, String, nil?: true |
#entry_type ⇒ Symbol, :expiration_change
388 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 388 required :entry_type, const: :expiration_change |
#expiry_date ⇒ Time?
An ISO 8601 format date that identifies the origination credit block to expire
431 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 431 optional :expiry_date, Time, nil?: true |
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource. Individual keys can be removed
by setting the value to null, and the entire metadata mapping can be cleared
by setting metadata to null.
439 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 439 optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true |
#target_expiry_date ⇒ Date
A date (specified in YYYY-MM-DD format) used for expiration change, denoting when credits transferred (as part of a partial block expiration) should expire. This date must be on or after the effective date of the credit block.
396 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 396 required :target_expiry_date, Date |
Instance Method Details
#to_hash ⇒ {
301 |
# File 'sig/orb/models/customers/credits/ledger_create_entry_params.rbs', line 301
def to_hash: -> {
|