Class: Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment
- Defined in:
- lib/orb/models/customers/credits/ledger_create_entry_params.rb,
sig/orb/models/customers/credits/ledger_create_entry_params.rbs
Defined Under Namespace
Classes: Filter, InvoiceSettings
Instance Attribute Summary collapse
-
#amount ⇒ Float
The number of credits to effect.
-
#currency ⇒ String?
The currency or custom pricing unit to use for this ledger entry.
-
#description ⇒ String?
Optional metadata that can be specified when adding ledger results via the API.
-
#effective_date ⇒ Time?
An ISO 8601 format date that denotes when this credit balance should become available for use.
- #entry_type ⇒ Symbol, :increment
-
#expiry_date ⇒ Time?
An ISO 8601 format date that denotes when this credit balance should expire.
-
#filters ⇒ Array<Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment::Filter>?
Optional filter to specify which items this credit block applies to.
-
#invoice_settings ⇒ Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment::InvoiceSettings?
Passing
invoice_settingsautomatically generates an invoice for the newly added credits. -
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource.
-
#per_unit_cost_basis ⇒ String?
Can only be specified when entry_type=increment.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
77 |
# File 'sig/orb/models/customers/credits/ledger_create_entry_params.rbs', line 77
def initialize: (
|
Instance Attribute Details
#amount ⇒ Float
The number of credits to effect. Note that this is required for increment, decrement, void, or undo operations.
49 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 49 required :amount, Float |
#currency ⇒ String?
The currency or custom pricing unit to use for this ledger entry. If this is a real-world currency, it must match the customer's invoicing currency.
61 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 61 optional :currency, String, nil?: true |
#description ⇒ String?
Optional metadata that can be specified when adding ledger results via the API. For example, this can be used to note an increment refers to trial credits, or for noting corrections as a result of an incident, etc.
69 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 69 optional :description, String, nil?: true |
#effective_date ⇒ Time?
An ISO 8601 format date that denotes when this credit balance should become available for use.
76 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 76 optional :effective_date, Time, nil?: true |
#entry_type ⇒ Symbol, :increment
54 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 54 required :entry_type, const: :increment |
#expiry_date ⇒ Time?
An ISO 8601 format date that denotes when this credit balance should expire.
82 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 82 optional :expiry_date, Time, nil?: true |
#filters ⇒ Array<Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment::Filter>?
Optional filter to specify which items this credit block applies to. If not specified, the block will apply to all items for the pricing unit.
89 90 91 92 93 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 89 optional :filters, -> { Orb::Internal::Type::ArrayOf[Orb::Customers::Credits::LedgerCreateEntryParams::Body::Increment::Filter] }, nil?: true |
#invoice_settings ⇒ Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment::InvoiceSettings?
Passing invoice_settings automatically generates an invoice for the newly
added credits. If invoice_settings is passed, you must specify
per_unit_cost_basis, as the calculation of the invoice total is done on that
basis.
102 103 104 105 106 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 102 optional :invoice_settings, -> { Orb::Customers::Credits::LedgerCreateEntryParams::Body::Increment::InvoiceSettings }, nil?: true |
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource. Individual keys can be removed
by setting the value to null, and the entire metadata mapping can be cleared
by setting metadata to null.
114 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 114 optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true |
#per_unit_cost_basis ⇒ String?
Can only be specified when entry_type=increment. How much, in the customer's currency, a customer paid for a single credit in this block
121 |
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 121 optional :per_unit_cost_basis, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/customers/credits/ledger_create_entry_params.rb', line 199
|
Instance Method Details
#to_hash ⇒ {
90 |
# File 'sig/orb/models/customers/credits/ledger_create_entry_params.rbs', line 90
def to_hash: -> {
|