Module: Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment::InvoiceSettings::InvoiceDate

Extended by:
Internal::Type::Union
Defined in:
lib/orb/models/customers/credits/ledger_create_entry_params.rb,
sig/orb/models/customers/credits/ledger_create_entry_params.rbs

Overview

An ISO 8601 format date that denotes when this invoice should be dated in the customer's timezone. If not provided, the invoice date will default to the credit block's effective date.

See Also:

  • Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment::InvoiceSettings#invoice_date

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.variants::Array[Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment::InvoiceSettings::invoice_date]

Returns:

  • (::Array[Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment::InvoiceSettings::invoice_date])


219
# File 'sig/orb/models/customers/credits/ledger_create_entry_params.rbs', line 219

def self?.variants: -> ::Array[Orb::Models::Customers::Credits::LedgerCreateEntryParams::Body::Increment::InvoiceSettings::invoice_date]