Class: Orb::Models::EvaluatePriceGroup
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::EvaluatePriceGroup
- Defined in:
- lib/orb/models/evaluate_price_group.rb,
sig/orb/models/evaluate_price_group.rbs
Defined Under Namespace
Modules: GroupingValue
Instance Attribute Summary collapse
-
#amount ⇒ String
The price's output for the group.
-
#grouping_values ⇒ Array<String, Float, Boolean>
The values for the group in the order specified by
grouping_keys. -
#quantity ⇒ Float
The price's usage quantity for the group.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
17 |
# File 'sig/orb/models/evaluate_price_group.rbs', line 17
def initialize: (
|
Instance Attribute Details
#amount ⇒ String
The price's output for the group
10 |
# File 'lib/orb/models/evaluate_price_group.rb', line 10 required :amount, String |
#grouping_values ⇒ Array<String, Float, Boolean>
The values for the group in the order specified by grouping_keys
16 17 |
# File 'lib/orb/models/evaluate_price_group.rb', line 16 required :grouping_values, -> { Orb::Internal::Type::ArrayOf[union: Orb::EvaluatePriceGroup::GroupingValue] } |
#quantity ⇒ Float
The price's usage quantity for the group
23 |
# File 'lib/orb/models/evaluate_price_group.rb', line 23 required :quantity, Float |
Instance Method Details
#to_hash ⇒ {
23 |
# File 'sig/orb/models/evaluate_price_group.rbs', line 23
def to_hash: -> {
|