Class: Orb::Models::EventUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/orb/models/event_update_params.rb,
sig/orb/models/event_update_params.rbs

Overview

See Also:

  • Orb::Resources::Events#update

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(event_id:, event_name:, properties:, timestamp:, customer_id: nil, external_customer_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::EventUpdateParams for more details.

Parameters:

  • event_id (String)
  • event_name (String)

    A name to meaningfully identify the action or event type.

  • properties (Hash{Symbol=>Object})

    A dictionary of custom properties. Values in this dictionary must be numeric, bo

  • timestamp (Time)

    An ISO 8601 format date with no timezone offset (i.e. UTC). This should represen

  • customer_id (String, nil) (defaults to: nil)

    The Orb Customer identifier

  • external_customer_id (String, nil) (defaults to: nil)

    An alias for the Orb customer, whose mapping is specified when creating the cust

  • request_options (Orb::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/orb/models/event_update_params.rb', line 49

Instance Attribute Details

#customer_idString?

The Orb Customer identifier

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


40
# File 'lib/orb/models/event_update_params.rb', line 40

optional :customer_id, String, nil?: true

#event_idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/orb/models/event_update_params.rb', line 13

required :event_id, String

#event_nameString

A name to meaningfully identify the action or event type.

Parameters:

  • value (String)

Returns:

  • (String)


19
# File 'lib/orb/models/event_update_params.rb', line 19

required :event_name, String

#external_customer_idString?

An alias for the Orb customer, whose mapping is specified when creating the customer

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


47
# File 'lib/orb/models/event_update_params.rb', line 47

optional :external_customer_id, String, nil?: true

#propertiesHash{Symbol=>Object}

A dictionary of custom properties. Values in this dictionary must be numeric, boolean, or strings. Nested dictionaries are disallowed.

Parameters:

  • value (::Hash[Symbol, top])

Returns:

  • (Hash{Symbol=>Object})


26
# File 'lib/orb/models/event_update_params.rb', line 26

required :properties, Orb::Internal::Type::HashOf[Orb::Internal::Type::Unknown]

#timestampTime

An ISO 8601 format date with no timezone offset (i.e. UTC). This should represent the time that usage was recorded, and is particularly important to attribute usage to a given billing period.

Parameters:

  • value (Time)

Returns:

  • (Time)


34
# File 'lib/orb/models/event_update_params.rb', line 34

required :timestamp, Time

Instance Method Details

#to_hash{

Returns:

  • ({)


40
# File 'sig/orb/models/event_update_params.rbs', line 40

def to_hash: -> {