Class: Orb::Models::Events::BackfillFetchResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/events/backfill_fetch_response.rb,
sig/orb/models/events/backfill_fetch_response.rbs

Overview

See Also:

  • Orb::Resources::Events::Backfills#fetch

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, close_time:, created_at:, customer_id:, events_ingested:, replace_existing_events:, reverted_at:, status:, timeframe_end:, timeframe_start:, deprecation_filter: nil) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::Events::BackfillFetchResponse for more details.

A backfill represents an update to historical usage data, adding or replacing events in a timeframe.

Parameters:

  • id (String)
  • close_time (Time, nil)

    If in the future, the time at which the backfill will automatically close. If in

  • created_at (Time)
  • customer_id (String, nil)

    The Orb-generated ID of the customer to which this backfill is scoped. If null

  • events_ingested (Integer)

    The number of events ingested in this backfill.

  • replace_existing_events (Boolean)

    If true, existing events in the backfill's timeframe will be replaced with the

  • reverted_at (Time, nil)

    The time at which this backfill was reverted.

  • status (Symbol, Orb::Models::Events::BackfillFetchResponse::Status)

    The status of the backfill.

  • timeframe_end (Time)
  • timeframe_start (Time)
  • deprecation_filter (String, nil) (defaults to: nil)

    A boolean [computed property](/extensibility/advanced-metrics#computed-propertie



# File 'lib/orb/models/events/backfill_fetch_response.rb', line 76

Instance Attribute Details

#close_timeTime?

If in the future, the time at which the backfill will automatically close. If in the past, the time at which the backfill was closed.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


18
# File 'lib/orb/models/events/backfill_fetch_response.rb', line 18

required :close_time, Time, nil?: true

#created_atTime

Parameters:

  • value (Time)

Returns:

  • (Time)


23
# File 'lib/orb/models/events/backfill_fetch_response.rb', line 23

required :created_at, Time

#customer_idString?

The Orb-generated ID of the customer to which this backfill is scoped. If null, this backfill is scoped to all customers.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


30
# File 'lib/orb/models/events/backfill_fetch_response.rb', line 30

required :customer_id, String, nil?: true

#deprecation_filterString?

A boolean computed property used to filter the set of events to deprecate

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


74
# File 'lib/orb/models/events/backfill_fetch_response.rb', line 74

optional :deprecation_filter, String, nil?: true

#events_ingestedInteger

The number of events ingested in this backfill.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


36
# File 'lib/orb/models/events/backfill_fetch_response.rb', line 36

required :events_ingested, Integer

#idString

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/orb/models/events/backfill_fetch_response.rb', line 11

required :id, String

#replace_existing_eventsBoolean

If true, existing events in the backfill's timeframe will be replaced with the newly ingested events associated with the backfill. If false, newly ingested events will be added to the existing events.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


44
# File 'lib/orb/models/events/backfill_fetch_response.rb', line 44

required :replace_existing_events, Orb::Internal::Type::Boolean

#reverted_atTime?

The time at which this backfill was reverted.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


50
# File 'lib/orb/models/events/backfill_fetch_response.rb', line 50

required :reverted_at, Time, nil?: true

#statusSymbol, Orb::Models::Events::BackfillFetchResponse::Status

The status of the backfill.

Parameters:

  • value (Orb::Models::Events::BackfillFetchResponse::status)

Returns:



56
# File 'lib/orb/models/events/backfill_fetch_response.rb', line 56

required :status, enum: -> { Orb::Models::Events::BackfillFetchResponse::Status }

#timeframe_endTime

Parameters:

  • value (Time)

Returns:

  • (Time)


61
# File 'lib/orb/models/events/backfill_fetch_response.rb', line 61

required :timeframe_end, Time

#timeframe_startTime

Parameters:

  • value (Time)

Returns:

  • (Time)


66
# File 'lib/orb/models/events/backfill_fetch_response.rb', line 66

required :timeframe_start, Time

Instance Method Details

#to_hash{

Returns:

  • ({)


56
# File 'sig/orb/models/events/backfill_fetch_response.rbs', line 56

def to_hash: -> {