Class: Orb::Models::Events::BackfillListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Events::BackfillListResponse
- Defined in:
- lib/orb/models/events/backfill_list_response.rb,
sig/orb/models/events/backfill_list_response.rbs
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#close_time ⇒ Time?
If in the future, the time at which the backfill will automatically close.
- #created_at ⇒ Time
-
#customer_id ⇒ String?
The Orb-generated ID of the customer to which this backfill is scoped.
-
#deprecation_filter ⇒ String?
A boolean computed property used to filter the set of events to deprecate.
-
#events_ingested ⇒ Integer
The number of events ingested in this backfill.
- #id ⇒ String
-
#replace_existing_events ⇒ Boolean
If
true, existing events in the backfill's timeframe will be replaced with the newly ingested events associated with the backfill. -
#reverted_at ⇒ Time?
The time at which this backfill was reverted.
-
#status ⇒ Symbol, Orb::Models::Events::BackfillListResponse::Status
The status of the backfill.
- #timeframe_end ⇒ Time
- #timeframe_start ⇒ Time
Instance Method Summary collapse
-
#initialize(id:, close_time:, created_at:, customer_id:, events_ingested:, replace_existing_events:, reverted_at:, status:, timeframe_end:, timeframe_start:, deprecation_filter: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BackfillListResponse for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, close_time:, created_at:, customer_id:, events_ingested:, replace_existing_events:, reverted_at:, status:, timeframe_end:, timeframe_start:, deprecation_filter: nil) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::Events::BackfillListResponse for more details.
A backfill represents an update to historical usage data, adding or replacing events in a timeframe.
|
|
# File 'lib/orb/models/events/backfill_list_response.rb', line 76
|
Instance Attribute Details
#close_time ⇒ Time?
If in the future, the time at which the backfill will automatically close. If in the past, the time at which the backfill was closed.
18 |
# File 'lib/orb/models/events/backfill_list_response.rb', line 18 required :close_time, Time, nil?: true |
#created_at ⇒ Time
23 |
# File 'lib/orb/models/events/backfill_list_response.rb', line 23 required :created_at, Time |
#customer_id ⇒ String?
The Orb-generated ID of the customer to which this backfill is scoped. If
null, this backfill is scoped to all customers.
30 |
# File 'lib/orb/models/events/backfill_list_response.rb', line 30 required :customer_id, String, nil?: true |
#deprecation_filter ⇒ String?
A boolean computed property used to filter the set of events to deprecate
74 |
# File 'lib/orb/models/events/backfill_list_response.rb', line 74 optional :deprecation_filter, String, nil?: true |
#events_ingested ⇒ Integer
The number of events ingested in this backfill.
36 |
# File 'lib/orb/models/events/backfill_list_response.rb', line 36 required :events_ingested, Integer |
#id ⇒ String
11 |
# File 'lib/orb/models/events/backfill_list_response.rb', line 11 required :id, String |
#replace_existing_events ⇒ Boolean
If true, existing events in the backfill's timeframe will be replaced with the
newly ingested events associated with the backfill. If false, newly ingested
events will be added to the existing events.
44 |
# File 'lib/orb/models/events/backfill_list_response.rb', line 44 required :replace_existing_events, Orb::Internal::Type::Boolean |
#reverted_at ⇒ Time?
The time at which this backfill was reverted.
50 |
# File 'lib/orb/models/events/backfill_list_response.rb', line 50 required :reverted_at, Time, nil?: true |
#status ⇒ Symbol, Orb::Models::Events::BackfillListResponse::Status
The status of the backfill.
56 |
# File 'lib/orb/models/events/backfill_list_response.rb', line 56 required :status, enum: -> { Orb::Models::Events::BackfillListResponse::Status } |
#timeframe_end ⇒ Time
61 |
# File 'lib/orb/models/events/backfill_list_response.rb', line 61 required :timeframe_end, Time |
#timeframe_start ⇒ Time
66 |
# File 'lib/orb/models/events/backfill_list_response.rb', line 66 required :timeframe_start, Time |
Instance Method Details
#to_hash ⇒ {
56 |
# File 'sig/orb/models/events/backfill_list_response.rbs', line 56
def to_hash: -> {
|