Class: Orb::Models::Invoice::CustomerBalanceTransaction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Invoice::CustomerBalanceTransaction
- Defined in:
- lib/orb/models/invoice.rb,
sig/orb/models/invoice.rbs
Defined Under Namespace
Instance Attribute Summary collapse
- #action ⇒ Symbol, Orb::Models::Invoice::CustomerBalanceTransaction::Action
-
#amount ⇒ String
The value of the amount changed in the transaction.
-
#created_at ⇒ Time
The creation time of this transaction.
- #credit_note ⇒ Orb::Models::CreditNoteTiny?
-
#description ⇒ String?
An optional description provided for manual customer balance adjustments.
-
#ending_balance ⇒ String
The new value of the customer's balance prior to the transaction, in the customer's currency.
-
#id ⇒ String
A unique id for this transaction.
- #invoice ⇒ Orb::Models::InvoiceTiny?
-
#starting_balance ⇒ String
The original value of the customer's balance prior to the transaction, in the customer's currency.
- #type ⇒ Symbol, Orb::Models::Invoice::CustomerBalanceTransaction::Type
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, action:, amount:, created_at:, credit_note:, description:, ending_balance:, invoice:, starting_balance:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CustomerBalanceTransaction for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, action:, amount:, created_at:, credit_note:, description:, ending_balance:, invoice:, starting_balance:, type:) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::Invoice::CustomerBalanceTransaction for more details.
|
|
# File 'lib/orb/models/invoice.rb', line 668
|
Instance Attribute Details
#action ⇒ Symbol, Orb::Models::Invoice::CustomerBalanceTransaction::Action
619 |
# File 'lib/orb/models/invoice.rb', line 619 required :action, enum: -> { Orb::Invoice::CustomerBalanceTransaction::Action } |
#amount ⇒ String
The value of the amount changed in the transaction.
625 |
# File 'lib/orb/models/invoice.rb', line 625 required :amount, String |
#created_at ⇒ Time
The creation time of this transaction.
631 |
# File 'lib/orb/models/invoice.rb', line 631 required :created_at, Time |
#credit_note ⇒ Orb::Models::CreditNoteTiny?
636 |
# File 'lib/orb/models/invoice.rb', line 636 required :credit_note, -> { Orb::CreditNoteTiny }, nil?: true |
#description ⇒ String?
An optional description provided for manual customer balance adjustments.
642 |
# File 'lib/orb/models/invoice.rb', line 642 required :description, String, nil?: true |
#ending_balance ⇒ String
The new value of the customer's balance prior to the transaction, in the customer's currency.
649 |
# File 'lib/orb/models/invoice.rb', line 649 required :ending_balance, String |
#id ⇒ String
A unique id for this transaction.
614 |
# File 'lib/orb/models/invoice.rb', line 614 required :id, String |
#invoice ⇒ Orb::Models::InvoiceTiny?
654 |
# File 'lib/orb/models/invoice.rb', line 654 required :invoice, -> { Orb::InvoiceTiny }, nil?: true |
#starting_balance ⇒ String
The original value of the customer's balance prior to the transaction, in the customer's currency.
661 |
# File 'lib/orb/models/invoice.rb', line 661 required :starting_balance, String |
#type ⇒ Symbol, Orb::Models::Invoice::CustomerBalanceTransaction::Type
666 |
# File 'lib/orb/models/invoice.rb', line 666 required :type, enum: -> { Orb::Invoice::CustomerBalanceTransaction::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/invoice.rb', line 707
|
Instance Method Details
#to_hash ⇒ {
346 |
# File 'sig/orb/models/invoice.rbs', line 346
def to_hash: -> {
|