Class: Orb::Models::InvoiceAccountingSyncSucceededWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::InvoiceAccountingSyncSucceededWebhookEvent
- Defined in:
- lib/orb/models/invoice_accounting_sync_succeeded_webhook_event.rb,
sig/orb/models/invoice_accounting_sync_succeeded_webhook_event.rbs
Defined Under Namespace
Modules: Type Classes: AccountingSyncRecord, Properties
Instance Attribute Summary collapse
- #accounting_sync_record ⇒ Orb::Models::InvoiceAccountingSyncSucceededWebhookEvent::AccountingSyncRecord
-
#created_at ⇒ Time
The time at which this event was created, to the second.
-
#id ⇒ String
The ID of this webhook event.
-
#invoice ⇒ Orb::Models::Invoice
An
Invoiceis a fundamental billing entity, representing the request for payment for a single subscription. - #properties ⇒ Orb::Models::InvoiceAccountingSyncSucceededWebhookEvent::Properties
-
#type ⇒ Symbol, Orb::Models::InvoiceAccountingSyncSucceededWebhookEvent::Type
The event this payload describes.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(connection_type:) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(connection_type:) ⇒ Object
|
|
# File 'lib/orb/models/invoice_accounting_sync_succeeded_webhook_event.rb', line 45
|
Instance Attribute Details
#accounting_sync_record ⇒ Orb::Models::InvoiceAccountingSyncSucceededWebhookEvent::AccountingSyncRecord
15 16 |
# File 'lib/orb/models/invoice_accounting_sync_succeeded_webhook_event.rb', line 15 required :accounting_sync_record, -> { Orb::InvoiceAccountingSyncSucceededWebhookEvent::AccountingSyncRecord } |
#created_at ⇒ Time
The time at which this event was created, to the second.
22 |
# File 'lib/orb/models/invoice_accounting_sync_succeeded_webhook_event.rb', line 22 required :created_at, Time |
#id ⇒ String
The ID of this webhook event.
10 |
# File 'lib/orb/models/invoice_accounting_sync_succeeded_webhook_event.rb', line 10 required :id, String |
#invoice ⇒ Orb::Models::Invoice
An Invoice is a fundamental billing entity,
representing the request for payment for a single subscription. This includes a
set of line items, which correspond to prices in the subscription's plan and can
represent fixed recurring fees or usage-based fees. They are generated at the
end of a billing period, or as the result of an action, such as a cancellation.
32 |
# File 'lib/orb/models/invoice_accounting_sync_succeeded_webhook_event.rb', line 32 required :invoice, -> { Orb::Invoice } |
#properties ⇒ Orb::Models::InvoiceAccountingSyncSucceededWebhookEvent::Properties
37 |
# File 'lib/orb/models/invoice_accounting_sync_succeeded_webhook_event.rb', line 37 required :properties, -> { Orb::InvoiceAccountingSyncSucceededWebhookEvent::Properties } |
#type ⇒ Symbol, Orb::Models::InvoiceAccountingSyncSucceededWebhookEvent::Type
The event this payload describes.
43 |
# File 'lib/orb/models/invoice_accounting_sync_succeeded_webhook_event.rb', line 43 required :type, enum: -> { Orb::InvoiceAccountingSyncSucceededWebhookEvent::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/invoice_accounting_sync_succeeded_webhook_event.rb', line 129
|
Instance Method Details
#to_hash ⇒ {
35 |
# File 'sig/orb/models/invoice_accounting_sync_succeeded_webhook_event.rbs', line 35
def to_hash: -> {
|