Class: Orb::Models::InvoiceDueDateRecalculationStartedWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::InvoiceDueDateRecalculationStartedWebhookEvent
- Defined in:
- lib/orb/models/invoice_due_date_recalculation_started_webhook_event.rb,
sig/orb/models/invoice_due_date_recalculation_started_webhook_event.rbs
Defined Under Namespace
Modules: Type Classes: Properties
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The time at which this event was created, to the second.
-
#id ⇒ String
The ID of this webhook event.
- #properties ⇒ Orb::Models::InvoiceDueDateRecalculationStartedWebhookEvent::Properties
-
#type ⇒ Symbol, Orb::Models::InvoiceDueDateRecalculationStartedWebhookEvent::Type
The event this payload describes.
Instance Method Summary collapse
- #initialize(started_at:) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(started_at:) ⇒ Object
|
|
# File 'lib/orb/models/invoice_due_date_recalculation_started_webhook_event.rb', line 29
|
Instance Attribute Details
#created_at ⇒ Time
The time at which this event was created, to the second.
16 |
# File 'lib/orb/models/invoice_due_date_recalculation_started_webhook_event.rb', line 16 required :created_at, Time |
#id ⇒ String
The ID of this webhook event.
10 |
# File 'lib/orb/models/invoice_due_date_recalculation_started_webhook_event.rb', line 10 required :id, String |
#properties ⇒ Orb::Models::InvoiceDueDateRecalculationStartedWebhookEvent::Properties
21 |
# File 'lib/orb/models/invoice_due_date_recalculation_started_webhook_event.rb', line 21 required :properties, -> { Orb::InvoiceDueDateRecalculationStartedWebhookEvent::Properties } |
#type ⇒ Symbol, Orb::Models::InvoiceDueDateRecalculationStartedWebhookEvent::Type
The event this payload describes.
27 |
# File 'lib/orb/models/invoice_due_date_recalculation_started_webhook_event.rb', line 27 required :type, enum: -> { Orb::InvoiceDueDateRecalculationStartedWebhookEvent::Type } |
Instance Method Details
#to_hash ⇒ {
27 |
# File 'sig/orb/models/invoice_due_date_recalculation_started_webhook_event.rbs', line 27
def to_hash: -> {
|