Class: Orb::Models::InvoiceDunningScheduleStepExecutedWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::InvoiceDunningScheduleStepExecutedWebhookEvent
- Defined in:
- lib/orb/models/invoice_dunning_schedule_step_executed_webhook_event.rb,
sig/orb/models/invoice_dunning_schedule_step_executed_webhook_event.rbs
Defined Under Namespace
Modules: Type Classes: Properties
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The time at which this event was created, to the second.
-
#id ⇒ String
The ID of this webhook event.
-
#invoice ⇒ Orb::Models::Invoice
An
Invoiceis a fundamental billing entity, representing the request for payment for a single subscription. - #properties ⇒ Orb::Models::InvoiceDunningScheduleStepExecutedWebhookEvent::Properties
-
#type ⇒ Symbol, Orb::Models::InvoiceDunningScheduleStepExecutedWebhookEvent::Type
The event this payload describes.
Instance Method Summary collapse
- #initialize(actions:, created_at:, execution_time:, manually_triggered_at:, modified_at:, status:, step_number:, timestamp:) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(actions:, created_at:, execution_time:, manually_triggered_at:, modified_at:, status:, step_number:, timestamp:) ⇒ Object
|
|
# File 'lib/orb/models/invoice_dunning_schedule_step_executed_webhook_event.rb', line 39
|
Instance Attribute Details
#created_at ⇒ Time
The time at which this event was created, to the second.
16 |
# File 'lib/orb/models/invoice_dunning_schedule_step_executed_webhook_event.rb', line 16 required :created_at, Time |
#id ⇒ String
The ID of this webhook event.
10 |
# File 'lib/orb/models/invoice_dunning_schedule_step_executed_webhook_event.rb', line 10 required :id, String |
#invoice ⇒ Orb::Models::Invoice
An Invoice is a fundamental billing entity,
representing the request for payment for a single subscription. This includes a
set of line items, which correspond to prices in the subscription's plan and can
represent fixed recurring fees or usage-based fees. They are generated at the
end of a billing period, or as the result of an action, such as a cancellation.
26 |
# File 'lib/orb/models/invoice_dunning_schedule_step_executed_webhook_event.rb', line 26 required :invoice, -> { Orb::Invoice } |
#properties ⇒ Orb::Models::InvoiceDunningScheduleStepExecutedWebhookEvent::Properties
31 |
# File 'lib/orb/models/invoice_dunning_schedule_step_executed_webhook_event.rb', line 31 required :properties, -> { Orb::InvoiceDunningScheduleStepExecutedWebhookEvent::Properties } |
#type ⇒ Symbol, Orb::Models::InvoiceDunningScheduleStepExecutedWebhookEvent::Type
The event this payload describes.
37 |
# File 'lib/orb/models/invoice_dunning_schedule_step_executed_webhook_event.rb', line 37 required :type, enum: -> { Orb::InvoiceDunningScheduleStepExecutedWebhookEvent::Type } |
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/orb/models/invoice_dunning_schedule_step_executed_webhook_event.rbs', line 31
def to_hash: -> {
|