Module: Orb::Models::InvoiceEditedWebhookEvent::Properties::PreviousAttributes::LineItem::Adjustment

Extended by:
Internal::Type::Union
Defined in:
lib/orb/models/invoice_edited_webhook_event.rb,
sig/orb/models/invoice_edited_webhook_event.rbs

Defined Under Namespace

Classes: TieredPercentageDiscount

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(id:, adjusted_subtotal:, adjustments:, amount:, credits_applied:, end_date:, filter:, grouping:, name:, partially_invoiced_amount:, price:, quantity:, start_date:, sub_line_items:, subtotal:, tax_amounts:, usage_customer_ids:) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::InvoiceEditedWebhookEvent::Properties::PreviousAttributes::LineItem for more details.

Parameters:



308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
# File 'lib/orb/models/invoice_edited_webhook_event.rb', line 308

module Adjustment
  extend Orb::Internal::Type::Union

  discriminator :adjustment_type

  variant :usage_discount, -> { Orb::MonetaryUsageDiscountAdjustment }

  variant :amount_discount, -> { Orb::MonetaryAmountDiscountAdjustment }

  variant :percentage_discount, -> { Orb::MonetaryPercentageDiscountAdjustment }

  variant :tiered_percentage_discount,
          -> { Orb::InvoiceEditedWebhookEvent::Properties::PreviousAttributes::LineItem::Adjustment::TieredPercentageDiscount }

  variant :minimum, -> { Orb::MonetaryMinimumAdjustment }

  variant :maximum, -> { Orb::MonetaryMaximumAdjustment }

  class TieredPercentageDiscount < Orb::Internal::Type::BaseModel
    # @!attribute id
    #
    #   @return [String]
    required :id, String

    # @!attribute adjustment_type
    #
    #   @return [Symbol, :tiered_percentage_discount]
    required :adjustment_type, const: :tiered_percentage_discount

    # @!attribute amount
    #   The value applied by an adjustment.
    #
    #   @return [String]
    required :amount, String

    # @!attribute applies_to_price_ids
    #   @deprecated
    #
    #   The price IDs that this adjustment applies to.
    #
    #   @return [Array<String>]
    required :applies_to_price_ids, Orb::Internal::Type::ArrayOf[String]

    # @!attribute filters
    #   The filters that determine which prices to apply this adjustment to.
    #
    #   @return [Array<Orb::Models::InvoiceEditedWebhookEvent::Properties::PreviousAttributes::LineItem::Adjustment::TieredPercentageDiscount::Filter>]
    required :filters,
             -> do
               Orb::Internal::Type::ArrayOf[
                 Orb::InvoiceEditedWebhookEvent::Properties::PreviousAttributes::LineItem::Adjustment::TieredPercentageDiscount::Filter
               ]
             end

    # @!attribute is_invoice_level
    #   True for adjustments that apply to an entire invoice, false for adjustments that
    #   apply to only one price.
    #
    #   @return [Boolean]
    required :is_invoice_level, Orb::Internal::Type::Boolean

    # @!attribute reason
    #   The reason for the adjustment.
    #
    #   @return [String, nil]
    required :reason, String, nil?: true

    # @!attribute replaces_adjustment_id
    #   The adjustment id this adjustment replaces. This adjustment will take the place
    #   of the replaced adjustment in plan version migrations.
    #
    #   @return [String, nil]
    required :replaces_adjustment_id, String, nil?: true

    # @!attribute tiers
    #   The ordered, contiguous bands of cumulative eligible spend, each discounted at
    #   its own percentage (progressive fill-a-tier), applied to the prices this
    #   adjustment covers in a given billing period.
    #
    #   @return [Array<Orb::Models::InvoiceEditedWebhookEvent::Properties::PreviousAttributes::LineItem::Adjustment::TieredPercentageDiscount::Tier>]
    required :tiers,
             -> do
               Orb::Internal::Type::ArrayOf[
                 Orb::InvoiceEditedWebhookEvent::Properties::PreviousAttributes::LineItem::Adjustment::TieredPercentageDiscount::Tier
               ]
             end

    # @!method initialize(id:, amount:, applies_to_price_ids:, filters:, is_invoice_level:, reason:, replaces_adjustment_id:, tiers:, adjustment_type: :tiered_percentage_discount)
    #   Some parameter documentations has been truncated, see
    #   {Orb::Models::InvoiceEditedWebhookEvent::Properties::PreviousAttributes::LineItem::Adjustment::TieredPercentageDiscount}
    #   for more details.
    #
    #   @param id [String]
    #
    #   @param amount [String] The value applied by an adjustment.
    #
    #   @param applies_to_price_ids [Array<String>] The price IDs that this adjustment applies to.
    #
    #   @param filters [Array<Orb::Models::InvoiceEditedWebhookEvent::Properties::PreviousAttributes::LineItem::Adjustment::TieredPercentageDiscount::Filter>] The filters that determine which prices to apply this adjustment to.
    #
    #   @param is_invoice_level [Boolean] True for adjustments that apply to an entire invoice, false for adjustments that
    #
    #   @param reason [String, nil] The reason for the adjustment.
    #
    #   @param replaces_adjustment_id [String, nil] The adjustment id this adjustment replaces. This adjustment will take the place
    #
    #   @param tiers [Array<Orb::Models::InvoiceEditedWebhookEvent::Properties::PreviousAttributes::LineItem::Adjustment::TieredPercentageDiscount::Tier>] The ordered, contiguous bands of cumulative eligible spend, each discounted at i
    #
    #   @param adjustment_type [Symbol, :tiered_percentage_discount]

    class Filter < Orb::Internal::Type::BaseModel
      # @!attribute field
      #   The property of the price to filter on.
      #
      #   @return [Symbol, Orb::Models::InvoiceEditedWebhookEvent::Properties::PreviousAttributes::LineItem::Adjustment::TieredPercentageDiscount::Filter::Field]
      required :field,
               enum: -> { Orb::InvoiceEditedWebhookEvent::Properties::PreviousAttributes::LineItem::Adjustment::TieredPercentageDiscount::Filter::Field }

      # @!attribute operator
      #   Should prices that match the filter be included or excluded.
      #
      #   @return [Symbol, Orb::Models::InvoiceEditedWebhookEvent::Properties::PreviousAttributes::LineItem::Adjustment::TieredPercentageDiscount::Filter::Operator]
      required :operator,
               enum: -> { Orb::InvoiceEditedWebhookEvent::Properties::PreviousAttributes::LineItem::Adjustment::TieredPercentageDiscount::Filter::Operator }

      # @!attribute values
      #   The IDs or values that match this filter.
      #
      #   @return [Array<String>]
      required :values, Orb::Internal::Type::ArrayOf[String]

      # @!method initialize(field:, operator:, values:)
      #   @param field [Symbol, Orb::Models::InvoiceEditedWebhookEvent::Properties::PreviousAttributes::LineItem::Adjustment::TieredPercentageDiscount::Filter::Field] The property of the price to filter on.
      #
      #   @param operator [Symbol, Orb::Models::InvoiceEditedWebhookEvent::Properties::PreviousAttributes::LineItem::Adjustment::TieredPercentageDiscount::Filter::Operator] Should prices that match the filter be included or excluded.
      #
      #   @param values [Array<String>] The IDs or values that match this filter.

      # The property of the price to filter on.
      #
      # @see Orb::Models::InvoiceEditedWebhookEvent::Properties::PreviousAttributes::LineItem::Adjustment::TieredPercentageDiscount::Filter#field
      module Field
        extend Orb::Internal::Type::Enum

        PRICE_ID = :price_id
        ITEM_ID = :item_id
        PRICE_TYPE = :price_type
        CURRENCY = :currency
        PRICING_UNIT_ID = :pricing_unit_id

        # @!method self.values
        #   @return [Array<Symbol>]
      end

      # Should prices that match the filter be included or excluded.
      #
      # @see Orb::Models::InvoiceEditedWebhookEvent::Properties::PreviousAttributes::LineItem::Adjustment::TieredPercentageDiscount::Filter#operator
      module Operator
        extend Orb::Internal::Type::Enum

        INCLUDES = :includes
        EXCLUDES = :excludes

        # @!method self.values
        #   @return [Array<Symbol>]
      end
    end

    class Tier < Orb::Internal::Type::BaseModel
      # @!attribute lower_bound
      #   Exclusive lower bound of cumulative spend for this tier.
      #
      #   @return [Float]
      required :lower_bound, Float

      # @!attribute percentage
      #   The percentage (between 0 and 1) discounted from spend that falls within this
      #   tier.
      #
      #   @return [Float]
      required :percentage, Float

      # @!attribute upper_bound
      #   Inclusive upper bound of cumulative spend for this tier; null for the final
      #   open-ended tier.
      #
      #   @return [Float, nil]
      optional :upper_bound, Float, nil?: true

      # @!method initialize(lower_bound:, percentage:, upper_bound: nil)
      #   Some parameter documentations has been truncated, see
      #   {Orb::Models::InvoiceEditedWebhookEvent::Properties::PreviousAttributes::LineItem::Adjustment::TieredPercentageDiscount::Tier}
      #   for more details.
      #
      #   One band of a tiered percentage discount. Bounds are denominated in the
      #   discount's currency. `lower_bound` is the exclusive start of the band and
      #   `upper_bound` is the inclusive end; `upper_bound` is null only for the
      #   open-ended final tier.
      #
      #   @param lower_bound [Float] Exclusive lower bound of cumulative spend for this tier.
      #
      #   @param percentage [Float] The percentage (between 0 and 1) discounted from spend that falls within this ti
      #
      #   @param upper_bound [Float, nil] Inclusive upper bound of cumulative spend for this tier; null for the final open
    end
  end

  # @!method self.variants
  #   @return [Array(Orb::Models::MonetaryUsageDiscountAdjustment, Orb::Models::MonetaryAmountDiscountAdjustment, Orb::Models::MonetaryPercentageDiscountAdjustment, Orb::Models::InvoiceEditedWebhookEvent::Properties::PreviousAttributes::LineItem::Adjustment::TieredPercentageDiscount, Orb::Models::MonetaryMinimumAdjustment, Orb::Models::MonetaryMaximumAdjustment)]
end

#self?.variants ⇒ ::Array[Orb::Models::InvoiceEditedWebhookEvent::Properties::PreviousAttributes::LineItem::adjustment]

Returns:

  • (::Array[Orb::Models::InvoiceEditedWebhookEvent::Properties::PreviousAttributes::LineItem::adjustment])


360
# File 'sig/orb/models/invoice_edited_webhook_event.rbs', line 360

def self?.variants: -> ::Array[Orb::Models::InvoiceEditedWebhookEvent::Properties::PreviousAttributes::LineItem::adjustment]