Class: Orb::Models::InvoiceFetchParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/orb/models/invoice_fetch_params.rb,
sig/orb/models/invoice_fetch_params.rbs

Overview

See Also:

  • Orb::Resources::Invoices#fetch

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(invoice_id:, include_zero_quantity_line_items: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::InvoiceFetchParams for more details.

Parameters:

  • invoice_id (String)
  • include_zero_quantity_line_items (Boolean, nil) (defaults to: nil) —

    Whether to return line items with a quantity of zero. When omitted, Orb returns

  • request_options (Orb::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/orb/models/invoice_fetch_params.rb', line 23


Instance Attribute Details

#include_zero_quantity_line_items ⇒ Boolean?

Whether to return line items with a quantity of zero. When omitted, Orb returns every line item. A line item that is grouped as part of a line item minimum is always returned; an invoice-level minimum does not exempt it.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


21
# File 'lib/orb/models/invoice_fetch_params.rb', line 21

optional :include_zero_quantity_line_items, Orb::Internal::Type::Boolean, nil?: true

#invoice_id ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/orb/models/invoice_fetch_params.rb', line 13

required :invoice_id, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


21
# File 'sig/orb/models/invoice_fetch_params.rbs', line 21

def to_hash: -> {