Class: Orb::Models::InvoiceFetchUpcomingResponse::CreditNote

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/invoice_fetch_upcoming_response.rb,
sig/orb/models/invoice_fetch_upcoming_response.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



277
# File 'sig/orb/models/invoice_fetch_upcoming_response.rbs', line 277

def initialize: (

Instance Attribute Details

#credit_note_numberString

Parameters:

  • value (String)

Returns:

  • (String)


558
# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 558

required :credit_note_number, String

#idString

Parameters:

  • value (String)

Returns:

  • (String)


553
# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 553

required :id, String

#memoString?

An optional memo supplied on the credit note.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


564
# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 564

required :memo, String, nil?: true

#reasonString

Parameters:

  • value (String)

Returns:

  • (String)


569
# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 569

required :reason, String

#totalString

Parameters:

  • value (String)

Returns:

  • (String)


574
# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 574

required :total, String

#typeString

Parameters:

  • value (String)

Returns:

  • (String)


579
# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 579

required :type, String

#voided_atTime?

If the credit note has a status of void, this gives a timestamp when the credit note was voided.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


586
# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 586

required :voided_at, Time, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


287
# File 'sig/orb/models/invoice_fetch_upcoming_response.rbs', line 287

def to_hash: -> {