Class: Orb::Models::InvoiceFetchUpcomingResponse::CustomerBalanceTransaction

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/invoice_fetch_upcoming_response.rb,
sig/orb/models/invoice_fetch_upcoming_response.rbs

Defined Under Namespace

Modules: Action, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, action:, amount:, created_at:, credit_note:, description:, ending_balance:, invoice:, starting_balance:, type:) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::InvoiceFetchUpcomingResponse::CustomerBalanceTransaction for more details.

Parameters:



# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 667

Instance Attribute Details

#actionSymbol, Orb::Models::InvoiceFetchUpcomingResponse::CustomerBalanceTransaction::Action

Parameters:

  • value (Orb::Models::InvoiceFetchUpcomingResponse::CustomerBalanceTransaction::action)

Returns:



617
618
# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 617

required :action,
enum: -> { Orb::Models::InvoiceFetchUpcomingResponse::CustomerBalanceTransaction::Action }

#amountString

The value of the amount changed in the transaction.

Parameters:

  • value (String)

Returns:

  • (String)


624
# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 624

required :amount, String

#created_atTime

The creation time of this transaction.

Parameters:

  • value (Time)

Returns:

  • (Time)


630
# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 630

required :created_at, Time

#credit_noteOrb::Models::CreditNoteTiny?

Parameters:

Returns:



635
# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 635

required :credit_note, -> { Orb::CreditNoteTiny }, nil?: true

#descriptionString?

An optional description provided for manual customer balance adjustments.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


641
# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 641

required :description, String, nil?: true

#ending_balanceString

The new value of the customer's balance prior to the transaction, in the customer's currency.

Parameters:

  • value (String)

Returns:

  • (String)


648
# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 648

required :ending_balance, String

#idString

A unique id for this transaction.

Parameters:

  • value (String)

Returns:

  • (String)


612
# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 612

required :id, String

#invoiceOrb::Models::InvoiceTiny?

Parameters:

Returns:



653
# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 653

required :invoice, -> { Orb::InvoiceTiny }, nil?: true

#starting_balanceString

The original value of the customer's balance prior to the transaction, in the customer's currency.

Parameters:

  • value (String)

Returns:

  • (String)


660
# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 660

required :starting_balance, String

#typeSymbol, Orb::Models::InvoiceFetchUpcomingResponse::CustomerBalanceTransaction::Type

Parameters:

  • value (Orb::Models::InvoiceFetchUpcomingResponse::CustomerBalanceTransaction::type_)

Returns:



665
# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 665

required :type, enum: -> { Orb::Models::InvoiceFetchUpcomingResponse::CustomerBalanceTransaction::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 707

Instance Method Details

#to_hash{

Returns:

  • ({)


346
# File 'sig/orb/models/invoice_fetch_upcoming_response.rbs', line 346

def to_hash: -> {