Class: Orb::Models::InvoiceFetchUpcomingResponse::PaymentAttempt

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/invoice_fetch_upcoming_response.rb,
sig/orb/models/invoice_fetch_upcoming_response.rbs

Defined Under Namespace

Modules: PaymentProvider

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, amount:, created_at:, payment_provider:, payment_provider_id:, receipt_pdf:, succeeded:) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::InvoiceFetchUpcomingResponse::PaymentAttempt for more details.

Parameters:

  • id (String) —

    The ID of the payment attempt.

  • amount (String) —

    The amount of the payment attempt.

  • created_at (Time) —

    The time at which the payment attempt was created.

  • payment_provider (Symbol, Orb::Models::InvoiceFetchUpcomingResponse::PaymentAttempt::PaymentProvider, nil) —

    The payment provider that attempted to collect the payment.

  • payment_provider_id (String, nil) —

    The ID of the payment attempt in the payment provider.

  • receipt_pdf (String, nil) —

    URL to the downloadable PDF version of the receipt. This field will be null fo

  • succeeded (Boolean) —

    Whether the payment attempt succeeded.



# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 1172

Instance Attribute Details

#amount ⇒ String

The amount of the payment attempt.

Parameters:

  • value (String)

Returns:

  • (String)


1137
# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 1137

required :amount, String

#created_at ⇒ Time

The time at which the payment attempt was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


1143
# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 1143

required :created_at, Time

#id ⇒ String

The ID of the payment attempt.

Parameters:

  • value (String)

Returns:

  • (String)


1131
# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 1131

required :id, String

#payment_provider ⇒ Symbol, ...

The payment provider that attempted to collect the payment.

Parameters:

  • value (Orb::Models::InvoiceFetchUpcomingResponse::PaymentAttempt::payment_provider, nil)

Returns:



1149
1150
1151
# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 1149

required :payment_provider,
enum: -> { Orb::Models::InvoiceFetchUpcomingResponse::PaymentAttempt::PaymentProvider },
nil?: true

#payment_provider_id ⇒ String?

The ID of the payment attempt in the payment provider.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1157
# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 1157

required :payment_provider_id, String, nil?: true

#receipt_pdf ⇒ String?

URL to the downloadable PDF version of the receipt. This field will be null for payment attempts that did not succeed.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1164
# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 1164

required :receipt_pdf, String, nil?: true

#succeeded ⇒ Boolean

Whether the payment attempt succeeded.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


1170
# File 'lib/orb/models/invoice_fetch_upcoming_response.rb', line 1170

required :succeeded, Orb::Internal::Type::Boolean

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


712
# File 'sig/orb/models/invoice_fetch_upcoming_response.rbs', line 712

def to_hash: -> {