Class: Orb::Models::InvoiceIssueSummaryParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::InvoiceIssueSummaryParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/orb/models/invoice_issue_summary_params.rb,
sig/orb/models/invoice_issue_summary_params.rbs
Overview
Instance Attribute Summary collapse
- #invoice_id ⇒ String
-
#synchronous ⇒ Boolean?
If true, the invoice will be issued synchronously.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(invoice_id:, synchronous: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see InvoiceIssueSummaryParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(invoice_id:, synchronous: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::InvoiceIssueSummaryParams for more details.
|
|
# File 'lib/orb/models/invoice_issue_summary_params.rb', line 25
|
Instance Attribute Details
#invoice_id ⇒ String
13 |
# File 'lib/orb/models/invoice_issue_summary_params.rb', line 13 required :invoice_id, String |
#synchronous ⇒ Boolean?
If true, the invoice will be issued synchronously. If false, the invoice will be issued asynchronously. The synchronous option is only available for invoices that have no usage fees. If the invoice is configured to sync to an external provider, a successful response from this endpoint guarantees the invoice is present in the provider.
23 |
# File 'lib/orb/models/invoice_issue_summary_params.rb', line 23 optional :synchronous, Orb::Internal::Type::Boolean |
Instance Method Details
#to_hash ⇒ {
23 |
# File 'sig/orb/models/invoice_issue_summary_params.rbs', line 23
def to_hash: -> {
|