Class: Orb::Models::InvoiceListSummaryResponse::CustomerBalanceTransaction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::InvoiceListSummaryResponse::CustomerBalanceTransaction
- Defined in:
- lib/orb/models/invoice_list_summary_response.rb,
sig/orb/models/invoice_list_summary_response.rbs
Defined Under Namespace
Instance Attribute Summary collapse
- #action ⇒ Symbol, Orb::Models::InvoiceListSummaryResponse::CustomerBalanceTransaction::Action
-
#amount ⇒ String
The value of the amount changed in the transaction.
-
#created_at ⇒ Time
The creation time of this transaction.
- #credit_note ⇒ Orb::Models::CreditNoteTiny?
-
#description ⇒ String?
An optional description provided for manual customer balance adjustments.
-
#ending_balance ⇒ String
The new value of the customer's balance prior to the transaction, in the customer's currency.
-
#id ⇒ String
A unique id for this transaction.
- #invoice ⇒ Orb::Models::InvoiceTiny?
-
#starting_balance ⇒ String
The original value of the customer's balance prior to the transaction, in the customer's currency.
- #type ⇒ Symbol, Orb::Models::InvoiceListSummaryResponse::CustomerBalanceTransaction::Type
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, action:, amount:, created_at:, credit_note:, description:, ending_balance:, invoice:, starting_balance:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CustomerBalanceTransaction for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, action:, amount:, created_at:, credit_note:, description:, ending_balance:, invoice:, starting_balance:, type:) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::InvoiceListSummaryResponse::CustomerBalanceTransaction for more details.
|
|
# File 'lib/orb/models/invoice_list_summary_response.rb', line 604
|
Instance Attribute Details
#action ⇒ Symbol, Orb::Models::InvoiceListSummaryResponse::CustomerBalanceTransaction::Action
555 |
# File 'lib/orb/models/invoice_list_summary_response.rb', line 555 required :action, enum: -> { Orb::Models::InvoiceListSummaryResponse::CustomerBalanceTransaction::Action } |
#amount ⇒ String
The value of the amount changed in the transaction.
561 |
# File 'lib/orb/models/invoice_list_summary_response.rb', line 561 required :amount, String |
#created_at ⇒ Time
The creation time of this transaction.
567 |
# File 'lib/orb/models/invoice_list_summary_response.rb', line 567 required :created_at, Time |
#credit_note ⇒ Orb::Models::CreditNoteTiny?
572 |
# File 'lib/orb/models/invoice_list_summary_response.rb', line 572 required :credit_note, -> { Orb::CreditNoteTiny }, nil?: true |
#description ⇒ String?
An optional description provided for manual customer balance adjustments.
578 |
# File 'lib/orb/models/invoice_list_summary_response.rb', line 578 required :description, String, nil?: true |
#ending_balance ⇒ String
The new value of the customer's balance prior to the transaction, in the customer's currency.
585 |
# File 'lib/orb/models/invoice_list_summary_response.rb', line 585 required :ending_balance, String |
#id ⇒ String
A unique id for this transaction.
550 |
# File 'lib/orb/models/invoice_list_summary_response.rb', line 550 required :id, String |
#invoice ⇒ Orb::Models::InvoiceTiny?
590 |
# File 'lib/orb/models/invoice_list_summary_response.rb', line 590 required :invoice, -> { Orb::InvoiceTiny }, nil?: true |
#starting_balance ⇒ String
The original value of the customer's balance prior to the transaction, in the customer's currency.
597 |
# File 'lib/orb/models/invoice_list_summary_response.rb', line 597 required :starting_balance, String |
#type ⇒ Symbol, Orb::Models::InvoiceListSummaryResponse::CustomerBalanceTransaction::Type
602 |
# File 'lib/orb/models/invoice_list_summary_response.rb', line 602 required :type, enum: -> { Orb::Models::InvoiceListSummaryResponse::CustomerBalanceTransaction::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/invoice_list_summary_response.rb', line 644
|
Instance Method Details
#to_hash ⇒ {
306 |
# File 'sig/orb/models/invoice_list_summary_response.rbs', line 306
def to_hash: -> {
|