Class: Orb::Models::InvoiceListSummaryResponse::PaymentAttempt

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/invoice_list_summary_response.rb,
sig/orb/models/invoice_list_summary_response.rbs

Defined Under Namespace

Modules: PaymentProvider

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, amount:, created_at:, payment_provider:, payment_provider_id:, receipt_pdf:, succeeded:) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::InvoiceListSummaryResponse::PaymentAttempt for more details.

Parameters:

  • id (String)

    The ID of the payment attempt.

  • amount (String)

    The amount of the payment attempt.

  • created_at (Time)

    The time at which the payment attempt was created.

  • payment_provider (Symbol, Orb::Models::InvoiceListSummaryResponse::PaymentAttempt::PaymentProvider, nil)

    The payment provider that attempted to collect the payment.

  • payment_provider_id (String, nil)

    The ID of the payment attempt in the payment provider.

  • receipt_pdf (String, nil)

    URL to the downloadable PDF version of the receipt. This field will be null fo

  • succeeded (Boolean)

    Whether the payment attempt succeeded.



# File 'lib/orb/models/invoice_list_summary_response.rb', line 718

Instance Attribute Details

#amountString

The amount of the payment attempt.

Parameters:

  • value (String)

Returns:

  • (String)


683
# File 'lib/orb/models/invoice_list_summary_response.rb', line 683

required :amount, String

#created_atTime

The time at which the payment attempt was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


689
# File 'lib/orb/models/invoice_list_summary_response.rb', line 689

required :created_at, Time

#idString

The ID of the payment attempt.

Parameters:

  • value (String)

Returns:

  • (String)


677
# File 'lib/orb/models/invoice_list_summary_response.rb', line 677

required :id, String

#payment_providerSymbol, ...

The payment provider that attempted to collect the payment.

Parameters:

  • value (Orb::Models::InvoiceListSummaryResponse::PaymentAttempt::payment_provider, nil)

Returns:



695
696
697
# File 'lib/orb/models/invoice_list_summary_response.rb', line 695

required :payment_provider,
enum: -> { Orb::Models::InvoiceListSummaryResponse::PaymentAttempt::PaymentProvider },
nil?: true

#payment_provider_idString?

The ID of the payment attempt in the payment provider.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


703
# File 'lib/orb/models/invoice_list_summary_response.rb', line 703

required :payment_provider_id, String, nil?: true

#receipt_pdfString?

URL to the downloadable PDF version of the receipt. This field will be null for payment attempts that did not succeed.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


710
# File 'lib/orb/models/invoice_list_summary_response.rb', line 710

required :receipt_pdf, String, nil?: true

#succeededBoolean

Whether the payment attempt succeeded.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


716
# File 'lib/orb/models/invoice_list_summary_response.rb', line 716

required :succeeded, Orb::Internal::Type::Boolean

Instance Method Details

#to_hash{

Returns:

  • ({)


408
# File 'sig/orb/models/invoice_list_summary_response.rbs', line 408

def to_hash: -> {