Class: Orb::Models::InvoiceMarkPaidParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::InvoiceMarkPaidParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/orb/models/invoice_mark_paid_params.rb,
sig/orb/models/invoice_mark_paid_params.rbs
Overview
Instance Attribute Summary collapse
-
#external_id ⇒ String?
An optional external ID to associate with the payment.
- #invoice_id ⇒ String
-
#notes ⇒ String?
An optional note to associate with the payment.
-
#payment_received_date ⇒ Date
A date string to specify the date of the payment.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(invoice_id:, payment_received_date:, external_id: nil, notes: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(invoice_id:, payment_received_date:, external_id: nil, notes: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/orb/models/invoice_mark_paid_params.rb', line 33
|
Instance Attribute Details
#external_id ⇒ String?
An optional external ID to associate with the payment.
25 |
# File 'lib/orb/models/invoice_mark_paid_params.rb', line 25 optional :external_id, String, nil?: true |
#invoice_id ⇒ String
13 |
# File 'lib/orb/models/invoice_mark_paid_params.rb', line 13 required :invoice_id, String |
#notes ⇒ String?
An optional note to associate with the payment.
31 |
# File 'lib/orb/models/invoice_mark_paid_params.rb', line 31 optional :notes, String, nil?: true |
#payment_received_date ⇒ Date
A date string to specify the date of the payment.
19 |
# File 'lib/orb/models/invoice_mark_paid_params.rb', line 19 required :payment_received_date, Date |
Instance Method Details
#to_hash ⇒ {
32 |
# File 'sig/orb/models/invoice_mark_paid_params.rbs', line 32
def to_hash: -> {
|