Class: Orb::Models::InvoicePaymentFailedWebhookEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/invoice_payment_failed_webhook_event.rb,
sig/orb/models/invoice_payment_failed_webhook_event.rbs

Defined Under Namespace

Modules: Type Classes: Properties

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(payment_provider:, payment_provider_id:, payment_provider_transaction_id:) ⇒ Object

Parameters:

  • payment_provider (String, nil)
  • payment_provider_id (String, nil)
  • payment_provider_transaction_id (String, nil)


# File 'lib/orb/models/invoice_payment_failed_webhook_event.rb', line 39

Instance Attribute Details

#created_at ⇒ Time

The time at which this event was created, to the second.

Parameters:

  • value (Time)

Returns:

  • (Time)


16
# File 'lib/orb/models/invoice_payment_failed_webhook_event.rb', line 16

required :created_at, Time

#id ⇒ String

The ID of this webhook event.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/orb/models/invoice_payment_failed_webhook_event.rb', line 10

required :id, String

#invoice ⇒ Orb::Models::Invoice

An Invoice is a fundamental billing entity, representing the request for payment for a single subscription. This includes a set of line items, which correspond to prices in the subscription's plan and can represent fixed recurring fees or usage-based fees. They are generated at the end of a billing period, or as the result of an action, such as a cancellation.

Parameters:

Returns:



26
# File 'lib/orb/models/invoice_payment_failed_webhook_event.rb', line 26

required :invoice, -> { Orb::Invoice }

#properties ⇒ Orb::Models::InvoicePaymentFailedWebhookEvent::Properties

Parameters:

  • value (Orb::InvoicePaymentFailedWebhookEvent::Properties)

Returns:



31
# File 'lib/orb/models/invoice_payment_failed_webhook_event.rb', line 31

required :properties, -> { Orb::InvoicePaymentFailedWebhookEvent::Properties }

#type ⇒ Symbol, Orb::Models::InvoicePaymentFailedWebhookEvent::Type

The event this payload describes.

Parameters:

  • value (Orb::Models::InvoicePaymentFailedWebhookEvent::type_)

Returns:



37
# File 'lib/orb/models/invoice_payment_failed_webhook_event.rb', line 37

required :type, enum: -> { Orb::InvoicePaymentFailedWebhookEvent::Type }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


31
# File 'sig/orb/models/invoice_payment_failed_webhook_event.rbs', line 31

def to_hash: -> {