Class: Orb::Models::ItemUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/orb/models/item_update_params.rb,
sig/orb/models/item_update_params.rbs

Overview

See Also:

  • Orb::Resources::Items#update

Defined Under Namespace

Classes: ExternalConnection

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



24
# File 'sig/orb/models/item_update_params.rbs', line 24

def initialize: (

Instance Attribute Details

#external_connectionsArray<Orb::Models::ItemUpdateParams::ExternalConnection>?

Parameters:

  • value (::Array[Orb::ItemUpdateParams::ExternalConnection], nil)

Returns:



18
19
20
# File 'lib/orb/models/item_update_params.rb', line 18

optional :external_connections,
-> { Orb::Internal::Type::ArrayOf[Orb::ItemUpdateParams::ExternalConnection] },
nil?: true

#item_idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/orb/models/item_update_params.rb', line 13

required :item_id, String

#metadataHash{Symbol=>String, nil}?

User-specified key/value pairs for the resource. Individual keys can be removed by setting the value to null, and the entire metadata mapping can be cleared by setting metadata to null.

Parameters:

  • value (::Hash[Symbol, String?], nil)

Returns:

  • (Hash{Symbol=>String, nil}, nil)


28
# File 'lib/orb/models/item_update_params.rb', line 28

optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true

#nameString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


33
# File 'lib/orb/models/item_update_params.rb', line 33

optional :name, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


32
# File 'sig/orb/models/item_update_params.rbs', line 32

def to_hash: -> {