Class: Orb::Models::ItemUpdateParams::ExternalConnection
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::ItemUpdateParams::ExternalConnection
- Defined in:
- lib/orb/models/item_update_params.rb,
sig/orb/models/item_update_params.rbs
Defined Under Namespace
Modules: ExternalConnectionName
Instance Attribute Summary collapse
-
#external_connection_name ⇒ Symbol, Orb::Models::ItemUpdateParams::ExternalConnection::ExternalConnectionName
The name of the external system this item is connected to.
-
#external_entity_id ⇒ String
The identifier of this item in the external system.
Instance Method Summary collapse
-
#initialize(external_connection_name:, external_entity_id:) ⇒ Object
constructor
Represents a connection between an Item and an external system for invoicing or tax calculation purposes.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(external_connection_name:, external_entity_id:) ⇒ Object
Represents a connection between an Item and an external system for invoicing or tax calculation purposes.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/orb/models/item_update_params.rb', line 49 class ExternalConnection < Orb::Internal::Type::BaseModel # @!attribute external_connection_name # The name of the external system this item is connected to. # # @return [Symbol, Orb::Models::ItemUpdateParams::ExternalConnection::ExternalConnectionName] required :external_connection_name, enum: -> { Orb::ItemUpdateParams::ExternalConnection::ExternalConnectionName } # @!attribute external_entity_id # The identifier of this item in the external system. # # @return [String] required :external_entity_id, String # @!method initialize(external_connection_name:, external_entity_id:) # Represents a connection between an Item and an external system for invoicing or # tax calculation purposes. # # @param external_connection_name [Symbol, Orb::Models::ItemUpdateParams::ExternalConnection::ExternalConnectionName] The name of the external system this item is connected to. # # @param external_entity_id [String] The identifier of this item in the external system. # The name of the external system this item is connected to. # # @see Orb::Models::ItemUpdateParams::ExternalConnection#external_connection_name module ExternalConnectionName extend Orb::Internal::Type::Enum STRIPE = :stripe QUICKBOOKS = :quickbooks BILL_COM = :"bill.com" NETSUITE = :netsuite TAXJAR = :taxjar AVALARA = :avalara ANROK = :anrok NUMERAL = :numeral STRIPE_TAX = :stripe_tax # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#external_connection_name ⇒ Symbol, Orb::Models::ItemUpdateParams::ExternalConnection::ExternalConnectionName
The name of the external system this item is connected to.
54 55 |
# File 'lib/orb/models/item_update_params.rb', line 54 required :external_connection_name, enum: -> { Orb::ItemUpdateParams::ExternalConnection::ExternalConnectionName } |
#external_entity_id ⇒ String
The identifier of this item in the external system.
61 |
# File 'lib/orb/models/item_update_params.rb', line 61 required :external_entity_id, String |
Instance Method Details
#to_hash ⇒ {
56 |
# File 'sig/orb/models/item_update_params.rbs', line 56
def to_hash: -> {
|