Class: Orb::Models::LicenseRetrieveByExternalIDParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/orb/models/license_retrieve_by_external_id_params.rb,
sig/orb/models/license_retrieve_by_external_id_params.rbs

Overview

See Also:

  • Orb::Resources::Licenses#retrieve_by_external_id

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(external_license_id:, license_type_id:, subscription_id:, request_options: {}) ⇒ Object

Parameters:

  • external_license_id (String)
  • license_type_id (String)

    The ID of the license type to fetch the license for.

  • subscription_id (String)

    The ID of the subscription to fetch the license for.

  • request_options (Orb::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/orb/models/license_retrieve_by_external_id_params.rb', line 27

Instance Attribute Details

#external_license_idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/orb/models/license_retrieve_by_external_id_params.rb', line 13

required :external_license_id, String

#license_type_idString

The ID of the license type to fetch the license for.

Parameters:

  • value (String)

Returns:

  • (String)


19
# File 'lib/orb/models/license_retrieve_by_external_id_params.rb', line 19

required :license_type_id, String

#subscription_idString

The ID of the subscription to fetch the license for.

Parameters:

  • value (String)

Returns:

  • (String)


25
# File 'lib/orb/models/license_retrieve_by_external_id_params.rb', line 25

required :subscription_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


28
# File 'sig/orb/models/license_retrieve_by_external_id_params.rbs', line 28

def to_hash: -> {