Class: Orb::Models::Licenses::ExternalLicenseGetUsageResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Licenses::ExternalLicenseGetUsageResponse::Data
- Defined in:
- lib/orb/models/licenses/external_license_get_usage_response.rb,
sig/orb/models/licenses/external_license_get_usage_response.rbs
Instance Attribute Summary collapse
-
#allocated_credits ⇒ Float
The total credits allocated to this license for the period.
-
#allocation_eligible_credits ⇒ Float?
Credits consumed while the license was active (eligible for individual allocation deduction).
-
#consumed_credits ⇒ Float
The credits consumed by this license for the period.
-
#end_date ⇒ Date
The end date of the usage period.
-
#external_license_id ⇒ String?
The external identifier for the license.
-
#license_id ⇒ String?
The unique identifier for the license.
-
#license_type_id ⇒ String
The unique identifier for the license type.
-
#pricing_unit ⇒ String
The pricing unit for the credits (e.g., 'credits').
-
#remaining_credits ⇒ Float
The remaining credits available for this license (allocated - consumed).
-
#shared_pool_credits ⇒ Float?
Credits consumed while the license was inactive (draws from shared pool, not individual allocation).
-
#start_date ⇒ Date
The start date of the usage period.
-
#subscription_id ⇒ String
The unique identifier for the subscription.
Instance Method Summary collapse
-
#initialize(allocated_credits:, consumed_credits:, end_date:, license_type_id:, pricing_unit:, remaining_credits:, start_date:, subscription_id:, allocation_eligible_credits: nil, external_license_id: nil, license_id: nil, shared_pool_credits: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(allocated_credits:, consumed_credits:, end_date:, license_type_id:, pricing_unit:, remaining_credits:, start_date:, subscription_id:, allocation_eligible_credits: nil, external_license_id: nil, license_id: nil, shared_pool_credits: nil) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::Licenses::ExternalLicenseGetUsageResponse::Data for more details.
The LicenseUsage resource represents usage and remaining credits for a license over a date range.
When grouped by 'day' only, license_id and external_license_id will be null as the data is aggregated across all licenses.
23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/orb/models/licenses/external_license_get_usage_response.rb', line 23 class Data < Orb::Internal::Type::BaseModel # @!attribute allocated_credits # The total credits allocated to this license for the period. # # @return [Float] required :allocated_credits, Float # @!attribute consumed_credits # The credits consumed by this license for the period. # # @return [Float] required :consumed_credits, Float # @!attribute end_date # The end date of the usage period. # # @return [Date] required :end_date, Date # @!attribute license_type_id # The unique identifier for the license type. # # @return [String] required :license_type_id, String # @!attribute pricing_unit # The pricing unit for the credits (e.g., 'credits'). # # @return [String] required :pricing_unit, String # @!attribute remaining_credits # The remaining credits available for this license (allocated - consumed). # # @return [Float] required :remaining_credits, Float # @!attribute start_date # The start date of the usage period. # # @return [Date] required :start_date, Date # @!attribute subscription_id # The unique identifier for the subscription. # # @return [String] required :subscription_id, String # @!attribute allocation_eligible_credits # Credits consumed while the license was active (eligible for individual # allocation deduction). # # @return [Float, nil] optional :allocation_eligible_credits, Float, nil?: true # @!attribute external_license_id # The external identifier for the license. Null when grouped by day only. # # @return [String, nil] optional :external_license_id, String, nil?: true # @!attribute license_id # The unique identifier for the license. Null when grouped by day only. # # @return [String, nil] optional :license_id, String, nil?: true # @!attribute shared_pool_credits # Credits consumed while the license was inactive (draws from shared pool, not # individual allocation). # # @return [Float, nil] optional :shared_pool_credits, Float, nil?: true # @!method initialize(allocated_credits:, consumed_credits:, end_date:, license_type_id:, pricing_unit:, remaining_credits:, start_date:, subscription_id:, allocation_eligible_credits: nil, external_license_id: nil, license_id: nil, shared_pool_credits: nil) # Some parameter documentations has been truncated, see # {Orb::Models::Licenses::ExternalLicenseGetUsageResponse::Data} for more details. # # The LicenseUsage resource represents usage and remaining credits for a license # over a date range. # # When grouped by 'day' only, license_id and external_license_id will be null as # the data is aggregated across all licenses. # # @param allocated_credits [Float] The total credits allocated to this license for the period. # # @param consumed_credits [Float] The credits consumed by this license for the period. # # @param end_date [Date] The end date of the usage period. # # @param license_type_id [String] The unique identifier for the license type. # # @param pricing_unit [String] The pricing unit for the credits (e.g., 'credits'). # # @param remaining_credits [Float] The remaining credits available for this license (allocated - consumed). # # @param start_date [Date] The start date of the usage period. # # @param subscription_id [String] The unique identifier for the subscription. # # @param allocation_eligible_credits [Float, nil] Credits consumed while the license was active (eligible for individual allocatio # # @param external_license_id [String, nil] The external identifier for the license. Null when grouped by day only. # # @param license_id [String, nil] The unique identifier for the license. Null when grouped by day only. # # @param shared_pool_credits [Float, nil] Credits consumed while the license was inactive (draws from shared pool, not ind end |
Instance Attribute Details
#allocated_credits ⇒ Float
The total credits allocated to this license for the period.
28 |
# File 'lib/orb/models/licenses/external_license_get_usage_response.rb', line 28 required :allocated_credits, Float |
#allocation_eligible_credits ⇒ Float?
Credits consumed while the license was active (eligible for individual allocation deduction).
77 |
# File 'lib/orb/models/licenses/external_license_get_usage_response.rb', line 77 optional :allocation_eligible_credits, Float, nil?: true |
#consumed_credits ⇒ Float
The credits consumed by this license for the period.
34 |
# File 'lib/orb/models/licenses/external_license_get_usage_response.rb', line 34 required :consumed_credits, Float |
#end_date ⇒ Date
The end date of the usage period.
40 |
# File 'lib/orb/models/licenses/external_license_get_usage_response.rb', line 40 required :end_date, Date |
#external_license_id ⇒ String?
The external identifier for the license. Null when grouped by day only.
83 |
# File 'lib/orb/models/licenses/external_license_get_usage_response.rb', line 83 optional :external_license_id, String, nil?: true |
#license_id ⇒ String?
The unique identifier for the license. Null when grouped by day only.
89 |
# File 'lib/orb/models/licenses/external_license_get_usage_response.rb', line 89 optional :license_id, String, nil?: true |
#license_type_id ⇒ String
The unique identifier for the license type.
46 |
# File 'lib/orb/models/licenses/external_license_get_usage_response.rb', line 46 required :license_type_id, String |
#pricing_unit ⇒ String
The pricing unit for the credits (e.g., 'credits').
52 |
# File 'lib/orb/models/licenses/external_license_get_usage_response.rb', line 52 required :pricing_unit, String |
#remaining_credits ⇒ Float
The remaining credits available for this license (allocated - consumed).
58 |
# File 'lib/orb/models/licenses/external_license_get_usage_response.rb', line 58 required :remaining_credits, Float |
#shared_pool_credits ⇒ Float?
Credits consumed while the license was inactive (draws from shared pool, not individual allocation).
96 |
# File 'lib/orb/models/licenses/external_license_get_usage_response.rb', line 96 optional :shared_pool_credits, Float, nil?: true |
#start_date ⇒ Date
The start date of the usage period.
64 |
# File 'lib/orb/models/licenses/external_license_get_usage_response.rb', line 64 required :start_date, Date |
#subscription_id ⇒ String
The unique identifier for the subscription.
70 |
# File 'lib/orb/models/licenses/external_license_get_usage_response.rb', line 70 required :subscription_id, String |
Instance Method Details
#to_hash ⇒ {
81 |
# File 'sig/orb/models/licenses/external_license_get_usage_response.rbs', line 81
def to_hash: -> {
|