Class: Orb::Models::Licenses::UsageGetAllUsageParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Licenses::UsageGetAllUsageParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/orb/models/licenses/usage_get_all_usage_params.rb,
sig/orb/models/licenses/usage_get_all_usage_params.rbs
Overview
Instance Attribute Summary collapse
-
#cursor ⇒ String?
Pagination cursor from a previous request.
-
#end_date ⇒ Date?
End date for the usage period (YYYY-MM-DD).
-
#group_by ⇒ String?
How to group the results.
-
#license_type_id ⇒ String
The license type ID to filter licenses by.
-
#limit ⇒ Integer?
Maximum number of rows in the response data (default 20, max 100).
-
#start_date ⇒ Date?
Start date for the usage period (YYYY-MM-DD).
-
#subscription_id ⇒ String
The subscription ID to get license usage for.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(license_type_id:, subscription_id:, cursor: nil, end_date: nil, group_by: nil, limit: nil, start_date: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see UsageGetAllUsageParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(license_type_id:, subscription_id:, cursor: nil, end_date: nil, group_by: nil, limit: nil, start_date: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::Licenses::UsageGetAllUsageParams for more details.
|
|
# File 'lib/orb/models/licenses/usage_get_all_usage_params.rb', line 56
|
Instance Attribute Details
#cursor ⇒ String?
Pagination cursor from a previous request.
27 |
# File 'lib/orb/models/licenses/usage_get_all_usage_params.rb', line 27 optional :cursor, String, nil?: true |
#end_date ⇒ Date?
End date for the usage period (YYYY-MM-DD). Defaults to end of current billing period.
34 |
# File 'lib/orb/models/licenses/usage_get_all_usage_params.rb', line 34 optional :end_date, Date, nil?: true |
#group_by ⇒ String?
How to group the results. Valid values: 'license', 'day'. Can be combined (e.g., 'license,day').
41 |
# File 'lib/orb/models/licenses/usage_get_all_usage_params.rb', line 41 optional :group_by, String, nil?: true |
#license_type_id ⇒ String
The license type ID to filter licenses by.
15 |
# File 'lib/orb/models/licenses/usage_get_all_usage_params.rb', line 15 required :license_type_id, String |
#limit ⇒ Integer?
Maximum number of rows in the response data (default 20, max 100).
47 |
# File 'lib/orb/models/licenses/usage_get_all_usage_params.rb', line 47 optional :limit, Integer |
#start_date ⇒ Date?
Start date for the usage period (YYYY-MM-DD). Defaults to start of current billing period.
54 |
# File 'lib/orb/models/licenses/usage_get_all_usage_params.rb', line 54 optional :start_date, Date, nil?: true |
#subscription_id ⇒ String
The subscription ID to get license usage for.
21 |
# File 'lib/orb/models/licenses/usage_get_all_usage_params.rb', line 21 required :subscription_id, String |
Instance Method Details
#to_hash ⇒ {
47 |
# File 'sig/orb/models/licenses/usage_get_all_usage_params.rbs', line 47
def to_hash: -> {
|