Class: Orb::Models::MatrixValue

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/matrix_value.rb,
sig/orb/models/matrix_value.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(dimension_values:, unit_amount:) ⇒ Object

Configuration for a single matrix value

Parameters:

  • dimension_values (Array<String, nil>)

    One or two matrix keys to filter usage to this Matrix value by

  • unit_amount (String)

    Unit price for the specified dimension_values



# File 'lib/orb/models/matrix_value.rb', line 18

Instance Attribute Details

#dimension_valuesArray<String, nil>

One or two matrix keys to filter usage to this Matrix value by

Parameters:

  • value (::Array[String?])

Returns:

  • (Array<String, nil>)


10
# File 'lib/orb/models/matrix_value.rb', line 10

required :dimension_values, Orb::Internal::Type::ArrayOf[String, nil?: true]

#unit_amountString

Unit price for the specified dimension_values

Parameters:

  • value (String)

Returns:

  • (String)


16
# File 'lib/orb/models/matrix_value.rb', line 16

required :unit_amount, String

Instance Method Details

#to_hash{

Returns:

  • ({)


16
# File 'sig/orb/models/matrix_value.rbs', line 16

def to_hash: -> {