Class: Orb::Models::MatrixWithAllocationConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/matrix_with_allocation_config.rb,
sig/orb/models/matrix_with_allocation_config.rbs

Defined Under Namespace

Classes: MatrixValue

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



20
# File 'sig/orb/models/matrix_with_allocation_config.rbs', line 20

def initialize: (

Instance Attribute Details

#allocationString

Usage allocation

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/orb/models/matrix_with_allocation_config.rb', line 10

required :allocation, String

#default_unit_amountString

Default per unit rate for any usage not bucketed into a specified matrix_value

Parameters:

  • value (String)

Returns:

  • (String)


16
# File 'lib/orb/models/matrix_with_allocation_config.rb', line 16

required :default_unit_amount, String

#dimensionsArray<String, nil>

One or two event property values to evaluate matrix groups by

Parameters:

  • value (::Array[String?])

Returns:

  • (Array<String, nil>)


22
# File 'lib/orb/models/matrix_with_allocation_config.rb', line 22

required :dimensions, Orb::Internal::Type::ArrayOf[String, nil?: true]

#matrix_valuesArray<Orb::Models::MatrixWithAllocationConfig::MatrixValue>

Matrix values configuration

Parameters:

  • value (::Array[Orb::MatrixWithAllocationConfig::MatrixValue])

Returns:



28
# File 'lib/orb/models/matrix_with_allocation_config.rb', line 28

required :matrix_values, -> { Orb::Internal::Type::ArrayOf[Orb::MatrixWithAllocationConfig::MatrixValue] }

Instance Method Details

#to_hash{

Returns:

  • ({)


27
# File 'sig/orb/models/matrix_with_allocation_config.rbs', line 27

def to_hash: -> {