Class: Orb::Models::MatrixWithAllocationConfig::MatrixValue
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::MatrixWithAllocationConfig::MatrixValue
- Defined in:
- lib/orb/models/matrix_with_allocation_config.rb,
sig/orb/models/matrix_with_allocation_config.rbs
Instance Attribute Summary collapse
-
#dimension_values ⇒ Array<String, nil>
One or two matrix keys to filter usage to this Matrix value by.
- #scaling_factor ⇒ String? deprecated Deprecated.
-
#unit_amount ⇒ String
Unit price for the specified dimension_values.
Instance Method Summary collapse
-
#initialize(dimension_values:, unit_amount:, scaling_factor: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see MatrixValue for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(dimension_values:, unit_amount:, scaling_factor: nil) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::MatrixWithAllocationConfig::MatrixValue for more details.
Configuration for a single matrix value
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/orb/models/matrix_with_allocation_config.rb', line 55 class MatrixValue < Orb::Internal::Type::BaseModel # @!attribute dimension_values # One or two matrix keys to filter usage to this Matrix value by. For example, # ["region", "tier"] could be used to filter cloud usage by a cloud region and an # instance tier. # # @return [Array<String, nil>] required :dimension_values, Orb::Internal::Type::ArrayOf[String, nil?: true] # @!attribute unit_amount # Unit price for the specified dimension_values # # @return [String] required :unit_amount, String # @!attribute scaling_factor # @deprecated # # Optional multiplier applied to rated quantity before unit_amount. # # @return [String, nil] optional :scaling_factor, String, nil?: true # @!method initialize(dimension_values:, unit_amount:, scaling_factor: nil) # Some parameter documentations has been truncated, see # {Orb::Models::MatrixWithAllocationConfig::MatrixValue} for more details. # # Configuration for a single matrix value # # @param dimension_values [Array<String, nil>] One or two matrix keys to filter usage to this Matrix value by. For example, ["r # # @param unit_amount [String] Unit price for the specified dimension_values # # @param scaling_factor [String, nil] Optional multiplier applied to rated quantity before unit_amount. end |
Instance Attribute Details
#dimension_values ⇒ Array<String, nil>
One or two matrix keys to filter usage to this Matrix value by. For example, ["region", "tier"] could be used to filter cloud usage by a cloud region and an instance tier.
62 |
# File 'lib/orb/models/matrix_with_allocation_config.rb', line 62 required :dimension_values, Orb::Internal::Type::ArrayOf[String, nil?: true] |
#scaling_factor ⇒ String?
Optional multiplier applied to rated quantity before unit_amount.
76 |
# File 'lib/orb/models/matrix_with_allocation_config.rb', line 76 optional :scaling_factor, String, nil?: true |
#unit_amount ⇒ String
Unit price for the specified dimension_values
68 |
# File 'lib/orb/models/matrix_with_allocation_config.rb', line 68 required :unit_amount, String |
Instance Method Details
#to_hash ⇒ {
59 |
# File 'sig/orb/models/matrix_with_allocation_config.rbs', line 59
def to_hash: -> {
|