Class: Orb::Models::Maximum
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Maximum
- Defined in:
- lib/orb/models/maximum.rb,
sig/orb/models/maximum.rbs
Defined Under Namespace
Classes: Filter
Instance Attribute Summary collapse
- #applies_to_price_ids ⇒ Array<String> deprecated Deprecated.
-
#filters ⇒ Array<Orb::Models::Maximum::Filter>
The filters that determine which prices to apply this maximum to.
-
#maximum_amount ⇒ String
Maximum amount applied.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
17 |
# File 'sig/orb/models/maximum.rbs', line 17
def initialize: (
|
Instance Attribute Details
#applies_to_price_ids ⇒ Array<String>
Deprecated.
List of price_ids that this maximum amount applies to. For plan/plan phase maximums, this can be a subset of prices.
13 |
# File 'lib/orb/models/maximum.rb', line 13 required :applies_to_price_ids, Orb::Internal::Type::ArrayOf[String] |
#filters ⇒ Array<Orb::Models::Maximum::Filter>
The filters that determine which prices to apply this maximum to.
19 |
# File 'lib/orb/models/maximum.rb', line 19 required :filters, -> { Orb::Internal::Type::ArrayOf[Orb::Maximum::Filter] } |
#maximum_amount ⇒ String
Maximum amount applied
25 |
# File 'lib/orb/models/maximum.rb', line 25 required :maximum_amount, String |
Instance Method Details
#to_hash ⇒ {
23 |
# File 'sig/orb/models/maximum.rbs', line 23
def to_hash: -> {
|