Class: Orb::Models::MaximumInterval
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::MaximumInterval
- Defined in:
- lib/orb/models/maximum_interval.rb,
sig/orb/models/maximum_interval.rbs
Defined Under Namespace
Classes: Filter
Instance Attribute Summary collapse
-
#applies_to_price_interval_ids ⇒ Array<String>
The price interval ids that this maximum interval applies to.
-
#end_date ⇒ Time?
The end date of the maximum interval.
-
#filters ⇒ Array<Orb::Models::MaximumInterval::Filter>
The filters that determine which prices this maximum interval applies to.
-
#maximum_amount ⇒ String
The maximum amount to charge in a given billing period for the price intervals this transform applies to.
-
#start_date ⇒ Time
The start date of the maximum interval.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
23 |
# File 'sig/orb/models/maximum_interval.rbs', line 23
def initialize: (
|
Instance Attribute Details
#applies_to_price_interval_ids ⇒ Array<String>
The price interval ids that this maximum interval applies to.
10 |
# File 'lib/orb/models/maximum_interval.rb', line 10 required :applies_to_price_interval_ids, Orb::Internal::Type::ArrayOf[String] |
#end_date ⇒ Time?
The end date of the maximum interval.
16 |
# File 'lib/orb/models/maximum_interval.rb', line 16 required :end_date, Time, nil?: true |
#filters ⇒ Array<Orb::Models::MaximumInterval::Filter>
The filters that determine which prices this maximum interval applies to.
22 |
# File 'lib/orb/models/maximum_interval.rb', line 22 required :filters, -> { Orb::Internal::Type::ArrayOf[Orb::MaximumInterval::Filter] } |
#maximum_amount ⇒ String
The maximum amount to charge in a given billing period for the price intervals this transform applies to.
29 |
# File 'lib/orb/models/maximum_interval.rb', line 29 required :maximum_amount, String |
#start_date ⇒ Time
The start date of the maximum interval.
35 |
# File 'lib/orb/models/maximum_interval.rb', line 35 required :start_date, Time |
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/orb/models/maximum_interval.rbs', line 31
def to_hash: -> {
|