Class: Orb::Models::MutatedSubscription::DiscountInterval::TieredPercentage
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::MutatedSubscription::DiscountInterval::TieredPercentage
- Defined in:
- lib/orb/models/mutated_subscription.rb,
sig/orb/models/mutated_subscription.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#applies_to_price_interval_ids ⇒ Array<String>
The price interval ids that this discount interval applies to.
- #discount_type ⇒ Symbol, :tiered_percentage
-
#end_date ⇒ Time?
The end date of the discount interval.
-
#filters ⇒ Array<Orb::Models::MutatedSubscription::DiscountInterval::TieredPercentage::Filter>
The filters that determine which prices this discount interval applies to.
-
#start_date ⇒ Time
The start date of the discount interval.
-
#tiers ⇒ Array<Orb::Models::MutatedSubscription::DiscountInterval::TieredPercentage::Tier>
Only available if discount_type is
tiered_percentage.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
191 |
# File 'sig/orb/models/mutated_subscription.rbs', line 191
def initialize: (
|
Instance Attribute Details
#applies_to_price_interval_ids ⇒ Array<String>
The price interval ids that this discount interval applies to.
306 |
# File 'lib/orb/models/mutated_subscription.rb', line 306 required :applies_to_price_interval_ids, Orb::Internal::Type::ArrayOf[String] |
#discount_type ⇒ Symbol, :tiered_percentage
311 |
# File 'lib/orb/models/mutated_subscription.rb', line 311 required :discount_type, const: :tiered_percentage |
#end_date ⇒ Time?
The end date of the discount interval.
317 |
# File 'lib/orb/models/mutated_subscription.rb', line 317 required :end_date, Time, nil?: true |
#filters ⇒ Array<Orb::Models::MutatedSubscription::DiscountInterval::TieredPercentage::Filter>
The filters that determine which prices this discount interval applies to.
323 324 |
# File 'lib/orb/models/mutated_subscription.rb', line 323 required :filters, -> { Orb::Internal::Type::ArrayOf[Orb::MutatedSubscription::DiscountInterval::TieredPercentage::Filter] } |
#start_date ⇒ Time
The start date of the discount interval.
330 |
# File 'lib/orb/models/mutated_subscription.rb', line 330 required :start_date, Time |
#tiers ⇒ Array<Orb::Models::MutatedSubscription::DiscountInterval::TieredPercentage::Tier>
Only available if discount_type is tiered_percentage. The ordered, contiguous
bands of cumulative eligible spend, each discounted at its own percentage.
337 338 |
# File 'lib/orb/models/mutated_subscription.rb', line 337 required :tiers, -> { Orb::Internal::Type::ArrayOf[Orb::MutatedSubscription::DiscountInterval::TieredPercentage::Tier] } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/mutated_subscription.rb', line 409
|
Instance Method Details
#to_hash ⇒ {
200 |
# File 'sig/orb/models/mutated_subscription.rbs', line 200
def to_hash: -> {
|