Class: Orb::Models::NewAllocationPrice::Filter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::NewAllocationPrice::Filter
- Defined in:
- lib/orb/models/new_allocation_price.rb,
sig/orb/models/new_allocation_price.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#field ⇒ Symbol, Orb::Models::NewAllocationPrice::Filter::Field
The property of the price the block applies to.
-
#operator ⇒ Symbol, Orb::Models::NewAllocationPrice::Filter::Operator
Should prices that match the filter be included or excluded.
-
#values ⇒ Array<String>
The IDs or values that match this filter.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(field:, operator:, values:) ⇒ Object
constructor
A PriceFilter that only allows item_id field for block filters.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(field:, operator:, values:) ⇒ Object
A PriceFilter that only allows item_id field for block filters.
|
|
# File 'lib/orb/models/new_allocation_price.rb', line 133
|
Instance Attribute Details
#field ⇒ Symbol, Orb::Models::NewAllocationPrice::Filter::Field
The property of the price the block applies to. Only item_id is supported.
119 |
# File 'lib/orb/models/new_allocation_price.rb', line 119 required :field, enum: -> { Orb::NewAllocationPrice::Filter::Field } |
#operator ⇒ Symbol, Orb::Models::NewAllocationPrice::Filter::Operator
Should prices that match the filter be included or excluded.
125 |
# File 'lib/orb/models/new_allocation_price.rb', line 125 required :operator, enum: -> { Orb::NewAllocationPrice::Filter::Operator } |
#values ⇒ Array<String>
The IDs or values that match this filter.
131 |
# File 'lib/orb/models/new_allocation_price.rb', line 131 required :values, Orb::Internal::Type::ArrayOf[String] |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/new_allocation_price.rb', line 150
|
Instance Method Details
#to_hash ⇒ {
100 |
# File 'sig/orb/models/new_allocation_price.rbs', line 100
def to_hash: -> {
|