Class: Orb::Models::NewFloatingGroupedTieredPrice

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/new_floating_grouped_tiered_price.rb,
sig/orb/models/new_floating_grouped_tiered_price.rbs

Defined Under Namespace

Modules: Cadence, ModelType Classes: GroupedTieredConfig

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(tier_lower_bound:, unit_amount:) ⇒ Object

Configuration for a single tier

Parameters:

  • tier_lower_bound (String)
  • unit_amount (String)

    Per unit amount



# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 121

Instance Attribute Details

#billable_metric_idString?

The id of the billable metric for the price. Only needed if the price is usage-based.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


47
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 47

optional :billable_metric_id, String, nil?: true

#billed_in_advanceBoolean?

If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


54
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 54

optional :billed_in_advance, Orb::Internal::Type::Boolean, nil?: true

#billing_cycle_configurationOrb::Models::NewBillingCycleConfiguration?

For custom cadence: specifies the duration of the billing period in days or months.



61
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 61

optional :billing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true

#cadenceSymbol, Orb::Models::NewFloatingGroupedTieredPrice::Cadence

The cadence to bill for this price on.

Parameters:

  • value (Orb::Models::NewFloatingGroupedTieredPrice::cadence)

Returns:



10
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 10

required :cadence, enum: -> { Orb::NewFloatingGroupedTieredPrice::Cadence }

#conversion_rateFloat?

The per unit conversion rate of the price currency to the invoicing currency.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


67
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 67

optional :conversion_rate, Float, nil?: true

#conversion_rate_configOrb::Models::UnitConversionRateConfig, ...

The configuration for the rate of the price currency to the invoicing currency.

Parameters:

  • value (Orb::Models::conversion_rate_config, nil)

Returns:



73
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 73

optional :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true

#currencyString

An ISO 4217 currency string for which this price is billed in.

Parameters:

  • value (String)

Returns:

  • (String)


16
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 16

required :currency, String

#dimensional_price_configurationOrb::Models::NewDimensionalPriceConfiguration?

For dimensional price: specifies a price group and dimension values



79
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 79

optional :dimensional_price_configuration, -> { Orb::NewDimensionalPriceConfiguration }, nil?: true

#external_price_idString?

An alias for the price.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


85
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 85

optional :external_price_id, String, nil?: true

#fixed_price_quantityFloat?

If the Price represents a fixed cost, this represents the quantity of units applied.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


92
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 92

optional :fixed_price_quantity, Float, nil?: true

#grouped_tiered_configOrb::Models::NewFloatingGroupedTieredPrice::GroupedTieredConfig

Configuration for grouped_tiered pricing

Parameters:

  • value (Orb::NewFloatingGroupedTieredPrice::GroupedTieredConfig)

Returns:



22
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 22

required :grouped_tiered_config, -> { Orb::NewFloatingGroupedTieredPrice::GroupedTieredConfig }

#invoice_grouping_keyString?

The property used to group this price on an invoice

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


98
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 98

optional :invoice_grouping_key, String, nil?: true

#invoicing_cycle_configurationOrb::Models::NewBillingCycleConfiguration?

Within each billing cycle, specifies the cadence at which invoices are produced. If unspecified, a single invoice is produced per billing cycle.



105
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 105

optional :invoicing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true

#item_idString

The id of the item the price will be associated with.

Parameters:

  • value (String)

Returns:

  • (String)


28
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 28

required :item_id, String

#license_type_idString?

The ID of the license type to associate with this price.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


111
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 111

optional :license_type_id, String, nil?: true

#metadataHash{Symbol=>String, nil}?

User-specified key/value pairs for the resource. Individual keys can be removed by setting the value to null, and the entire metadata mapping can be cleared by setting metadata to null.

Parameters:

  • value (::Hash[Symbol, String?], nil)

Returns:

  • (Hash{Symbol=>String, nil}, nil)


119
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 119

optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true

#model_typeSymbol, Orb::Models::NewFloatingGroupedTieredPrice::ModelType

The pricing model type

Parameters:

  • value (Orb::Models::NewFloatingGroupedTieredPrice::model_type)

Returns:



34
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 34

required :model_type, enum: -> { Orb::NewFloatingGroupedTieredPrice::ModelType }

#nameString

The name of the price.

Parameters:

  • value (String)

Returns:

  • (String)


40
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 40

required :name, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 174

Instance Method Details

#to_hash{

Returns:

  • ({)


83
# File 'sig/orb/models/new_floating_grouped_tiered_price.rbs', line 83

def to_hash: -> {