Class: Orb::Models::NewFloatingMatrixWithDisplayNamePrice

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/new_floating_matrix_with_display_name_price.rb,
sig/orb/models/new_floating_matrix_with_display_name_price.rbs

Defined Under Namespace

Modules: Cadence, ModelType Classes: MatrixWithDisplayNameConfig

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(dimension_value:, display_name:, unit_amount:) ⇒ Object

Configuration for a unit amount item

Parameters:

  • dimension_value (String)

    The dimension value

  • display_name (String)

    Display name for this dimension value

  • unit_amount (String)

    Per unit amount



# File 'lib/orb/models/new_floating_matrix_with_display_name_price.rb', line 122

Instance Attribute Details

#billable_metric_idString?

The id of the billable metric for the price. Only needed if the price is usage-based.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


48
# File 'lib/orb/models/new_floating_matrix_with_display_name_price.rb', line 48

optional :billable_metric_id, String, nil?: true

#billed_in_advanceBoolean?

If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


55
# File 'lib/orb/models/new_floating_matrix_with_display_name_price.rb', line 55

optional :billed_in_advance, Orb::Internal::Type::Boolean, nil?: true

#billing_cycle_configurationOrb::Models::NewBillingCycleConfiguration?

For custom cadence: specifies the duration of the billing period in days or months.



62
# File 'lib/orb/models/new_floating_matrix_with_display_name_price.rb', line 62

optional :billing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true

#cadenceSymbol, Orb::Models::NewFloatingMatrixWithDisplayNamePrice::Cadence

The cadence to bill for this price on.

Parameters:

  • value (Orb::Models::NewFloatingMatrixWithDisplayNamePrice::cadence)

Returns:



10
# File 'lib/orb/models/new_floating_matrix_with_display_name_price.rb', line 10

required :cadence, enum: -> { Orb::NewFloatingMatrixWithDisplayNamePrice::Cadence }

#conversion_rateFloat?

The per unit conversion rate of the price currency to the invoicing currency.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


68
# File 'lib/orb/models/new_floating_matrix_with_display_name_price.rb', line 68

optional :conversion_rate, Float, nil?: true

#conversion_rate_configOrb::Models::UnitConversionRateConfig, ...

The configuration for the rate of the price currency to the invoicing currency.

Parameters:

  • value (Orb::Models::conversion_rate_config, nil)

Returns:



74
# File 'lib/orb/models/new_floating_matrix_with_display_name_price.rb', line 74

optional :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true

#currencyString

An ISO 4217 currency string for which this price is billed in.

Parameters:

  • value (String)

Returns:

  • (String)


16
# File 'lib/orb/models/new_floating_matrix_with_display_name_price.rb', line 16

required :currency, String

#dimensional_price_configurationOrb::Models::NewDimensionalPriceConfiguration?

For dimensional price: specifies a price group and dimension values



80
# File 'lib/orb/models/new_floating_matrix_with_display_name_price.rb', line 80

optional :dimensional_price_configuration, -> { Orb::NewDimensionalPriceConfiguration }, nil?: true

#external_price_idString?

An alias for the price.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


86
# File 'lib/orb/models/new_floating_matrix_with_display_name_price.rb', line 86

optional :external_price_id, String, nil?: true

#fixed_price_quantityFloat?

If the Price represents a fixed cost, this represents the quantity of units applied.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


93
# File 'lib/orb/models/new_floating_matrix_with_display_name_price.rb', line 93

optional :fixed_price_quantity, Float, nil?: true

#invoice_grouping_keyString?

The property used to group this price on an invoice

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


99
# File 'lib/orb/models/new_floating_matrix_with_display_name_price.rb', line 99

optional :invoice_grouping_key, String, nil?: true

#invoicing_cycle_configurationOrb::Models::NewBillingCycleConfiguration?

Within each billing cycle, specifies the cadence at which invoices are produced. If unspecified, a single invoice is produced per billing cycle.



106
# File 'lib/orb/models/new_floating_matrix_with_display_name_price.rb', line 106

optional :invoicing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true

#item_idString

The id of the item the price will be associated with.

Parameters:

  • value (String)

Returns:

  • (String)


22
# File 'lib/orb/models/new_floating_matrix_with_display_name_price.rb', line 22

required :item_id, String

#license_type_idString?

The ID of the license type to associate with this price.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


112
# File 'lib/orb/models/new_floating_matrix_with_display_name_price.rb', line 112

optional :license_type_id, String, nil?: true

#matrix_with_display_name_configOrb::Models::NewFloatingMatrixWithDisplayNamePrice::MatrixWithDisplayNameConfig

Configuration for matrix_with_display_name pricing

Parameters:

  • value (Orb::NewFloatingMatrixWithDisplayNamePrice::MatrixWithDisplayNameConfig)

Returns:



28
29
# File 'lib/orb/models/new_floating_matrix_with_display_name_price.rb', line 28

required :matrix_with_display_name_config,
-> { Orb::NewFloatingMatrixWithDisplayNamePrice::MatrixWithDisplayNameConfig }

#metadataHash{Symbol=>String, nil}?

User-specified key/value pairs for the resource. Individual keys can be removed by setting the value to null, and the entire metadata mapping can be cleared by setting metadata to null.

Parameters:

  • value (::Hash[Symbol, String?], nil)

Returns:

  • (Hash{Symbol=>String, nil}, nil)


120
# File 'lib/orb/models/new_floating_matrix_with_display_name_price.rb', line 120

optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true

#model_typeSymbol, Orb::Models::NewFloatingMatrixWithDisplayNamePrice::ModelType

The pricing model type

Parameters:

  • value (Orb::Models::NewFloatingMatrixWithDisplayNamePrice::model_type)

Returns:



35
# File 'lib/orb/models/new_floating_matrix_with_display_name_price.rb', line 35

required :model_type, enum: -> { Orb::NewFloatingMatrixWithDisplayNamePrice::ModelType }

#nameString

The name of the price.

Parameters:

  • value (String)

Returns:

  • (String)


41
# File 'lib/orb/models/new_floating_matrix_with_display_name_price.rb', line 41

required :name, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/orb/models/new_floating_matrix_with_display_name_price.rb', line 175

Instance Method Details

#to_hash{

Returns:

  • ({)


83
# File 'sig/orb/models/new_floating_matrix_with_display_name_price.rbs', line 83

def to_hash: -> {