Class: Orb::Models::NewPlanScalableMatrixWithUnitPricingPrice::ScalableMatrixWithUnitPricingConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::NewPlanScalableMatrixWithUnitPricingPrice::ScalableMatrixWithUnitPricingConfig
- Defined in:
- lib/orb/models/new_plan_scalable_matrix_with_unit_pricing_price.rb,
sig/orb/models/new_plan_scalable_matrix_with_unit_pricing_price.rbs
Overview
Defined Under Namespace
Classes: MatrixScalingFactor
Instance Attribute Summary collapse
-
#first_dimension ⇒ String
Used to determine the unit rate.
-
#grouping_key ⇒ String?
The property used to group this price.
-
#matrix_scaling_factors ⇒ Array<Orb::Models::NewPlanScalableMatrixWithUnitPricingPrice::ScalableMatrixWithUnitPricingConfig::MatrixScalingFactor>
Apply a scaling factor to each dimension.
-
#prorate ⇒ Boolean?
If true, the unit price will be prorated to the billing period.
-
#second_dimension ⇒ String?
Used to determine the unit rate (optional).
-
#unit_price ⇒ String
The final unit price to rate against the output of the matrix.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
158 |
# File 'sig/orb/models/new_plan_scalable_matrix_with_unit_pricing_price.rbs', line 158
def initialize: (
|
Instance Attribute Details
#first_dimension ⇒ String
Used to determine the unit rate
207 |
# File 'lib/orb/models/new_plan_scalable_matrix_with_unit_pricing_price.rb', line 207 required :first_dimension, String |
#grouping_key ⇒ String?
The property used to group this price
226 |
# File 'lib/orb/models/new_plan_scalable_matrix_with_unit_pricing_price.rb', line 226 optional :grouping_key, String, nil?: true |
#matrix_scaling_factors ⇒ Array<Orb::Models::NewPlanScalableMatrixWithUnitPricingPrice::ScalableMatrixWithUnitPricingConfig::MatrixScalingFactor>
Apply a scaling factor to each dimension
213 214 |
# File 'lib/orb/models/new_plan_scalable_matrix_with_unit_pricing_price.rb', line 213 required :matrix_scaling_factors, -> { Orb::Internal::Type::ArrayOf[Orb::NewPlanScalableMatrixWithUnitPricingPrice::ScalableMatrixWithUnitPricingConfig::MatrixScalingFactor] } |
#prorate ⇒ Boolean?
If true, the unit price will be prorated to the billing period
232 |
# File 'lib/orb/models/new_plan_scalable_matrix_with_unit_pricing_price.rb', line 232 optional :prorate, Orb::Internal::Type::Boolean, nil?: true |
#second_dimension ⇒ String?
Used to determine the unit rate (optional)
238 |
# File 'lib/orb/models/new_plan_scalable_matrix_with_unit_pricing_price.rb', line 238 optional :second_dimension, String, nil?: true |
#unit_price ⇒ String
The final unit price to rate against the output of the matrix
220 |
# File 'lib/orb/models/new_plan_scalable_matrix_with_unit_pricing_price.rb', line 220 required :unit_price, String |
Instance Method Details
#to_hash ⇒ {
167 |
# File 'sig/orb/models/new_plan_scalable_matrix_with_unit_pricing_price.rbs', line 167
def to_hash: -> {
|