Class: Orb::Models::NewPlanTieredPackagePrice
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::NewPlanTieredPackagePrice
- Defined in:
- lib/orb/models/new_plan_tiered_package_price.rb,
sig/orb/models/new_plan_tiered_package_price.rbs
Defined Under Namespace
Modules: Cadence, ModelType Classes: TieredPackageConfig
Instance Attribute Summary collapse
-
#billable_metric_id ⇒ String?
The id of the billable metric for the price.
-
#billed_in_advance ⇒ Boolean?
If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.
-
#billing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
For custom cadence: specifies the duration of the billing period in days or months.
-
#cadence ⇒ Symbol, Orb::Models::NewPlanTieredPackagePrice::Cadence
The cadence to bill for this price on.
-
#conversion_rate ⇒ Float?
The per unit conversion rate of the price currency to the invoicing currency.
-
#conversion_rate_config ⇒ Orb::Models::UnitConversionRateConfig, ...
The configuration for the rate of the price currency to the invoicing currency.
-
#currency ⇒ String?
An ISO 4217 currency string, or custom pricing unit identifier, in which this price is billed.
-
#dimensional_price_configuration ⇒ Orb::Models::NewDimensionalPriceConfiguration?
For dimensional price: specifies a price group and dimension values.
-
#external_price_id ⇒ String?
An alias for the price.
-
#fixed_price_quantity ⇒ Float?
If the Price represents a fixed cost, this represents the quantity of units applied.
-
#invoice_grouping_key ⇒ String?
The property used to group this price on an invoice.
-
#invoicing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
Within each billing cycle, specifies the cadence at which invoices are produced.
-
#item_id ⇒ String
The id of the item the price will be associated with.
-
#license_type_id ⇒ String?
The ID of the license type to associate with this price.
-
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource.
-
#model_type ⇒ Symbol, Orb::Models::NewPlanTieredPackagePrice::ModelType
The pricing model type.
-
#name ⇒ String
The name of the price.
-
#reference_id ⇒ String?
A transient ID that can be used to reference this price when adding adjustments in the same API call.
-
#tiered_package_config ⇒ Orb::Models::NewPlanTieredPackagePrice::TieredPackageConfig
Configuration for tiered_package pricing.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(cadence:, item_id:, model_type:, name:, tiered_package_config:, billable_metric_id: nil, billed_in_advance: nil, billing_cycle_configuration: nil, conversion_rate: nil, conversion_rate_config: nil, currency: nil, dimensional_price_configuration: nil, external_price_id: nil, fixed_price_quantity: nil, invoice_grouping_key: nil, invoicing_cycle_configuration: nil, license_type_id: nil, metadata: nil, reference_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see NewPlanTieredPackagePrice for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cadence:, item_id:, model_type:, name:, tiered_package_config:, billable_metric_id: nil, billed_in_advance: nil, billing_cycle_configuration: nil, conversion_rate: nil, conversion_rate_config: nil, currency: nil, dimensional_price_configuration: nil, external_price_id: nil, fixed_price_quantity: nil, invoice_grouping_key: nil, invoicing_cycle_configuration: nil, license_type_id: nil, metadata: nil, reference_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::NewPlanTieredPackagePrice for more details.
|
|
# File 'lib/orb/models/new_plan_tiered_package_price.rb', line 129
|
Instance Attribute Details
#billable_metric_id ⇒ String?
The id of the billable metric for the price. Only needed if the price is usage-based.
41 |
# File 'lib/orb/models/new_plan_tiered_package_price.rb', line 41 optional :billable_metric_id, String, nil?: true |
#billed_in_advance ⇒ Boolean?
If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.
48 |
# File 'lib/orb/models/new_plan_tiered_package_price.rb', line 48 optional :billed_in_advance, Orb::Internal::Type::Boolean, nil?: true |
#billing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
For custom cadence: specifies the duration of the billing period in days or months.
55 |
# File 'lib/orb/models/new_plan_tiered_package_price.rb', line 55 optional :billing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true |
#cadence ⇒ Symbol, Orb::Models::NewPlanTieredPackagePrice::Cadence
The cadence to bill for this price on.
10 |
# File 'lib/orb/models/new_plan_tiered_package_price.rb', line 10 required :cadence, enum: -> { Orb::NewPlanTieredPackagePrice::Cadence } |
#conversion_rate ⇒ Float?
The per unit conversion rate of the price currency to the invoicing currency.
61 |
# File 'lib/orb/models/new_plan_tiered_package_price.rb', line 61 optional :conversion_rate, Float, nil?: true |
#conversion_rate_config ⇒ Orb::Models::UnitConversionRateConfig, ...
The configuration for the rate of the price currency to the invoicing currency.
67 |
# File 'lib/orb/models/new_plan_tiered_package_price.rb', line 67 optional :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true |
#currency ⇒ String?
An ISO 4217 currency string, or custom pricing unit identifier, in which this price is billed.
74 |
# File 'lib/orb/models/new_plan_tiered_package_price.rb', line 74 optional :currency, String, nil?: true |
#dimensional_price_configuration ⇒ Orb::Models::NewDimensionalPriceConfiguration?
For dimensional price: specifies a price group and dimension values
80 |
# File 'lib/orb/models/new_plan_tiered_package_price.rb', line 80 optional :dimensional_price_configuration, -> { Orb::NewDimensionalPriceConfiguration }, nil?: true |
#external_price_id ⇒ String?
An alias for the price.
86 |
# File 'lib/orb/models/new_plan_tiered_package_price.rb', line 86 optional :external_price_id, String, nil?: true |
#fixed_price_quantity ⇒ Float?
If the Price represents a fixed cost, this represents the quantity of units applied.
93 |
# File 'lib/orb/models/new_plan_tiered_package_price.rb', line 93 optional :fixed_price_quantity, Float, nil?: true |
#invoice_grouping_key ⇒ String?
The property used to group this price on an invoice
99 |
# File 'lib/orb/models/new_plan_tiered_package_price.rb', line 99 optional :invoice_grouping_key, String, nil?: true |
#invoicing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
Within each billing cycle, specifies the cadence at which invoices are produced. If unspecified, a single invoice is produced per billing cycle.
106 |
# File 'lib/orb/models/new_plan_tiered_package_price.rb', line 106 optional :invoicing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true |
#item_id ⇒ String
The id of the item the price will be associated with.
16 |
# File 'lib/orb/models/new_plan_tiered_package_price.rb', line 16 required :item_id, String |
#license_type_id ⇒ String?
The ID of the license type to associate with this price.
112 |
# File 'lib/orb/models/new_plan_tiered_package_price.rb', line 112 optional :license_type_id, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource. Individual keys can be removed
by setting the value to null, and the entire metadata mapping can be cleared
by setting metadata to null.
120 |
# File 'lib/orb/models/new_plan_tiered_package_price.rb', line 120 optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true |
#model_type ⇒ Symbol, Orb::Models::NewPlanTieredPackagePrice::ModelType
The pricing model type
22 |
# File 'lib/orb/models/new_plan_tiered_package_price.rb', line 22 required :model_type, enum: -> { Orb::NewPlanTieredPackagePrice::ModelType } |
#name ⇒ String
The name of the price.
28 |
# File 'lib/orb/models/new_plan_tiered_package_price.rb', line 28 required :name, String |
#reference_id ⇒ String?
A transient ID that can be used to reference this price when adding adjustments in the same API call.
127 |
# File 'lib/orb/models/new_plan_tiered_package_price.rb', line 127 optional :reference_id, String, nil?: true |
#tiered_package_config ⇒ Orb::Models::NewPlanTieredPackagePrice::TieredPackageConfig
Configuration for tiered_package pricing
34 |
# File 'lib/orb/models/new_plan_tiered_package_price.rb', line 34 required :tiered_package_config, -> { Orb::NewPlanTieredPackagePrice::TieredPackageConfig } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/new_plan_tiered_package_price.rb', line 184
|
Instance Method Details
#to_hash ⇒ {
87 |
# File 'sig/orb/models/new_plan_tiered_package_price.rbs', line 87
def to_hash: -> {
|