Class: Orb::Models::NewPlanTieredPackagePrice::TieredPackageConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::NewPlanTieredPackagePrice::TieredPackageConfig
- Defined in:
- lib/orb/models/new_plan_tiered_package_price.rb,
sig/orb/models/new_plan_tiered_package_price.rbs
Overview
Defined Under Namespace
Classes: Tier
Instance Attribute Summary collapse
- #package_size ⇒ String
-
#tiers ⇒ Array<Orb::Models::NewPlanTieredPackagePrice::TieredPackageConfig::Tier>
Apply tiered pricing after rounding up the quantity to the package size.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
146 |
# File 'sig/orb/models/new_plan_tiered_package_price.rbs', line 146
def initialize: (
|
Instance Attribute Details
#package_size ⇒ String
205 |
# File 'lib/orb/models/new_plan_tiered_package_price.rb', line 205 required :package_size, String |
#tiers ⇒ Array<Orb::Models::NewPlanTieredPackagePrice::TieredPackageConfig::Tier>
Apply tiered pricing after rounding up the quantity to the package size. Tiers are defined using exclusive lower bounds. The tier bounds are defined based on the total quantity rather than the number of packages, so they must be multiples of the package size.
214 215 |
# File 'lib/orb/models/new_plan_tiered_package_price.rb', line 214 required :tiers, -> { Orb::Internal::Type::ArrayOf[Orb::NewPlanTieredPackagePrice::TieredPackageConfig::Tier] } |
Instance Method Details
#to_hash ⇒ {
151 |
# File 'sig/orb/models/new_plan_tiered_package_price.rbs', line 151
def to_hash: -> {
|