Class: Orb::Models::NewPlanTieredWithMinimumPrice::TieredWithMinimumConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/new_plan_tiered_with_minimum_price.rb,
sig/orb/models/new_plan_tiered_with_minimum_price.rbs

Overview

See Also:

  • Orb::Models::NewPlanTieredWithMinimumPrice#tiered_with_minimum_config

Defined Under Namespace

Classes: Tier

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



153
# File 'sig/orb/models/new_plan_tiered_with_minimum_price.rbs', line 153

def initialize: (

Instance Attribute Details

#hide_zero_amount_tiersBoolean?

If true, tiers with an accrued amount of 0 will not be included in the rating.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


214
# File 'lib/orb/models/new_plan_tiered_with_minimum_price.rb', line 214

optional :hide_zero_amount_tiers, Orb::Internal::Type::Boolean

#prorateBoolean?

If true, the unit price will be prorated to the billing period

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


220
# File 'lib/orb/models/new_plan_tiered_with_minimum_price.rb', line 220

optional :prorate, Orb::Internal::Type::Boolean

#tiersArray<Orb::Models::NewPlanTieredWithMinimumPrice::TieredWithMinimumConfig::Tier>

Tiered pricing with a minimum amount dependent on the volume tier. Tiers are defined using exclusive lower bounds.

Parameters:

  • value (::Array[Orb::NewPlanTieredWithMinimumPrice::TieredWithMinimumConfig::Tier])

Returns:



207
208
# File 'lib/orb/models/new_plan_tiered_with_minimum_price.rb', line 207

required :tiers,
-> { Orb::Internal::Type::ArrayOf[Orb::NewPlanTieredWithMinimumPrice::TieredWithMinimumConfig::Tier] }

Instance Method Details

#to_hash{

Returns:

  • ({)


159
# File 'sig/orb/models/new_plan_tiered_with_minimum_price.rbs', line 159

def to_hash: -> {