Class: Orb::Models::NewSubscriptionScalableMatrixWithUnitPricingPrice::ScalableMatrixWithUnitPricingConfig

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/new_subscription_scalable_matrix_with_unit_pricing_price.rb,
sig/orb/models/new_subscription_scalable_matrix_with_unit_pricing_price.rbs

Overview

See Also:

  • Orb::Models::NewSubscriptionScalableMatrixWithUnitPricingPrice#scalable_matrix_with_unit_pricing_config

Defined Under Namespace

Classes: MatrixScalingFactor

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



158
# File 'sig/orb/models/new_subscription_scalable_matrix_with_unit_pricing_price.rbs', line 158

def initialize: (

Instance Attribute Details

#first_dimensionString

Used to determine the unit rate

Parameters:

  • value (String)

Returns:

  • (String)


208
# File 'lib/orb/models/new_subscription_scalable_matrix_with_unit_pricing_price.rb', line 208

required :first_dimension, String

#grouping_keyString?

The property used to group this price

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


231
# File 'lib/orb/models/new_subscription_scalable_matrix_with_unit_pricing_price.rb', line 231

optional :grouping_key, String, nil?: true

#matrix_scaling_factorsArray<Orb::Models::NewSubscriptionScalableMatrixWithUnitPricingPrice::ScalableMatrixWithUnitPricingConfig::MatrixScalingFactor>

Apply a scaling factor to each dimension

Parameters:

  • value (::Array[Orb::NewSubscriptionScalableMatrixWithUnitPricingPrice::ScalableMatrixWithUnitPricingConfig::MatrixScalingFactor])

Returns:



214
215
216
217
218
219
# File 'lib/orb/models/new_subscription_scalable_matrix_with_unit_pricing_price.rb', line 214

required :matrix_scaling_factors,
-> do
  Orb::Internal::Type::ArrayOf[
    Orb::NewSubscriptionScalableMatrixWithUnitPricingPrice::ScalableMatrixWithUnitPricingConfig::MatrixScalingFactor
  ]
end

#prorateBoolean?

If true, the unit price will be prorated to the billing period

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


237
# File 'lib/orb/models/new_subscription_scalable_matrix_with_unit_pricing_price.rb', line 237

optional :prorate, Orb::Internal::Type::Boolean, nil?: true

#second_dimensionString?

Used to determine the unit rate (optional)

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


243
# File 'lib/orb/models/new_subscription_scalable_matrix_with_unit_pricing_price.rb', line 243

optional :second_dimension, String, nil?: true

#unit_priceString

The final unit price to rate against the output of the matrix

Parameters:

  • value (String)

Returns:

  • (String)


225
# File 'lib/orb/models/new_subscription_scalable_matrix_with_unit_pricing_price.rb', line 225

required :unit_price, String

Instance Method Details

#to_hash{

Returns:

  • ({)


167
# File 'sig/orb/models/new_subscription_scalable_matrix_with_unit_pricing_price.rbs', line 167

def to_hash: -> {