Class: Orb::Models::NewSubscriptionThresholdTotalAmountPrice::ThresholdTotalAmountConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/new_subscription_threshold_total_amount_price.rb,
sig/orb/models/new_subscription_threshold_total_amount_price.rbs

Overview

See Also:

  • Orb::Models::NewSubscriptionThresholdTotalAmountPrice#threshold_total_amount_config

Defined Under Namespace

Classes: ConsumptionTable

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



146
# File 'sig/orb/models/new_subscription_threshold_total_amount_price.rbs', line 146

def initialize: (

Instance Attribute Details

#consumption_tableArray<Orb::Models::NewSubscriptionThresholdTotalAmountPrice::ThresholdTotalAmountConfig::ConsumptionTable>

When the quantity consumed passes a provided threshold, the configured total will be charged

Parameters:

  • value (::Array[Orb::NewSubscriptionThresholdTotalAmountPrice::ThresholdTotalAmountConfig::ConsumptionTable])

Returns:



208
209
# File 'lib/orb/models/new_subscription_threshold_total_amount_price.rb', line 208

required :consumption_table,
-> { Orb::Internal::Type::ArrayOf[Orb::NewSubscriptionThresholdTotalAmountPrice::ThresholdTotalAmountConfig::ConsumptionTable] }

#prorateBoolean?

If true, the unit price will be prorated to the billing period

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


215
# File 'lib/orb/models/new_subscription_threshold_total_amount_price.rb', line 215

optional :prorate, Orb::Internal::Type::Boolean, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


151
# File 'sig/orb/models/new_subscription_threshold_total_amount_price.rbs', line 151

def to_hash: -> {