Class: Orb::Models::NewSubscriptionTieredWithMinimumPrice::TieredWithMinimumConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::NewSubscriptionTieredWithMinimumPrice::TieredWithMinimumConfig
- Defined in:
- lib/orb/models/new_subscription_tiered_with_minimum_price.rb,
sig/orb/models/new_subscription_tiered_with_minimum_price.rbs
Overview
Defined Under Namespace
Classes: Tier
Instance Attribute Summary collapse
-
#hide_zero_amount_tiers ⇒ Boolean?
If true, tiers with an accrued amount of 0 will not be included in the rating.
-
#prorate ⇒ Boolean?
If true, the unit price will be prorated to the billing period.
-
#tiers ⇒ Array<Orb::Models::NewSubscriptionTieredWithMinimumPrice::TieredWithMinimumConfig::Tier>
Tiered pricing with a minimum amount dependent on the volume tier.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
153 |
# File 'sig/orb/models/new_subscription_tiered_with_minimum_price.rbs', line 153
def initialize: (
|
Instance Attribute Details
#hide_zero_amount_tiers ⇒ Boolean?
If true, tiers with an accrued amount of 0 will not be included in the rating.
215 |
# File 'lib/orb/models/new_subscription_tiered_with_minimum_price.rb', line 215 optional :hide_zero_amount_tiers, Orb::Internal::Type::Boolean |
#prorate ⇒ Boolean?
If true, the unit price will be prorated to the billing period
221 |
# File 'lib/orb/models/new_subscription_tiered_with_minimum_price.rb', line 221 optional :prorate, Orb::Internal::Type::Boolean |
#tiers ⇒ Array<Orb::Models::NewSubscriptionTieredWithMinimumPrice::TieredWithMinimumConfig::Tier>
Tiered pricing with a minimum amount dependent on the volume tier. Tiers are defined using exclusive lower bounds.
208 209 |
# File 'lib/orb/models/new_subscription_tiered_with_minimum_price.rb', line 208 required :tiers, -> { Orb::Internal::Type::ArrayOf[Orb::NewSubscriptionTieredWithMinimumPrice::TieredWithMinimumConfig::Tier] } |
Instance Method Details
#to_hash ⇒ {
159 |
# File 'sig/orb/models/new_subscription_tiered_with_minimum_price.rbs', line 159
def to_hash: -> {
|