Class: Orb::Models::PlanCreateParams::Price::LicenseAllocationPrice::LicenseAllocation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::PlanCreateParams::Price::LicenseAllocationPrice::LicenseAllocation
- Defined in:
- lib/orb/models/plan_create_params.rb,
sig/orb/models/plan_create_params.rbs
Instance Attribute Summary collapse
-
#amount ⇒ String
The amount of credits granted per active license per cadence.
-
#currency ⇒ String
The currency of the license allocation.
-
#write_off_overage ⇒ Boolean?
When True, overage beyond the allocation is written off.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
247 |
# File 'sig/orb/models/plan_create_params.rbs', line 247
def initialize: (
|
Instance Attribute Details
#amount ⇒ String
The amount of credits granted per active license per cadence.
353 |
# File 'lib/orb/models/plan_create_params.rb', line 353 required :amount, String |
#currency ⇒ String
The currency of the license allocation.
359 |
# File 'lib/orb/models/plan_create_params.rb', line 359 required :currency, String |
#write_off_overage ⇒ Boolean?
When True, overage beyond the allocation is written off.
365 |
# File 'lib/orb/models/plan_create_params.rb', line 365 optional :write_off_overage, Orb::Internal::Type::Boolean, nil?: true |
Instance Method Details
#to_hash ⇒ {
253 |
# File 'sig/orb/models/plan_create_params.rbs', line 253
def to_hash: -> {
|