Class: Orb::Models::PlanUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/orb/models/plan_update_params.rb,
sig/orb/models/plan_update_params.rbs

Overview

See Also:

  • Orb::Resources::Plans#update

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(plan_id:, description: nil, external_plan_id: nil, metadata: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::PlanUpdateParams for more details.

Parameters:

  • plan_id (String)
  • description (String, nil) (defaults to: nil)

    An optional user-defined description of the plan.

  • external_plan_id (String, nil) (defaults to: nil)

    An optional user-defined ID for this plan resource, used throughout the system a

  • metadata (Hash{Symbol=>String, nil}, nil) (defaults to: nil)

    User-specified key/value pairs for the resource. Individual keys can be removed

  • request_options (Orb::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/orb/models/plan_update_params.rb', line 37

Instance Attribute Details

#descriptionString?

An optional user-defined description of the plan.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


19
# File 'lib/orb/models/plan_update_params.rb', line 19

optional :description, String, nil?: true

#external_plan_idString?

An optional user-defined ID for this plan resource, used throughout the system as an alias for this Plan. Use this field to identify a plan by an existing identifier in your system.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


27
# File 'lib/orb/models/plan_update_params.rb', line 27

optional :external_plan_id, String, nil?: true

#metadataHash{Symbol=>String, nil}?

User-specified key/value pairs for the resource. Individual keys can be removed by setting the value to null, and the entire metadata mapping can be cleared by setting metadata to null.

Parameters:

  • value (::Hash[Symbol, String?], nil)

Returns:

  • (Hash{Symbol=>String, nil}, nil)


35
# File 'lib/orb/models/plan_update_params.rb', line 35

optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true

#plan_idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/orb/models/plan_update_params.rb', line 13

required :plan_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


32
# File 'sig/orb/models/plan_update_params.rbs', line 32

def to_hash: -> {