Class: Orb::Models::PlanVersion

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/plan_version.rb,
sig/orb/models/plan_version.rbs

Overview

See Also:

  • Orb::Resources::Beta#create_plan_version

Defined Under Namespace

Modules: Adjustment

Constant Summary collapse

Orb =

Returns:

  • (:PlanPhaseUsageDiscountAdjustment)

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



23
# File 'sig/orb/models/plan_version.rbs', line 23

def initialize: (

Instance Attribute Details

#adjustmentsArray<Orb::Models::PlanPhaseUsageDiscountAdjustment, Orb::Models::PlanPhaseAmountDiscountAdjustment, Orb::Models::PlanPhasePercentageDiscountAdjustment, Orb::Models::PlanVersion::Adjustment::TieredPercentageDiscount, Orb::Models::PlanPhaseMinimumAdjustment, Orb::Models::PlanPhaseMaximumAdjustment>

Adjustments for this plan. If the plan has phases, this includes adjustments across all phases of the plan.



12
# File 'lib/orb/models/plan_version.rb', line 12

required :adjustments, -> { Orb::Internal::Type::ArrayOf[union: Orb::PlanVersion::Adjustment] }

#created_atTime

Parameters:

  • value (Time)

Returns:

  • (Time)


17
# File 'lib/orb/models/plan_version.rb', line 17

required :created_at, Time

#plan_phasesArray<Orb::Models::PlanVersionPhase>?

Parameters:

Returns:



22
# File 'lib/orb/models/plan_version.rb', line 22

required :plan_phases, -> { Orb::Internal::Type::ArrayOf[Orb::PlanVersionPhase] }, nil?: true

#pricesArray<Orb::Models::Price::Unit, Orb::Models::Price::Tiered, Orb::Models::Price::Bulk, Orb::Models::Price::BulkWithFilters, Orb::Models::Price::Package, Orb::Models::Price::Matrix, Orb::Models::Price::ThresholdTotalAmount, Orb::Models::Price::TieredPackage, Orb::Models::Price::TieredWithMinimum, Orb::Models::Price::GroupedTiered, Orb::Models::Price::TieredPackageWithMinimum, Orb::Models::Price::PackageWithAllocation, Orb::Models::Price::UnitWithPercent, Orb::Models::Price::MatrixWithAllocation, Orb::Models::Price::MatrixWithThresholdDiscounts, Orb::Models::Price::TieredWithProration, Orb::Models::Price::UnitWithProration, Orb::Models::Price::GroupedAllocation, Orb::Models::Price::BulkWithProration, Orb::Models::Price::GroupedWithProratedMinimum, Orb::Models::Price::GroupedWithMeteredMinimum, Orb::Models::Price::GroupedWithMinMaxThresholds, Orb::Models::Price::MatrixWithDisplayName, Orb::Models::Price::GroupedTieredPackage, Orb::Models::Price::MaxGroupTieredPackage, Orb::Models::Price::ScalableMatrixWithUnitPricing, Orb::Models::Price::ScalableMatrixWithTieredPricing, Orb::Models::Price::CumulativeGroupedBulk, Orb::Models::Price::CumulativeGroupedAllocation, Orb::Models::Price::DailyCreditAllowance, Orb::Models::Price::MeteredAllowance, Orb::Models::Price::MinimumComposite, Orb::Models::Price::Percent, Orb::Models::Price::EventOutput>

Prices for this plan. If the plan has phases, this includes prices across all phases of the plan.



29
# File 'lib/orb/models/plan_version.rb', line 29

required :prices, -> { Orb::Internal::Type::ArrayOf[union: Orb::Price] }

#versionInteger

Parameters:

  • value (Integer)

Returns:

  • (Integer)


34
# File 'lib/orb/models/plan_version.rb', line 34

required :version, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


31
# File 'sig/orb/models/plan_version.rbs', line 31

def to_hash: -> {