Class: Orb::Models::PlanVersionPhase

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/plan_version_phase.rb,
sig/orb/models/plan_version_phase.rbs

Defined Under Namespace

Modules: DurationUnit

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, description:, duration:, duration_unit:, name:, order:) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::PlanVersionPhase for more details.

Parameters:

  • id (String)
  • description (String, nil)
  • duration (Integer, nil)

    How many terms of length duration_unit this phase is active for. If null, this

  • duration_unit (Symbol, Orb::Models::PlanVersionPhase::DurationUnit, nil)
  • name (String)
  • order (Integer)

    Determines the ordering of the phase in a plan's lifecycle. 1 = first phase.



# File 'lib/orb/models/plan_version_phase.rb', line 39

Instance Attribute Details

#descriptionString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


14
# File 'lib/orb/models/plan_version_phase.rb', line 14

required :description, String, nil?: true

#durationInteger?

How many terms of length duration_unit this phase is active for. If null, this phase is evergreen and active indefinitely

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


21
# File 'lib/orb/models/plan_version_phase.rb', line 21

required :duration, Integer, nil?: true

#duration_unitSymbol, ...

Parameters:

  • value (Orb::Models::PlanVersionPhase::duration_unit, nil)

Returns:



26
# File 'lib/orb/models/plan_version_phase.rb', line 26

required :duration_unit, enum: -> { Orb::PlanVersionPhase::DurationUnit }, nil?: true

#idString

Parameters:

  • value (String)

Returns:

  • (String)


9
# File 'lib/orb/models/plan_version_phase.rb', line 9

required :id, String

#nameString

Parameters:

  • value (String)

Returns:

  • (String)


31
# File 'lib/orb/models/plan_version_phase.rb', line 31

required :name, String

#orderInteger

Determines the ordering of the phase in a plan's lifecycle. 1 = first phase.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


37
# File 'lib/orb/models/plan_version_phase.rb', line 37

required :order, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


35
# File 'sig/orb/models/plan_version_phase.rbs', line 35

def to_hash: -> {