Class: Orb::Models::Price::BulkWithFilters::BulkWithFiltersConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Price::BulkWithFilters::BulkWithFiltersConfig
- Defined in:
- lib/orb/models/price.rb,
sig/orb/models/price.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#filters ⇒ Array<Orb::Models::Price::BulkWithFilters::BulkWithFiltersConfig::Filter>
Property filters to apply (all must match).
-
#tiers ⇒ Array<Orb::Models::Price::BulkWithFilters::BulkWithFiltersConfig::Tier>
Bulk tiers for rating based on total usage volume.
Instance Method Summary collapse
-
#initialize(property_key:, property_value:) ⇒ Object
constructor
Configuration for a single property filter.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(property_key:, property_value:) ⇒ Object
Configuration for a single property filter
|
|
# File 'lib/orb/models/price.rb', line 1472
|
Instance Attribute Details
#filters ⇒ Array<Orb::Models::Price::BulkWithFilters::BulkWithFiltersConfig::Filter>
Property filters to apply (all must match)
1442 1443 |
# File 'lib/orb/models/price.rb', line 1442 required :filters, -> { Orb::Internal::Type::ArrayOf[Orb::Price::BulkWithFilters::BulkWithFiltersConfig::Filter] } |
#tiers ⇒ Array<Orb::Models::Price::BulkWithFilters::BulkWithFiltersConfig::Tier>
Bulk tiers for rating based on total usage volume
1449 1450 |
# File 'lib/orb/models/price.rb', line 1449 required :tiers, -> { Orb::Internal::Type::ArrayOf[Orb::Price::BulkWithFilters::BulkWithFiltersConfig::Tier] } |
Instance Method Details
#to_hash ⇒ {
1048 |
# File 'sig/orb/models/price.rbs', line 1048
def to_hash: -> {
|