Class: Orb::Models::Price::CumulativeGroupedAllocation
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, CumulativeGroupedAllocationConfig, LicenseType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cumulative_allocation:, group_allocation:, grouping_key:, unit_amount:) ⇒ Object
Configuration for cumulative_grouped_allocation pricing
|
# File 'lib/orb/models/price.rb', line 12568
|
Instance Attribute Details
12403
|
# File 'lib/orb/models/price.rb', line 12403
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
12408
|
# File 'lib/orb/models/price.rb', line 12408
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
12413
|
# File 'lib/orb/models/price.rb', line 12413
required :billing_mode, enum: -> { Orb::Price::CumulativeGroupedAllocation::BillingMode }
|
12418
|
# File 'lib/orb/models/price.rb', line 12418
required :cadence, enum: -> { Orb::Price::CumulativeGroupedAllocation::Cadence }
|
12423
12424
12425
12426
12427
|
# File 'lib/orb/models/price.rb', line 12423
required :composite_price_filters,
-> {
Orb::Internal::Type::ArrayOf[Orb::Price::CumulativeGroupedAllocation::CompositePriceFilter]
},
nil?: true
|
#conversion_rate ⇒ Float?
12432
|
# File 'lib/orb/models/price.rb', line 12432
required :conversion_rate, Float, nil?: true
|
12437
|
# File 'lib/orb/models/price.rb', line 12437
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
12442
|
# File 'lib/orb/models/price.rb', line 12442
required :created_at, Time
|
12447
|
# File 'lib/orb/models/price.rb', line 12447
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
Configuration for cumulative_grouped_allocation pricing
12453
12454
|
# File 'lib/orb/models/price.rb', line 12453
required :cumulative_grouped_allocation_config,
-> { Orb::Price::CumulativeGroupedAllocation::CumulativeGroupedAllocationConfig }
|
#currency ⇒ String
12459
|
# File 'lib/orb/models/price.rb', line 12459
required :currency, String
|
12558
|
# File 'lib/orb/models/price.rb', line 12558
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
12465
|
# File 'lib/orb/models/price.rb', line 12465
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
12470
|
# File 'lib/orb/models/price.rb', line 12470
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
12475
|
# File 'lib/orb/models/price.rb', line 12475
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
12398
|
# File 'lib/orb/models/price.rb', line 12398
required :id, String
|
#invoice_grouping_key ⇒ String?
12480
|
# File 'lib/orb/models/price.rb', line 12480
required :invoice_grouping_key, String, nil?: true
|
12485
|
# File 'lib/orb/models/price.rb', line 12485
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
12492
|
# File 'lib/orb/models/price.rb', line 12492
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
12566
|
# File 'lib/orb/models/price.rb', line 12566
optional :license_type, -> { Orb::Price::CumulativeGroupedAllocation::LicenseType }, nil?: true
|
12498
|
# File 'lib/orb/models/price.rb', line 12498
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
12504
|
# File 'lib/orb/models/price.rb', line 12504
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
12513
|
# File 'lib/orb/models/price.rb', line 12513
required :metadata, Orb::Internal::Type::HashOf[String]
|
12519
|
# File 'lib/orb/models/price.rb', line 12519
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
12525
|
# File 'lib/orb/models/price.rb', line 12525
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :cumulative_grouped_allocation
12531
|
# File 'lib/orb/models/price.rb', line 12531
required :model_type, const: :cumulative_grouped_allocation
|
#name ⇒ String
12536
|
# File 'lib/orb/models/price.rb', line 12536
required :name, String
|
#plan_phase_order ⇒ Integer?
12541
|
# File 'lib/orb/models/price.rb', line 12541
required :plan_phase_order, Integer, nil?: true
|
12546
|
# File 'lib/orb/models/price.rb', line 12546
required :price_type, enum: -> { Orb::Price::CumulativeGroupedAllocation::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
12553
|
# File 'lib/orb/models/price.rb', line 12553
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 12639
|
Instance Method Details
#to_hash ⇒ {
9397
|
# File 'sig/orb/models/price.rbs', line 9397
def to_hash: -> {
|