Class: Orb::Models::Price::CumulativeGroupedAllocation::CumulativeGroupedAllocationConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Price::CumulativeGroupedAllocation::CumulativeGroupedAllocationConfig
- Defined in:
- lib/orb/models/price.rb,
sig/orb/models/price.rbs
Overview
Instance Attribute Summary collapse
-
#cumulative_allocation ⇒ String
The overall allocation across all groups.
-
#group_allocation ⇒ String
The allocation per individual group.
-
#grouping_key ⇒ String
The event property used to group usage before applying allocations.
-
#unit_amount ⇒ String
The amount to charge for each unit outside of the allocation.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
8868 |
# File 'sig/orb/models/price.rbs', line 8868
def initialize: (
|
Instance Attribute Details
#cumulative_allocation ⇒ String
The overall allocation across all groups
11839 |
# File 'lib/orb/models/price.rb', line 11839 required :cumulative_allocation, String |
#group_allocation ⇒ String
The allocation per individual group
11845 |
# File 'lib/orb/models/price.rb', line 11845 required :group_allocation, String |
#grouping_key ⇒ String
The event property used to group usage before applying allocations
11851 |
# File 'lib/orb/models/price.rb', line 11851 required :grouping_key, String |
#unit_amount ⇒ String
The amount to charge for each unit outside of the allocation
11857 |
# File 'lib/orb/models/price.rb', line 11857 required :unit_amount, String |
Instance Method Details
#to_hash ⇒ {
8875 |
# File 'sig/orb/models/price.rbs', line 8875
def to_hash: -> {
|