Class: Orb::Models::Price::CumulativeGroupedBulk::CumulativeGroupedBulkConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Price::CumulativeGroupedBulk::CumulativeGroupedBulkConfig
- Defined in:
- lib/orb/models/price.rb,
sig/orb/models/price.rbs
Overview
Defined Under Namespace
Classes: DimensionValue
Instance Attribute Summary collapse
-
#dimension_values ⇒ Array<Orb::Models::Price::CumulativeGroupedBulk::CumulativeGroupedBulkConfig::DimensionValue>
Each tier lower bound must have the same group of values.
- #group ⇒ String
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
8541 |
# File 'sig/orb/models/price.rbs', line 8541
def initialize: (
|
Instance Attribute Details
#dimension_values ⇒ Array<Orb::Models::Price::CumulativeGroupedBulk::CumulativeGroupedBulkConfig::DimensionValue>
Each tier lower bound must have the same group of values.
11419 11420 |
# File 'lib/orb/models/price.rb', line 11419 required :dimension_values, -> { Orb::Internal::Type::ArrayOf[Orb::Price::CumulativeGroupedBulk::CumulativeGroupedBulkConfig::DimensionValue] } |
#group ⇒ String
11425 |
# File 'lib/orb/models/price.rb', line 11425 required :group, String |
Instance Method Details
#to_hash ⇒ {
8546 |
# File 'sig/orb/models/price.rbs', line 8546
def to_hash: -> {
|