Class: Orb::Models::Price::EventOutput
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, EventOutputConfig, LicenseType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(unit_rating_key:, default_unit_rate: nil, grouping_key: nil) ⇒ Object
Some parameter documentations has been truncated, see
EventOutputConfig for more details.
Configuration for event_output pricing
|
# File 'lib/orb/models/price.rb', line 14645
|
Instance Attribute Details
14483
|
# File 'lib/orb/models/price.rb', line 14483
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
14488
|
# File 'lib/orb/models/price.rb', line 14488
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
14493
|
# File 'lib/orb/models/price.rb', line 14493
required :billing_mode, enum: -> { Orb::Price::EventOutput::BillingMode }
|
14498
|
# File 'lib/orb/models/price.rb', line 14498
required :cadence, enum: -> { Orb::Price::EventOutput::Cadence }
|
14503
14504
14505
|
# File 'lib/orb/models/price.rb', line 14503
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::EventOutput::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
14510
|
# File 'lib/orb/models/price.rb', line 14510
required :conversion_rate, Float, nil?: true
|
14515
|
# File 'lib/orb/models/price.rb', line 14515
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
14520
|
# File 'lib/orb/models/price.rb', line 14520
required :created_at, Time
|
14525
|
# File 'lib/orb/models/price.rb', line 14525
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
14530
|
# File 'lib/orb/models/price.rb', line 14530
required :currency, String
|
14635
|
# File 'lib/orb/models/price.rb', line 14635
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
14536
|
# File 'lib/orb/models/price.rb', line 14536
required :discount, union: -> { Orb::Discount }, nil?: true
|
Configuration for event_output pricing
14542
|
# File 'lib/orb/models/price.rb', line 14542
required :event_output_config, -> { Orb::Price::EventOutput::EventOutputConfig }
|
#external_price_id ⇒ String?
14547
|
# File 'lib/orb/models/price.rb', line 14547
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
14552
|
# File 'lib/orb/models/price.rb', line 14552
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
14478
|
# File 'lib/orb/models/price.rb', line 14478
required :id, String
|
#invoice_grouping_key ⇒ String?
14557
|
# File 'lib/orb/models/price.rb', line 14557
required :invoice_grouping_key, String, nil?: true
|
14562
|
# File 'lib/orb/models/price.rb', line 14562
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
14569
|
# File 'lib/orb/models/price.rb', line 14569
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
14643
|
# File 'lib/orb/models/price.rb', line 14643
optional :license_type, -> { Orb::Price::EventOutput::LicenseType }, nil?: true
|
14575
|
# File 'lib/orb/models/price.rb', line 14575
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
14581
|
# File 'lib/orb/models/price.rb', line 14581
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
14590
|
# File 'lib/orb/models/price.rb', line 14590
required :metadata, Orb::Internal::Type::HashOf[String]
|
14596
|
# File 'lib/orb/models/price.rb', line 14596
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
14602
|
# File 'lib/orb/models/price.rb', line 14602
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :event_output
14608
|
# File 'lib/orb/models/price.rb', line 14608
required :model_type, const: :event_output
|
#name ⇒ String
14613
|
# File 'lib/orb/models/price.rb', line 14613
required :name, String
|
#plan_phase_order ⇒ Integer?
14618
|
# File 'lib/orb/models/price.rb', line 14618
required :plan_phase_order, Integer, nil?: true
|
14623
|
# File 'lib/orb/models/price.rb', line 14623
required :price_type, enum: -> { Orb::Price::EventOutput::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
14630
|
# File 'lib/orb/models/price.rb', line 14630
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 14716
|
Instance Method Details
#to_hash ⇒ {
10940
|
# File 'sig/orb/models/price.rbs', line 10940
def to_hash: -> {
|