Class: Orb::Models::Price::EventOutput::LicenseType

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/price.rb,
sig/orb/models/price.rbs

Overview

See Also:

  • Orb::Models::Price::EventOutput#license_type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, grouping_key:, name:) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::Price::EventOutput::LicenseType for more details.

The LicenseType resource represents a type of license that can be assigned to users. License types are used during billing by grouping metrics on the configured grouping key.

Parameters:

  • id (String) —

    The Orb-assigned unique identifier for the license type.

  • grouping_key (String) —

    The key used for grouping licenses of this type. This is typically a user identi

  • name (String) —

    The name of the license type.



# File 'lib/orb/models/price.rb', line 14860

Instance Attribute Details

#grouping_key ⇒ String

The key used for grouping licenses of this type. This is typically a user identifier field.

Parameters:

  • value (String)

Returns:

  • (String)


14852
# File 'lib/orb/models/price.rb', line 14852

required :grouping_key, String

#id ⇒ String

The Orb-assigned unique identifier for the license type.

Parameters:

  • value (String)

Returns:

  • (String)


14845
# File 'lib/orb/models/price.rb', line 14845

required :id, String

#name ⇒ String

The name of the license type.

Parameters:

  • value (String)

Returns:

  • (String)


14858
# File 'lib/orb/models/price.rb', line 14858

required :name, String

Instance Method Details

#to_hash ⇒ { id: String, grouping_key: String, name: String }

Returns:

  • ({ id: String, grouping_key: String, name: String })


11107
# File 'sig/orb/models/price.rbs', line 11107

def to_hash: -> { id: String, grouping_key: String, name: String }