Class: Orb::Models::Price::GroupedAllocation
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, GroupedAllocationConfig, LicenseType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(allocation:, grouping_key:, overage_unit_rate:) ⇒ Object
Configuration for grouped_allocation pricing
|
# File 'lib/orb/models/price.rb', line 7911
|
Instance Attribute Details
7749
|
# File 'lib/orb/models/price.rb', line 7749
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
7754
|
# File 'lib/orb/models/price.rb', line 7754
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
7759
|
# File 'lib/orb/models/price.rb', line 7759
required :billing_mode, enum: -> { Orb::Price::GroupedAllocation::BillingMode }
|
7764
|
# File 'lib/orb/models/price.rb', line 7764
required :cadence, enum: -> { Orb::Price::GroupedAllocation::Cadence }
|
7769
7770
7771
|
# File 'lib/orb/models/price.rb', line 7769
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::GroupedAllocation::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
7776
|
# File 'lib/orb/models/price.rb', line 7776
required :conversion_rate, Float, nil?: true
|
7781
|
# File 'lib/orb/models/price.rb', line 7781
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
7786
|
# File 'lib/orb/models/price.rb', line 7786
required :created_at, Time
|
7791
|
# File 'lib/orb/models/price.rb', line 7791
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
7796
|
# File 'lib/orb/models/price.rb', line 7796
required :currency, String
|
7901
|
# File 'lib/orb/models/price.rb', line 7901
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
7802
|
# File 'lib/orb/models/price.rb', line 7802
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
7807
|
# File 'lib/orb/models/price.rb', line 7807
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
7812
|
# File 'lib/orb/models/price.rb', line 7812
required :fixed_price_quantity, Float, nil?: true
|
Configuration for grouped_allocation pricing
7818
|
# File 'lib/orb/models/price.rb', line 7818
required :grouped_allocation_config, -> { Orb::Price::GroupedAllocation::GroupedAllocationConfig }
|
#id ⇒ String
7744
|
# File 'lib/orb/models/price.rb', line 7744
required :id, String
|
#invoice_grouping_key ⇒ String?
7823
|
# File 'lib/orb/models/price.rb', line 7823
required :invoice_grouping_key, String, nil?: true
|
7828
|
# File 'lib/orb/models/price.rb', line 7828
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
7835
|
# File 'lib/orb/models/price.rb', line 7835
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
7909
|
# File 'lib/orb/models/price.rb', line 7909
optional :license_type, -> { Orb::Price::GroupedAllocation::LicenseType }, nil?: true
|
7841
|
# File 'lib/orb/models/price.rb', line 7841
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
7847
|
# File 'lib/orb/models/price.rb', line 7847
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
7856
|
# File 'lib/orb/models/price.rb', line 7856
required :metadata, Orb::Internal::Type::HashOf[String]
|
7862
|
# File 'lib/orb/models/price.rb', line 7862
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
7868
|
# File 'lib/orb/models/price.rb', line 7868
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :grouped_allocation
7874
|
# File 'lib/orb/models/price.rb', line 7874
required :model_type, const: :grouped_allocation
|
#name ⇒ String
7879
|
# File 'lib/orb/models/price.rb', line 7879
required :name, String
|
#plan_phase_order ⇒ Integer?
7884
|
# File 'lib/orb/models/price.rb', line 7884
required :plan_phase_order, Integer, nil?: true
|
7889
|
# File 'lib/orb/models/price.rb', line 7889
required :price_type, enum: -> { Orb::Price::GroupedAllocation::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
7896
|
# File 'lib/orb/models/price.rb', line 7896
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 7982
|
Instance Method Details
#to_hash ⇒ {
5899
|
# File 'sig/orb/models/price.rbs', line 5899
def to_hash: -> {
|