Class: Orb::Models::Price::GroupedTiered
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, GroupedTieredConfig, LicenseType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(tier_lower_bound:, unit_amount:) ⇒ Object
Configuration for a single tier
|
# File 'lib/orb/models/price.rb', line 3782
|
Instance Attribute Details
3620
|
# File 'lib/orb/models/price.rb', line 3620
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
3625
|
# File 'lib/orb/models/price.rb', line 3625
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
3630
|
# File 'lib/orb/models/price.rb', line 3630
required :billing_mode, enum: -> { Orb::Price::GroupedTiered::BillingMode }
|
3635
|
# File 'lib/orb/models/price.rb', line 3635
required :cadence, enum: -> { Orb::Price::GroupedTiered::Cadence }
|
3640
3641
3642
|
# File 'lib/orb/models/price.rb', line 3640
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::GroupedTiered::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
3647
|
# File 'lib/orb/models/price.rb', line 3647
required :conversion_rate, Float, nil?: true
|
3652
|
# File 'lib/orb/models/price.rb', line 3652
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
3657
|
# File 'lib/orb/models/price.rb', line 3657
required :created_at, Time
|
3662
|
# File 'lib/orb/models/price.rb', line 3662
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
3667
|
# File 'lib/orb/models/price.rb', line 3667
required :currency, String
|
3772
|
# File 'lib/orb/models/price.rb', line 3772
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
3673
|
# File 'lib/orb/models/price.rb', line 3673
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
3678
|
# File 'lib/orb/models/price.rb', line 3678
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
3683
|
# File 'lib/orb/models/price.rb', line 3683
required :fixed_price_quantity, Float, nil?: true
|
Configuration for grouped_tiered pricing
3689
|
# File 'lib/orb/models/price.rb', line 3689
required :grouped_tiered_config, -> { Orb::Price::GroupedTiered::GroupedTieredConfig }
|
#id ⇒ String
3615
|
# File 'lib/orb/models/price.rb', line 3615
required :id, String
|
#invoice_grouping_key ⇒ String?
3694
|
# File 'lib/orb/models/price.rb', line 3694
required :invoice_grouping_key, String, nil?: true
|
3699
|
# File 'lib/orb/models/price.rb', line 3699
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
3706
|
# File 'lib/orb/models/price.rb', line 3706
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
3780
|
# File 'lib/orb/models/price.rb', line 3780
optional :license_type, -> { Orb::Price::GroupedTiered::LicenseType }, nil?: true
|
3712
|
# File 'lib/orb/models/price.rb', line 3712
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
3718
|
# File 'lib/orb/models/price.rb', line 3718
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
3727
|
# File 'lib/orb/models/price.rb', line 3727
required :metadata, Orb::Internal::Type::HashOf[String]
|
3733
|
# File 'lib/orb/models/price.rb', line 3733
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
3739
|
# File 'lib/orb/models/price.rb', line 3739
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :grouped_tiered
3745
|
# File 'lib/orb/models/price.rb', line 3745
required :model_type, const: :grouped_tiered
|
#name ⇒ String
3750
|
# File 'lib/orb/models/price.rb', line 3750
required :name, String
|
#plan_phase_order ⇒ Integer?
3755
|
# File 'lib/orb/models/price.rb', line 3755
required :plan_phase_order, Integer, nil?: true
|
3760
|
# File 'lib/orb/models/price.rb', line 3760
required :price_type, enum: -> { Orb::Price::GroupedTiered::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
3767
|
# File 'lib/orb/models/price.rb', line 3767
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 3853
|
Instance Method Details
#to_hash ⇒ {
2798
|
# File 'sig/orb/models/price.rbs', line 2798
def to_hash: -> {
|