Class: Orb::Models::Price::GroupedTieredMatrix
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, GroupedTieredMatrixConfig, LicenseType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(dimension_value:, tier_lower_bound:, unit_amount:) ⇒ Object
Configuration for a single tier scoped to a dimension value
|
# File 'lib/orb/models/price.rb', line 4194
|
Instance Attribute Details
4032
|
# File 'lib/orb/models/price.rb', line 4032
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
4037
|
# File 'lib/orb/models/price.rb', line 4037
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
4042
|
# File 'lib/orb/models/price.rb', line 4042
required :billing_mode, enum: -> { Orb::Price::GroupedTieredMatrix::BillingMode }
|
4047
|
# File 'lib/orb/models/price.rb', line 4047
required :cadence, enum: -> { Orb::Price::GroupedTieredMatrix::Cadence }
|
4052
4053
4054
|
# File 'lib/orb/models/price.rb', line 4052
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::GroupedTieredMatrix::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
4059
|
# File 'lib/orb/models/price.rb', line 4059
required :conversion_rate, Float, nil?: true
|
4064
|
# File 'lib/orb/models/price.rb', line 4064
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
4069
|
# File 'lib/orb/models/price.rb', line 4069
required :created_at, Time
|
4074
|
# File 'lib/orb/models/price.rb', line 4074
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
4079
|
# File 'lib/orb/models/price.rb', line 4079
required :currency, String
|
4184
|
# File 'lib/orb/models/price.rb', line 4184
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
4085
|
# File 'lib/orb/models/price.rb', line 4085
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
4090
|
# File 'lib/orb/models/price.rb', line 4090
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
4095
|
# File 'lib/orb/models/price.rb', line 4095
required :fixed_price_quantity, Float, nil?: true
|
Configuration for grouped_tiered_matrix pricing
4101
|
# File 'lib/orb/models/price.rb', line 4101
required :grouped_tiered_matrix_config, -> { Orb::Price::GroupedTieredMatrix::GroupedTieredMatrixConfig }
|
#id ⇒ String
4027
|
# File 'lib/orb/models/price.rb', line 4027
required :id, String
|
#invoice_grouping_key ⇒ String?
4106
|
# File 'lib/orb/models/price.rb', line 4106
required :invoice_grouping_key, String, nil?: true
|
4111
|
# File 'lib/orb/models/price.rb', line 4111
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
4118
|
# File 'lib/orb/models/price.rb', line 4118
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
4192
|
# File 'lib/orb/models/price.rb', line 4192
optional :license_type, -> { Orb::Price::GroupedTieredMatrix::LicenseType }, nil?: true
|
4124
|
# File 'lib/orb/models/price.rb', line 4124
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
4130
|
# File 'lib/orb/models/price.rb', line 4130
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
4139
|
# File 'lib/orb/models/price.rb', line 4139
required :metadata, Orb::Internal::Type::HashOf[String]
|
4145
|
# File 'lib/orb/models/price.rb', line 4145
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
4151
|
# File 'lib/orb/models/price.rb', line 4151
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :grouped_tiered_matrix
4157
|
# File 'lib/orb/models/price.rb', line 4157
required :model_type, const: :grouped_tiered_matrix
|
#name ⇒ String
4162
|
# File 'lib/orb/models/price.rb', line 4162
required :name, String
|
#plan_phase_order ⇒ Integer?
4167
|
# File 'lib/orb/models/price.rb', line 4167
required :plan_phase_order, Integer, nil?: true
|
4172
|
# File 'lib/orb/models/price.rb', line 4172
required :price_type, enum: -> { Orb::Price::GroupedTieredMatrix::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
4179
|
# File 'lib/orb/models/price.rb', line 4179
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 4265
|
Instance Method Details
#to_hash ⇒ {
3107
|
# File 'sig/orb/models/price.rbs', line 3107
def to_hash: -> {
|