Class: Orb::Models::Price::GroupedTieredPackage
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, GroupedTieredPackageConfig, LicenseType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(per_unit:, tier_lower_bound:) ⇒ Object
Configuration for a single tier
|
# File 'lib/orb/models/price.rb', line 10404
|
Instance Attribute Details
10241
|
# File 'lib/orb/models/price.rb', line 10241
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
10246
|
# File 'lib/orb/models/price.rb', line 10246
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
10251
|
# File 'lib/orb/models/price.rb', line 10251
required :billing_mode, enum: -> { Orb::Price::GroupedTieredPackage::BillingMode }
|
10256
|
# File 'lib/orb/models/price.rb', line 10256
required :cadence, enum: -> { Orb::Price::GroupedTieredPackage::Cadence }
|
10261
10262
10263
|
# File 'lib/orb/models/price.rb', line 10261
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::GroupedTieredPackage::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
10268
|
# File 'lib/orb/models/price.rb', line 10268
required :conversion_rate, Float, nil?: true
|
10273
|
# File 'lib/orb/models/price.rb', line 10273
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
10278
|
# File 'lib/orb/models/price.rb', line 10278
required :created_at, Time
|
10283
|
# File 'lib/orb/models/price.rb', line 10283
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
10288
|
# File 'lib/orb/models/price.rb', line 10288
required :currency, String
|
10394
|
# File 'lib/orb/models/price.rb', line 10394
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
10294
|
# File 'lib/orb/models/price.rb', line 10294
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
10299
|
# File 'lib/orb/models/price.rb', line 10299
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
10304
|
# File 'lib/orb/models/price.rb', line 10304
required :fixed_price_quantity, Float, nil?: true
|
Configuration for grouped_tiered_package pricing
10310
10311
|
# File 'lib/orb/models/price.rb', line 10310
required :grouped_tiered_package_config,
-> { Orb::Price::GroupedTieredPackage::GroupedTieredPackageConfig }
|
#id ⇒ String
10236
|
# File 'lib/orb/models/price.rb', line 10236
required :id, String
|
#invoice_grouping_key ⇒ String?
10316
|
# File 'lib/orb/models/price.rb', line 10316
required :invoice_grouping_key, String, nil?: true
|
10321
|
# File 'lib/orb/models/price.rb', line 10321
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
10328
|
# File 'lib/orb/models/price.rb', line 10328
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
10402
|
# File 'lib/orb/models/price.rb', line 10402
optional :license_type, -> { Orb::Price::GroupedTieredPackage::LicenseType }, nil?: true
|
10334
|
# File 'lib/orb/models/price.rb', line 10334
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
10340
|
# File 'lib/orb/models/price.rb', line 10340
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
10349
|
# File 'lib/orb/models/price.rb', line 10349
required :metadata, Orb::Internal::Type::HashOf[String]
|
10355
|
# File 'lib/orb/models/price.rb', line 10355
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
10361
|
# File 'lib/orb/models/price.rb', line 10361
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :grouped_tiered_package
10367
|
# File 'lib/orb/models/price.rb', line 10367
required :model_type, const: :grouped_tiered_package
|
#name ⇒ String
10372
|
# File 'lib/orb/models/price.rb', line 10372
required :name, String
|
#plan_phase_order ⇒ Integer?
10377
|
# File 'lib/orb/models/price.rb', line 10377
required :plan_phase_order, Integer, nil?: true
|
10382
|
# File 'lib/orb/models/price.rb', line 10382
required :price_type, enum: -> { Orb::Price::GroupedTieredPackage::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
10389
|
# File 'lib/orb/models/price.rb', line 10389
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 10475
|
Instance Method Details
#to_hash ⇒ {
7764
|
# File 'sig/orb/models/price.rbs', line 7764
def to_hash: -> {
|