Class: Orb::Models::Price::GroupedWithProratedMinimum::GroupedWithProratedMinimumConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Price::GroupedWithProratedMinimum::GroupedWithProratedMinimumConfig
- Defined in:
- lib/orb/models/price.rb,
sig/orb/models/price.rbs
Overview
Instance Attribute Summary collapse
-
#grouping_key ⇒ String
How to determine the groups that should each have a minimum.
-
#minimum ⇒ String
The minimum amount to charge per group.
-
#unit_rate ⇒ String
The amount to charge per unit.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
5966 |
# File 'sig/orb/models/price.rbs', line 5966
def initialize: (
|
Instance Attribute Details
#grouping_key ⇒ String
How to determine the groups that should each have a minimum
7983 |
# File 'lib/orb/models/price.rb', line 7983 required :grouping_key, String |
#minimum ⇒ String
The minimum amount to charge per group
7989 |
# File 'lib/orb/models/price.rb', line 7989 required :minimum, String |
#unit_rate ⇒ String
The amount to charge per unit
7995 |
# File 'lib/orb/models/price.rb', line 7995 required :unit_rate, String |
Instance Method Details
#to_hash ⇒ {
5972 |
# File 'sig/orb/models/price.rbs', line 5972
def to_hash: -> {
|