Class: Orb::Models::Price::MatrixWithAllocation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/price.rb,
sig/orb/models/price.rbs

Defined Under Namespace

Modules: BillingMode, Cadence, PriceType Classes: CompositePriceFilter, LicenseType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, billable_metric:, billing_cycle_configuration:, billing_mode:, cadence:, composite_price_filters:, conversion_rate:, conversion_rate_config:, created_at:, credit_allocation:, currency:, discount:, external_price_id:, fixed_price_quantity:, invoice_grouping_key:, invoicing_cycle_configuration:, item:, matrix_with_allocation_config:, maximum:, maximum_amount:, metadata:, minimum:, minimum_amount:, name:, plan_phase_order:, price_type:, replaces_price_id:, dimensional_price_configuration: nil, license_type: nil, model_type: :matrix_with_allocation) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::Price::MatrixWithAllocation for more details.

Parameters:



# File 'lib/orb/models/price.rb', line 5824

Instance Attribute Details

#billable_metric ⇒ Orb::Models::BillableMetricTiny?

Parameters:

Returns:



5662
# File 'lib/orb/models/price.rb', line 5662

required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true

#billing_cycle_configuration ⇒ Orb::Models::BillingCycleConfiguration



5667
# File 'lib/orb/models/price.rb', line 5667

required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }

#billing_mode ⇒ Symbol, Orb::Models::Price::MatrixWithAllocation::BillingMode

Parameters:

  • value (Orb::Models::Price::MatrixWithAllocation::billing_mode)

Returns:



5672
# File 'lib/orb/models/price.rb', line 5672

required :billing_mode, enum: -> { Orb::Price::MatrixWithAllocation::BillingMode }

#cadence ⇒ Symbol, Orb::Models::Price::MatrixWithAllocation::Cadence

Parameters:

  • value (Orb::Models::Price::MatrixWithAllocation::cadence)

Returns:



5677
# File 'lib/orb/models/price.rb', line 5677

required :cadence, enum: -> { Orb::Price::MatrixWithAllocation::Cadence }

#composite_price_filters ⇒ Array<Orb::Models::Price::MatrixWithAllocation::CompositePriceFilter>?

Parameters:

  • value (::Array[Orb::Price::MatrixWithAllocation::CompositePriceFilter], nil)

Returns:



5682
5683
5684
# File 'lib/orb/models/price.rb', line 5682

required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::MatrixWithAllocation::CompositePriceFilter] },
nil?: true

#conversion_rate ⇒ Float?

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


5689
# File 'lib/orb/models/price.rb', line 5689

required :conversion_rate, Float, nil?: true

#conversion_rate_config ⇒ Orb::Models::UnitConversionRateConfig, ...

Parameters:

  • value (Orb::Models::conversion_rate_config, nil)

Returns:



5694
# File 'lib/orb/models/price.rb', line 5694

required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true

#created_at ⇒ Time

Parameters:

  • value (Time)

Returns:

  • (Time)


5699
# File 'lib/orb/models/price.rb', line 5699

required :created_at, Time

#credit_allocation ⇒ Orb::Models::Allocation?

Parameters:

Returns:



5704
# File 'lib/orb/models/price.rb', line 5704

required :credit_allocation, -> { Orb::Allocation }, nil?: true

#currency ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


5709
# File 'lib/orb/models/price.rb', line 5709

required :currency, String

#dimensional_price_configuration ⇒ Orb::Models::DimensionalPriceConfiguration?



5814
# File 'lib/orb/models/price.rb', line 5814

optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true

#discount ⇒ Orb::Models::PercentageDiscount, ...

Deprecated.


5715
# File 'lib/orb/models/price.rb', line 5715

required :discount, union: -> { Orb::Discount }, nil?: true

#external_price_id ⇒ String?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


5720
# File 'lib/orb/models/price.rb', line 5720

required :external_price_id, String, nil?: true

#fixed_price_quantity ⇒ Float?

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


5725
# File 'lib/orb/models/price.rb', line 5725

required :fixed_price_quantity, Float, nil?: true

#id ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


5657
# File 'lib/orb/models/price.rb', line 5657

required :id, String

#invoice_grouping_key ⇒ String?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


5730
# File 'lib/orb/models/price.rb', line 5730

required :invoice_grouping_key, String, nil?: true

#invoicing_cycle_configuration ⇒ Orb::Models::BillingCycleConfiguration?



5735
# File 'lib/orb/models/price.rb', line 5735

required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true

#item ⇒ Orb::Models::ItemSlim

A minimal representation of an Item containing only the essential identifying information.

Parameters:

Returns:



5742
# File 'lib/orb/models/price.rb', line 5742

required :item, -> { Orb::ItemSlim }

#license_type ⇒ Orb::Models::Price::MatrixWithAllocation::LicenseType?

The LicenseType resource represents a type of license that can be assigned to users. License types are used during billing by grouping metrics on the configured grouping key.

Parameters:

  • value (Orb::Price::MatrixWithAllocation::LicenseType, nil)

Returns:



5822
# File 'lib/orb/models/price.rb', line 5822

optional :license_type, -> { Orb::Price::MatrixWithAllocation::LicenseType }, nil?: true

#matrix_with_allocation_config ⇒ Orb::Models::MatrixWithAllocationConfig

Configuration for matrix_with_allocation pricing



5748
# File 'lib/orb/models/price.rb', line 5748

required :matrix_with_allocation_config, -> { Orb::MatrixWithAllocationConfig }

#maximum ⇒ Orb::Models::Maximum?

Deprecated.

Parameters:

Returns:



5754
# File 'lib/orb/models/price.rb', line 5754

required :maximum, -> { Orb::Maximum }, nil?: true

#maximum_amount ⇒ String?

Deprecated.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


5760
# File 'lib/orb/models/price.rb', line 5760

required :maximum_amount, String, nil?: true

#metadata ⇒ Hash{Symbol=>String}

User specified key-value pairs for the resource. If not present, this defaults to an empty dictionary. Individual keys can be removed by setting the value to null, and the entire metadata mapping can be cleared by setting metadata to null.

Parameters:

  • value (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String})


5769
# File 'lib/orb/models/price.rb', line 5769

required :metadata, Orb::Internal::Type::HashOf[String]

#minimum ⇒ Orb::Models::Minimum?

Deprecated.

Parameters:

Returns:



5775
# File 'lib/orb/models/price.rb', line 5775

required :minimum, -> { Orb::Minimum }, nil?: true

#minimum_amount ⇒ String?

Deprecated.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


5781
# File 'lib/orb/models/price.rb', line 5781

required :minimum_amount, String, nil?: true

#model_type ⇒ Symbol, :matrix_with_allocation

The pricing model type

Parameters:

  • value (:matrix_with_allocation)

Returns:

  • (Symbol, :matrix_with_allocation)


5787
# File 'lib/orb/models/price.rb', line 5787

required :model_type, const: :matrix_with_allocation

#name ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


5792
# File 'lib/orb/models/price.rb', line 5792

required :name, String

#plan_phase_order ⇒ Integer?

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


5797
# File 'lib/orb/models/price.rb', line 5797

required :plan_phase_order, Integer, nil?: true

#price_type ⇒ Symbol, Orb::Models::Price::MatrixWithAllocation::PriceType

Parameters:

  • value (Orb::Models::Price::MatrixWithAllocation::price_type)

Returns:



5802
# File 'lib/orb/models/price.rb', line 5802

required :price_type, enum: -> { Orb::Price::MatrixWithAllocation::PriceType }

#replaces_price_id ⇒ String?

The price id this price replaces. This price will take the place of the replaced price in plan version migrations.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


5809
# File 'lib/orb/models/price.rb', line 5809

required :replaces_price_id, String, nil?: true

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/orb/models/price.rb', line 5895

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


4333
# File 'sig/orb/models/price.rbs', line 4333

def to_hash: -> {