Class: Orb::Models::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::ThresholdDiscountGroup
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::ThresholdDiscountGroup
- Defined in:
- lib/orb/models/price.rb,
sig/orb/models/price.rbs
Instance Attribute Summary collapse
-
#above_threshold_discount_percentage ⇒ String
Discount rate applied to spend above the threshold.
-
#below_threshold_discount_percentage ⇒ String
Discount rate applied to spend at or below the threshold.
-
#cell_coordinates ⇒ String
Semicolon-separated list of matrix cell coordinates targeted by this group.
- #description ⇒ String?
- #threshold_amount ⇒ String
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
4477 |
# File 'sig/orb/models/price.rbs', line 4477
def initialize: (
|
Instance Attribute Details
#above_threshold_discount_percentage ⇒ String
Discount rate applied to spend above the threshold.
5978 |
# File 'lib/orb/models/price.rb', line 5978 required :above_threshold_discount_percentage, String |
#below_threshold_discount_percentage ⇒ String
Discount rate applied to spend at or below the threshold. Set to 0 for no baseline discount.
5985 |
# File 'lib/orb/models/price.rb', line 5985 required :below_threshold_discount_percentage, String |
#cell_coordinates ⇒ String
Semicolon-separated list of matrix cell coordinates targeted by this group. Each
coordinate is first,second when the matrix has two dimensions, or just first
for a single-dimension matrix. Example: blue,circle;green,triangle.
5993 |
# File 'lib/orb/models/price.rb', line 5993 required :cell_coordinates, String |
#description ⇒ String?
6003 |
# File 'lib/orb/models/price.rb', line 6003 optional :description, String, nil?: true |
#threshold_amount ⇒ String
5998 |
# File 'lib/orb/models/price.rb', line 5998 required :threshold_amount, String |
Instance Method Details
#to_hash ⇒ {
4485 |
# File 'sig/orb/models/price.rbs', line 4485
def to_hash: -> {
|