Class: Orb::Models::Price::MeteredAllowance::LicenseType
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Price::MeteredAllowance::LicenseType
- Defined in:
- lib/orb/models/price.rb,
sig/orb/models/price.rbs
Overview
Instance Attribute Summary collapse
-
#grouping_key ⇒ String
The key used for grouping licenses of this type.
-
#id ⇒ String
The Orb-assigned unique identifier for the license type.
-
#name ⇒ String
The name of the license type.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
10209 |
# File 'sig/orb/models/price.rbs', line 10209
def initialize: (
|
Instance Attribute Details
#grouping_key ⇒ String
The key used for grouping licenses of this type. This is typically a user identifier field.
13653 |
# File 'lib/orb/models/price.rb', line 13653 required :grouping_key, String |
#id ⇒ String
The Orb-assigned unique identifier for the license type.
13646 |
# File 'lib/orb/models/price.rb', line 13646 required :id, String |
#name ⇒ String
The name of the license type.
13659 |
# File 'lib/orb/models/price.rb', line 13659 required :name, String |
Instance Method Details
#to_hash ⇒ { id: String, grouping_key: String, name: String }
10215 |
# File 'sig/orb/models/price.rbs', line 10215
def to_hash: -> { id: String, grouping_key: String, name: String }
|