Class: Orb::Models::Price::MinimumComposite::LicenseType
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Price::MinimumComposite::LicenseType
- Defined in:
- lib/orb/models/price.rb,
sig/orb/models/price.rbs
Overview
Instance Attribute Summary collapse
-
#grouping_key ⇒ String
The key used for grouping licenses of this type.
-
#id ⇒ String
The Orb-assigned unique identifier for the license type.
-
#name ⇒ String
The name of the license type.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
10496 |
# File 'sig/orb/models/price.rbs', line 10496 def initialize: ( |
Instance Attribute Details
#grouping_key ⇒ String
The key used for grouping licenses of this type. This is typically a user identifier field.
14041 |
# File 'lib/orb/models/price.rb', line 14041 required :grouping_key, String |
#id ⇒ String
The Orb-assigned unique identifier for the license type.
14034 |
# File 'lib/orb/models/price.rb', line 14034 required :id, String |
#name ⇒ String
The name of the license type.
14047 |
# File 'lib/orb/models/price.rb', line 14047 required :name, String |
Instance Method Details
#to_hash ⇒ { id: String, grouping_key: String, name: String }
10502 |
# File 'sig/orb/models/price.rbs', line 10502 def to_hash: -> { id: String, grouping_key: String, name: String } |