Class: Orb::Models::Price::MinimumComposite::MinimumCompositeConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Price::MinimumComposite::MinimumCompositeConfig
- Defined in:
- lib/orb/models/price.rb,
sig/orb/models/price.rbs
Overview
Instance Attribute Summary collapse
-
#minimum_amount ⇒ String
The minimum amount to apply.
-
#prorated ⇒ Boolean?
If true, subtotals from this price are prorated based on the service period.
Instance Method Summary collapse
-
#initialize ⇒ MinimumCompositeConfig
constructor
A new instance of MinimumCompositeConfig.
- #to_hash ⇒ { minimum_amount: String, prorated: bool }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ MinimumCompositeConfig
Returns a new instance of MinimumCompositeConfig.
9811 |
# File 'sig/orb/models/price.rbs', line 9811
def initialize: (minimum_amount: String, ?prorated: bool) -> void
|
Instance Attribute Details
#minimum_amount ⇒ String
The minimum amount to apply
13119 |
# File 'lib/orb/models/price.rb', line 13119 required :minimum_amount, String |
#prorated ⇒ Boolean?
If true, subtotals from this price are prorated based on the service period
13125 |
# File 'lib/orb/models/price.rb', line 13125 optional :prorated, Orb::Internal::Type::Boolean |
Instance Method Details
#to_hash ⇒ { minimum_amount: String, prorated: bool }
9813 |
# File 'sig/orb/models/price.rbs', line 9813
def to_hash: -> { minimum_amount: String, prorated: bool }
|