Class: Orb::Models::Price::Percent
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, PercentConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(percent:, maximum_amount: nil, minimum_amount: nil, prorated: nil) ⇒ Object
Some parameter documentations has been truncated, see
PercentConfig for more details.
Configuration for percent pricing
|
# File 'lib/orb/models/price.rb', line 14236
|
Instance Attribute Details
14074
|
# File 'lib/orb/models/price.rb', line 14074
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
14079
|
# File 'lib/orb/models/price.rb', line 14079
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
14084
|
# File 'lib/orb/models/price.rb', line 14084
required :billing_mode, enum: -> { Orb::Price::Percent::BillingMode }
|
14089
|
# File 'lib/orb/models/price.rb', line 14089
required :cadence, enum: -> { Orb::Price::Percent::Cadence }
|
14094
14095
14096
|
# File 'lib/orb/models/price.rb', line 14094
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::Percent::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
14101
|
# File 'lib/orb/models/price.rb', line 14101
required :conversion_rate, Float, nil?: true
|
14106
|
# File 'lib/orb/models/price.rb', line 14106
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
14111
|
# File 'lib/orb/models/price.rb', line 14111
required :created_at, Time
|
14116
|
# File 'lib/orb/models/price.rb', line 14116
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
14121
|
# File 'lib/orb/models/price.rb', line 14121
required :currency, String
|
14226
|
# File 'lib/orb/models/price.rb', line 14226
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
14127
|
# File 'lib/orb/models/price.rb', line 14127
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
14132
|
# File 'lib/orb/models/price.rb', line 14132
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
14137
|
# File 'lib/orb/models/price.rb', line 14137
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
14069
|
# File 'lib/orb/models/price.rb', line 14069
required :id, String
|
#invoice_grouping_key ⇒ String?
14142
|
# File 'lib/orb/models/price.rb', line 14142
required :invoice_grouping_key, String, nil?: true
|
14147
|
# File 'lib/orb/models/price.rb', line 14147
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
14154
|
# File 'lib/orb/models/price.rb', line 14154
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
14234
|
# File 'lib/orb/models/price.rb', line 14234
optional :license_type, -> { Orb::Price::Percent::LicenseType }, nil?: true
|
14160
|
# File 'lib/orb/models/price.rb', line 14160
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
14166
|
# File 'lib/orb/models/price.rb', line 14166
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
14175
|
# File 'lib/orb/models/price.rb', line 14175
required :metadata, Orb::Internal::Type::HashOf[String]
|
14181
|
# File 'lib/orb/models/price.rb', line 14181
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
14187
|
# File 'lib/orb/models/price.rb', line 14187
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :percent
14193
|
# File 'lib/orb/models/price.rb', line 14193
required :model_type, const: :percent
|
#name ⇒ String
14198
|
# File 'lib/orb/models/price.rb', line 14198
required :name, String
|
Configuration for percent pricing
14204
|
# File 'lib/orb/models/price.rb', line 14204
required :percent_config, -> { Orb::Price::Percent::PercentConfig }
|
#plan_phase_order ⇒ Integer?
14209
|
# File 'lib/orb/models/price.rb', line 14209
required :plan_phase_order, Integer, nil?: true
|
14214
|
# File 'lib/orb/models/price.rb', line 14214
required :price_type, enum: -> { Orb::Price::Percent::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
14221
|
# File 'lib/orb/models/price.rb', line 14221
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 14307
|
Instance Method Details
#to_hash ⇒ {
10634
|
# File 'sig/orb/models/price.rbs', line 10634
def to_hash: -> {
|