Class: Orb::Models::Price::ScalableMatrixWithTieredPricing
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, ScalableMatrixWithTieredPricingConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(tier_lower_bound:, unit_amount:) ⇒ Object
Configuration for a single tier entry with business logic
|
# File 'lib/orb/models/price.rb', line 11698
|
Instance Attribute Details
11533
|
# File 'lib/orb/models/price.rb', line 11533
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
11538
|
# File 'lib/orb/models/price.rb', line 11538
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
11543
|
# File 'lib/orb/models/price.rb', line 11543
required :billing_mode, enum: -> { Orb::Price::ScalableMatrixWithTieredPricing::BillingMode }
|
11548
|
# File 'lib/orb/models/price.rb', line 11548
required :cadence, enum: -> { Orb::Price::ScalableMatrixWithTieredPricing::Cadence }
|
11553
11554
11555
11556
11557
|
# File 'lib/orb/models/price.rb', line 11553
required :composite_price_filters,
-> {
Orb::Internal::Type::ArrayOf[Orb::Price::ScalableMatrixWithTieredPricing::CompositePriceFilter]
},
nil?: true
|
#conversion_rate ⇒ Float?
11562
|
# File 'lib/orb/models/price.rb', line 11562
required :conversion_rate, Float, nil?: true
|
11567
|
# File 'lib/orb/models/price.rb', line 11567
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
11572
|
# File 'lib/orb/models/price.rb', line 11572
required :created_at, Time
|
11577
|
# File 'lib/orb/models/price.rb', line 11577
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
11582
|
# File 'lib/orb/models/price.rb', line 11582
required :currency, String
|
11688
|
# File 'lib/orb/models/price.rb', line 11688
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
11588
|
# File 'lib/orb/models/price.rb', line 11588
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
11593
|
# File 'lib/orb/models/price.rb', line 11593
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
11598
|
# File 'lib/orb/models/price.rb', line 11598
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
11528
|
# File 'lib/orb/models/price.rb', line 11528
required :id, String
|
#invoice_grouping_key ⇒ String?
11603
|
# File 'lib/orb/models/price.rb', line 11603
required :invoice_grouping_key, String, nil?: true
|
11608
|
# File 'lib/orb/models/price.rb', line 11608
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
11615
|
# File 'lib/orb/models/price.rb', line 11615
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
11696
|
# File 'lib/orb/models/price.rb', line 11696
optional :license_type, -> { Orb::Price::ScalableMatrixWithTieredPricing::LicenseType }, nil?: true
|
11621
|
# File 'lib/orb/models/price.rb', line 11621
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
11627
|
# File 'lib/orb/models/price.rb', line 11627
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
11636
|
# File 'lib/orb/models/price.rb', line 11636
required :metadata, Orb::Internal::Type::HashOf[String]
|
11642
|
# File 'lib/orb/models/price.rb', line 11642
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
11648
|
# File 'lib/orb/models/price.rb', line 11648
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :scalable_matrix_with_tiered_pricing
11654
|
# File 'lib/orb/models/price.rb', line 11654
required :model_type, const: :scalable_matrix_with_tiered_pricing
|
#name ⇒ String
11659
|
# File 'lib/orb/models/price.rb', line 11659
required :name, String
|
#plan_phase_order ⇒ Integer?
11664
|
# File 'lib/orb/models/price.rb', line 11664
required :plan_phase_order, Integer, nil?: true
|
11669
|
# File 'lib/orb/models/price.rb', line 11669
required :price_type, enum: -> { Orb::Price::ScalableMatrixWithTieredPricing::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
11676
|
# File 'lib/orb/models/price.rb', line 11676
required :replaces_price_id, String, nil?: true
|
Configuration for scalable_matrix_with_tiered_pricing pricing
11682
11683
|
# File 'lib/orb/models/price.rb', line 11682
required :scalable_matrix_with_tiered_pricing_config,
-> { Orb::Price::ScalableMatrixWithTieredPricing::ScalableMatrixWithTieredPricingConfig }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 11769
|
Instance Method Details
#to_hash ⇒ {
8730
|
# File 'sig/orb/models/price.rbs', line 8730
def to_hash: -> {
|