Class: Orb::Models::Price::ScalableMatrixWithUnitPricing::ScalableMatrixWithUnitPricingConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/price.rb,
sig/orb/models/price.rbs

Overview

See Also:

  • Orb::Models::Price::ScalableMatrixWithUnitPricing#scalable_matrix_with_unit_pricing_config

Defined Under Namespace

Classes: MatrixScalingFactor

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



8537
# File 'sig/orb/models/price.rbs', line 8537

def initialize: (

Instance Attribute Details

#first_dimension ⇒ String

Used to determine the unit rate

Parameters:

  • value (String)

Returns:

  • (String)


11413
# File 'lib/orb/models/price.rb', line 11413

required :first_dimension, String

#grouping_key ⇒ String?

The property used to group this price

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


11432
# File 'lib/orb/models/price.rb', line 11432

optional :grouping_key, String, nil?: true

#matrix_scaling_factors ⇒ Array<Orb::Models::Price::ScalableMatrixWithUnitPricing::ScalableMatrixWithUnitPricingConfig::MatrixScalingFactor>

Apply a scaling factor to each dimension

Parameters:

  • value (::Array[Orb::Price::ScalableMatrixWithUnitPricing::ScalableMatrixWithUnitPricingConfig::MatrixScalingFactor])

Returns:



11419
11420
# File 'lib/orb/models/price.rb', line 11419

required :matrix_scaling_factors,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::ScalableMatrixWithUnitPricing::ScalableMatrixWithUnitPricingConfig::MatrixScalingFactor] }

#prorate ⇒ Boolean?

If true, the unit price will be prorated to the billing period

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


11438
# File 'lib/orb/models/price.rb', line 11438

optional :prorate, Orb::Internal::Type::Boolean, nil?: true

#second_dimension ⇒ String?

Used to determine the unit rate (optional)

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


11444
# File 'lib/orb/models/price.rb', line 11444

optional :second_dimension, String, nil?: true

#unit_price ⇒ String

The final unit price to rate against the output of the matrix

Parameters:

  • value (String)

Returns:

  • (String)


11426
# File 'lib/orb/models/price.rb', line 11426

required :unit_price, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


8546
# File 'sig/orb/models/price.rbs', line 8546

def to_hash: -> {