Class: Orb::Models::Price::ThresholdTotalAmount
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, ThresholdTotalAmountConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(threshold:, total_amount:) ⇒ Object
Configuration for a single threshold
|
# File 'lib/orb/models/price.rb', line 2526
|
Instance Attribute Details
2363
|
# File 'lib/orb/models/price.rb', line 2363
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
2368
|
# File 'lib/orb/models/price.rb', line 2368
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
2373
|
# File 'lib/orb/models/price.rb', line 2373
required :billing_mode, enum: -> { Orb::Price::ThresholdTotalAmount::BillingMode }
|
2378
|
# File 'lib/orb/models/price.rb', line 2378
required :cadence, enum: -> { Orb::Price::ThresholdTotalAmount::Cadence }
|
2383
2384
2385
|
# File 'lib/orb/models/price.rb', line 2383
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::ThresholdTotalAmount::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
2390
|
# File 'lib/orb/models/price.rb', line 2390
required :conversion_rate, Float, nil?: true
|
2395
|
# File 'lib/orb/models/price.rb', line 2395
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
2400
|
# File 'lib/orb/models/price.rb', line 2400
required :created_at, Time
|
2405
|
# File 'lib/orb/models/price.rb', line 2405
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
2410
|
# File 'lib/orb/models/price.rb', line 2410
required :currency, String
|
2516
|
# File 'lib/orb/models/price.rb', line 2516
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
2416
|
# File 'lib/orb/models/price.rb', line 2416
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
2421
|
# File 'lib/orb/models/price.rb', line 2421
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
2426
|
# File 'lib/orb/models/price.rb', line 2426
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
2358
|
# File 'lib/orb/models/price.rb', line 2358
required :id, String
|
#invoice_grouping_key ⇒ String?
2431
|
# File 'lib/orb/models/price.rb', line 2431
required :invoice_grouping_key, String, nil?: true
|
2436
|
# File 'lib/orb/models/price.rb', line 2436
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
2443
|
# File 'lib/orb/models/price.rb', line 2443
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
2524
|
# File 'lib/orb/models/price.rb', line 2524
optional :license_type, -> { Orb::Price::ThresholdTotalAmount::LicenseType }, nil?: true
|
2449
|
# File 'lib/orb/models/price.rb', line 2449
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
2455
|
# File 'lib/orb/models/price.rb', line 2455
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
2464
|
# File 'lib/orb/models/price.rb', line 2464
required :metadata, Orb::Internal::Type::HashOf[String]
|
2470
|
# File 'lib/orb/models/price.rb', line 2470
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
2476
|
# File 'lib/orb/models/price.rb', line 2476
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :threshold_total_amount
2482
|
# File 'lib/orb/models/price.rb', line 2482
required :model_type, const: :threshold_total_amount
|
#name ⇒ String
2487
|
# File 'lib/orb/models/price.rb', line 2487
required :name, String
|
#plan_phase_order ⇒ Integer?
2492
|
# File 'lib/orb/models/price.rb', line 2492
required :plan_phase_order, Integer, nil?: true
|
2497
|
# File 'lib/orb/models/price.rb', line 2497
required :price_type, enum: -> { Orb::Price::ThresholdTotalAmount::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
2504
|
# File 'lib/orb/models/price.rb', line 2504
required :replaces_price_id, String, nil?: true
|
Configuration for threshold_total_amount pricing
2510
2511
|
# File 'lib/orb/models/price.rb', line 2510
required :threshold_total_amount_config,
-> { Orb::Price::ThresholdTotalAmount::ThresholdTotalAmountConfig }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 2597
|
Instance Method Details
#to_hash ⇒ {
1856
|
# File 'sig/orb/models/price.rbs', line 1856
def to_hash: -> {
|