Class: Orb::Models::Price::ThresholdTotalAmount::ThresholdTotalAmountConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Price::ThresholdTotalAmount::ThresholdTotalAmountConfig
- Defined in:
- lib/orb/models/price.rb,
sig/orb/models/price.rbs
Overview
Defined Under Namespace
Classes: ConsumptionTable
Instance Attribute Summary collapse
-
#consumption_table ⇒ Array<Orb::Models::Price::ThresholdTotalAmount::ThresholdTotalAmountConfig::ConsumptionTable>
When the quantity consumed passes a provided threshold, the configured total will be charged.
-
#prorate ⇒ Boolean?
If true, the unit price will be prorated to the billing period.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
1990 |
# File 'sig/orb/models/price.rbs', line 1990
def initialize: (
|
Instance Attribute Details
#consumption_table ⇒ Array<Orb::Models::Price::ThresholdTotalAmount::ThresholdTotalAmountConfig::ConsumptionTable>
When the quantity consumed passes a provided threshold, the configured total will be charged
2687 2688 |
# File 'lib/orb/models/price.rb', line 2687 required :consumption_table, -> { Orb::Internal::Type::ArrayOf[Orb::Price::ThresholdTotalAmount::ThresholdTotalAmountConfig::ConsumptionTable] } |
#prorate ⇒ Boolean?
If true, the unit price will be prorated to the billing period
2694 |
# File 'lib/orb/models/price.rb', line 2694 optional :prorate, Orb::Internal::Type::Boolean, nil?: true |
Instance Method Details
#to_hash ⇒ {
1995 |
# File 'sig/orb/models/price.rbs', line 1995
def to_hash: -> {
|