Class: Orb::Models::Price::TieredMatrixWithAllocation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/price.rb,
sig/orb/models/price.rbs

Defined Under Namespace

Modules: BillingMode, Cadence, PriceType Classes: CompositePriceFilter, LicenseType, TieredMatrixWithAllocationConfig

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(dimension_values:, tier_lower_bound:, unit_amount:) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier for more details.

Configuration for a single tier scoped to one matrix cell

Parameters:

  • dimension_values (Array<String>) —

    The matrix cell this tier applies to, as one or two dimension values

  • tier_lower_bound (String) —

    Exclusive tier starting value. The tier runs up to and including the next bound

  • unit_amount (String) —

    Per unit amount



# File 'lib/orb/models/price.rb', line 6193

Instance Attribute Details

#billable_metric ⇒ Orb::Models::BillableMetricTiny?

Parameters:

Returns:



6028
# File 'lib/orb/models/price.rb', line 6028

required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true

#billing_cycle_configuration ⇒ Orb::Models::BillingCycleConfiguration



6033
# File 'lib/orb/models/price.rb', line 6033

required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }

#billing_mode ⇒ Symbol, Orb::Models::Price::TieredMatrixWithAllocation::BillingMode

Parameters:

  • value (Orb::Models::Price::TieredMatrixWithAllocation::billing_mode)

Returns:



6038
# File 'lib/orb/models/price.rb', line 6038

required :billing_mode, enum: -> { Orb::Price::TieredMatrixWithAllocation::BillingMode }

#cadence ⇒ Symbol, Orb::Models::Price::TieredMatrixWithAllocation::Cadence

Parameters:

  • value (Orb::Models::Price::TieredMatrixWithAllocation::cadence)

Returns:



6043
# File 'lib/orb/models/price.rb', line 6043

required :cadence, enum: -> { Orb::Price::TieredMatrixWithAllocation::Cadence }

#composite_price_filters ⇒ Array<Orb::Models::Price::TieredMatrixWithAllocation::CompositePriceFilter>?

Parameters:

  • value (::Array[Orb::Price::TieredMatrixWithAllocation::CompositePriceFilter], nil)

Returns:



6048
6049
6050
6051
6052
# File 'lib/orb/models/price.rb', line 6048

required :composite_price_filters,
-> {
  Orb::Internal::Type::ArrayOf[Orb::Price::TieredMatrixWithAllocation::CompositePriceFilter]
},
nil?: true

#conversion_rate ⇒ Float?

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


6057
# File 'lib/orb/models/price.rb', line 6057

required :conversion_rate, Float, nil?: true

#conversion_rate_config ⇒ Orb::Models::UnitConversionRateConfig, ...

Parameters:

  • value (Orb::Models::conversion_rate_config, nil)

Returns:



6062
# File 'lib/orb/models/price.rb', line 6062

required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true

#created_at ⇒ Time

Parameters:

  • value (Time)

Returns:

  • (Time)


6067
# File 'lib/orb/models/price.rb', line 6067

required :created_at, Time

#credit_allocation ⇒ Orb::Models::Allocation?

Parameters:

Returns:



6072
# File 'lib/orb/models/price.rb', line 6072

required :credit_allocation, -> { Orb::Allocation }, nil?: true

#currency ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


6077
# File 'lib/orb/models/price.rb', line 6077

required :currency, String

#dimensional_price_configuration ⇒ Orb::Models::DimensionalPriceConfiguration?



6183
# File 'lib/orb/models/price.rb', line 6183

optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true

#discount ⇒ Orb::Models::PercentageDiscount, ...

Deprecated.


6083
# File 'lib/orb/models/price.rb', line 6083

required :discount, union: -> { Orb::Discount }, nil?: true

#external_price_id ⇒ String?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


6088
# File 'lib/orb/models/price.rb', line 6088

required :external_price_id, String, nil?: true

#fixed_price_quantity ⇒ Float?

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


6093
# File 'lib/orb/models/price.rb', line 6093

required :fixed_price_quantity, Float, nil?: true

#id ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


6023
# File 'lib/orb/models/price.rb', line 6023

required :id, String

#invoice_grouping_key ⇒ String?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


6098
# File 'lib/orb/models/price.rb', line 6098

required :invoice_grouping_key, String, nil?: true

#invoicing_cycle_configuration ⇒ Orb::Models::BillingCycleConfiguration?



6103
# File 'lib/orb/models/price.rb', line 6103

required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true

#item ⇒ Orb::Models::ItemSlim

A minimal representation of an Item containing only the essential identifying information.

Parameters:

Returns:



6110
# File 'lib/orb/models/price.rb', line 6110

required :item, -> { Orb::ItemSlim }

#license_type ⇒ Orb::Models::Price::TieredMatrixWithAllocation::LicenseType?

The LicenseType resource represents a type of license that can be assigned to users. License types are used during billing by grouping metrics on the configured grouping key.

Parameters:

  • value (Orb::Price::TieredMatrixWithAllocation::LicenseType, nil)

Returns:



6191
# File 'lib/orb/models/price.rb', line 6191

optional :license_type, -> { Orb::Price::TieredMatrixWithAllocation::LicenseType }, nil?: true

#maximum ⇒ Orb::Models::Maximum?

Deprecated.

Parameters:

Returns:



6116
# File 'lib/orb/models/price.rb', line 6116

required :maximum, -> { Orb::Maximum }, nil?: true

#maximum_amount ⇒ String?

Deprecated.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


6122
# File 'lib/orb/models/price.rb', line 6122

required :maximum_amount, String, nil?: true

#metadata ⇒ Hash{Symbol=>String}

User specified key-value pairs for the resource. If not present, this defaults to an empty dictionary. Individual keys can be removed by setting the value to null, and the entire metadata mapping can be cleared by setting metadata to null.

Parameters:

  • value (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String})


6131
# File 'lib/orb/models/price.rb', line 6131

required :metadata, Orb::Internal::Type::HashOf[String]

#minimum ⇒ Orb::Models::Minimum?

Deprecated.

Parameters:

Returns:



6137
# File 'lib/orb/models/price.rb', line 6137

required :minimum, -> { Orb::Minimum }, nil?: true

#minimum_amount ⇒ String?

Deprecated.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


6143
# File 'lib/orb/models/price.rb', line 6143

required :minimum_amount, String, nil?: true

#model_type ⇒ Symbol, :tiered_matrix_with_allocation

The pricing model type

Parameters:

  • value (:tiered_matrix_with_allocation)

Returns:

  • (Symbol, :tiered_matrix_with_allocation)


6149
# File 'lib/orb/models/price.rb', line 6149

required :model_type, const: :tiered_matrix_with_allocation

#name ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


6154
# File 'lib/orb/models/price.rb', line 6154

required :name, String

#plan_phase_order ⇒ Integer?

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


6159
# File 'lib/orb/models/price.rb', line 6159

required :plan_phase_order, Integer, nil?: true

#price_type ⇒ Symbol, Orb::Models::Price::TieredMatrixWithAllocation::PriceType

Parameters:

  • value (Orb::Models::Price::TieredMatrixWithAllocation::price_type)

Returns:



6164
# File 'lib/orb/models/price.rb', line 6164

required :price_type, enum: -> { Orb::Price::TieredMatrixWithAllocation::PriceType }

#replaces_price_id ⇒ String?

The price id this price replaces. This price will take the place of the replaced price in plan version migrations.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


6171
# File 'lib/orb/models/price.rb', line 6171

required :replaces_price_id, String, nil?: true

#tiered_matrix_with_allocation_config ⇒ Orb::Models::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig

Configuration for tiered_matrix_with_allocation pricing

Parameters:

  • value (Orb::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig)

Returns:



6177
6178
# File 'lib/orb/models/price.rb', line 6177

required :tiered_matrix_with_allocation_config,
-> { Orb::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig }

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/orb/models/price.rb', line 6264

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


4605
# File 'sig/orb/models/price.rbs', line 4605

def to_hash: -> {