Class: Orb::Models::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/price.rb,
sig/orb/models/price.rbs

Overview

See Also:

  • Orb::Models::Price::TieredMatrixWithAllocation#tiered_matrix_with_allocation_config

Defined Under Namespace

Classes: Tier

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



4747
# File 'sig/orb/models/price.rbs', line 4747

def initialize: (

Instance Attribute Details

#allocation ⇒ String

Usage allocation, pooled across all matrix cells

Parameters:

  • value (String)

Returns:

  • (String)


6357
# File 'lib/orb/models/price.rb', line 6357

required :allocation, String

#default_unit_amount ⇒ String

Per unit rate for usage whose matrix cell has no configured tiers

Parameters:

  • value (String)

Returns:

  • (String)


6363
# File 'lib/orb/models/price.rb', line 6363

required :default_unit_amount, String

#dimensions ⇒ Array<String>

One or two event property values to evaluate matrix cells by

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


6369
# File 'lib/orb/models/price.rb', line 6369

required :dimensions, Orb::Internal::Type::ArrayOf[String]

#tiers ⇒ Array<Orb::Models::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier>

Graduated tiers keyed by matrix cell; usage in a cell is tiered only against its own rows

Parameters:

  • value (::Array[Orb::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier])

Returns:



6376
6377
# File 'lib/orb/models/price.rb', line 6376

required :tiers,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier] }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


4754
# File 'sig/orb/models/price.rbs', line 4754

def to_hash: -> {