Class: Orb::Models::Price::TieredPackage
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, TieredPackageConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(per_unit:, tier_lower_bound:) ⇒ Object
Configuration for a single tier with business logic
|
# File 'lib/orb/models/price.rb', line 2940
|
Instance Attribute Details
2778
|
# File 'lib/orb/models/price.rb', line 2778
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
2783
|
# File 'lib/orb/models/price.rb', line 2783
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
2788
|
# File 'lib/orb/models/price.rb', line 2788
required :billing_mode, enum: -> { Orb::Price::TieredPackage::BillingMode }
|
2793
|
# File 'lib/orb/models/price.rb', line 2793
required :cadence, enum: -> { Orb::Price::TieredPackage::Cadence }
|
2798
2799
2800
|
# File 'lib/orb/models/price.rb', line 2798
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::TieredPackage::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
2805
|
# File 'lib/orb/models/price.rb', line 2805
required :conversion_rate, Float, nil?: true
|
2810
|
# File 'lib/orb/models/price.rb', line 2810
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
2815
|
# File 'lib/orb/models/price.rb', line 2815
required :created_at, Time
|
2820
|
# File 'lib/orb/models/price.rb', line 2820
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
2825
|
# File 'lib/orb/models/price.rb', line 2825
required :currency, String
|
2930
|
# File 'lib/orb/models/price.rb', line 2930
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
2831
|
# File 'lib/orb/models/price.rb', line 2831
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
2836
|
# File 'lib/orb/models/price.rb', line 2836
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
2841
|
# File 'lib/orb/models/price.rb', line 2841
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
2773
|
# File 'lib/orb/models/price.rb', line 2773
required :id, String
|
#invoice_grouping_key ⇒ String?
2846
|
# File 'lib/orb/models/price.rb', line 2846
required :invoice_grouping_key, String, nil?: true
|
2851
|
# File 'lib/orb/models/price.rb', line 2851
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
2858
|
# File 'lib/orb/models/price.rb', line 2858
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
2938
|
# File 'lib/orb/models/price.rb', line 2938
optional :license_type, -> { Orb::Price::TieredPackage::LicenseType }, nil?: true
|
2864
|
# File 'lib/orb/models/price.rb', line 2864
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
2870
|
# File 'lib/orb/models/price.rb', line 2870
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
2879
|
# File 'lib/orb/models/price.rb', line 2879
required :metadata, Orb::Internal::Type::HashOf[String]
|
2885
|
# File 'lib/orb/models/price.rb', line 2885
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
2891
|
# File 'lib/orb/models/price.rb', line 2891
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :tiered_package
2897
|
# File 'lib/orb/models/price.rb', line 2897
required :model_type, const: :tiered_package
|
#name ⇒ String
2902
|
# File 'lib/orb/models/price.rb', line 2902
required :name, String
|
#plan_phase_order ⇒ Integer?
2907
|
# File 'lib/orb/models/price.rb', line 2907
required :plan_phase_order, Integer, nil?: true
|
2912
|
# File 'lib/orb/models/price.rb', line 2912
required :price_type, enum: -> { Orb::Price::TieredPackage::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
2919
|
# File 'lib/orb/models/price.rb', line 2919
required :replaces_price_id, String, nil?: true
|
Configuration for tiered_package pricing
2925
|
# File 'lib/orb/models/price.rb', line 2925
required :tiered_package_config, -> { Orb::Price::TieredPackage::TieredPackageConfig }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 3011
|
Instance Method Details
#to_hash ⇒ {
2162
|
# File 'sig/orb/models/price.rbs', line 2162
def to_hash: -> {
|