Class: Orb::Models::Price::TieredPackage::TieredPackageConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Price::TieredPackage::TieredPackageConfig
- Defined in:
- lib/orb/models/price.rb,
sig/orb/models/price.rbs
Overview
Defined Under Namespace
Classes: Tier
Instance Attribute Summary collapse
- #package_size ⇒ String
-
#tiers ⇒ Array<Orb::Models::Price::TieredPackage::TieredPackageConfig::Tier>
Apply tiered pricing after rounding up the quantity to the package size.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
2297 |
# File 'sig/orb/models/price.rbs', line 2297
def initialize: (
|
Instance Attribute Details
#package_size ⇒ String
3101 |
# File 'lib/orb/models/price.rb', line 3101 required :package_size, String |
#tiers ⇒ Array<Orb::Models::Price::TieredPackage::TieredPackageConfig::Tier>
Apply tiered pricing after rounding up the quantity to the package size. Tiers are defined using exclusive lower bounds. The tier bounds are defined based on the total quantity rather than the number of packages, so they must be multiples of the package size.
3110 |
# File 'lib/orb/models/price.rb', line 3110 required :tiers, -> { Orb::Internal::Type::ArrayOf[Orb::Price::TieredPackage::TieredPackageConfig::Tier] } |
Instance Method Details
#to_hash ⇒ {
2302 |
# File 'sig/orb/models/price.rbs', line 2302
def to_hash: -> {
|