Class: Orb::Models::Price::TieredPackageWithMinimum::TieredPackageWithMinimumConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Price::TieredPackageWithMinimum::TieredPackageWithMinimumConfig
- Defined in:
- lib/orb/models/price.rb,
sig/orb/models/price.rbs
Overview
Defined Under Namespace
Classes: Tier
Instance Attribute Summary collapse
- #package_size ⇒ Float
-
#tiers ⇒ Array<Orb::Models::Price::TieredPackageWithMinimum::TieredPackageWithMinimumConfig::Tier>
Apply tiered pricing after rounding up the quantity to the package size.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
3241 |
# File 'sig/orb/models/price.rbs', line 3241
def initialize: (
|
Instance Attribute Details
#package_size ⇒ Float
4356 |
# File 'lib/orb/models/price.rb', line 4356 required :package_size, Float |
#tiers ⇒ Array<Orb::Models::Price::TieredPackageWithMinimum::TieredPackageWithMinimumConfig::Tier>
Apply tiered pricing after rounding up the quantity to the package size. Tiers are defined using exclusive lower bounds.
4363 4364 |
# File 'lib/orb/models/price.rb', line 4363 required :tiers, -> { Orb::Internal::Type::ArrayOf[Orb::Price::TieredPackageWithMinimum::TieredPackageWithMinimumConfig::Tier] } |
Instance Method Details
#to_hash ⇒ {
3246 |
# File 'sig/orb/models/price.rbs', line 3246
def to_hash: -> {
|