Class: Orb::Models::Price::TieredWithMinimum
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, TieredWithMinimumConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(minimum_amount:, tier_lower_bound:, unit_amount:) ⇒ Object
Configuration for a single tier
|
# File 'lib/orb/models/price.rb', line 3353
|
Instance Attribute Details
3191
|
# File 'lib/orb/models/price.rb', line 3191
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
3196
|
# File 'lib/orb/models/price.rb', line 3196
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
3201
|
# File 'lib/orb/models/price.rb', line 3201
required :billing_mode, enum: -> { Orb::Price::TieredWithMinimum::BillingMode }
|
3206
|
# File 'lib/orb/models/price.rb', line 3206
required :cadence, enum: -> { Orb::Price::TieredWithMinimum::Cadence }
|
3211
3212
3213
|
# File 'lib/orb/models/price.rb', line 3211
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::TieredWithMinimum::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
3218
|
# File 'lib/orb/models/price.rb', line 3218
required :conversion_rate, Float, nil?: true
|
3223
|
# File 'lib/orb/models/price.rb', line 3223
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
3228
|
# File 'lib/orb/models/price.rb', line 3228
required :created_at, Time
|
3233
|
# File 'lib/orb/models/price.rb', line 3233
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
3238
|
# File 'lib/orb/models/price.rb', line 3238
required :currency, String
|
3343
|
# File 'lib/orb/models/price.rb', line 3343
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
3244
|
# File 'lib/orb/models/price.rb', line 3244
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
3249
|
# File 'lib/orb/models/price.rb', line 3249
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
3254
|
# File 'lib/orb/models/price.rb', line 3254
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
3186
|
# File 'lib/orb/models/price.rb', line 3186
required :id, String
|
#invoice_grouping_key ⇒ String?
3259
|
# File 'lib/orb/models/price.rb', line 3259
required :invoice_grouping_key, String, nil?: true
|
3264
|
# File 'lib/orb/models/price.rb', line 3264
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
3271
|
# File 'lib/orb/models/price.rb', line 3271
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
3351
|
# File 'lib/orb/models/price.rb', line 3351
optional :license_type, -> { Orb::Price::TieredWithMinimum::LicenseType }, nil?: true
|
3277
|
# File 'lib/orb/models/price.rb', line 3277
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
3283
|
# File 'lib/orb/models/price.rb', line 3283
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
3292
|
# File 'lib/orb/models/price.rb', line 3292
required :metadata, Orb::Internal::Type::HashOf[String]
|
3298
|
# File 'lib/orb/models/price.rb', line 3298
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
3304
|
# File 'lib/orb/models/price.rb', line 3304
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :tiered_with_minimum
3310
|
# File 'lib/orb/models/price.rb', line 3310
required :model_type, const: :tiered_with_minimum
|
#name ⇒ String
3315
|
# File 'lib/orb/models/price.rb', line 3315
required :name, String
|
#plan_phase_order ⇒ Integer?
3320
|
# File 'lib/orb/models/price.rb', line 3320
required :plan_phase_order, Integer, nil?: true
|
3325
|
# File 'lib/orb/models/price.rb', line 3325
required :price_type, enum: -> { Orb::Price::TieredWithMinimum::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
3332
|
# File 'lib/orb/models/price.rb', line 3332
required :replaces_price_id, String, nil?: true
|
Configuration for tiered_with_minimum pricing
3338
|
# File 'lib/orb/models/price.rb', line 3338
required :tiered_with_minimum_config, -> { Orb::Price::TieredWithMinimum::TieredWithMinimumConfig }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 3424
|
Instance Method Details
#to_hash ⇒ {
2468
|
# File 'sig/orb/models/price.rbs', line 2468
def to_hash: -> {
|