Class: Orb::Models::Price::TieredWithMinimum::TieredWithMinimumConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Price::TieredWithMinimum::TieredWithMinimumConfig
- Defined in:
- lib/orb/models/price.rb,
sig/orb/models/price.rbs
Overview
Defined Under Namespace
Classes: Tier
Instance Attribute Summary collapse
-
#hide_zero_amount_tiers ⇒ Boolean?
If true, tiers with an accrued amount of 0 will not be included in the rating.
-
#prorate ⇒ Boolean?
If true, the unit price will be prorated to the billing period.
-
#tiers ⇒ Array<Orb::Models::Price::TieredWithMinimum::TieredWithMinimumConfig::Tier>
Tiered pricing with a minimum amount dependent on the volume tier.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
2609 |
# File 'sig/orb/models/price.rbs', line 2609
def initialize: (
|
Instance Attribute Details
#hide_zero_amount_tiers ⇒ Boolean?
If true, tiers with an accrued amount of 0 will not be included in the rating.
3521 |
# File 'lib/orb/models/price.rb', line 3521 optional :hide_zero_amount_tiers, Orb::Internal::Type::Boolean |
#prorate ⇒ Boolean?
If true, the unit price will be prorated to the billing period
3527 |
# File 'lib/orb/models/price.rb', line 3527 optional :prorate, Orb::Internal::Type::Boolean |
#tiers ⇒ Array<Orb::Models::Price::TieredWithMinimum::TieredWithMinimumConfig::Tier>
Tiered pricing with a minimum amount dependent on the volume tier. Tiers are defined using exclusive lower bounds.
3514 3515 |
# File 'lib/orb/models/price.rb', line 3514 required :tiers, -> { Orb::Internal::Type::ArrayOf[Orb::Price::TieredWithMinimum::TieredWithMinimumConfig::Tier] } |
Instance Method Details
#to_hash ⇒ {
2615 |
# File 'sig/orb/models/price.rbs', line 2615
def to_hash: -> {
|