Class: Orb::Models::Price::TieredWithProration
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, TieredWithProrationConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(tier_lower_bound:, unit_amount:) ⇒ Object
Configuration for a single tiered with proration tier
|
# File 'lib/orb/models/price.rb', line 7124
|
Instance Attribute Details
6962
|
# File 'lib/orb/models/price.rb', line 6962
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
6967
|
# File 'lib/orb/models/price.rb', line 6967
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
6972
|
# File 'lib/orb/models/price.rb', line 6972
required :billing_mode, enum: -> { Orb::Price::TieredWithProration::BillingMode }
|
6977
|
# File 'lib/orb/models/price.rb', line 6977
required :cadence, enum: -> { Orb::Price::TieredWithProration::Cadence }
|
6982
6983
6984
|
# File 'lib/orb/models/price.rb', line 6982
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::TieredWithProration::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
6989
|
# File 'lib/orb/models/price.rb', line 6989
required :conversion_rate, Float, nil?: true
|
6994
|
# File 'lib/orb/models/price.rb', line 6994
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
6999
|
# File 'lib/orb/models/price.rb', line 6999
required :created_at, Time
|
7004
|
# File 'lib/orb/models/price.rb', line 7004
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
7009
|
# File 'lib/orb/models/price.rb', line 7009
required :currency, String
|
7114
|
# File 'lib/orb/models/price.rb', line 7114
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
7015
|
# File 'lib/orb/models/price.rb', line 7015
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
7020
|
# File 'lib/orb/models/price.rb', line 7020
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
7025
|
# File 'lib/orb/models/price.rb', line 7025
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
6957
|
# File 'lib/orb/models/price.rb', line 6957
required :id, String
|
#invoice_grouping_key ⇒ String?
7030
|
# File 'lib/orb/models/price.rb', line 7030
required :invoice_grouping_key, String, nil?: true
|
7035
|
# File 'lib/orb/models/price.rb', line 7035
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
7042
|
# File 'lib/orb/models/price.rb', line 7042
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
7122
|
# File 'lib/orb/models/price.rb', line 7122
optional :license_type, -> { Orb::Price::TieredWithProration::LicenseType }, nil?: true
|
7048
|
# File 'lib/orb/models/price.rb', line 7048
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
7054
|
# File 'lib/orb/models/price.rb', line 7054
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
7063
|
# File 'lib/orb/models/price.rb', line 7063
required :metadata, Orb::Internal::Type::HashOf[String]
|
7069
|
# File 'lib/orb/models/price.rb', line 7069
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
7075
|
# File 'lib/orb/models/price.rb', line 7075
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :tiered_with_proration
7081
|
# File 'lib/orb/models/price.rb', line 7081
required :model_type, const: :tiered_with_proration
|
#name ⇒ String
7086
|
# File 'lib/orb/models/price.rb', line 7086
required :name, String
|
#plan_phase_order ⇒ Integer?
7091
|
# File 'lib/orb/models/price.rb', line 7091
required :plan_phase_order, Integer, nil?: true
|
7096
|
# File 'lib/orb/models/price.rb', line 7096
required :price_type, enum: -> { Orb::Price::TieredWithProration::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
7103
|
# File 'lib/orb/models/price.rb', line 7103
required :replaces_price_id, String, nil?: true
|
Configuration for tiered_with_proration pricing
7109
|
# File 'lib/orb/models/price.rb', line 7109
required :tiered_with_proration_config, -> { Orb::Price::TieredWithProration::TieredWithProrationConfig }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 7195
|
Instance Method Details
#to_hash ⇒ {
5313
|
# File 'sig/orb/models/price.rbs', line 5313
def to_hash: -> {
|