Class: Orb::Models::Price::Unit
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
-
#initialize(id:, billable_metric:, billing_cycle_configuration:, billing_mode:, cadence:, composite_price_filters:, conversion_rate:, conversion_rate_config:, created_at:, credit_allocation:, currency:, discount:, external_price_id:, fixed_price_quantity:, invoice_grouping_key:, invoicing_cycle_configuration:, item:, maximum:, maximum_amount:, metadata:, minimum:, minimum_amount:, name:, plan_phase_order:, price_type:, replaces_price_id:, unit_config:, dimensional_price_configuration: nil, license_type: nil, model_type: :unit) ⇒ Object
constructor
Some parameter documentations has been truncated, see Unit for more details.
-
#to_hash ⇒ {
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, billable_metric:, billing_cycle_configuration:, billing_mode:, cadence:, composite_price_filters:, conversion_rate:, conversion_rate_config:, created_at:, credit_allocation:, currency:, discount:, external_price_id:, fixed_price_quantity:, invoice_grouping_key:, invoicing_cycle_configuration:, item:, maximum:, maximum_amount:, metadata:, minimum:, minimum_amount:, name:, plan_phase_order:, price_type:, replaces_price_id:, unit_config:, dimensional_price_configuration: nil, license_type: nil, model_type: :unit) ⇒ Object
|
# File 'lib/orb/models/price.rb', line 263
|
Instance Attribute Details
101
|
# File 'lib/orb/models/price.rb', line 101
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
106
|
# File 'lib/orb/models/price.rb', line 106
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
111
|
# File 'lib/orb/models/price.rb', line 111
required :billing_mode, enum: -> { Orb::Price::Unit::BillingMode }
|
116
|
# File 'lib/orb/models/price.rb', line 116
required :cadence, enum: -> { Orb::Price::Unit::Cadence }
|
121
122
123
|
# File 'lib/orb/models/price.rb', line 121
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::Unit::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
128
|
# File 'lib/orb/models/price.rb', line 128
required :conversion_rate, Float, nil?: true
|
133
|
# File 'lib/orb/models/price.rb', line 133
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
138
|
# File 'lib/orb/models/price.rb', line 138
required :created_at, Time
|
143
|
# File 'lib/orb/models/price.rb', line 143
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
148
|
# File 'lib/orb/models/price.rb', line 148
required :currency, String
|
253
|
# File 'lib/orb/models/price.rb', line 253
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
154
|
# File 'lib/orb/models/price.rb', line 154
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
159
|
# File 'lib/orb/models/price.rb', line 159
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
164
|
# File 'lib/orb/models/price.rb', line 164
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
96
|
# File 'lib/orb/models/price.rb', line 96
required :id, String
|
#invoice_grouping_key ⇒ String?
169
|
# File 'lib/orb/models/price.rb', line 169
required :invoice_grouping_key, String, nil?: true
|
174
|
# File 'lib/orb/models/price.rb', line 174
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
181
|
# File 'lib/orb/models/price.rb', line 181
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
261
|
# File 'lib/orb/models/price.rb', line 261
optional :license_type, -> { Orb::Price::Unit::LicenseType }, nil?: true
|
187
|
# File 'lib/orb/models/price.rb', line 187
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
193
|
# File 'lib/orb/models/price.rb', line 193
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
202
|
# File 'lib/orb/models/price.rb', line 202
required :metadata, Orb::Internal::Type::HashOf[String]
|
208
|
# File 'lib/orb/models/price.rb', line 208
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
214
|
# File 'lib/orb/models/price.rb', line 214
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :unit
220
|
# File 'lib/orb/models/price.rb', line 220
required :model_type, const: :unit
|
#name ⇒ String
225
|
# File 'lib/orb/models/price.rb', line 225
required :name, String
|
#plan_phase_order ⇒ Integer?
230
|
# File 'lib/orb/models/price.rb', line 230
required :plan_phase_order, Integer, nil?: true
|
235
|
# File 'lib/orb/models/price.rb', line 235
required :price_type, enum: -> { Orb::Price::Unit::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
242
|
# File 'lib/orb/models/price.rb', line 242
required :replaces_price_id, String, nil?: true
|
Configuration for unit pricing
248
|
# File 'lib/orb/models/price.rb', line 248
required :unit_config, -> { Orb::UnitConfig }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 334
|
Instance Method Details
#to_hash ⇒ {
172
|
# File 'sig/orb/models/price.rbs', line 172
def to_hash: -> {
|