Class: Orb::Models::Price::UnitWithPercent
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, UnitWithPercentConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(percent:, unit_amount:) ⇒ Object
Configuration for unit_with_percent pricing
|
# File 'lib/orb/models/price.rb', line 5436
|
Instance Attribute Details
5274
|
# File 'lib/orb/models/price.rb', line 5274
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
5279
|
# File 'lib/orb/models/price.rb', line 5279
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
5284
|
# File 'lib/orb/models/price.rb', line 5284
required :billing_mode, enum: -> { Orb::Price::UnitWithPercent::BillingMode }
|
5289
|
# File 'lib/orb/models/price.rb', line 5289
required :cadence, enum: -> { Orb::Price::UnitWithPercent::Cadence }
|
5294
5295
5296
|
# File 'lib/orb/models/price.rb', line 5294
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::UnitWithPercent::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
5301
|
# File 'lib/orb/models/price.rb', line 5301
required :conversion_rate, Float, nil?: true
|
5306
|
# File 'lib/orb/models/price.rb', line 5306
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
5311
|
# File 'lib/orb/models/price.rb', line 5311
required :created_at, Time
|
5316
|
# File 'lib/orb/models/price.rb', line 5316
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
5321
|
# File 'lib/orb/models/price.rb', line 5321
required :currency, String
|
5426
|
# File 'lib/orb/models/price.rb', line 5426
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
5327
|
# File 'lib/orb/models/price.rb', line 5327
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
5332
|
# File 'lib/orb/models/price.rb', line 5332
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
5337
|
# File 'lib/orb/models/price.rb', line 5337
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
5269
|
# File 'lib/orb/models/price.rb', line 5269
required :id, String
|
#invoice_grouping_key ⇒ String?
5342
|
# File 'lib/orb/models/price.rb', line 5342
required :invoice_grouping_key, String, nil?: true
|
5347
|
# File 'lib/orb/models/price.rb', line 5347
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
5354
|
# File 'lib/orb/models/price.rb', line 5354
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
5434
|
# File 'lib/orb/models/price.rb', line 5434
optional :license_type, -> { Orb::Price::UnitWithPercent::LicenseType }, nil?: true
|
5360
|
# File 'lib/orb/models/price.rb', line 5360
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
5366
|
# File 'lib/orb/models/price.rb', line 5366
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
5375
|
# File 'lib/orb/models/price.rb', line 5375
required :metadata, Orb::Internal::Type::HashOf[String]
|
5381
|
# File 'lib/orb/models/price.rb', line 5381
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
5387
|
# File 'lib/orb/models/price.rb', line 5387
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :unit_with_percent
5393
|
# File 'lib/orb/models/price.rb', line 5393
required :model_type, const: :unit_with_percent
|
#name ⇒ String
5398
|
# File 'lib/orb/models/price.rb', line 5398
required :name, String
|
#plan_phase_order ⇒ Integer?
5403
|
# File 'lib/orb/models/price.rb', line 5403
required :plan_phase_order, Integer, nil?: true
|
5408
|
# File 'lib/orb/models/price.rb', line 5408
required :price_type, enum: -> { Orb::Price::UnitWithPercent::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
5415
|
# File 'lib/orb/models/price.rb', line 5415
required :replaces_price_id, String, nil?: true
|
Configuration for unit_with_percent pricing
5421
|
# File 'lib/orb/models/price.rb', line 5421
required :unit_with_percent_config, -> { Orb::Price::UnitWithPercent::UnitWithPercentConfig }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 5507
|
Instance Method Details
#to_hash ⇒ {
4049
|
# File 'sig/orb/models/price.rbs', line 4049
def to_hash: -> {
|