Class: Orb::Models::Price::UnitWithProration
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, UnitWithProrationConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(unit_amount:) ⇒ Object
Configuration for unit_with_proration pricing
|
# File 'lib/orb/models/price.rb', line 7531
|
Instance Attribute Details
7369
|
# File 'lib/orb/models/price.rb', line 7369
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
7374
|
# File 'lib/orb/models/price.rb', line 7374
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
7379
|
# File 'lib/orb/models/price.rb', line 7379
required :billing_mode, enum: -> { Orb::Price::UnitWithProration::BillingMode }
|
7384
|
# File 'lib/orb/models/price.rb', line 7384
required :cadence, enum: -> { Orb::Price::UnitWithProration::Cadence }
|
7389
7390
7391
|
# File 'lib/orb/models/price.rb', line 7389
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::UnitWithProration::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
7396
|
# File 'lib/orb/models/price.rb', line 7396
required :conversion_rate, Float, nil?: true
|
7401
|
# File 'lib/orb/models/price.rb', line 7401
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
7406
|
# File 'lib/orb/models/price.rb', line 7406
required :created_at, Time
|
7411
|
# File 'lib/orb/models/price.rb', line 7411
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
7416
|
# File 'lib/orb/models/price.rb', line 7416
required :currency, String
|
7521
|
# File 'lib/orb/models/price.rb', line 7521
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
7422
|
# File 'lib/orb/models/price.rb', line 7422
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
7427
|
# File 'lib/orb/models/price.rb', line 7427
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
7432
|
# File 'lib/orb/models/price.rb', line 7432
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
7364
|
# File 'lib/orb/models/price.rb', line 7364
required :id, String
|
#invoice_grouping_key ⇒ String?
7437
|
# File 'lib/orb/models/price.rb', line 7437
required :invoice_grouping_key, String, nil?: true
|
7442
|
# File 'lib/orb/models/price.rb', line 7442
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
7449
|
# File 'lib/orb/models/price.rb', line 7449
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
7529
|
# File 'lib/orb/models/price.rb', line 7529
optional :license_type, -> { Orb::Price::UnitWithProration::LicenseType }, nil?: true
|
7455
|
# File 'lib/orb/models/price.rb', line 7455
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
7461
|
# File 'lib/orb/models/price.rb', line 7461
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
7470
|
# File 'lib/orb/models/price.rb', line 7470
required :metadata, Orb::Internal::Type::HashOf[String]
|
7476
|
# File 'lib/orb/models/price.rb', line 7476
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
7482
|
# File 'lib/orb/models/price.rb', line 7482
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :unit_with_proration
7488
|
# File 'lib/orb/models/price.rb', line 7488
required :model_type, const: :unit_with_proration
|
#name ⇒ String
7493
|
# File 'lib/orb/models/price.rb', line 7493
required :name, String
|
#plan_phase_order ⇒ Integer?
7498
|
# File 'lib/orb/models/price.rb', line 7498
required :plan_phase_order, Integer, nil?: true
|
7503
|
# File 'lib/orb/models/price.rb', line 7503
required :price_type, enum: -> { Orb::Price::UnitWithProration::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
7510
|
# File 'lib/orb/models/price.rb', line 7510
required :replaces_price_id, String, nil?: true
|
Configuration for unit_with_proration pricing
7516
|
# File 'lib/orb/models/price.rb', line 7516
required :unit_with_proration_config, -> { Orb::Price::UnitWithProration::UnitWithProrationConfig }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 7602
|
Instance Method Details
#to_hash ⇒ {
5617
|
# File 'sig/orb/models/price.rbs', line 5617
def to_hash: -> {
|