Class: Orb::Models::PriceCreateParams::Body::GroupedWithMinMaxThresholds::GroupedWithMinMaxThresholdsConfig

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/price_create_params.rb,
sig/orb/models/price_create_params.rbs

Overview

See Also:

  • Orb::Models::PriceCreateParams::Body::GroupedWithMinMaxThresholds#grouped_with_min_max_thresholds_config

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



589
# File 'sig/orb/models/price_create_params.rbs', line 589

def initialize: (

Instance Attribute Details

#grouping_keyString

The event property used to group before applying thresholds

Parameters:

  • value (String)

Returns:

  • (String)


819
# File 'lib/orb/models/price_create_params.rb', line 819

required :grouping_key, String

#maximum_chargeString

The maximum amount to charge each group

Parameters:

  • value (String)

Returns:

  • (String)


825
# File 'lib/orb/models/price_create_params.rb', line 825

required :maximum_charge, String

#minimum_chargeString

The minimum amount to charge each group, regardless of usage

Parameters:

  • value (String)

Returns:

  • (String)


831
# File 'lib/orb/models/price_create_params.rb', line 831

required :minimum_charge, String

#per_unit_rateString

The base price charged per group

Parameters:

  • value (String)

Returns:

  • (String)


837
# File 'lib/orb/models/price_create_params.rb', line 837

required :per_unit_rate, String

Instance Method Details

#to_hash{

Returns:

  • ({)


596
# File 'sig/orb/models/price_create_params.rbs', line 596

def to_hash: -> {