Class: Orb::Models::PriceCreateParams::Body::MeteredAllowance

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/price_create_params.rb,
sig/orb/models/price_create_params.rbs

Defined Under Namespace

Modules: Cadence Classes: MeteredAllowanceConfig

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(cadence:, currency:, item_id:, metered_allowance_config:, name:, billable_metric_id: nil, billed_in_advance: nil, billing_cycle_configuration: nil, conversion_rate: nil, conversion_rate_config: nil, dimensional_price_configuration: nil, external_price_id: nil, fixed_price_quantity: nil, invoice_grouping_key: nil, invoicing_cycle_configuration: nil, license_type_id: nil, metadata: nil, model_type: :metered_allowance) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::PriceCreateParams::Body::MeteredAllowance for more details.

Parameters:

  • cadence (Symbol, Orb::Models::PriceCreateParams::Body::MeteredAllowance::Cadence)

    The cadence to bill for this price on.

  • currency (String)

    An ISO 4217 currency string for which this price is billed in.

  • item_id (String)

    The id of the item the price will be associated with.

  • metered_allowance_config (Orb::Models::PriceCreateParams::Body::MeteredAllowance::MeteredAllowanceConfig)

    Configuration for metered_allowance pricing

  • name (String)

    The name of the price.

  • billable_metric_id (String, nil) (defaults to: nil)

    The id of the billable metric for the price. Only needed if the price is usage-b

  • billed_in_advance (Boolean, nil) (defaults to: nil)

    If the Price represents a fixed cost, the price will be billed in-advance if thi

  • billing_cycle_configuration (Orb::Models::NewBillingCycleConfiguration, nil) (defaults to: nil)

    For custom cadence: specifies the duration of the billing period in days or mont

  • conversion_rate (Float, nil) (defaults to: nil)

    The per unit conversion rate of the price currency to the invoicing currency.

  • conversion_rate_config (Orb::Models::UnitConversionRateConfig, Orb::Models::TieredConversionRateConfig, nil) (defaults to: nil)

    The configuration for the rate of the price currency to the invoicing currency.

  • dimensional_price_configuration (Orb::Models::NewDimensionalPriceConfiguration, nil) (defaults to: nil)

    For dimensional price: specifies a price group and dimension values

  • external_price_id (String, nil) (defaults to: nil)

    An alias for the price.

  • fixed_price_quantity (Float, nil) (defaults to: nil)

    If the Price represents a fixed cost, this represents the quantity of units appl

  • invoice_grouping_key (String, nil) (defaults to: nil)

    The property used to group this price on an invoice

  • invoicing_cycle_configuration (Orb::Models::NewBillingCycleConfiguration, nil) (defaults to: nil)

    Within each billing cycle, specifies the cadence at which invoices are produced.

  • license_type_id (String, nil) (defaults to: nil)

    The ID of the license type to associate with this price.

  • metadata (Hash{Symbol=>String, nil}, nil) (defaults to: nil)

    User-specified key/value pairs for the resource. Individual keys can be removed

  • model_type (Symbol, :metered_allowance) (defaults to: :metered_allowance)

    The pricing model type



# File 'lib/orb/models/price_create_params.rb', line 1439

Instance Attribute Details

#billable_metric_idString?

The id of the billable metric for the price. Only needed if the price is usage-based.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1365
# File 'lib/orb/models/price_create_params.rb', line 1365

optional :billable_metric_id, String, nil?: true

#billed_in_advanceBoolean?

If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


1372
# File 'lib/orb/models/price_create_params.rb', line 1372

optional :billed_in_advance, Orb::Internal::Type::Boolean, nil?: true

#billing_cycle_configurationOrb::Models::NewBillingCycleConfiguration?

For custom cadence: specifies the duration of the billing period in days or months.



1379
# File 'lib/orb/models/price_create_params.rb', line 1379

optional :billing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true

#cadenceSymbol, Orb::Models::PriceCreateParams::Body::MeteredAllowance::Cadence

The cadence to bill for this price on.

Parameters:

  • value (Orb::Models::PriceCreateParams::Body::MeteredAllowance::cadence)

Returns:



1327
# File 'lib/orb/models/price_create_params.rb', line 1327

required :cadence, enum: -> { Orb::PriceCreateParams::Body::MeteredAllowance::Cadence }

#conversion_rateFloat?

The per unit conversion rate of the price currency to the invoicing currency.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


1385
# File 'lib/orb/models/price_create_params.rb', line 1385

optional :conversion_rate, Float, nil?: true

#conversion_rate_configOrb::Models::UnitConversionRateConfig, ...

The configuration for the rate of the price currency to the invoicing currency.

Parameters:

  • value (Orb::Models::conversion_rate_config, nil)

Returns:



1391
# File 'lib/orb/models/price_create_params.rb', line 1391

optional :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true

#currencyString

An ISO 4217 currency string for which this price is billed in.

Parameters:

  • value (String)

Returns:

  • (String)


1333
# File 'lib/orb/models/price_create_params.rb', line 1333

required :currency, String

#dimensional_price_configurationOrb::Models::NewDimensionalPriceConfiguration?

For dimensional price: specifies a price group and dimension values



1397
# File 'lib/orb/models/price_create_params.rb', line 1397

optional :dimensional_price_configuration, -> { Orb::NewDimensionalPriceConfiguration }, nil?: true

#external_price_idString?

An alias for the price.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1403
# File 'lib/orb/models/price_create_params.rb', line 1403

optional :external_price_id, String, nil?: true

#fixed_price_quantityFloat?

If the Price represents a fixed cost, this represents the quantity of units applied.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


1410
# File 'lib/orb/models/price_create_params.rb', line 1410

optional :fixed_price_quantity, Float, nil?: true

#invoice_grouping_keyString?

The property used to group this price on an invoice

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1416
# File 'lib/orb/models/price_create_params.rb', line 1416

optional :invoice_grouping_key, String, nil?: true

#invoicing_cycle_configurationOrb::Models::NewBillingCycleConfiguration?

Within each billing cycle, specifies the cadence at which invoices are produced. If unspecified, a single invoice is produced per billing cycle.



1423
# File 'lib/orb/models/price_create_params.rb', line 1423

optional :invoicing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true

#item_idString

The id of the item the price will be associated with.

Parameters:

  • value (String)

Returns:

  • (String)


1339
# File 'lib/orb/models/price_create_params.rb', line 1339

required :item_id, String

#license_type_idString?

The ID of the license type to associate with this price.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1429
# File 'lib/orb/models/price_create_params.rb', line 1429

optional :license_type_id, String, nil?: true

#metadataHash{Symbol=>String, nil}?

User-specified key/value pairs for the resource. Individual keys can be removed by setting the value to null, and the entire metadata mapping can be cleared by setting metadata to null.

Parameters:

  • value (::Hash[Symbol, String?], nil)

Returns:

  • (Hash{Symbol=>String, nil}, nil)


1437
# File 'lib/orb/models/price_create_params.rb', line 1437

optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true

#metered_allowance_configOrb::Models::PriceCreateParams::Body::MeteredAllowance::MeteredAllowanceConfig

Configuration for metered_allowance pricing

Parameters:

  • value (Orb::PriceCreateParams::Body::MeteredAllowance::MeteredAllowanceConfig)

Returns:



1345
1346
# File 'lib/orb/models/price_create_params.rb', line 1345

required :metered_allowance_config,
-> { Orb::PriceCreateParams::Body::MeteredAllowance::MeteredAllowanceConfig }

#model_typeSymbol, :metered_allowance

The pricing model type

Parameters:

  • value (:metered_allowance)

Returns:

  • (Symbol, :metered_allowance)


1352
# File 'lib/orb/models/price_create_params.rb', line 1352

required :model_type, const: :metered_allowance

#nameString

The name of the price.

Parameters:

  • value (String)

Returns:

  • (String)


1358
# File 'lib/orb/models/price_create_params.rb', line 1358

required :name, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/orb/models/price_create_params.rb', line 1492

Instance Method Details

#to_hash{

Returns:

  • ({)


1009
# File 'sig/orb/models/price_create_params.rbs', line 1009

def to_hash: -> {