Class: Orb::Models::PriceCreateParams::Body::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/price_create_params.rb,
sig/orb/models/price_create_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(allocation:, default_unit_amount:, dimensions:, tiers:) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::PriceCreateParams::Body::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig for more details.

Configuration for tiered_matrix_with_allocation pricing

Parameters:



810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
# File 'lib/orb/models/price_create_params.rb', line 810

class Tier < Orb::Internal::Type::BaseModel
  # @!attribute dimension_values
  #   The matrix cell this tier applies to, as one or two dimension values
  #
  #   @return [Array<String>]
  required :dimension_values, Orb::Internal::Type::ArrayOf[String]

  # @!attribute tier_lower_bound
  #   Exclusive tier starting value. The tier runs up to and including the next bound
  #   configured for the same matrix cell.
  #
  #   @return [String]
  required :tier_lower_bound, String

  # @!attribute unit_amount
  #   Per unit amount
  #
  #   @return [String]
  required :unit_amount, String

  # @!method initialize(dimension_values:, tier_lower_bound:, unit_amount:)
  #   Some parameter documentations has been truncated, see
  #   {Orb::Models::PriceCreateParams::Body::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier}
  #   for more details.
  #
  #   Configuration for a single tier scoped to one matrix cell
  #
  #   @param dimension_values [Array<String>] The matrix cell this tier applies to, as one or two dimension values
  #
  #   @param tier_lower_bound [String] Exclusive tier starting value. The tier runs up to and including the next bound
  #
  #   @param unit_amount [String] Per unit amount
end

Instance Attribute Details

#dimension_values ⇒ Array<String>

The matrix cell this tier applies to, as one or two dimension values

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


815
# File 'lib/orb/models/price_create_params.rb', line 815

required :dimension_values, Orb::Internal::Type::ArrayOf[String]

#tier_lower_bound ⇒ String

Exclusive tier starting value. The tier runs up to and including the next bound configured for the same matrix cell.

Parameters:

  • value (String)

Returns:

  • (String)


822
# File 'lib/orb/models/price_create_params.rb', line 822

required :tier_lower_bound, String

#unit_amount ⇒ String

Per unit amount

Parameters:

  • value (String)

Returns:

  • (String)


828
# File 'lib/orb/models/price_create_params.rb', line 828

required :unit_amount, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


574
# File 'sig/orb/models/price_create_params.rbs', line 574

def to_hash: -> {