Class: Orb::Models::PriceEvaluateMultipleParams::PriceEvaluation::Price::DailyCreditAllowance::DailyCreditAllowanceConfig::MatrixValue

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/price_evaluate_multiple_params.rb,
sig/orb/models/price_evaluate_multiple_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(daily_allowance:, default_unit_amount:, dimensions:, event_day_property:, matrix_values:) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::PriceEvaluateMultipleParams::PriceEvaluation::Price::DailyCreditAllowance::DailyCreditAllowanceConfig for more details.

Configuration for daily_credit_allowance pricing

matrix_

Parameters:



1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 1425

class MatrixValue < Orb::Internal::Type::BaseModel
  # @!attribute dimension_values
  #   One or two matrix keys to filter usage to this value by. For example, ["model"]
  #   could be used to apply a different credit rate to each AI model.
  #
  #   @return [Array<String, nil>]
  required :dimension_values, Orb::Internal::Type::ArrayOf[String, nil?: true]

  # @!attribute unit_amount
  #   Credits charged per unit of usage matching the specified dimension_values
  #
  #   @return [String]
  required :unit_amount, String

  # @!method initialize(dimension_values:, unit_amount:)
  #   Some parameter documentations has been truncated, see
  #   {Orb::Models::PriceEvaluateMultipleParams::PriceEvaluation::Price::DailyCreditAllowance::DailyCreditAllowanceConfig::MatrixValue}
  #   for more details.
  #
  #   Per-dimension credit price for the daily credit allowance model.
  #
  #   @param dimension_values [Array<String, nil>] One or two matrix keys to filter usage to this value by. For example, ["model"]
  #
  #   @param unit_amount [String] Credits charged per unit of usage matching the specified dimension_values
end

Instance Attribute Details

#dimension_valuesArray<String, nil>

One or two matrix keys to filter usage to this value by. For example, ["model"] could be used to apply a different credit rate to each AI model.

Parameters:

  • value (::Array[String?])

Returns:

  • (Array<String, nil>)


1431
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 1431

required :dimension_values, Orb::Internal::Type::ArrayOf[String, nil?: true]

#unit_amountString

Credits charged per unit of usage matching the specified dimension_values

Parameters:

  • value (String)

Returns:

  • (String)


1437
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 1437

required :unit_amount, String

Instance Method Details

#to_hash{

Returns:

  • ({)


1018
# File 'sig/orb/models/price_evaluate_multiple_params.rbs', line 1018

def to_hash: -> {