Class: Orb::Models::PriceEvaluateMultipleParams::PriceEvaluation::Price::GroupedTieredMatrix
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::PriceEvaluateMultipleParams::PriceEvaluation::Price::GroupedTieredMatrix
- Defined in:
- lib/orb/models/price_evaluate_multiple_params.rb,
sig/orb/models/price_evaluate_multiple_params.rbs
Defined Under Namespace
Modules: Cadence Classes: GroupedTieredMatrixConfig
Instance Attribute Summary collapse
-
#billable_metric_id ⇒ String?
The id of the billable metric for the price.
-
#billed_in_advance ⇒ Boolean?
If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.
-
#billing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
For custom cadence: specifies the duration of the billing period in days or months.
-
#cadence ⇒ Symbol, Orb::Models::PriceEvaluateMultipleParams::PriceEvaluation::Price::GroupedTieredMatrix::Cadence
The cadence to bill for this price on.
-
#conversion_rate ⇒ Float?
The per unit conversion rate of the price currency to the invoicing currency.
-
#conversion_rate_config ⇒ Orb::Models::UnitConversionRateConfig, ...
The configuration for the rate of the price currency to the invoicing currency.
-
#currency ⇒ String
An ISO 4217 currency string for which this price is billed in.
-
#dimensional_price_configuration ⇒ Orb::Models::NewDimensionalPriceConfiguration?
For dimensional price: specifies a price group and dimension values.
-
#external_price_id ⇒ String?
An alias for the price.
-
#fixed_price_quantity ⇒ Float?
If the Price represents a fixed cost, this represents the quantity of units applied.
-
#grouped_tiered_matrix_config ⇒ Orb::Models::PriceEvaluateMultipleParams::PriceEvaluation::Price::GroupedTieredMatrix::GroupedTieredMatrixConfig
Configuration for grouped_tiered_matrix pricing.
-
#invoice_grouping_key ⇒ String?
The property used to group this price on an invoice.
-
#invoicing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
Within each billing cycle, specifies the cadence at which invoices are produced.
-
#item_id ⇒ String
The id of the item the price will be associated with.
-
#license_type_id ⇒ String?
The ID of the license type to associate with this price.
-
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource.
-
#model_type ⇒ Symbol, :grouped_tiered_matrix
The pricing model type.
-
#name ⇒ String
The name of the price.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(cadence:, currency:, grouped_tiered_matrix_config:, item_id:, name:, billable_metric_id: nil, billed_in_advance: nil, billing_cycle_configuration: nil, conversion_rate: nil, conversion_rate_config: nil, dimensional_price_configuration: nil, external_price_id: nil, fixed_price_quantity: nil, invoice_grouping_key: nil, invoicing_cycle_configuration: nil, license_type_id: nil, metadata: nil, model_type: :grouped_tiered_matrix) ⇒ Object
constructor
Some parameter documentations has been truncated, see GroupedTieredMatrix for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cadence:, currency:, grouped_tiered_matrix_config:, item_id:, name:, billable_metric_id: nil, billed_in_advance: nil, billing_cycle_configuration: nil, conversion_rate: nil, conversion_rate_config: nil, dimensional_price_configuration: nil, external_price_id: nil, fixed_price_quantity: nil, invoice_grouping_key: nil, invoicing_cycle_configuration: nil, license_type_id: nil, metadata: nil, model_type: :grouped_tiered_matrix) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::PriceEvaluateMultipleParams::PriceEvaluation::Price::GroupedTieredMatrix for more details.
|
|
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 568
|
Instance Attribute Details
#billable_metric_id ⇒ String?
The id of the billable metric for the price. Only needed if the price is usage-based.
490 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 490 optional :billable_metric_id, String, nil?: true |
#billed_in_advance ⇒ Boolean?
If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.
497 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 497 optional :billed_in_advance, Orb::Internal::Type::Boolean, nil?: true |
#billing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
For custom cadence: specifies the duration of the billing period in days or months.
504 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 504 optional :billing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true |
#cadence ⇒ Symbol, Orb::Models::PriceEvaluateMultipleParams::PriceEvaluation::Price::GroupedTieredMatrix::Cadence
The cadence to bill for this price on.
451 452 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 451 required :cadence, enum: -> { Orb::PriceEvaluateMultipleParams::PriceEvaluation::Price::GroupedTieredMatrix::Cadence } |
#conversion_rate ⇒ Float?
The per unit conversion rate of the price currency to the invoicing currency.
510 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 510 optional :conversion_rate, Float, nil?: true |
#conversion_rate_config ⇒ Orb::Models::UnitConversionRateConfig, ...
The configuration for the rate of the price currency to the invoicing currency.
516 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 516 optional :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true |
#currency ⇒ String
An ISO 4217 currency string for which this price is billed in.
458 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 458 required :currency, String |
#dimensional_price_configuration ⇒ Orb::Models::NewDimensionalPriceConfiguration?
For dimensional price: specifies a price group and dimension values
522 523 524 525 526 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 522 optional :dimensional_price_configuration, -> { Orb::NewDimensionalPriceConfiguration }, nil?: true |
#external_price_id ⇒ String?
An alias for the price.
532 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 532 optional :external_price_id, String, nil?: true |
#fixed_price_quantity ⇒ Float?
If the Price represents a fixed cost, this represents the quantity of units applied.
539 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 539 optional :fixed_price_quantity, Float, nil?: true |
#grouped_tiered_matrix_config ⇒ Orb::Models::PriceEvaluateMultipleParams::PriceEvaluation::Price::GroupedTieredMatrix::GroupedTieredMatrixConfig
Configuration for grouped_tiered_matrix pricing
464 465 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 464 required :grouped_tiered_matrix_config, -> { Orb::PriceEvaluateMultipleParams::PriceEvaluation::Price::GroupedTieredMatrix::GroupedTieredMatrixConfig } |
#invoice_grouping_key ⇒ String?
The property used to group this price on an invoice
545 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 545 optional :invoice_grouping_key, String, nil?: true |
#invoicing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
Within each billing cycle, specifies the cadence at which invoices are produced. If unspecified, a single invoice is produced per billing cycle.
552 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 552 optional :invoicing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true |
#item_id ⇒ String
The id of the item the price will be associated with.
471 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 471 required :item_id, String |
#license_type_id ⇒ String?
The ID of the license type to associate with this price.
558 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 558 optional :license_type_id, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource. Individual keys can be removed
by setting the value to null, and the entire metadata mapping can be cleared
by setting metadata to null.
566 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 566 optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true |
#model_type ⇒ Symbol, :grouped_tiered_matrix
The pricing model type
477 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 477 required :model_type, const: :grouped_tiered_matrix |
#name ⇒ String
The name of the price.
483 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 483 required :name, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 622
|
Instance Method Details
#to_hash ⇒ {
390 |
# File 'sig/orb/models/price_evaluate_multiple_params.rbs', line 390
def to_hash: -> {
|