Class: Orb::Models::PriceEvaluateMultipleParams::PriceEvaluation::Price::GroupedTieredMatrix::GroupedTieredMatrixConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::PriceEvaluateMultipleParams::PriceEvaluation::Price::GroupedTieredMatrix::GroupedTieredMatrixConfig
- Defined in:
- lib/orb/models/price_evaluate_multiple_params.rb,
sig/orb/models/price_evaluate_multiple_params.rbs
Overview
Defined Under Namespace
Classes: Tier
Instance Attribute Summary collapse
-
#default_unit_amount ⇒ String
Per unit rate for usage whose dimension value has no configured tiers.
-
#dimension ⇒ String
The billable metric property used to group usage before tiering.
-
#tiers ⇒ Array<Orb::Models::PriceEvaluateMultipleParams::PriceEvaluation::Price::GroupedTieredMatrix::GroupedTieredMatrixConfig::Tier>
Graduated tiers keyed by dimension value; usage for a value is tiered only against its own rows.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
446 |
# File 'sig/orb/models/price_evaluate_multiple_params.rbs', line 446
def initialize: (
|
Instance Attribute Details
#default_unit_amount ⇒ String
Per unit rate for usage whose dimension value has no configured tiers
632 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 632 required :default_unit_amount, String |
#dimension ⇒ String
The billable metric property used to group usage before tiering
638 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 638 required :dimension, String |
#tiers ⇒ Array<Orb::Models::PriceEvaluateMultipleParams::PriceEvaluation::Price::GroupedTieredMatrix::GroupedTieredMatrixConfig::Tier>
Graduated tiers keyed by dimension value; usage for a value is tiered only against its own rows
645 646 647 648 649 650 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 645 required :tiers, -> do Orb::Internal::Type::ArrayOf[ Orb::PriceEvaluateMultipleParams::PriceEvaluation::Price::GroupedTieredMatrix::GroupedTieredMatrixConfig::Tier ] end |
Instance Method Details
#to_hash ⇒ {
452 |
# File 'sig/orb/models/price_evaluate_multiple_params.rbs', line 452
def to_hash: -> {
|