Class: Orb::Models::PriceEvaluateMultipleParams::PriceEvaluation::Price::Percent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::PriceEvaluateMultipleParams::PriceEvaluation::Price::Percent
- Defined in:
- lib/orb/models/price_evaluate_multiple_params.rb,
sig/orb/models/price_evaluate_multiple_params.rbs
Defined Under Namespace
Modules: Cadence Classes: PercentConfig
Instance Attribute Summary collapse
-
#billable_metric_id ⇒ String?
The id of the billable metric for the price.
-
#billed_in_advance ⇒ Boolean?
If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.
-
#billing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
For custom cadence: specifies the duration of the billing period in days or months.
-
#cadence ⇒ Symbol, Orb::Models::PriceEvaluateMultipleParams::PriceEvaluation::Price::Percent::Cadence
The cadence to bill for this price on.
-
#conversion_rate ⇒ Float?
The per unit conversion rate of the price currency to the invoicing currency.
-
#conversion_rate_config ⇒ Orb::Models::UnitConversionRateConfig, ...
The configuration for the rate of the price currency to the invoicing currency.
-
#currency ⇒ String
An ISO 4217 currency string for which this price is billed in.
-
#dimensional_price_configuration ⇒ Orb::Models::NewDimensionalPriceConfiguration?
For dimensional price: specifies a price group and dimension values.
-
#external_price_id ⇒ String?
An alias for the price.
-
#fixed_price_quantity ⇒ Float?
If the Price represents a fixed cost, this represents the quantity of units applied.
-
#invoice_grouping_key ⇒ String?
The property used to group this price on an invoice.
-
#invoicing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
Within each billing cycle, specifies the cadence at which invoices are produced.
-
#item_id ⇒ String
The id of the item the price will be associated with.
-
#license_type_id ⇒ String?
The ID of the license type to associate with this price.
-
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource.
-
#model_type ⇒ Symbol, :percent
The pricing model type.
-
#name ⇒ String
The name of the price.
-
#percent_config ⇒ Orb::Models::PriceEvaluateMultipleParams::PriceEvaluation::Price::Percent::PercentConfig
Configuration for percent pricing.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(cadence:, currency:, item_id:, name:, percent_config:, billable_metric_id: nil, billed_in_advance: nil, billing_cycle_configuration: nil, conversion_rate: nil, conversion_rate_config: nil, dimensional_price_configuration: nil, external_price_id: nil, fixed_price_quantity: nil, invoice_grouping_key: nil, invoicing_cycle_configuration: nil, license_type_id: nil, metadata: nil, model_type: :percent) ⇒ Object
constructor
Some parameter documentations has been truncated, see Percent for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cadence:, currency:, item_id:, name:, percent_config:, billable_metric_id: nil, billed_in_advance: nil, billing_cycle_configuration: nil, conversion_rate: nil, conversion_rate_config: nil, dimensional_price_configuration: nil, external_price_id: nil, fixed_price_quantity: nil, invoice_grouping_key: nil, invoicing_cycle_configuration: nil, license_type_id: nil, metadata: nil, model_type: :percent) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::PriceEvaluateMultipleParams::PriceEvaluation::Price::Percent for more details.
|
|
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 1818
|
Instance Attribute Details
#billable_metric_id ⇒ String?
The id of the billable metric for the price. Only needed if the price is usage-based.
1740 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 1740 optional :billable_metric_id, String, nil?: true |
#billed_in_advance ⇒ Boolean?
If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.
1747 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 1747 optional :billed_in_advance, Orb::Internal::Type::Boolean, nil?: true |
#billing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
For custom cadence: specifies the duration of the billing period in days or months.
1754 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 1754 optional :billing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true |
#cadence ⇒ Symbol, Orb::Models::PriceEvaluateMultipleParams::PriceEvaluation::Price::Percent::Cadence
The cadence to bill for this price on.
1702 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 1702 required :cadence, enum: -> { Orb::PriceEvaluateMultipleParams::PriceEvaluation::Price::Percent::Cadence } |
#conversion_rate ⇒ Float?
The per unit conversion rate of the price currency to the invoicing currency.
1760 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 1760 optional :conversion_rate, Float, nil?: true |
#conversion_rate_config ⇒ Orb::Models::UnitConversionRateConfig, ...
The configuration for the rate of the price currency to the invoicing currency.
1766 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 1766 optional :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true |
#currency ⇒ String
An ISO 4217 currency string for which this price is billed in.
1708 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 1708 required :currency, String |
#dimensional_price_configuration ⇒ Orb::Models::NewDimensionalPriceConfiguration?
For dimensional price: specifies a price group and dimension values
1772 1773 1774 1775 1776 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 1772 optional :dimensional_price_configuration, -> { Orb::NewDimensionalPriceConfiguration }, nil?: true |
#external_price_id ⇒ String?
An alias for the price.
1782 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 1782 optional :external_price_id, String, nil?: true |
#fixed_price_quantity ⇒ Float?
If the Price represents a fixed cost, this represents the quantity of units applied.
1789 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 1789 optional :fixed_price_quantity, Float, nil?: true |
#invoice_grouping_key ⇒ String?
The property used to group this price on an invoice
1795 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 1795 optional :invoice_grouping_key, String, nil?: true |
#invoicing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
Within each billing cycle, specifies the cadence at which invoices are produced. If unspecified, a single invoice is produced per billing cycle.
1802 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 1802 optional :invoicing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true |
#item_id ⇒ String
The id of the item the price will be associated with.
1714 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 1714 required :item_id, String |
#license_type_id ⇒ String?
The ID of the license type to associate with this price.
1808 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 1808 optional :license_type_id, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource. Individual keys can be removed
by setting the value to null, and the entire metadata mapping can be cleared
by setting metadata to null.
1816 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 1816 optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true |
#model_type ⇒ Symbol, :percent
The pricing model type
1720 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 1720 required :model_type, const: :percent |
#name ⇒ String
The name of the price.
1726 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 1726 required :name, String |
#percent_config ⇒ Orb::Models::PriceEvaluateMultipleParams::PriceEvaluation::Price::Percent::PercentConfig
Configuration for percent pricing
1732 1733 |
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 1732 required :percent_config, -> { Orb::PriceEvaluateMultipleParams::PriceEvaluation::Price::Percent::PercentConfig } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/price_evaluate_multiple_params.rb', line 1872
|
Instance Method Details
#to_hash ⇒ {
1275 |
# File 'sig/orb/models/price_evaluate_multiple_params.rbs', line 1275
def to_hash: -> {
|