Class: Orb::Models::PriceEvaluateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/orb/models/price_evaluate_params.rb,
sig/orb/models/price_evaluate_params.rbs

Overview

See Also:

  • Orb::Resources::Prices#evaluate

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(price_id:, timeframe_end:, timeframe_start:, customer_id: nil, external_customer_id: nil, filter: nil, grouping_keys: nil, metric_parameter_overrides: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::PriceEvaluateParams for more details.

Parameters:

  • price_id (String)
  • timeframe_end (Time)

    The exclusive upper bound for event timestamps

  • timeframe_start (Time)

    The inclusive lower bound for event timestamps

  • customer_id (String, nil) (defaults to: nil)

    The ID of the customer to which this evaluation is scoped.

  • external_customer_id (String, nil) (defaults to: nil)

    The external customer ID of the customer to which this evaluation is scoped.

  • filter (String, nil) (defaults to: nil)

    A boolean [computed property](/extensibility/advanced-metrics#computed-propertie

  • grouping_keys (Array<String>) (defaults to: nil)

    Properties (or [computed properties](/extensibility/advanced-metrics#computed-pr

  • metric_parameter_overrides (Hash{Symbol=>Object}, nil) (defaults to: nil)

    Optional overrides for parameterized billable metric parameters. If the metric h

  • request_options (Orb::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/orb/models/price_evaluate_params.rb', line 64

Instance Attribute Details

#customer_idString?

The ID of the customer to which this evaluation is scoped.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


31
# File 'lib/orb/models/price_evaluate_params.rb', line 31

optional :customer_id, String, nil?: true

#external_customer_idString?

The external customer ID of the customer to which this evaluation is scoped.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


37
# File 'lib/orb/models/price_evaluate_params.rb', line 37

optional :external_customer_id, String, nil?: true

#filterString?

A boolean computed property used to filter the underlying billable metric

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


45
# File 'lib/orb/models/price_evaluate_params.rb', line 45

optional :filter, String, nil?: true

#grouping_keysArray<String>?

Properties (or computed properties) used to group the underlying billable metric

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


53
# File 'lib/orb/models/price_evaluate_params.rb', line 53

optional :grouping_keys, Orb::Internal::Type::ArrayOf[String]

#metric_parameter_overridesHash{Symbol=>Object}?

Optional overrides for parameterized billable metric parameters. If the metric has parameter definitions and no overrides are provided, defaults will be used.

Parameters:

  • value (::Hash[Symbol, top], nil)

Returns:

  • (Hash{Symbol=>Object}, nil)


60
61
62
# File 'lib/orb/models/price_evaluate_params.rb', line 60

optional :metric_parameter_overrides,
Orb::Internal::Type::HashOf[Orb::Internal::Type::Unknown],
nil?: true

#price_idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/orb/models/price_evaluate_params.rb', line 13

required :price_id, String

#timeframe_endTime

The exclusive upper bound for event timestamps

Parameters:

  • value (Time)

Returns:

  • (Time)


19
# File 'lib/orb/models/price_evaluate_params.rb', line 19

required :timeframe_end, Time

#timeframe_startTime

The inclusive lower bound for event timestamps

Parameters:

  • value (Time)

Returns:

  • (Time)


25
# File 'lib/orb/models/price_evaluate_params.rb', line 25

required :timeframe_start, Time

Instance Method Details

#to_hash{

Returns:

  • ({)


50
# File 'sig/orb/models/price_evaluate_params.rbs', line 50

def to_hash: -> {