Class: Orb::Models::PriceEvaluatePreviewEventsParams::PriceEvaluation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::PriceEvaluatePreviewEventsParams::PriceEvaluation
- Defined in:
- lib/orb/models/price_evaluate_preview_events_params.rb,
sig/orb/models/price_evaluate_preview_events_params.rbs
Defined Under Namespace
Modules: Price
Constant Summary collapse
- Orb =
Instance Attribute Summary collapse
-
#external_price_id ⇒ String?
The external ID of a price to evaluate that exists in your Orb account.
-
#filter ⇒ String?
A boolean computed property used to filter the underlying billable metric.
-
#grouping_keys ⇒ Array<String>?
Properties (or computed properties) used to group the underlying billable metric.
-
#metric_parameter_overrides ⇒ Hash{Symbol=>Object}?
Optional overrides for parameterized billable metric parameters.
-
#price ⇒ Orb::Models::NewFloatingUnitPrice, ...
New floating price request body params.
-
#price_id ⇒ String?
The ID of a price to evaluate that exists in your Orb account.
Instance Method Summary collapse
-
#initialize(external_price_id: nil, filter: nil, grouping_keys: nil, metric_parameter_overrides: nil, price: nil, price_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PriceEvaluation for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(external_price_id: nil, filter: nil, grouping_keys: nil, metric_parameter_overrides: nil, price: nil, price_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::PriceEvaluatePreviewEventsParams::PriceEvaluation for more details.
|
|
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 160
|
Instance Attribute Details
#external_price_id ⇒ String?
The external ID of a price to evaluate that exists in your Orb account.
117 |
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 117 optional :external_price_id, String, nil?: true |
#filter ⇒ String?
A boolean computed property used to filter the underlying billable metric
125 |
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 125 optional :filter, String, nil?: true |
#grouping_keys ⇒ Array<String>?
Properties (or computed properties) used to group the underlying billable metric
133 |
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 133 optional :grouping_keys, Orb::Internal::Type::ArrayOf[String] |
#metric_parameter_overrides ⇒ Hash{Symbol=>Object}?
Optional overrides for parameterized billable metric parameters. If the metric has parameter definitions and no overrides are provided, defaults will be used.
140 141 142 |
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 140 optional :metric_parameter_overrides, Orb::Internal::Type::HashOf[Orb::Internal::Type::Unknown], nil?: true |
#price ⇒ Orb::Models::NewFloatingUnitPrice, ...
New floating price request body params.
148 149 150 151 152 |
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 148 optional :price, union: -> { Orb::PriceEvaluatePreviewEventsParams::PriceEvaluation::Price }, nil?: true |
#price_id ⇒ String?
The ID of a price to evaluate that exists in your Orb account.
158 |
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 158 optional :price_id, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
129 |
# File 'sig/orb/models/price_evaluate_preview_events_params.rbs', line 129
def to_hash: -> {
|