Class: Orb::Models::PriceEvaluatePreviewEventsParams::PriceEvaluation::Price::CumulativeGroupedAllocation

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/price_evaluate_preview_events_params.rb,
sig/orb/models/price_evaluate_preview_events_params.rbs

Defined Under Namespace

Modules: Cadence Classes: CumulativeGroupedAllocationConfig

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(cadence:, cumulative_grouped_allocation_config:, currency:, item_id:, name:, billable_metric_id: nil, billed_in_advance: nil, billing_cycle_configuration: nil, conversion_rate: nil, conversion_rate_config: nil, dimensional_price_configuration: nil, external_price_id: nil, fixed_price_quantity: nil, invoice_grouping_key: nil, invoicing_cycle_configuration: nil, license_type_id: nil, metadata: nil, model_type: :cumulative_grouped_allocation) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::PriceEvaluatePreviewEventsParams::PriceEvaluation::Price::CumulativeGroupedAllocation for more details.

Parameters:

  • cadence (Symbol, Orb::Models::PriceEvaluatePreviewEventsParams::PriceEvaluation::Price::CumulativeGroupedAllocation::Cadence)

    The cadence to bill for this price on.

  • cumulative_grouped_allocation_config (Orb::Models::PriceEvaluatePreviewEventsParams::PriceEvaluation::Price::CumulativeGroupedAllocation::CumulativeGroupedAllocationConfig)

    Configuration for cumulative_grouped_allocation pricing

  • currency (String)

    An ISO 4217 currency string for which this price is billed in.

  • item_id (String)

    The id of the item the price will be associated with.

  • name (String)

    The name of the price.

  • billable_metric_id (String, nil) (defaults to: nil)

    The id of the billable metric for the price. Only needed if the price is usage-b

  • billed_in_advance (Boolean, nil) (defaults to: nil)

    If the Price represents a fixed cost, the price will be billed in-advance if thi

  • billing_cycle_configuration (Orb::Models::NewBillingCycleConfiguration, nil) (defaults to: nil)

    For custom cadence: specifies the duration of the billing period in days or mont

  • conversion_rate (Float, nil) (defaults to: nil)

    The per unit conversion rate of the price currency to the invoicing currency.

  • conversion_rate_config (Orb::Models::UnitConversionRateConfig, Orb::Models::TieredConversionRateConfig, nil) (defaults to: nil)

    The configuration for the rate of the price currency to the invoicing currency.

  • dimensional_price_configuration (Orb::Models::NewDimensionalPriceConfiguration, nil) (defaults to: nil)

    For dimensional price: specifies a price group and dimension values

  • external_price_id (String, nil) (defaults to: nil)

    An alias for the price.

  • fixed_price_quantity (Float, nil) (defaults to: nil)

    If the Price represents a fixed cost, this represents the quantity of units appl

  • invoice_grouping_key (String, nil) (defaults to: nil)

    The property used to group this price on an invoice

  • invoicing_cycle_configuration (Orb::Models::NewBillingCycleConfiguration, nil) (defaults to: nil)

    Within each billing cycle, specifies the cadence at which invoices are produced.

  • license_type_id (String, nil) (defaults to: nil)

    The ID of the license type to associate with this price.

  • metadata (Hash{Symbol=>String, nil}, nil) (defaults to: nil)

    User-specified key/value pairs for the resource. Individual keys can be removed

  • model_type (Symbol, :cumulative_grouped_allocation) (defaults to: :cumulative_grouped_allocation)

    The pricing model type



# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 1161

Instance Attribute Details

#billable_metric_idString?

The id of the billable metric for the price. Only needed if the price is usage-based.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1083
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 1083

optional :billable_metric_id, String, nil?: true

#billed_in_advanceBoolean?

If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


1090
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 1090

optional :billed_in_advance, Orb::Internal::Type::Boolean, nil?: true

#billing_cycle_configurationOrb::Models::NewBillingCycleConfiguration?

For custom cadence: specifies the duration of the billing period in days or months.



1097
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 1097

optional :billing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true

#cadenceSymbol, Orb::Models::PriceEvaluatePreviewEventsParams::PriceEvaluation::Price::CumulativeGroupedAllocation::Cadence

The cadence to bill for this price on.

Parameters:

  • value (Orb::Models::PriceEvaluatePreviewEventsParams::PriceEvaluation::Price::CumulativeGroupedAllocation::cadence)

Returns:



1044
1045
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 1044

required :cadence,
enum: -> { Orb::PriceEvaluatePreviewEventsParams::PriceEvaluation::Price::CumulativeGroupedAllocation::Cadence }

#conversion_rateFloat?

The per unit conversion rate of the price currency to the invoicing currency.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


1103
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 1103

optional :conversion_rate, Float, nil?: true

#conversion_rate_configOrb::Models::UnitConversionRateConfig, ...

The configuration for the rate of the price currency to the invoicing currency.

Parameters:

  • value (Orb::Models::conversion_rate_config, nil)

Returns:



1109
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 1109

optional :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true

#cumulative_grouped_allocation_configOrb::Models::PriceEvaluatePreviewEventsParams::PriceEvaluation::Price::CumulativeGroupedAllocation::CumulativeGroupedAllocationConfig

Configuration for cumulative_grouped_allocation pricing

Parameters:

  • value (Orb::PriceEvaluatePreviewEventsParams::PriceEvaluation::Price::CumulativeGroupedAllocation::CumulativeGroupedAllocationConfig)

Returns:



1051
1052
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 1051

required :cumulative_grouped_allocation_config,
-> { Orb::PriceEvaluatePreviewEventsParams::PriceEvaluation::Price::CumulativeGroupedAllocation::CumulativeGroupedAllocationConfig }

#currencyString

An ISO 4217 currency string for which this price is billed in.

Parameters:

  • value (String)

Returns:

  • (String)


1058
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 1058

required :currency, String

#dimensional_price_configurationOrb::Models::NewDimensionalPriceConfiguration?

For dimensional price: specifies a price group and dimension values



1115
1116
1117
1118
1119
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 1115

optional :dimensional_price_configuration,
-> {
  Orb::NewDimensionalPriceConfiguration
},
nil?: true

#external_price_idString?

An alias for the price.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1125
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 1125

optional :external_price_id, String, nil?: true

#fixed_price_quantityFloat?

If the Price represents a fixed cost, this represents the quantity of units applied.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


1132
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 1132

optional :fixed_price_quantity, Float, nil?: true

#invoice_grouping_keyString?

The property used to group this price on an invoice

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1138
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 1138

optional :invoice_grouping_key, String, nil?: true

#invoicing_cycle_configurationOrb::Models::NewBillingCycleConfiguration?

Within each billing cycle, specifies the cadence at which invoices are produced. If unspecified, a single invoice is produced per billing cycle.



1145
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 1145

optional :invoicing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true

#item_idString

The id of the item the price will be associated with.

Parameters:

  • value (String)

Returns:

  • (String)


1064
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 1064

required :item_id, String

#license_type_idString?

The ID of the license type to associate with this price.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1151
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 1151

optional :license_type_id, String, nil?: true

#metadataHash{Symbol=>String, nil}?

User-specified key/value pairs for the resource. Individual keys can be removed by setting the value to null, and the entire metadata mapping can be cleared by setting metadata to null.

Parameters:

  • value (::Hash[Symbol, String?], nil)

Returns:

  • (Hash{Symbol=>String, nil}, nil)


1159
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 1159

optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true

#model_typeSymbol, :cumulative_grouped_allocation

The pricing model type

Parameters:

  • value (:cumulative_grouped_allocation)

Returns:

  • (Symbol, :cumulative_grouped_allocation)


1070
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 1070

required :model_type, const: :cumulative_grouped_allocation

#nameString

The name of the price.

Parameters:

  • value (String)

Returns:

  • (String)


1076
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 1076

required :name, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 1215

Instance Method Details

#to_hash{

Returns:

  • ({)


818
# File 'sig/orb/models/price_evaluate_preview_events_params.rbs', line 818

def to_hash: -> {