Class: Orb::Models::PriceEvaluatePreviewEventsParams::PriceEvaluation::Price::CumulativeGroupedAllocation::CumulativeGroupedAllocationConfig

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/price_evaluate_preview_events_params.rb,
sig/orb/models/price_evaluate_preview_events_params.rbs

Overview

See Also:

  • Orb::Models::PriceEvaluatePreviewEventsParams::PriceEvaluation::Price::CumulativeGroupedAllocation#cumulative_grouped_allocation_config

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



877
# File 'sig/orb/models/price_evaluate_preview_events_params.rbs', line 877

def initialize: (

Instance Attribute Details

#cumulative_allocationString

The overall allocation across all groups

Parameters:

  • value (String)

Returns:

  • (String)


1225
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 1225

required :cumulative_allocation, String

#group_allocationString

The allocation per individual group

Parameters:

  • value (String)

Returns:

  • (String)


1231
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 1231

required :group_allocation, String

#grouping_keyString

The event property used to group usage before applying allocations

Parameters:

  • value (String)

Returns:

  • (String)


1237
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 1237

required :grouping_key, String

#unit_amountString

The amount to charge for each unit outside of the allocation

Parameters:

  • value (String)

Returns:

  • (String)


1243
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 1243

required :unit_amount, String

Instance Method Details

#to_hash{

Returns:

  • ({)


884
# File 'sig/orb/models/price_evaluate_preview_events_params.rbs', line 884

def to_hash: -> {