Class: Orb::Models::PriceEvaluatePreviewEventsParams::PriceEvaluation::Price::EventOutput::EventOutputConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::PriceEvaluatePreviewEventsParams::PriceEvaluation::Price::EventOutput::EventOutputConfig
- Defined in:
- lib/orb/models/price_evaluate_preview_events_params.rb,
sig/orb/models/price_evaluate_preview_events_params.rbs
Overview
Instance Attribute Summary collapse
-
#default_unit_rate ⇒ String?
If provided, this amount will be used as the unit rate when an event does not have a value for the
unit_rating_key. -
#grouping_key ⇒ String?
An optional key in the event data to group by (e.g., event ID).
-
#unit_rating_key ⇒ String
The key in the event data to extract the unit rate from.
Instance Method Summary collapse
-
#initialize(unit_rating_key:, default_unit_rate: nil, grouping_key: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see EventOutputConfig for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(unit_rating_key:, default_unit_rate: nil, grouping_key: nil) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::PriceEvaluatePreviewEventsParams::PriceEvaluation::Price::EventOutput::EventOutputConfig for more details.
Configuration for event_output pricing
|
|
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 2196
|
Instance Attribute Details
#default_unit_rate ⇒ String?
If provided, this amount will be used as the unit rate when an event does not
have a value for the unit_rating_key. If not provided, events missing a unit
rate will be ignored.
2187 |
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 2187 optional :default_unit_rate, String, nil?: true |
#grouping_key ⇒ String?
An optional key in the event data to group by (e.g., event ID). All events will also be grouped by their unit rate.
2194 |
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 2194 optional :grouping_key, String, nil?: true |
#unit_rating_key ⇒ String
The key in the event data to extract the unit rate from.
2179 |
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 2179 required :unit_rating_key, String |
Instance Method Details
#to_hash ⇒ {
1540 |
# File 'sig/orb/models/price_evaluate_preview_events_params.rbs', line 1540
def to_hash: -> {
|