Class: Orb::Models::PriceEvaluatePreviewEventsParams::PriceEvaluation::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::ThresholdDiscountGroup

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/price_evaluate_preview_events_params.rb,
sig/orb/models/price_evaluate_preview_events_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



564
# File 'sig/orb/models/price_evaluate_preview_events_params.rbs', line 564

def initialize: (

Instance Attribute Details

#above_threshold_discount_percentageString

Discount rate applied to spend above the threshold.

Parameters:

  • value (String)

Returns:

  • (String)


775
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 775

required :above_threshold_discount_percentage, String

#below_threshold_discount_percentageString

Discount rate applied to spend at or below the threshold. Set to 0 for no baseline discount.

Parameters:

  • value (String)

Returns:

  • (String)


782
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 782

required :below_threshold_discount_percentage, String

#cell_coordinatesString

Semicolon-separated list of matrix cell coordinates targeted by this group. Each coordinate is first,second when the matrix has two dimensions, or just first for a single-dimension matrix. Example: blue,circle;green,triangle.

Parameters:

  • value (String)

Returns:

  • (String)


790
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 790

required :cell_coordinates, String

#descriptionString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


800
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 800

optional :description, String, nil?: true

#threshold_amountString

Parameters:

  • value (String)

Returns:

  • (String)


795
# File 'lib/orb/models/price_evaluate_preview_events_params.rb', line 795

required :threshold_amount, String

Instance Method Details

#to_hash{

Returns:

  • ({)


572
# File 'sig/orb/models/price_evaluate_preview_events_params.rbs', line 572

def to_hash: -> {