Class: Orb::Models::SalesOrderAccountingSyncSucceededWebhookEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/sales_order_accounting_sync_succeeded_webhook_event.rb,
sig/orb/models/sales_order_accounting_sync_succeeded_webhook_event.rbs

Defined Under Namespace

Modules: Type Classes: AccountingSyncRecord, Properties

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(connection_type:) ⇒ Object

Parameters:

  • connection_type (String)


# File 'lib/orb/models/sales_order_accounting_sync_succeeded_webhook_event.rb', line 45

Instance Attribute Details

#accounting_sync_record ⇒ Orb::Models::SalesOrderAccountingSyncSucceededWebhookEvent::AccountingSyncRecord

Parameters:

  • value (Orb::SalesOrderAccountingSyncSucceededWebhookEvent::AccountingSyncRecord)

Returns:



15
16
# File 'lib/orb/models/sales_order_accounting_sync_succeeded_webhook_event.rb', line 15

required :accounting_sync_record,
-> { Orb::SalesOrderAccountingSyncSucceededWebhookEvent::AccountingSyncRecord }

#created_at ⇒ Time

The time at which this event was created, to the second.

Parameters:

  • value (Time)

Returns:

  • (Time)


22
# File 'lib/orb/models/sales_order_accounting_sync_succeeded_webhook_event.rb', line 22

required :created_at, Time

#id ⇒ String

The ID of this webhook event.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/orb/models/sales_order_accounting_sync_succeeded_webhook_event.rb', line 10

required :id, String

#invoice ⇒ Orb::Models::Invoice

An Invoice is a fundamental billing entity, representing the request for payment for a single subscription. This includes a set of line items, which correspond to prices in the subscription's plan and can represent fixed recurring fees or usage-based fees. They are generated at the end of a billing period, or as the result of an action, such as a cancellation.

Parameters:

Returns:



32
# File 'lib/orb/models/sales_order_accounting_sync_succeeded_webhook_event.rb', line 32

required :invoice, -> { Orb::Invoice }

#properties ⇒ Orb::Models::SalesOrderAccountingSyncSucceededWebhookEvent::Properties

Parameters:

  • value (Orb::SalesOrderAccountingSyncSucceededWebhookEvent::Properties)

Returns:



37
# File 'lib/orb/models/sales_order_accounting_sync_succeeded_webhook_event.rb', line 37

required :properties, -> { Orb::SalesOrderAccountingSyncSucceededWebhookEvent::Properties }

#type ⇒ Symbol, Orb::Models::SalesOrderAccountingSyncSucceededWebhookEvent::Type

The event this payload describes.

Parameters:

  • value (Orb::Models::SalesOrderAccountingSyncSucceededWebhookEvent::type_)

Returns:



43
# File 'lib/orb/models/sales_order_accounting_sync_succeeded_webhook_event.rb', line 43

required :type, enum: -> { Orb::SalesOrderAccountingSyncSucceededWebhookEvent::Type }

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/orb/models/sales_order_accounting_sync_succeeded_webhook_event.rb', line 129

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


35
# File 'sig/orb/models/sales_order_accounting_sync_succeeded_webhook_event.rbs', line 35

def to_hash: -> {