Class: Orb::Models::Subscription::DiscountInterval::TieredPercentage
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Subscription::DiscountInterval::TieredPercentage
- Defined in:
- lib/orb/models/subscription.rb,
sig/orb/models/subscription.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#applies_to_price_interval_ids ⇒ Array<String>
The price interval ids that this discount interval applies to.
- #discount_type ⇒ Symbol, :tiered_percentage
-
#end_date ⇒ Time?
The end date of the discount interval.
-
#filters ⇒ Array<Orb::Models::Subscription::DiscountInterval::TieredPercentage::Filter>
The filters that determine which prices this discount interval applies to.
-
#start_date ⇒ Time
The start date of the discount interval.
-
#tiers ⇒ Array<Orb::Models::Subscription::DiscountInterval::TieredPercentage::Tier>
Only available if discount_type is
tiered_percentage.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
186 |
# File 'sig/orb/models/subscription.rbs', line 186
def initialize: (
|
Instance Attribute Details
#applies_to_price_interval_ids ⇒ Array<String>
The price interval ids that this discount interval applies to.
317 |
# File 'lib/orb/models/subscription.rb', line 317 required :applies_to_price_interval_ids, Orb::Internal::Type::ArrayOf[String] |
#discount_type ⇒ Symbol, :tiered_percentage
322 |
# File 'lib/orb/models/subscription.rb', line 322 required :discount_type, const: :tiered_percentage |
#end_date ⇒ Time?
The end date of the discount interval.
328 |
# File 'lib/orb/models/subscription.rb', line 328 required :end_date, Time, nil?: true |
#filters ⇒ Array<Orb::Models::Subscription::DiscountInterval::TieredPercentage::Filter>
The filters that determine which prices this discount interval applies to.
334 335 |
# File 'lib/orb/models/subscription.rb', line 334 required :filters, -> { Orb::Internal::Type::ArrayOf[Orb::Subscription::DiscountInterval::TieredPercentage::Filter] } |
#start_date ⇒ Time
The start date of the discount interval.
341 |
# File 'lib/orb/models/subscription.rb', line 341 required :start_date, Time |
#tiers ⇒ Array<Orb::Models::Subscription::DiscountInterval::TieredPercentage::Tier>
Only available if discount_type is tiered_percentage. The ordered, contiguous
bands of cumulative eligible spend, each discounted at its own percentage.
348 349 |
# File 'lib/orb/models/subscription.rb', line 348 required :tiers, -> { Orb::Internal::Type::ArrayOf[Orb::Subscription::DiscountInterval::TieredPercentage::Tier] } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/subscription.rb', line 419
|
Instance Method Details
#to_hash ⇒ {
195 |
# File 'sig/orb/models/subscription.rbs', line 195
def to_hash: -> {
|