Class: Orb::Models::SubscriptionAccountingSyncSucceededWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionAccountingSyncSucceededWebhookEvent
- Defined in:
- lib/orb/models/subscription_accounting_sync_succeeded_webhook_event.rb,
sig/orb/models/subscription_accounting_sync_succeeded_webhook_event.rbs
Defined Under Namespace
Modules: Type Classes: AccountingSyncRecord, Properties
Instance Attribute Summary collapse
- #accounting_sync_record ⇒ Orb::Models::SubscriptionAccountingSyncSucceededWebhookEvent::AccountingSyncRecord
-
#created_at ⇒ Time
The time at which this event was created, to the second.
-
#id ⇒ String
The ID of this webhook event.
- #properties ⇒ Orb::Models::SubscriptionAccountingSyncSucceededWebhookEvent::Properties
-
#subscription ⇒ Orb::Models::Subscription
A subscription represents the purchase of a plan by a customer.
-
#type ⇒ Symbol, Orb::Models::SubscriptionAccountingSyncSucceededWebhookEvent::Type
The event this payload describes.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(connection_type:) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(connection_type:) ⇒ Object
|
|
# File 'lib/orb/models/subscription_accounting_sync_succeeded_webhook_event.rb', line 59
|
Instance Attribute Details
#accounting_sync_record ⇒ Orb::Models::SubscriptionAccountingSyncSucceededWebhookEvent::AccountingSyncRecord
15 16 |
# File 'lib/orb/models/subscription_accounting_sync_succeeded_webhook_event.rb', line 15 required :accounting_sync_record, -> { Orb::SubscriptionAccountingSyncSucceededWebhookEvent::AccountingSyncRecord } |
#created_at ⇒ Time
The time at which this event was created, to the second.
22 |
# File 'lib/orb/models/subscription_accounting_sync_succeeded_webhook_event.rb', line 22 required :created_at, Time |
#id ⇒ String
The ID of this webhook event.
10 |
# File 'lib/orb/models/subscription_accounting_sync_succeeded_webhook_event.rb', line 10 required :id, String |
#properties ⇒ Orb::Models::SubscriptionAccountingSyncSucceededWebhookEvent::Properties
27 |
# File 'lib/orb/models/subscription_accounting_sync_succeeded_webhook_event.rb', line 27 required :properties, -> { Orb::SubscriptionAccountingSyncSucceededWebhookEvent::Properties } |
#subscription ⇒ Orb::Models::Subscription
A subscription represents the purchase of a plan by a customer.
By default, subscriptions begin on the day that they're created and renew automatically for each billing cycle at the cadence that's configured in the plan definition.
Subscriptions also default to beginning of month alignment, which means the
first invoice issued for the subscription will have pro-rated charges between
the start_date and the first of the following month. Subsequent billing
periods will always start and end on a month boundary (e.g. subsequent month
starts for monthly billing).
Depending on the plan configuration, any flat recurring fees will be billed either at the beginning (in-advance) or end (in-arrears) of each billing cycle. Plans default to in-advance billing. Usage-based fees are billed in arrears as usage is accumulated. In the normal course of events, you can expect an invoice to contain usage-based charges for the previous period, and a recurring fee for the following period.
51 |
# File 'lib/orb/models/subscription_accounting_sync_succeeded_webhook_event.rb', line 51 required :subscription, -> { Orb::Subscription } |
#type ⇒ Symbol, Orb::Models::SubscriptionAccountingSyncSucceededWebhookEvent::Type
The event this payload describes.
57 |
# File 'lib/orb/models/subscription_accounting_sync_succeeded_webhook_event.rb', line 57 required :type, enum: -> { Orb::SubscriptionAccountingSyncSucceededWebhookEvent::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/subscription_accounting_sync_succeeded_webhook_event.rb', line 143
|
Instance Method Details
#to_hash ⇒ {
35 |
# File 'sig/orb/models/subscription_accounting_sync_succeeded_webhook_event.rbs', line 35
def to_hash: -> {
|