Class: Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/subscription_alert_disabled_webhook_event.rb,
sig/orb/models/subscription_alert_disabled_webhook_event.rbs

Overview

See Also:

  • Orb::Models::SubscriptionAlertDisabledWebhookEvent#properties

Defined Under Namespace

Modules: Reason Classes: AlertConfiguration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(value:) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::ThresholdOverride::Threshold for more details.

Thresholds are used to define the conditions under which an alert will be triggered.

Parameters:

  • value (String) —

    The value at which an alert will fire. For credit balance alerts, the alert will



# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 84

Instance Attribute Details

#alert_configuration ⇒ Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration

Alerts within Orb monitor spending, usage, or credit balance and trigger webhooks when a threshold is exceeded.

Alerts created through the API can be scoped to either customers or subscriptions.

Parameters:

  • value (Orb::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration)

Returns:



66
67
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 66

required :alert_configuration,
-> { Orb::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration }

#cardinality ⇒ Integer?

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


72
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 72

required :cardinality, Integer, nil?: true

#cardinality_limit ⇒ Integer?

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


77
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 77

required :cardinality_limit, Integer, nil?: true

#reason ⇒ Symbol, Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties::Reason

Parameters:

  • value (Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties::reason)

Returns:



82
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 82

required :reason, enum: -> { Orb::SubscriptionAlertDisabledWebhookEvent::Properties::Reason }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


63
# File 'sig/orb/models/subscription_alert_disabled_webhook_event.rbs', line 63

def to_hash: -> {