Class: Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration
- Defined in:
- lib/orb/models/subscription_alert_disabled_webhook_event.rb,
sig/orb/models/subscription_alert_disabled_webhook_event.rbs
Overview
Defined Under Namespace
Modules: Type Classes: BalanceAlertStatus, LicenseType, Metric, Plan, PriceFilter, Threshold, ThresholdOverride
Instance Attribute Summary collapse
-
#balance_alert_status ⇒ Array<Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::BalanceAlertStatus>?
The current status of the alert.
-
#created_at ⇒ Time
The creation time of the resource in Orb.
-
#currency ⇒ String?
The name of the currency the credit balance or invoice cost is denominated in.
-
#customer ⇒ Orb::Models::CustomerMinified?
The customer the alert applies to.
-
#enabled ⇒ Boolean
Whether the alert is enabled or disabled.
-
#grouping_keys ⇒ Array<String>?
The property keys to group cost alerts by.
-
#id ⇒ String
Also referred to as alert_id in this documentation.
-
#license_type ⇒ Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::LicenseType?
Minified license type for alert serialization.
-
#metric ⇒ Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::Metric?
The metric the alert applies to.
-
#plan ⇒ Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::Plan?
The plan the alert applies to.
-
#price_filters ⇒ Array<Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::PriceFilter>?
Filters scoping which prices are included in spend and grouped cost alert evaluation.
-
#subscription ⇒ Orb::Models::SubscriptionMinified?
The subscription the alert applies to.
-
#threshold_overrides ⇒ Array<Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::ThresholdOverride>?
Per-group threshold overrides.
-
#thresholds ⇒ Array<Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::Threshold>?
The thresholds that define the conditions under which the alert will be triggered.
-
#type ⇒ Symbol, Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::Type
The type of alert.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:) ⇒ Object
constructor
Minified license type for alert serialization.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:) ⇒ Object
Minified license type for alert serialization.
|
|
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 224
|
Instance Attribute Details
#balance_alert_status ⇒ Array<Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::BalanceAlertStatus>?
The current status of the alert. This field is only present for credit balance alerts.
177 178 179 180 181 |
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 177 optional :balance_alert_status, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::BalanceAlertStatus] }, nil?: true |
#created_at ⇒ Time
The creation time of the resource in Orb.
112 |
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 112 required :created_at, Time |
#currency ⇒ String?
The name of the currency the credit balance or invoice cost is denominated in.
118 |
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 118 required :currency, String, nil?: true |
#customer ⇒ Orb::Models::CustomerMinified?
The customer the alert applies to.
124 |
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 124 required :customer, -> { Orb::CustomerMinified }, nil?: true |
#enabled ⇒ Boolean
Whether the alert is enabled or disabled.
130 |
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 130 required :enabled, Orb::Internal::Type::Boolean |
#grouping_keys ⇒ Array<String>?
The property keys to group cost alerts by. Only present for cost alerts with grouping enabled.
188 |
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 188 optional :grouping_keys, Orb::Internal::Type::ArrayOf[String], nil?: true |
#id ⇒ String
Also referred to as alert_id in this documentation.
106 |
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 106 required :id, String |
#license_type ⇒ Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::LicenseType?
Minified license type for alert serialization.
194 195 196 197 198 |
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 194 optional :license_type, -> { Orb::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::LicenseType }, nil?: true |
#metric ⇒ Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::Metric?
The metric the alert applies to.
136 137 138 |
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 136 required :metric, -> { Orb::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::Metric }, nil?: true |
#plan ⇒ Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::Plan?
The plan the alert applies to.
144 145 146 |
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 144 required :plan, -> { Orb::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::Plan }, nil?: true |
#price_filters ⇒ Array<Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::PriceFilter>?
Filters scoping which prices are included in spend and grouped cost alert evaluation. Alerts use the price_id, item_id, and price_type fields only; the alert's pricing unit is reported by currency.
206 207 208 209 210 |
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 206 optional :price_filters, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::PriceFilter] }, nil?: true |
#subscription ⇒ Orb::Models::SubscriptionMinified?
The subscription the alert applies to.
152 |
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 152 required :subscription, -> { Orb::SubscriptionMinified }, nil?: true |
#threshold_overrides ⇒ Array<Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::ThresholdOverride>?
Per-group threshold overrides. Each override maps a specific combination of grouping_keys values to a replacement threshold list. Only present for grouped cost alerts that have at least one override.
218 219 220 221 222 |
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 218 optional :threshold_overrides, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::ThresholdOverride] }, nil?: true |
#thresholds ⇒ Array<Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::Threshold>?
The thresholds that define the conditions under which the alert will be triggered.
159 160 161 162 163 |
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 159 required :thresholds, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::Threshold] }, nil?: true |
#type ⇒ Symbol, Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::Type
The type of alert. This must be a valid alert type.
169 170 |
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 169 required :type, enum: -> { Orb::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 353
|
Instance Method Details
#to_hash ⇒ {
138 |
# File 'sig/orb/models/subscription_alert_disabled_webhook_event.rbs', line 138
def to_hash: -> {
|