Class: Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration::Plan

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/subscription_alert_disabled_webhook_event.rb,
sig/orb/models/subscription_alert_disabled_webhook_event.rbs

Overview

See Also:

  • Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties::AlertConfiguration#plan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



183
# File 'sig/orb/models/subscription_alert_disabled_webhook_event.rbs', line 183

def initialize: (

Instance Attribute Details

#external_plan_id ⇒ String?

An optional user-defined ID for this plan resource, used throughout the system as an alias for this Plan. Use this field to identify a plan by an existing identifier in your system.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


291
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 291

required :external_plan_id, String, nil?: true

#id ⇒ String?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


283
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 283

required :id, String, nil?: true

#name ⇒ String?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


296
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 296

required :name, String, nil?: true

#plan_version ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


301
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 301

required :plan_version, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


190
# File 'sig/orb/models/subscription_alert_disabled_webhook_event.rbs', line 190

def to_hash: -> {