Class: Orb::Models::SubscriptionChangeApplyParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/orb/models/subscription_change_apply_params.rb,
sig/orb/models/subscription_change_apply_params.rbs

Overview

See Also:

  • Orb::Resources::SubscriptionChanges#apply

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(subscription_change_id:, description: nil, mark_as_paid: nil, payment_external_id: nil, payment_notes: nil, payment_received_date: nil, previously_collected_amount: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::SubscriptionChangeApplyParams for more details.

Parameters:

  • subscription_change_id (String)
  • description (String, nil) (defaults to: nil)

    Description to apply to the balance transaction representing this credit.

  • mark_as_paid (Boolean, nil) (defaults to: nil)

    Mark all pending invoices that are payable as paid. If amount is also provided,

  • payment_external_id (String, nil) (defaults to: nil)

    An optional external ID to associate with the payment. Only applicable when mark

  • payment_notes (String, nil) (defaults to: nil)

    Optional notes about the payment. Only applicable when mark_as_paid is true.

  • payment_received_date (Date, nil) (defaults to: nil)

    A date string to specify the date the payment was received. Only applicable when

  • previously_collected_amount (String, nil) (defaults to: nil)

    Amount already collected to apply to the customer's balance. If mark_as_paid is

  • request_options (Orb::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/orb/models/subscription_change_apply_params.rb', line 55

Instance Attribute Details

#descriptionString?

Description to apply to the balance transaction representing this credit.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


19
# File 'lib/orb/models/subscription_change_apply_params.rb', line 19

optional :description, String, nil?: true

#mark_as_paidBoolean?

Mark all pending invoices that are payable as paid. If amount is also provided, mark as paid and credit the difference to the customer's balance.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


26
# File 'lib/orb/models/subscription_change_apply_params.rb', line 26

optional :mark_as_paid, Orb::Internal::Type::Boolean, nil?: true

#payment_external_idString?

An optional external ID to associate with the payment. Only applicable when mark_as_paid is true.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


33
# File 'lib/orb/models/subscription_change_apply_params.rb', line 33

optional :payment_external_id, String, nil?: true

#payment_notesString?

Optional notes about the payment. Only applicable when mark_as_paid is true.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


39
# File 'lib/orb/models/subscription_change_apply_params.rb', line 39

optional :payment_notes, String, nil?: true

#payment_received_dateDate?

A date string to specify the date the payment was received. Only applicable when mark_as_paid is true. If not provided, defaults to the current date.

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


46
# File 'lib/orb/models/subscription_change_apply_params.rb', line 46

optional :payment_received_date, Date, nil?: true

#previously_collected_amountString?

Amount already collected to apply to the customer's balance. If mark_as_paid is also provided, credit the difference to the customer's balance.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


53
# File 'lib/orb/models/subscription_change_apply_params.rb', line 53

optional :previously_collected_amount, String, nil?: true

#subscription_change_idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/orb/models/subscription_change_apply_params.rb', line 13

required :subscription_change_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


44
# File 'sig/orb/models/subscription_change_apply_params.rbs', line 44

def to_hash: -> {