Class: Orb::Models::SubscriptionChangeRetrieveResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionChangeRetrieveResponse
- Defined in:
- lib/orb/models/subscription_change_retrieve_response.rb,
sig/orb/models/subscription_change_retrieve_response.rbs
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#applied_at ⇒ Time?
When this change was applied.
-
#billing_cycle_alignment ⇒ String?
Billing cycle alignment for plan changes.
-
#cancelled_at ⇒ Time?
When this change was cancelled.
-
#change_option ⇒ String?
How the change is scheduled (e.g., 'immediate', 'end_of_subscription_term', 'requested_date').
-
#change_type ⇒ String
The type of change (e.g., 'schedule_plan_change', 'create_subscription').
-
#effective_date ⇒ Time?
When this change will take effect.
-
#expiration_time ⇒ Time
Subscription change will be cancelled at this time and can no longer be applied.
- #id ⇒ String
-
#plan_id ⇒ String?
The target plan ID for plan changes.
- #status ⇒ Symbol, Orb::Models::SubscriptionChangeRetrieveResponse::Status
- #subscription ⇒ Orb::Models::MutatedSubscription?
Instance Method Summary collapse
-
#initialize(id:, change_type:, expiration_time:, status:, subscription:, applied_at: nil, billing_cycle_alignment: nil, cancelled_at: nil, change_option: nil, effective_date: nil, plan_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see SubscriptionChangeRetrieveResponse for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, change_type:, expiration_time:, status:, subscription:, applied_at: nil, billing_cycle_alignment: nil, cancelled_at: nil, change_option: nil, effective_date: nil, plan_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::SubscriptionChangeRetrieveResponse for more details.
A subscription change represents a desired new subscription / pending change to
an existing subscription. It is a way to first preview the effects on the
subscription as well as any changes/creation of invoices (see
subscription.changed_resources).
|
|
# File 'lib/orb/models/subscription_change_retrieve_response.rb', line 71
|
Instance Attribute Details
#applied_at ⇒ Time?
When this change was applied.
38 |
# File 'lib/orb/models/subscription_change_retrieve_response.rb', line 38 optional :applied_at, Time, nil?: true |
#billing_cycle_alignment ⇒ String?
Billing cycle alignment for plan changes.
44 |
# File 'lib/orb/models/subscription_change_retrieve_response.rb', line 44 optional :billing_cycle_alignment, String, nil?: true |
#cancelled_at ⇒ Time?
When this change was cancelled.
50 |
# File 'lib/orb/models/subscription_change_retrieve_response.rb', line 50 optional :cancelled_at, Time, nil?: true |
#change_option ⇒ String?
How the change is scheduled (e.g., 'immediate', 'end_of_subscription_term', 'requested_date').
57 |
# File 'lib/orb/models/subscription_change_retrieve_response.rb', line 57 optional :change_option, String, nil?: true |
#change_type ⇒ String
The type of change (e.g., 'schedule_plan_change', 'create_subscription').
16 |
# File 'lib/orb/models/subscription_change_retrieve_response.rb', line 16 required :change_type, String |
#effective_date ⇒ Time?
When this change will take effect.
63 |
# File 'lib/orb/models/subscription_change_retrieve_response.rb', line 63 optional :effective_date, Time, nil?: true |
#expiration_time ⇒ Time
Subscription change will be cancelled at this time and can no longer be applied.
22 |
# File 'lib/orb/models/subscription_change_retrieve_response.rb', line 22 required :expiration_time, Time |
#id ⇒ String
10 |
# File 'lib/orb/models/subscription_change_retrieve_response.rb', line 10 required :id, String |
#plan_id ⇒ String?
The target plan ID for plan changes.
69 |
# File 'lib/orb/models/subscription_change_retrieve_response.rb', line 69 optional :plan_id, String, nil?: true |
#status ⇒ Symbol, Orb::Models::SubscriptionChangeRetrieveResponse::Status
27 |
# File 'lib/orb/models/subscription_change_retrieve_response.rb', line 27 required :status, enum: -> { Orb::Models::SubscriptionChangeRetrieveResponse::Status } |
#subscription ⇒ Orb::Models::MutatedSubscription?
32 |
# File 'lib/orb/models/subscription_change_retrieve_response.rb', line 32 required :subscription, -> { Orb::MutatedSubscription }, nil?: true |
Instance Method Details
#to_hash ⇒ {
55 |
# File 'sig/orb/models/subscription_change_retrieve_response.rbs', line 55
def to_hash: -> {
|