Class: Orb::Models::SubscriptionCostExceededWebhookEvent::Properties

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/subscription_cost_exceeded_webhook_event.rb,
sig/orb/models/subscription_cost_exceeded_webhook_event.rbs

Overview

See Also:

  • Orb::Models::SubscriptionCostExceededWebhookEvent#properties

Defined Under Namespace

Classes: AlertConfiguration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(alert_configuration:, amount_threshold:, evaluated_amount:, timeframe_end:, timeframe_start:) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::SubscriptionCostExceededWebhookEvent::Properties for more details.

Parameters:



# File 'lib/orb/models/subscription_cost_exceeded_webhook_event.rb', line 102


Instance Attribute Details

#alert_configuration ⇒ Orb::Models::SubscriptionCostExceededWebhookEvent::Properties::AlertConfiguration

Alerts within Orb monitor spending, usage, or credit balance and trigger webhooks when a threshold is exceeded.

Alerts created through the API can be scoped to either customers or subscriptions.

Parameters:

  • value (Orb::SubscriptionCostExceededWebhookEvent::Properties::AlertConfiguration)

Returns:



79
80
# File 'lib/orb/models/subscription_cost_exceeded_webhook_event.rb', line 79

required :alert_configuration,
-> { Orb::SubscriptionCostExceededWebhookEvent::Properties::AlertConfiguration }

#amount_threshold ⇒ String?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


85
# File 'lib/orb/models/subscription_cost_exceeded_webhook_event.rb', line 85

required :amount_threshold, String, nil?: true

#evaluated_amount ⇒ String?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


90
# File 'lib/orb/models/subscription_cost_exceeded_webhook_event.rb', line 90

required :evaluated_amount, String, nil?: true

#timeframe_end ⇒ Time

Parameters:

  • value (Time)

Returns:

  • (Time)


95
# File 'lib/orb/models/subscription_cost_exceeded_webhook_event.rb', line 95

required :timeframe_end, Time

#timeframe_start ⇒ Time

Parameters:

  • value (Time)

Returns:

  • (Time)


100
# File 'lib/orb/models/subscription_cost_exceeded_webhook_event.rb', line 100

required :timeframe_start, Time

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


67
# File 'sig/orb/models/subscription_cost_exceeded_webhook_event.rbs', line 67

def to_hash: -> {