Class: Orb::Models::SubscriptionCostExceededWebhookEvent::Properties::AlertConfiguration::ThresholdOverride::Threshold
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionCostExceededWebhookEvent::Properties::AlertConfiguration::ThresholdOverride::Threshold
- Defined in:
- lib/orb/models/subscription_cost_exceeded_webhook_event.rb,
sig/orb/models/subscription_cost_exceeded_webhook_event.rbs
Instance Attribute Summary collapse
-
#value ⇒ String
The value at which an alert will fire.
Instance Method Summary collapse
-
#initialize(group_values:, thresholds:, group_keys: nil) ⇒ Threshold
constructor
Some parameter documentations has been truncated, see Orb::Models::SubscriptionCostExceededWebhookEvent::Properties::AlertConfiguration::ThresholdOverride for more details.
- #to_hash ⇒ { value: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(group_values:, thresholds:, group_keys: nil) ⇒ Threshold
Some parameter documentations has been truncated, see Orb::Models::SubscriptionCostExceededWebhookEvent::Properties::AlertConfiguration::ThresholdOverride for more details.
A per-group threshold override on a grouped cost alert.
An empty thresholds list means the group is silenced (never fires). A
non-empty list fully replaces the default thresholds for that group.
504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 |
# File 'lib/orb/models/subscription_cost_exceeded_webhook_event.rb', line 504 class Threshold < Orb::Internal::Type::BaseModel # @!attribute value # The value at which an alert will fire. For credit balance alerts, the alert will # fire at or below this value. For usage and cost alerts, the alert will fire at # or above this value. # # @return [String] required :value, String # @!method initialize(value:) # Some parameter documentations has been truncated, see # {Orb::Models::SubscriptionCostExceededWebhookEvent::Properties::AlertConfiguration::ThresholdOverride::Threshold} # for more details. # # Thresholds are used to define the conditions under which an alert will be # triggered. # # @param value [String] The value at which an alert will fire. For credit balance alerts, the alert will end |
Instance Attribute Details
#value ⇒ String
The value at which an alert will fire. For credit balance alerts, the alert will fire at or below this value. For usage and cost alerts, the alert will fire at or above this value.
511 |
# File 'lib/orb/models/subscription_cost_exceeded_webhook_event.rb', line 511 required :value, String |
Instance Method Details
#to_hash ⇒ { value: String }
345 |
# File 'sig/orb/models/subscription_cost_exceeded_webhook_event.rbs', line 345
def to_hash: -> { value: String }
|