Class: Orb::Models::SubscriptionCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/orb/models/subscription_create_params.rb,
sig/orb/models/subscription_create_params.rbs

Overview

See Also:

  • Orb::Resources::Subscriptions#create

Defined Under Namespace

Modules: ExternalMarketplace Classes: AddAdjustment, AddPrice, RemoveAdjustment, RemovePrice, ReplaceAdjustment, ReplacePrice

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(external_price_id: nil, price_id: nil) ⇒ Object

Parameters:

  • external_price_id (String, nil) (defaults to: nil)

    The external price id of the price to remove on the subscription.

  • price_id (String, nil) (defaults to: nil)

    The id of the price to remove on the subscription.



# File 'lib/orb/models/subscription_create_params.rb', line 3030

Instance Attribute Details

#add_adjustmentsArray<Orb::Models::SubscriptionCreateParams::AddAdjustment>?

Additional adjustments to be added to the subscription. (Only available for accounts that have migrated off of legacy subscription overrides)

Parameters:

  • value (::Array[Orb::SubscriptionCreateParams::AddAdjustment], nil)

Returns:



15
16
17
# File 'lib/orb/models/subscription_create_params.rb', line 15

optional :add_adjustments,
-> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionCreateParams::AddAdjustment] },
nil?: true

#add_pricesArray<Orb::Models::SubscriptionCreateParams::AddPrice>?

Additional prices to be added to the subscription. (Only available for accounts that have migrated off of legacy subscription overrides)

Parameters:

  • value (::Array[Orb::SubscriptionCreateParams::AddPrice], nil)

Returns:



24
25
26
# File 'lib/orb/models/subscription_create_params.rb', line 24

optional :add_prices,
-> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionCreateParams::AddPrice] },
nil?: true

#align_billing_with_subscription_start_dateBoolean?

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


31
# File 'lib/orb/models/subscription_create_params.rb', line 31

optional :align_billing_with_subscription_start_date, Orb::Internal::Type::Boolean

#auto_collectionBoolean?

Determines whether issued invoices for this subscription will automatically be charged with the saved payment method on the due date. If not specified, this defaults to the behavior configured for this customer.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


39
# File 'lib/orb/models/subscription_create_params.rb', line 39

optional :auto_collection, Orb::Internal::Type::Boolean, nil?: true

#auto_issuanceBoolean?

Used to determine if invoices for this subscription will be automatically issued. If true, invoices will be automatically issued. If false, invoices will require manual approval. If null is specified, this defaults to the behavior configured for this customer.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


48
# File 'lib/orb/models/subscription_create_params.rb', line 48

optional :auto_issuance, Orb::Internal::Type::Boolean, nil?: true

#aws_regionString?

Deprecated.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


54
# File 'lib/orb/models/subscription_create_params.rb', line 54

optional :aws_region, String, nil?: true

#billing_cycle_anchor_configurationOrb::Models::BillingCycleAnchorConfiguration?



59
# File 'lib/orb/models/subscription_create_params.rb', line 59

optional :billing_cycle_anchor_configuration, -> { Orb::BillingCycleAnchorConfiguration }, nil?: true

#coupon_redemption_codeString?

Redemption code to be used for this subscription. If the coupon cannot be found by its redemption code, or cannot be redeemed, an error response will be returned and the subscription creation or plan change will not be scheduled.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


67
# File 'lib/orb/models/subscription_create_params.rb', line 67

optional :coupon_redemption_code, String, nil?: true

#credits_overage_rateFloat?

Deprecated.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


73
# File 'lib/orb/models/subscription_create_params.rb', line 73

optional :credits_overage_rate, Float, nil?: true

#currencyString?

The currency to use for the subscription. If not specified, the invoicing currency for the plan will be used.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


80
# File 'lib/orb/models/subscription_create_params.rb', line 80

optional :currency, String, nil?: true

#customer_idString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


85
# File 'lib/orb/models/subscription_create_params.rb', line 85

optional :customer_id, String, nil?: true

#default_invoice_memoString?

Determines the default memo on this subscription's invoices. Note that if this is not provided, it is determined by the plan configuration.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


92
# File 'lib/orb/models/subscription_create_params.rb', line 92

optional :default_invoice_memo, String, nil?: true

#end_dateTime?

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


97
# File 'lib/orb/models/subscription_create_params.rb', line 97

optional :end_date, Time, nil?: true

#external_customer_idString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


102
# File 'lib/orb/models/subscription_create_params.rb', line 102

optional :external_customer_id, String, nil?: true

#external_marketplaceSymbol, ...

Deprecated.

Parameters:

  • value (Orb::Models::SubscriptionCreateParams::external_marketplace, nil)

Returns:



108
109
110
# File 'lib/orb/models/subscription_create_params.rb', line 108

optional :external_marketplace,
enum: -> { Orb::SubscriptionCreateParams::ExternalMarketplace },
nil?: true

#external_marketplace_reporting_idString?

Deprecated.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


116
# File 'lib/orb/models/subscription_create_params.rb', line 116

optional :external_marketplace_reporting_id, String, nil?: true

#external_plan_idString?

The external_plan_id of the plan that the given subscription should be switched to. Note that either this property or plan_id must be specified.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


123
# File 'lib/orb/models/subscription_create_params.rb', line 123

optional :external_plan_id, String, nil?: true

#filterString?

An additional filter to apply to usage queries. This filter must be expressed as a boolean computed property. If null, usage queries will not include any additional filter.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


132
# File 'lib/orb/models/subscription_create_params.rb', line 132

optional :filter, String, nil?: true

#initial_phase_orderInteger?

The phase of the plan to start with

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


138
# File 'lib/orb/models/subscription_create_params.rb', line 138

optional :initial_phase_order, Integer, nil?: true

#invoicing_thresholdString?

When this subscription's accrued usage reaches this threshold, an invoice will be issued for the subscription. If not specified, invoices will only be issued at the end of the billing period.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


146
# File 'lib/orb/models/subscription_create_params.rb', line 146

optional :invoicing_threshold, String, nil?: true

#metadataHash{Symbol=>String, nil}?

User-specified key/value pairs for the resource. Individual keys can be removed by setting the value to null, and the entire metadata mapping can be cleared by setting metadata to null.

Parameters:

  • value (::Hash[Symbol, String?], nil)

Returns:

  • (Hash{Symbol=>String, nil}, nil)


154
# File 'lib/orb/models/subscription_create_params.rb', line 154

optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true

#nameString?

The name to use for the subscription. If not specified, the plan name will be used.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


161
# File 'lib/orb/models/subscription_create_params.rb', line 161

optional :name, String, nil?: true

#net_termsInteger?

The net terms determines the difference between the invoice date and the issue date for the invoice. If you intend the invoice to be due on issue, set this to 0. If not provided, this defaults to the value specified in the plan.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


169
# File 'lib/orb/models/subscription_create_params.rb', line 169

optional :net_terms, Integer, nil?: true

#per_credit_overage_amountFloat?

Deprecated.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


175
# File 'lib/orb/models/subscription_create_params.rb', line 175

optional :per_credit_overage_amount, Float, nil?: true

#plan_idString?

The plan that the given subscription should be switched to. Note that either this property or external_plan_id must be specified.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


182
# File 'lib/orb/models/subscription_create_params.rb', line 182

optional :plan_id, String, nil?: true

#plan_version_numberInteger?

Specifies which version of the plan to subscribe to. If null, the default version will be used.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


189
# File 'lib/orb/models/subscription_create_params.rb', line 189

optional :plan_version_number, Integer, nil?: true

#price_overridesArray<Object>?

Deprecated.

Optionally provide a list of overrides for prices on the plan

Parameters:

  • value (::Array[top], nil)

Returns:

  • (Array<Object>, nil)


197
# File 'lib/orb/models/subscription_create_params.rb', line 197

optional :price_overrides, Orb::Internal::Type::ArrayOf[Orb::Internal::Type::Unknown], nil?: true

#remove_adjustmentsArray<Orb::Models::SubscriptionCreateParams::RemoveAdjustment>?

Plan adjustments to be removed from the subscription. (Only available for accounts that have migrated off of legacy subscription overrides)

Parameters:

  • value (::Array[Orb::SubscriptionCreateParams::RemoveAdjustment], nil)

Returns:



204
205
206
# File 'lib/orb/models/subscription_create_params.rb', line 204

optional :remove_adjustments,
-> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionCreateParams::RemoveAdjustment] },
nil?: true

#remove_pricesArray<Orb::Models::SubscriptionCreateParams::RemovePrice>?

Plan prices to be removed from the subscription. (Only available for accounts that have migrated off of legacy subscription overrides)

Parameters:

  • value (::Array[Orb::SubscriptionCreateParams::RemovePrice], nil)

Returns:



213
214
215
# File 'lib/orb/models/subscription_create_params.rb', line 213

optional :remove_prices,
-> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionCreateParams::RemovePrice] },
nil?: true

#replace_adjustmentsArray<Orb::Models::SubscriptionCreateParams::ReplaceAdjustment>?

Plan adjustments to be replaced with additional adjustments on the subscription. (Only available for accounts that have migrated off of legacy subscription overrides)

Parameters:

  • value (::Array[Orb::SubscriptionCreateParams::ReplaceAdjustment], nil)

Returns:



223
224
225
# File 'lib/orb/models/subscription_create_params.rb', line 223

optional :replace_adjustments,
-> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionCreateParams::ReplaceAdjustment] },
nil?: true

#replace_pricesArray<Orb::Models::SubscriptionCreateParams::ReplacePrice>?

Plan prices to be replaced with additional prices on the subscription. (Only available for accounts that have migrated off of legacy subscription overrides)

Parameters:

  • value (::Array[Orb::SubscriptionCreateParams::ReplacePrice], nil)

Returns:



232
233
234
# File 'lib/orb/models/subscription_create_params.rb', line 232

optional :replace_prices,
-> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionCreateParams::ReplacePrice] },
nil?: true

#start_dateTime?

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


239
# File 'lib/orb/models/subscription_create_params.rb', line 239

optional :start_date, Time, nil?: true

#trial_duration_daysInteger?

The duration of the trial period in days. If not provided, this defaults to the value specified in the plan. If 0 is provided, the trial on the plan will be skipped.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


247
# File 'lib/orb/models/subscription_create_params.rb', line 247

optional :trial_duration_days, Integer, nil?: true

#usage_customer_idsArray<String>?

A list of customer IDs whose usage events will be aggregated and billed under this subscription. By default, a subscription only considers usage events associated with its attached customer's customer_id. When usage_customer_ids is provided, the subscription includes usage events from the specified customers only. Provided usage_customer_ids must be either the customer for this subscription itself, or any of that customer's children.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


258
# File 'lib/orb/models/subscription_create_params.rb', line 258

optional :usage_customer_ids, Orb::Internal::Type::ArrayOf[String], nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


154
# File 'sig/orb/models/subscription_create_params.rbs', line 154

def to_hash: -> {