Class: Orb::Models::SubscriptionCreateParams::AddPrice::Price::CumulativeGroupedAllocation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/subscription_create_params.rb,
sig/orb/models/subscription_create_params.rbs

Defined Under Namespace

Modules: Cadence Classes: CumulativeGroupedAllocationConfig

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(cadence:, cumulative_grouped_allocation_config:, item_id:, name:, billable_metric_id: nil, billed_in_advance: nil, billing_cycle_configuration: nil, conversion_rate: nil, conversion_rate_config: nil, currency: nil, dimensional_price_configuration: nil, external_price_id: nil, fixed_price_quantity: nil, invoice_grouping_key: nil, invoicing_cycle_configuration: nil, license_type_id: nil, metadata: nil, reference_id: nil, model_type: :cumulative_grouped_allocation) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::SubscriptionCreateParams::AddPrice::Price::CumulativeGroupedAllocation for more details.

Parameters:

  • cadence (Symbol, Orb::Models::SubscriptionCreateParams::AddPrice::Price::CumulativeGroupedAllocation::Cadence) —

    The cadence to bill for this price on.

  • cumulative_grouped_allocation_config (Orb::Models::SubscriptionCreateParams::AddPrice::Price::CumulativeGroupedAllocation::CumulativeGroupedAllocationConfig) —

    Configuration for cumulative_grouped_allocation pricing

  • item_id (String) —

    The id of the item the price will be associated with.

  • name (String) —

    The name of the price.

  • billable_metric_id (String, nil) (defaults to: nil) —

    The id of the billable metric for the price. Only needed if the price is usage-b

  • billed_in_advance (Boolean, nil) (defaults to: nil) —

    If the Price represents a fixed cost, the price will be billed in-advance if thi

  • billing_cycle_configuration (Orb::Models::NewBillingCycleConfiguration, nil) (defaults to: nil) —

    For custom cadence: specifies the duration of the billing period in days or mont

  • conversion_rate (Float, nil) (defaults to: nil) —

    The per unit conversion rate of the price currency to the invoicing currency.

  • conversion_rate_config (Orb::Models::UnitConversionRateConfig, Orb::Models::TieredConversionRateConfig, nil) (defaults to: nil) —

    The configuration for the rate of the price currency to the invoicing currency.

  • currency (String, nil) (defaults to: nil) —

    An ISO 4217 currency string, or custom pricing unit identifier, in which this pr

  • dimensional_price_configuration (Orb::Models::NewDimensionalPriceConfiguration, nil) (defaults to: nil) —

    For dimensional price: specifies a price group and dimension values

  • external_price_id (String, nil) (defaults to: nil) —

    An alias for the price.

  • fixed_price_quantity (Float, nil) (defaults to: nil) —

    If the Price represents a fixed cost, this represents the quantity of units appl

  • invoice_grouping_key (String, nil) (defaults to: nil) —

    The property used to group this price on an invoice

  • invoicing_cycle_configuration (Orb::Models::NewBillingCycleConfiguration, nil) (defaults to: nil) —

    Within each billing cycle, specifies the cadence at which invoices are produced.

  • license_type_id (String, nil) (defaults to: nil) —

    The ID of the license type to associate with this price. On a usage price this a

  • metadata (Hash{Symbol=>String, nil}, nil) (defaults to: nil) —

    User-specified key/value pairs for the resource. Individual keys can be removed

  • reference_id (String, nil) (defaults to: nil) —

    A transient ID that can be used to reference this price when adding adjustments

  • model_type (Symbol, :cumulative_grouped_allocation) (defaults to: :cumulative_grouped_allocation) —

    The pricing model type



# File 'lib/orb/models/subscription_create_params.rb', line 2518

Instance Attribute Details

#billable_metric_id ⇒ String?

The id of the billable metric for the price. Only needed if the price is usage-based.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2422
# File 'lib/orb/models/subscription_create_params.rb', line 2422

optional :billable_metric_id, String, nil?: true

#billed_in_advance ⇒ Boolean?

If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


2429
# File 'lib/orb/models/subscription_create_params.rb', line 2429

optional :billed_in_advance, Orb::Internal::Type::Boolean, nil?: true

#billing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?

For custom cadence: specifies the duration of the billing period in days or months.



2436
# File 'lib/orb/models/subscription_create_params.rb', line 2436

optional :billing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true

#cadence ⇒ Symbol, Orb::Models::SubscriptionCreateParams::AddPrice::Price::CumulativeGroupedAllocation::Cadence

The cadence to bill for this price on.

Parameters:

  • value (Orb::Models::SubscriptionCreateParams::AddPrice::Price::CumulativeGroupedAllocation::cadence)

Returns:



2389
2390
# File 'lib/orb/models/subscription_create_params.rb', line 2389

required :cadence,
enum: -> { Orb::SubscriptionCreateParams::AddPrice::Price::CumulativeGroupedAllocation::Cadence }

#conversion_rate ⇒ Float?

The per unit conversion rate of the price currency to the invoicing currency.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


2442
# File 'lib/orb/models/subscription_create_params.rb', line 2442

optional :conversion_rate, Float, nil?: true

#conversion_rate_config ⇒ Orb::Models::UnitConversionRateConfig, ...

The configuration for the rate of the price currency to the invoicing currency.

Parameters:

  • value (Orb::Models::conversion_rate_config, nil)

Returns:



2448
# File 'lib/orb/models/subscription_create_params.rb', line 2448

optional :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true

#cumulative_grouped_allocation_config ⇒ Orb::Models::SubscriptionCreateParams::AddPrice::Price::CumulativeGroupedAllocation::CumulativeGroupedAllocationConfig

Configuration for cumulative_grouped_allocation pricing

Parameters:

  • value (Orb::SubscriptionCreateParams::AddPrice::Price::CumulativeGroupedAllocation::CumulativeGroupedAllocationConfig)

Returns:



2396
2397
# File 'lib/orb/models/subscription_create_params.rb', line 2396

required :cumulative_grouped_allocation_config,
-> { Orb::SubscriptionCreateParams::AddPrice::Price::CumulativeGroupedAllocation::CumulativeGroupedAllocationConfig }

#currency ⇒ String?

An ISO 4217 currency string, or custom pricing unit identifier, in which this price is billed.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2455
# File 'lib/orb/models/subscription_create_params.rb', line 2455

optional :currency, String, nil?: true

#dimensional_price_configuration ⇒ Orb::Models::NewDimensionalPriceConfiguration?

For dimensional price: specifies a price group and dimension values



2461
2462
2463
2464
2465
# File 'lib/orb/models/subscription_create_params.rb', line 2461

optional :dimensional_price_configuration,
-> {
  Orb::NewDimensionalPriceConfiguration
},
nil?: true

#external_price_id ⇒ String?

An alias for the price.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2471
# File 'lib/orb/models/subscription_create_params.rb', line 2471

optional :external_price_id, String, nil?: true

#fixed_price_quantity ⇒ Float?

If the Price represents a fixed cost, this represents the quantity of units applied.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


2478
# File 'lib/orb/models/subscription_create_params.rb', line 2478

optional :fixed_price_quantity, Float, nil?: true

#invoice_grouping_key ⇒ String?

The property used to group this price on an invoice

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2484
# File 'lib/orb/models/subscription_create_params.rb', line 2484

optional :invoice_grouping_key, String, nil?: true

#invoicing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?

Within each billing cycle, specifies the cadence at which invoices are produced. If unspecified, a single invoice is produced per billing cycle.



2491
# File 'lib/orb/models/subscription_create_params.rb', line 2491

optional :invoicing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true

#item_id ⇒ String

The id of the item the price will be associated with.

Parameters:

  • value (String)

Returns:

  • (String)


2403
# File 'lib/orb/models/subscription_create_params.rb', line 2403

required :item_id, String

#license_type_id ⇒ String?

The ID of the license type to associate with this price. On a usage price this also marks the price as eligible to draw down from that license type's allocation; a usage price created without it is billed normally. Usage prices with a license type must use the unit model, and only draw down when their currency matches the allocation's.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2501
# File 'lib/orb/models/subscription_create_params.rb', line 2501

optional :license_type_id, String, nil?: true

#metadata ⇒ Hash{Symbol=>String, nil}?

User-specified key/value pairs for the resource. Individual keys can be removed by setting the value to null, and the entire metadata mapping can be cleared by setting metadata to null.

Parameters:

  • value (::Hash[Symbol, String?], nil)

Returns:

  • (Hash{Symbol=>String, nil}, nil)


2509
# File 'lib/orb/models/subscription_create_params.rb', line 2509

optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true

#model_type ⇒ Symbol, :cumulative_grouped_allocation

The pricing model type

Parameters:

  • value (:cumulative_grouped_allocation)

Returns:

  • (Symbol, :cumulative_grouped_allocation)


2409
# File 'lib/orb/models/subscription_create_params.rb', line 2409

required :model_type, const: :cumulative_grouped_allocation

#name ⇒ String

The name of the price.

Parameters:

  • value (String)

Returns:

  • (String)


2415
# File 'lib/orb/models/subscription_create_params.rb', line 2415

required :name, String

#reference_id ⇒ String?

A transient ID that can be used to reference this price when adding adjustments in the same API call.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2516
# File 'lib/orb/models/subscription_create_params.rb', line 2516

optional :reference_id, String, nil?: true

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/orb/models/subscription_create_params.rb', line 2574

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


1705
# File 'sig/orb/models/subscription_create_params.rbs', line 1705

def to_hash: -> {