Class: Orb::Models::SubscriptionCreateParams::AddPrice::Price::EventOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/subscription_create_params.rb,
sig/orb/models/subscription_create_params.rbs

Defined Under Namespace

Modules: Cadence Classes: EventOutputConfig

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(cadence:, event_output_config:, item_id:, name:, billable_metric_id: nil, billed_in_advance: nil, billing_cycle_configuration: nil, conversion_rate: nil, conversion_rate_config: nil, currency: nil, dimensional_price_configuration: nil, external_price_id: nil, fixed_price_quantity: nil, invoice_grouping_key: nil, invoicing_cycle_configuration: nil, license_type_id: nil, metadata: nil, reference_id: nil, model_type: :event_output) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::SubscriptionCreateParams::AddPrice::Price::EventOutput for more details.

Parameters:

  • cadence (Symbol, Orb::Models::SubscriptionCreateParams::AddPrice::Price::EventOutput::Cadence)

    The cadence to bill for this price on.

  • event_output_config (Orb::Models::SubscriptionCreateParams::AddPrice::Price::EventOutput::EventOutputConfig)

    Configuration for event_output pricing

  • item_id (String)

    The id of the item the price will be associated with.

  • name (String)

    The name of the price.

  • billable_metric_id (String, nil) (defaults to: nil)

    The id of the billable metric for the price. Only needed if the price is usage-b

  • billed_in_advance (Boolean, nil) (defaults to: nil)

    If the Price represents a fixed cost, the price will be billed in-advance if thi

  • billing_cycle_configuration (Orb::Models::NewBillingCycleConfiguration, nil) (defaults to: nil)

    For custom cadence: specifies the duration of the billing period in days or mont

  • conversion_rate (Float, nil) (defaults to: nil)

    The per unit conversion rate of the price currency to the invoicing currency.

  • conversion_rate_config (Orb::Models::UnitConversionRateConfig, Orb::Models::TieredConversionRateConfig, nil) (defaults to: nil)

    The configuration for the rate of the price currency to the invoicing currency.

  • currency (String, nil) (defaults to: nil)

    An ISO 4217 currency string, or custom pricing unit identifier, in which this pr

  • dimensional_price_configuration (Orb::Models::NewDimensionalPriceConfiguration, nil) (defaults to: nil)

    For dimensional price: specifies a price group and dimension values

  • external_price_id (String, nil) (defaults to: nil)

    An alias for the price.

  • fixed_price_quantity (Float, nil) (defaults to: nil)

    If the Price represents a fixed cost, this represents the quantity of units appl

  • invoice_grouping_key (String, nil) (defaults to: nil)

    The property used to group this price on an invoice

  • invoicing_cycle_configuration (Orb::Models::NewBillingCycleConfiguration, nil) (defaults to: nil)

    Within each billing cycle, specifies the cadence at which invoices are produced.

  • license_type_id (String, nil) (defaults to: nil)

    The ID of the license type to associate with this price.

  • metadata (Hash{Symbol=>String, nil}, nil) (defaults to: nil)

    User-specified key/value pairs for the resource. Individual keys can be removed

  • reference_id (String, nil) (defaults to: nil)

    A transient ID that can be used to reference this price when adding adjustments

  • model_type (Symbol, :event_output) (defaults to: :event_output)

    The pricing model type



# File 'lib/orb/models/subscription_create_params.rb', line 2947

Instance Attribute Details

#billable_metric_idString?

The id of the billable metric for the price. Only needed if the price is usage-based.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2855
# File 'lib/orb/models/subscription_create_params.rb', line 2855

optional :billable_metric_id, String, nil?: true

#billed_in_advanceBoolean?

If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


2862
# File 'lib/orb/models/subscription_create_params.rb', line 2862

optional :billed_in_advance, Orb::Internal::Type::Boolean, nil?: true

#billing_cycle_configurationOrb::Models::NewBillingCycleConfiguration?

For custom cadence: specifies the duration of the billing period in days or months.



2869
# File 'lib/orb/models/subscription_create_params.rb', line 2869

optional :billing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true

#cadenceSymbol, Orb::Models::SubscriptionCreateParams::AddPrice::Price::EventOutput::Cadence

The cadence to bill for this price on.

Parameters:

  • value (Orb::Models::SubscriptionCreateParams::AddPrice::Price::EventOutput::cadence)

Returns:



2823
# File 'lib/orb/models/subscription_create_params.rb', line 2823

required :cadence, enum: -> { Orb::SubscriptionCreateParams::AddPrice::Price::EventOutput::Cadence }

#conversion_rateFloat?

The per unit conversion rate of the price currency to the invoicing currency.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


2875
# File 'lib/orb/models/subscription_create_params.rb', line 2875

optional :conversion_rate, Float, nil?: true

#conversion_rate_configOrb::Models::UnitConversionRateConfig, ...

The configuration for the rate of the price currency to the invoicing currency.

Parameters:

  • value (Orb::Models::conversion_rate_config, nil)

Returns:



2881
# File 'lib/orb/models/subscription_create_params.rb', line 2881

optional :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true

#currencyString?

An ISO 4217 currency string, or custom pricing unit identifier, in which this price is billed.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2888
# File 'lib/orb/models/subscription_create_params.rb', line 2888

optional :currency, String, nil?: true

#dimensional_price_configurationOrb::Models::NewDimensionalPriceConfiguration?

For dimensional price: specifies a price group and dimension values



2894
2895
2896
2897
2898
# File 'lib/orb/models/subscription_create_params.rb', line 2894

optional :dimensional_price_configuration,
-> {
  Orb::NewDimensionalPriceConfiguration
},
nil?: true

#event_output_configOrb::Models::SubscriptionCreateParams::AddPrice::Price::EventOutput::EventOutputConfig

Configuration for event_output pricing

Parameters:

  • value (Orb::SubscriptionCreateParams::AddPrice::Price::EventOutput::EventOutputConfig)

Returns:



2829
2830
# File 'lib/orb/models/subscription_create_params.rb', line 2829

required :event_output_config,
-> { Orb::SubscriptionCreateParams::AddPrice::Price::EventOutput::EventOutputConfig }

#external_price_idString?

An alias for the price.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2904
# File 'lib/orb/models/subscription_create_params.rb', line 2904

optional :external_price_id, String, nil?: true

#fixed_price_quantityFloat?

If the Price represents a fixed cost, this represents the quantity of units applied.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


2911
# File 'lib/orb/models/subscription_create_params.rb', line 2911

optional :fixed_price_quantity, Float, nil?: true

#invoice_grouping_keyString?

The property used to group this price on an invoice

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2917
# File 'lib/orb/models/subscription_create_params.rb', line 2917

optional :invoice_grouping_key, String, nil?: true

#invoicing_cycle_configurationOrb::Models::NewBillingCycleConfiguration?

Within each billing cycle, specifies the cadence at which invoices are produced. If unspecified, a single invoice is produced per billing cycle.



2924
# File 'lib/orb/models/subscription_create_params.rb', line 2924

optional :invoicing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true

#item_idString

The id of the item the price will be associated with.

Parameters:

  • value (String)

Returns:

  • (String)


2836
# File 'lib/orb/models/subscription_create_params.rb', line 2836

required :item_id, String

#license_type_idString?

The ID of the license type to associate with this price.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2930
# File 'lib/orb/models/subscription_create_params.rb', line 2930

optional :license_type_id, String, nil?: true

#metadataHash{Symbol=>String, nil}?

User-specified key/value pairs for the resource. Individual keys can be removed by setting the value to null, and the entire metadata mapping can be cleared by setting metadata to null.

Parameters:

  • value (::Hash[Symbol, String?], nil)

Returns:

  • (Hash{Symbol=>String, nil}, nil)


2938
# File 'lib/orb/models/subscription_create_params.rb', line 2938

optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true

#model_typeSymbol, :event_output

The pricing model type

Parameters:

  • value (:event_output)

Returns:

  • (Symbol, :event_output)


2842
# File 'lib/orb/models/subscription_create_params.rb', line 2842

required :model_type, const: :event_output

#nameString

The name of the price.

Parameters:

  • value (String)

Returns:

  • (String)


2848
# File 'lib/orb/models/subscription_create_params.rb', line 2848

required :name, String

#reference_idString?

A transient ID that can be used to reference this price when adding adjustments in the same API call.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2945
# File 'lib/orb/models/subscription_create_params.rb', line 2945

optional :reference_id, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/orb/models/subscription_create_params.rb', line 3003

Instance Method Details

#to_hash{

Returns:

  • ({)


2014
# File 'sig/orb/models/subscription_create_params.rbs', line 2014

def to_hash: -> {