Class: Orb::Models::SubscriptionCreateParams::AddPrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::ThresholdDiscountGroup
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionCreateParams::AddPrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::ThresholdDiscountGroup
- Defined in:
- lib/orb/models/subscription_create_params.rb,
sig/orb/models/subscription_create_params.rbs
Instance Attribute Summary collapse
-
#above_threshold_discount_percentage ⇒ String
Discount rate applied to spend above the threshold.
-
#below_threshold_discount_percentage ⇒ String
Discount rate applied to spend at or below the threshold.
-
#cell_coordinates ⇒ String
Semicolon-separated list of matrix cell coordinates targeted by this group.
- #description ⇒ String?
- #threshold_amount ⇒ String
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
908 |
# File 'sig/orb/models/subscription_create_params.rbs', line 908
def initialize: (
|
Instance Attribute Details
#above_threshold_discount_percentage ⇒ String
Discount rate applied to spend above the threshold.
1321 |
# File 'lib/orb/models/subscription_create_params.rb', line 1321 required :above_threshold_discount_percentage, String |
#below_threshold_discount_percentage ⇒ String
Discount rate applied to spend at or below the threshold. Set to 0 for no baseline discount.
1328 |
# File 'lib/orb/models/subscription_create_params.rb', line 1328 required :below_threshold_discount_percentage, String |
#cell_coordinates ⇒ String
Semicolon-separated list of matrix cell coordinates targeted by this group. Each
coordinate is first,second when the matrix has two dimensions, or just first
for a single-dimension matrix. Example: blue,circle;green,triangle.
1336 |
# File 'lib/orb/models/subscription_create_params.rb', line 1336 required :cell_coordinates, String |
#description ⇒ String?
1346 |
# File 'lib/orb/models/subscription_create_params.rb', line 1346 optional :description, String, nil?: true |
#threshold_amount ⇒ String
1341 |
# File 'lib/orb/models/subscription_create_params.rb', line 1341 required :threshold_amount, String |
Instance Method Details
#to_hash ⇒ {
916 |
# File 'sig/orb/models/subscription_create_params.rbs', line 916
def to_hash: -> {
|