Class: Orb::Models::SubscriptionCreateParams::AddPrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/subscription_create_params.rb,
sig/orb/models/subscription_create_params.rbs

Overview

See Also:

  • Orb::Models::SubscriptionCreateParams::AddPrice::Price::TieredMatrixWithAllocation#tiered_matrix_with_allocation_config

Defined Under Namespace

Classes: Tier

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



1022
# File 'sig/orb/models/subscription_create_params.rbs', line 1022

def initialize: (

Instance Attribute Details

#allocation ⇒ String

Usage allocation, pooled across all matrix cells

Parameters:

  • value (String)

Returns:

  • (String)


1518
# File 'lib/orb/models/subscription_create_params.rb', line 1518

required :allocation, String

#default_unit_amount ⇒ String

Per unit rate for usage whose matrix cell has no configured tiers

Parameters:

  • value (String)

Returns:

  • (String)


1524
# File 'lib/orb/models/subscription_create_params.rb', line 1524

required :default_unit_amount, String

#dimensions ⇒ Array<String>

One or two event property values to evaluate matrix cells by

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


1530
# File 'lib/orb/models/subscription_create_params.rb', line 1530

required :dimensions, Orb::Internal::Type::ArrayOf[String]

#tiers ⇒ Array<Orb::Models::SubscriptionCreateParams::AddPrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier>

Graduated tiers keyed by matrix cell; usage in a cell is tiered only against its own rows

Parameters:

  • value (::Array[Orb::SubscriptionCreateParams::AddPrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier])

Returns:



1537
1538
1539
1540
1541
1542
# File 'lib/orb/models/subscription_create_params.rb', line 1537

required :tiers,
-> do
  Orb::Internal::Type::ArrayOf[
    Orb::SubscriptionCreateParams::AddPrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier
  ]
end

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


1029
# File 'sig/orb/models/subscription_create_params.rbs', line 1029

def to_hash: -> {