Class: Orb::Models::SubscriptionCreateParams::AddPrice::Price::TieredWithProration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionCreateParams::AddPrice::Price::TieredWithProration
- Defined in:
- lib/orb/models/subscription_create_params.rb,
sig/orb/models/subscription_create_params.rbs
Defined Under Namespace
Modules: Cadence Classes: TieredWithProrationConfig
Instance Attribute Summary collapse
-
#billable_metric_id ⇒ String?
The id of the billable metric for the price.
-
#billed_in_advance ⇒ Boolean?
If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.
-
#billing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
For custom cadence: specifies the duration of the billing period in days or months.
-
#cadence ⇒ Symbol, Orb::Models::SubscriptionCreateParams::AddPrice::Price::TieredWithProration::Cadence
The cadence to bill for this price on.
-
#conversion_rate ⇒ Float?
The per unit conversion rate of the price currency to the invoicing currency.
-
#conversion_rate_config ⇒ Orb::Models::UnitConversionRateConfig, ...
The configuration for the rate of the price currency to the invoicing currency.
-
#currency ⇒ String?
An ISO 4217 currency string, or custom pricing unit identifier, in which this price is billed.
-
#dimensional_price_configuration ⇒ Orb::Models::NewDimensionalPriceConfiguration?
For dimensional price: specifies a price group and dimension values.
-
#external_price_id ⇒ String?
An alias for the price.
-
#fixed_price_quantity ⇒ Float?
If the Price represents a fixed cost, this represents the quantity of units applied.
-
#invoice_grouping_key ⇒ String?
The property used to group this price on an invoice.
-
#invoicing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
Within each billing cycle, specifies the cadence at which invoices are produced.
-
#item_id ⇒ String
The id of the item the price will be associated with.
-
#license_type_id ⇒ String?
The ID of the license type to associate with this price.
-
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource.
-
#model_type ⇒ Symbol, :tiered_with_proration
The pricing model type.
-
#name ⇒ String
The name of the price.
-
#reference_id ⇒ String?
A transient ID that can be used to reference this price when adding adjustments in the same API call.
-
#tiered_with_proration_config ⇒ Orb::Models::SubscriptionCreateParams::AddPrice::Price::TieredWithProration::TieredWithProrationConfig
Configuration for tiered_with_proration pricing.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(cadence:, item_id:, name:, tiered_with_proration_config:, billable_metric_id: nil, billed_in_advance: nil, billing_cycle_configuration: nil, conversion_rate: nil, conversion_rate_config: nil, currency: nil, dimensional_price_configuration: nil, external_price_id: nil, fixed_price_quantity: nil, invoice_grouping_key: nil, invoicing_cycle_configuration: nil, license_type_id: nil, metadata: nil, reference_id: nil, model_type: :tiered_with_proration) ⇒ Object
constructor
Some parameter documentations has been truncated, see TieredWithProration for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cadence:, item_id:, name:, tiered_with_proration_config:, billable_metric_id: nil, billed_in_advance: nil, billing_cycle_configuration: nil, conversion_rate: nil, conversion_rate_config: nil, currency: nil, dimensional_price_configuration: nil, external_price_id: nil, fixed_price_quantity: nil, invoice_grouping_key: nil, invoicing_cycle_configuration: nil, license_type_id: nil, metadata: nil, reference_id: nil, model_type: :tiered_with_proration) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::SubscriptionCreateParams::AddPrice::Price::TieredWithProration for more details.
|
|
# File 'lib/orb/models/subscription_create_params.rb', line 1496
|
Instance Attribute Details
#billable_metric_id ⇒ String?
The id of the billable metric for the price. Only needed if the price is usage-based.
1404 |
# File 'lib/orb/models/subscription_create_params.rb', line 1404 optional :billable_metric_id, String, nil?: true |
#billed_in_advance ⇒ Boolean?
If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.
1411 |
# File 'lib/orb/models/subscription_create_params.rb', line 1411 optional :billed_in_advance, Orb::Internal::Type::Boolean, nil?: true |
#billing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
For custom cadence: specifies the duration of the billing period in days or months.
1418 |
# File 'lib/orb/models/subscription_create_params.rb', line 1418 optional :billing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true |
#cadence ⇒ Symbol, Orb::Models::SubscriptionCreateParams::AddPrice::Price::TieredWithProration::Cadence
The cadence to bill for this price on.
1371 1372 |
# File 'lib/orb/models/subscription_create_params.rb', line 1371 required :cadence, enum: -> { Orb::SubscriptionCreateParams::AddPrice::Price::TieredWithProration::Cadence } |
#conversion_rate ⇒ Float?
The per unit conversion rate of the price currency to the invoicing currency.
1424 |
# File 'lib/orb/models/subscription_create_params.rb', line 1424 optional :conversion_rate, Float, nil?: true |
#conversion_rate_config ⇒ Orb::Models::UnitConversionRateConfig, ...
The configuration for the rate of the price currency to the invoicing currency.
1430 |
# File 'lib/orb/models/subscription_create_params.rb', line 1430 optional :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true |
#currency ⇒ String?
An ISO 4217 currency string, or custom pricing unit identifier, in which this price is billed.
1437 |
# File 'lib/orb/models/subscription_create_params.rb', line 1437 optional :currency, String, nil?: true |
#dimensional_price_configuration ⇒ Orb::Models::NewDimensionalPriceConfiguration?
For dimensional price: specifies a price group and dimension values
1443 1444 1445 1446 1447 |
# File 'lib/orb/models/subscription_create_params.rb', line 1443 optional :dimensional_price_configuration, -> { Orb::NewDimensionalPriceConfiguration }, nil?: true |
#external_price_id ⇒ String?
An alias for the price.
1453 |
# File 'lib/orb/models/subscription_create_params.rb', line 1453 optional :external_price_id, String, nil?: true |
#fixed_price_quantity ⇒ Float?
If the Price represents a fixed cost, this represents the quantity of units applied.
1460 |
# File 'lib/orb/models/subscription_create_params.rb', line 1460 optional :fixed_price_quantity, Float, nil?: true |
#invoice_grouping_key ⇒ String?
The property used to group this price on an invoice
1466 |
# File 'lib/orb/models/subscription_create_params.rb', line 1466 optional :invoice_grouping_key, String, nil?: true |
#invoicing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
Within each billing cycle, specifies the cadence at which invoices are produced. If unspecified, a single invoice is produced per billing cycle.
1473 |
# File 'lib/orb/models/subscription_create_params.rb', line 1473 optional :invoicing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true |
#item_id ⇒ String
The id of the item the price will be associated with.
1378 |
# File 'lib/orb/models/subscription_create_params.rb', line 1378 required :item_id, String |
#license_type_id ⇒ String?
The ID of the license type to associate with this price.
1479 |
# File 'lib/orb/models/subscription_create_params.rb', line 1479 optional :license_type_id, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource. Individual keys can be removed
by setting the value to null, and the entire metadata mapping can be cleared
by setting metadata to null.
1487 |
# File 'lib/orb/models/subscription_create_params.rb', line 1487 optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true |
#model_type ⇒ Symbol, :tiered_with_proration
The pricing model type
1384 |
# File 'lib/orb/models/subscription_create_params.rb', line 1384 required :model_type, const: :tiered_with_proration |
#name ⇒ String
The name of the price.
1390 |
# File 'lib/orb/models/subscription_create_params.rb', line 1390 required :name, String |
#reference_id ⇒ String?
A transient ID that can be used to reference this price when adding adjustments in the same API call.
1494 |
# File 'lib/orb/models/subscription_create_params.rb', line 1494 optional :reference_id, String, nil?: true |
#tiered_with_proration_config ⇒ Orb::Models::SubscriptionCreateParams::AddPrice::Price::TieredWithProration::TieredWithProrationConfig
Configuration for tiered_with_proration pricing
1396 1397 |
# File 'lib/orb/models/subscription_create_params.rb', line 1396 required :tiered_with_proration_config, -> { Orb::SubscriptionCreateParams::AddPrice::Price::TieredWithProration::TieredWithProrationConfig } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/subscription_create_params.rb', line 1552
|
Instance Method Details
#to_hash ⇒ {
1011 |
# File 'sig/orb/models/subscription_create_params.rbs', line 1011
def to_hash: -> {
|