Class: Orb::Models::SubscriptionCreateParams::RemovePrice

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/subscription_create_params.rb,
sig/orb/models/subscription_create_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



2118
# File 'sig/orb/models/subscription_create_params.rbs', line 2118

def initialize: (

Instance Attribute Details

#external_price_idString?

The external price id of the price to remove on the subscription.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3078
# File 'lib/orb/models/subscription_create_params.rb', line 3078

optional :external_price_id, String, nil?: true

#price_idString?

The id of the price to remove on the subscription.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3084
# File 'lib/orb/models/subscription_create_params.rb', line 3084

optional :price_id, String, nil?: true

Instance Method Details

#to_hash{ external_price_id: String?, price_id: String? }

Returns:

  • ({ external_price_id: String?, price_id: String? })


2123
# File 'sig/orb/models/subscription_create_params.rbs', line 2123

def to_hash: -> { external_price_id: String?, price_id: String? }