Class: Orb::Models::SubscriptionCreateParams::ReplaceAdjustment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionCreateParams::ReplaceAdjustment
- Defined in:
- lib/orb/models/subscription_create_params.rb,
sig/orb/models/subscription_create_params.rbs
Defined Under Namespace
Modules: Adjustment
Constant Summary collapse
- Orb =
Instance Attribute Summary collapse
-
#adjustment ⇒ Orb::Models::NewPercentageDiscount, ...
The definition of a new adjustment to create and add to the subscription.
-
#replaces_adjustment_id ⇒ String
The id of the adjustment on the plan to replace in the subscription.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(adjustment:, replaces_adjustment_id:) ⇒ Object
|
|
# File 'lib/orb/models/subscription_create_params.rb', line 3105
|
Instance Attribute Details
#adjustment ⇒ Orb::Models::NewPercentageDiscount, ...
The definition of a new adjustment to create and add to the subscription.
3097 |
# File 'lib/orb/models/subscription_create_params.rb', line 3097 required :adjustment, union: -> { Orb::SubscriptionCreateParams::ReplaceAdjustment::Adjustment } |
#replaces_adjustment_id ⇒ String
The id of the adjustment on the plan to replace in the subscription.
3103 |
# File 'lib/orb/models/subscription_create_params.rb', line 3103 required :replaces_adjustment_id, String |
Instance Method Details
#to_hash ⇒ {
2142 |
# File 'sig/orb/models/subscription_create_params.rbs', line 2142
def to_hash: -> {
|