Class: Orb::Models::SubscriptionCreateParams::ReplacePrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/subscription_create_params.rb,
sig/orb/models/subscription_create_params.rbs

Overview

See Also:

  • Orb::Models::SubscriptionCreateParams::ReplacePrice::Price::TieredMatrixWithAllocation#tiered_matrix_with_allocation_config

Defined Under Namespace

Classes: Tier

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



3312
# File 'sig/orb/models/subscription_create_params.rbs', line 3312

def initialize: (

Instance Attribute Details

#allocation ⇒ String

Usage allocation, pooled across all matrix cells

Parameters:

  • value (String)

Returns:

  • (String)


4822
# File 'lib/orb/models/subscription_create_params.rb', line 4822

required :allocation, String

#default_unit_amount ⇒ String

Per unit rate for usage whose matrix cell has no configured tiers

Parameters:

  • value (String)

Returns:

  • (String)


4828
# File 'lib/orb/models/subscription_create_params.rb', line 4828

required :default_unit_amount, String

#dimensions ⇒ Array<String>

One or two event property values to evaluate matrix cells by

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


4834
# File 'lib/orb/models/subscription_create_params.rb', line 4834

required :dimensions, Orb::Internal::Type::ArrayOf[String]

#tiers ⇒ Array<Orb::Models::SubscriptionCreateParams::ReplacePrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier>

Graduated tiers keyed by matrix cell; usage in a cell is tiered only against its own rows

Parameters:

  • value (::Array[Orb::SubscriptionCreateParams::ReplacePrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier])

Returns:



4841
4842
4843
4844
4845
4846
# File 'lib/orb/models/subscription_create_params.rb', line 4841

required :tiers,
-> do
  Orb::Internal::Type::ArrayOf[
    Orb::SubscriptionCreateParams::ReplacePrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier
  ]
end

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


3319
# File 'sig/orb/models/subscription_create_params.rbs', line 3319

def to_hash: -> {