Class: Orb::Models::SubscriptionFetchCostsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionFetchCostsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/orb/models/subscription_fetch_costs_params.rb,
sig/orb/models/subscription_fetch_costs_params.rbs
Overview
Defined Under Namespace
Modules: ViewMode
Instance Attribute Summary collapse
-
#currency ⇒ String?
The currency or custom pricing unit to use.
- #subscription_id ⇒ String
-
#timeframe_end ⇒ Time?
Costs returned are exclusive of
timeframe_end. -
#timeframe_start ⇒ Time?
Costs returned are inclusive of
timeframe_start. -
#view_mode ⇒ Symbol, ...
Controls whether Orb returns cumulative costs since the start of the billing period, or incremental day-by-day costs.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(subscription_id:, currency: nil, timeframe_end: nil, timeframe_start: nil, view_mode: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see SubscriptionFetchCostsParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(subscription_id:, currency: nil, timeframe_end: nil, timeframe_start: nil, view_mode: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::SubscriptionFetchCostsParams for more details.
|
|
# File 'lib/orb/models/subscription_fetch_costs_params.rb', line 42
|
Instance Attribute Details
#currency ⇒ String?
The currency or custom pricing unit to use.
19 |
# File 'lib/orb/models/subscription_fetch_costs_params.rb', line 19 optional :currency, String, nil?: true |
#subscription_id ⇒ String
13 |
# File 'lib/orb/models/subscription_fetch_costs_params.rb', line 13 required :subscription_id, String |
#timeframe_end ⇒ Time?
Costs returned are exclusive of timeframe_end.
25 |
# File 'lib/orb/models/subscription_fetch_costs_params.rb', line 25 optional :timeframe_end, Time, nil?: true |
#timeframe_start ⇒ Time?
Costs returned are inclusive of timeframe_start.
31 |
# File 'lib/orb/models/subscription_fetch_costs_params.rb', line 31 optional :timeframe_start, Time, nil?: true |
#view_mode ⇒ Symbol, ...
Controls whether Orb returns cumulative costs since the start of the billing period, or incremental day-by-day costs. If your customer has minimums or discounts, it's strongly recommended that you use the default cumulative behavior.
40 |
# File 'lib/orb/models/subscription_fetch_costs_params.rb', line 40 optional :view_mode, enum: -> { Orb::SubscriptionFetchCostsParams::ViewMode }, nil?: true |
Instance Method Details
#to_hash ⇒ {
36 |
# File 'sig/orb/models/subscription_fetch_costs_params.rbs', line 36
def to_hash: -> {
|