Class: Orb::Models::SubscriptionFetchScheduleResponse::Plan

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/subscription_fetch_schedule_response.rb,
sig/orb/models/subscription_fetch_schedule_response.rbs

Overview

See Also:

  • Orb::Models::SubscriptionFetchScheduleResponse#plan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, external_plan_id:, name:) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::SubscriptionFetchScheduleResponse::Plan for more details.

Parameters:

  • id (String, nil)
  • external_plan_id (String, nil)

    An optional user-defined ID for this plan resource, used throughout the system a

  • name (String, nil)


# File 'lib/orb/models/subscription_fetch_schedule_response.rb', line 53

Instance Attribute Details

#external_plan_idString?

An optional user-defined ID for this plan resource, used throughout the system as an alias for this Plan. Use this field to identify a plan by an existing identifier in your system.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


46
# File 'lib/orb/models/subscription_fetch_schedule_response.rb', line 46

required :external_plan_id, String, nil?: true

#idString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


38
# File 'lib/orb/models/subscription_fetch_schedule_response.rb', line 38

required :id, String, nil?: true

#nameString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


51
# File 'lib/orb/models/subscription_fetch_schedule_response.rb', line 51

required :name, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


49
# File 'sig/orb/models/subscription_fetch_schedule_response.rbs', line 49

def to_hash: -> {