Class: Orb::Models::SubscriptionGroupedCostExceededWebhookEvent::Properties

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb,
sig/orb/models/subscription_grouped_cost_exceeded_webhook_event.rbs

Overview

See Also:

  • Orb::Models::SubscriptionGroupedCostExceededWebhookEvent#properties

Defined Under Namespace

Classes: AlertConfiguration, Group

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(value:) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::ThresholdOverride::Threshold for more details.

Thresholds are used to define the conditions under which an alert will be triggered.

Parameters:

  • value (String) —

    The value at which an alert will fire. For credit balance alerts, the alert will



# File 'lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb', line 90

Instance Attribute Details

#alert_configuration ⇒ Orb::Models::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration

Alerts within Orb monitor spending, usage, or credit balance and trigger webhooks when a threshold is exceeded.

Alerts created through the API can be scoped to either customers or subscriptions.

Parameters:

  • value (Orb::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration)

Returns:



66
67
# File 'lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb', line 66

required :alert_configuration,
-> { Orb::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration }

#grouping_keys ⇒ Array<String>

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


72
# File 'lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb', line 72

required :grouping_keys, Orb::Internal::Type::ArrayOf[String]

#groups ⇒ Array<Orb::Models::SubscriptionGroupedCostExceededWebhookEvent::Properties::Group>

Parameters:

  • value (::Array[Orb::SubscriptionGroupedCostExceededWebhookEvent::Properties::Group])

Returns:



77
78
# File 'lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb', line 77

required :groups,
-> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionGroupedCostExceededWebhookEvent::Properties::Group] }

#timeframe_end ⇒ Time

Parameters:

  • value (Time)

Returns:

  • (Time)


83
# File 'lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb', line 83

required :timeframe_end, Time

#timeframe_start ⇒ Time

Parameters:

  • value (Time)

Returns:

  • (Time)


88
# File 'lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb', line 88

required :timeframe_start, Time

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


67
# File 'sig/orb/models/subscription_grouped_cost_exceeded_webhook_event.rbs', line 67

def to_hash: -> {