Class: Orb::Models::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration
- Defined in:
- lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb,
sig/orb/models/subscription_grouped_cost_exceeded_webhook_event.rbs
Overview
Defined Under Namespace
Modules: Type Classes: BalanceAlertStatus, LicenseType, Metric, Plan, PriceFilter, Threshold, ThresholdOverride
Instance Attribute Summary collapse
-
#balance_alert_status ⇒ Array<Orb::Models::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::BalanceAlertStatus>?
The current status of the alert.
-
#created_at ⇒ Time
The creation time of the resource in Orb.
-
#currency ⇒ String?
The name of the currency the credit balance or invoice cost is denominated in.
-
#customer ⇒ Orb::Models::CustomerMinified?
The customer the alert applies to.
-
#enabled ⇒ Boolean
Whether the alert is enabled or disabled.
-
#grouping_keys ⇒ Array<String>?
The property keys to group cost alerts by.
-
#id ⇒ String
Also referred to as alert_id in this documentation.
-
#license_type ⇒ Orb::Models::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::LicenseType?
Minified license type for alert serialization.
-
#metric ⇒ Orb::Models::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::Metric?
The metric the alert applies to.
-
#plan ⇒ Orb::Models::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::Plan?
The plan the alert applies to.
-
#price_filters ⇒ Array<Orb::Models::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::PriceFilter>?
Filters scoping which prices are included in spend and grouped cost alert evaluation.
-
#subscription ⇒ Orb::Models::SubscriptionMinified?
The subscription the alert applies to.
-
#threshold_overrides ⇒ Array<Orb::Models::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::ThresholdOverride>?
Per-group threshold overrides.
-
#thresholds ⇒ Array<Orb::Models::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::Threshold>?
The thresholds that define the conditions under which the alert will be triggered.
-
#type ⇒ Symbol, Orb::Models::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::Type
The type of alert.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:) ⇒ Object
constructor
Minified license type for alert serialization.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:) ⇒ Object
Minified license type for alert serialization.
|
|
# File 'lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb', line 236
|
Instance Attribute Details
#balance_alert_status ⇒ Array<Orb::Models::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::BalanceAlertStatus>?
The current status of the alert. This field is only present for credit balance alerts.
189 190 191 192 193 |
# File 'lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb', line 189 optional :balance_alert_status, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::BalanceAlertStatus] }, nil?: true |
#created_at ⇒ Time
The creation time of the resource in Orb.
120 |
# File 'lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb', line 120 required :created_at, Time |
#currency ⇒ String?
The name of the currency the credit balance or invoice cost is denominated in.
126 |
# File 'lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb', line 126 required :currency, String, nil?: true |
#customer ⇒ Orb::Models::CustomerMinified?
The customer the alert applies to.
132 |
# File 'lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb', line 132 required :customer, -> { Orb::CustomerMinified }, nil?: true |
#enabled ⇒ Boolean
Whether the alert is enabled or disabled.
138 |
# File 'lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb', line 138 required :enabled, Orb::Internal::Type::Boolean |
#grouping_keys ⇒ Array<String>?
The property keys to group cost alerts by. Only present for cost alerts with grouping enabled.
200 |
# File 'lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb', line 200 optional :grouping_keys, Orb::Internal::Type::ArrayOf[String], nil?: true |
#id ⇒ String
Also referred to as alert_id in this documentation.
114 |
# File 'lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb', line 114 required :id, String |
#license_type ⇒ Orb::Models::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::LicenseType?
Minified license type for alert serialization.
206 207 208 209 210 |
# File 'lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb', line 206 optional :license_type, -> { Orb::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::LicenseType }, nil?: true |
#metric ⇒ Orb::Models::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::Metric?
The metric the alert applies to.
144 145 146 147 148 |
# File 'lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb', line 144 required :metric, -> { Orb::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::Metric }, nil?: true |
#plan ⇒ Orb::Models::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::Plan?
The plan the alert applies to.
154 155 156 157 158 |
# File 'lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb', line 154 required :plan, -> { Orb::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::Plan }, nil?: true |
#price_filters ⇒ Array<Orb::Models::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::PriceFilter>?
Filters scoping which prices are included in spend and grouped cost alert evaluation. Alerts use the price_id, item_id, and price_type fields only; the alert's pricing unit is reported by currency.
218 219 220 221 222 |
# File 'lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb', line 218 optional :price_filters, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::PriceFilter] }, nil?: true |
#subscription ⇒ Orb::Models::SubscriptionMinified?
The subscription the alert applies to.
164 |
# File 'lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb', line 164 required :subscription, -> { Orb::SubscriptionMinified }, nil?: true |
#threshold_overrides ⇒ Array<Orb::Models::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::ThresholdOverride>?
Per-group threshold overrides. Each override maps a specific combination of grouping_keys values to a replacement threshold list. Only present for grouped cost alerts that have at least one override.
230 231 232 233 234 |
# File 'lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb', line 230 optional :threshold_overrides, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::ThresholdOverride] }, nil?: true |
#thresholds ⇒ Array<Orb::Models::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::Threshold>?
The thresholds that define the conditions under which the alert will be triggered.
171 172 173 174 175 |
# File 'lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb', line 171 required :thresholds, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::Threshold] }, nil?: true |
#type ⇒ Symbol, Orb::Models::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::Type
The type of alert. This must be a valid alert type.
181 182 |
# File 'lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb', line 181 required :type, enum: -> { Orb::SubscriptionGroupedCostExceededWebhookEvent::Properties::AlertConfiguration::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/subscription_grouped_cost_exceeded_webhook_event.rb', line 365
|
Instance Method Details
#to_hash ⇒ {
143 |
# File 'sig/orb/models/subscription_grouped_cost_exceeded_webhook_event.rbs', line 143
def to_hash: -> {
|