Class: Orb::Models::SubscriptionInvoicingThresholdExceededWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionInvoicingThresholdExceededWebhookEvent
- Defined in:
- lib/orb/models/subscription_invoicing_threshold_exceeded_webhook_event.rb,
sig/orb/models/subscription_invoicing_threshold_exceeded_webhook_event.rbs
Defined Under Namespace
Modules: Type Classes: Properties, Subscription
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The time at which this event was created, to the second.
-
#id ⇒ String
The ID of this webhook event.
- #properties ⇒ Orb::Models::SubscriptionInvoicingThresholdExceededWebhookEvent::Properties
-
#subscription ⇒ Orb::Models::SubscriptionInvoicingThresholdExceededWebhookEvent::Subscription
A lightweight subscription representation for webhook payloads.
-
#type ⇒ Symbol, Orb::Models::SubscriptionInvoicingThresholdExceededWebhookEvent::Type
The event this payload describes.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(evaluated_amount:, invoice_id:, invoicing_threshold:, threshold_invoice_created:) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(evaluated_amount:, invoice_id:, invoicing_threshold:, threshold_invoice_created:) ⇒ Object
|
|
# File 'lib/orb/models/subscription_invoicing_threshold_exceeded_webhook_event.rb', line 38
|
Instance Attribute Details
#created_at ⇒ Time
The time at which this event was created, to the second.
16 |
# File 'lib/orb/models/subscription_invoicing_threshold_exceeded_webhook_event.rb', line 16 required :created_at, Time |
#id ⇒ String
The ID of this webhook event.
10 |
# File 'lib/orb/models/subscription_invoicing_threshold_exceeded_webhook_event.rb', line 10 required :id, String |
#properties ⇒ Orb::Models::SubscriptionInvoicingThresholdExceededWebhookEvent::Properties
21 |
# File 'lib/orb/models/subscription_invoicing_threshold_exceeded_webhook_event.rb', line 21 required :properties, -> { Orb::SubscriptionInvoicingThresholdExceededWebhookEvent::Properties } |
#subscription ⇒ Orb::Models::SubscriptionInvoicingThresholdExceededWebhookEvent::Subscription
A lightweight subscription representation for webhook payloads.
This avoids the expensive to_subscription_params() call required for full serialization.
30 |
# File 'lib/orb/models/subscription_invoicing_threshold_exceeded_webhook_event.rb', line 30 required :subscription, -> { Orb::SubscriptionInvoicingThresholdExceededWebhookEvent::Subscription } |
#type ⇒ Symbol, Orb::Models::SubscriptionInvoicingThresholdExceededWebhookEvent::Type
The event this payload describes.
36 |
# File 'lib/orb/models/subscription_invoicing_threshold_exceeded_webhook_event.rb', line 36 required :type, enum: -> { Orb::SubscriptionInvoicingThresholdExceededWebhookEvent::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/subscription_invoicing_threshold_exceeded_webhook_event.rb', line 173
|
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/orb/models/subscription_invoicing_threshold_exceeded_webhook_event.rbs', line 31
def to_hash: -> {
|