Class: Orb::Models::SubscriptionLicenseAllocationResetWebhookEvent::Subscription::Plan

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/subscription_license_allocation_reset_webhook_event.rb,
sig/orb/models/subscription_license_allocation_reset_webhook_event.rbs

Overview

See Also:

  • Orb::Models::SubscriptionLicenseAllocationResetWebhookEvent::Subscription#plan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



143
# File 'sig/orb/models/subscription_license_allocation_reset_webhook_event.rbs', line 143

def initialize: (

Instance Attribute Details

#external_plan_id ⇒ String?

An optional user-defined ID for this plan resource, used throughout the system as an alias for this Plan. Use this field to identify a plan by an existing identifier in your system.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


169
# File 'lib/orb/models/subscription_license_allocation_reset_webhook_event.rb', line 169

required :external_plan_id, String, nil?: true

#id ⇒ String?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


161
# File 'lib/orb/models/subscription_license_allocation_reset_webhook_event.rb', line 161

required :id, String, nil?: true

#name ⇒ String?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


174
# File 'lib/orb/models/subscription_license_allocation_reset_webhook_event.rb', line 174

required :name, String, nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


149
# File 'sig/orb/models/subscription_license_allocation_reset_webhook_event.rbs', line 149

def to_hash: -> {