Class: Orb::Models::SubscriptionLicenseBalanceThresholdReachedWebhookEvent::Properties::AlertConfiguration::Plan
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionLicenseBalanceThresholdReachedWebhookEvent::Properties::AlertConfiguration::Plan
show all
- Defined in:
- lib/orb/models/subscription_license_balance_threshold_reached_webhook_event.rb,
sig/orb/models/subscription_license_balance_threshold_reached_webhook_event.rbs
Overview
Instance Attribute Summary collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
183
|
# File 'sig/orb/models/subscription_license_balance_threshold_reached_webhook_event.rbs', line 183
def initialize: (
|
Instance Attribute Details
#external_plan_id ⇒ String?
An optional user-defined ID for this plan resource, used throughout the system
as an alias for this Plan. Use this field to identify a plan by an existing
identifier in your system.
301
|
# File 'lib/orb/models/subscription_license_balance_threshold_reached_webhook_event.rb', line 301
required :external_plan_id, String, nil?: true
|
#id ⇒ String?
293
|
# File 'lib/orb/models/subscription_license_balance_threshold_reached_webhook_event.rb', line 293
required :id, String, nil?: true
|
#name ⇒ String?
306
|
# File 'lib/orb/models/subscription_license_balance_threshold_reached_webhook_event.rb', line 306
required :name, String, nil?: true
|
#plan_version ⇒ String
311
|
# File 'lib/orb/models/subscription_license_balance_threshold_reached_webhook_event.rb', line 311
required :plan_version, String
|
Instance Method Details
#to_hash ⇒ {
190
|
# File 'sig/orb/models/subscription_license_balance_threshold_reached_webhook_event.rbs', line 190
def to_hash: -> {
|