Class: Orb::Models::SubscriptionPlanVersionChangedWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionPlanVersionChangedWebhookEvent
- Defined in:
- lib/orb/models/subscription_plan_version_changed_webhook_event.rb,
sig/orb/models/subscription_plan_version_changed_webhook_event.rbs
Defined Under Namespace
Modules: Type Classes: Properties
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The time at which this event was created, to the second.
-
#id ⇒ String
The ID of this webhook event.
- #properties ⇒ Orb::Models::SubscriptionPlanVersionChangedWebhookEvent::Properties
-
#subscription ⇒ Orb::Models::Subscription
A subscription represents the purchase of a plan by a customer.
-
#type ⇒ Symbol, Orb::Models::SubscriptionPlanVersionChangedWebhookEvent::Type
The event this payload describes.
Instance Method Summary collapse
- #initialize(effective_date:, new_plan_version_number:, previous_plan_version_number:) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(effective_date:, new_plan_version_number:, previous_plan_version_number:) ⇒ Object
|
|
# File 'lib/orb/models/subscription_plan_version_changed_webhook_event.rb', line 53
|
Instance Attribute Details
#created_at ⇒ Time
The time at which this event was created, to the second.
16 |
# File 'lib/orb/models/subscription_plan_version_changed_webhook_event.rb', line 16 required :created_at, Time |
#id ⇒ String
The ID of this webhook event.
10 |
# File 'lib/orb/models/subscription_plan_version_changed_webhook_event.rb', line 10 required :id, String |
#properties ⇒ Orb::Models::SubscriptionPlanVersionChangedWebhookEvent::Properties
21 |
# File 'lib/orb/models/subscription_plan_version_changed_webhook_event.rb', line 21 required :properties, -> { Orb::SubscriptionPlanVersionChangedWebhookEvent::Properties } |
#subscription ⇒ Orb::Models::Subscription
A subscription represents the purchase of a plan by a customer.
By default, subscriptions begin on the day that they're created and renew automatically for each billing cycle at the cadence that's configured in the plan definition.
Subscriptions also default to beginning of month alignment, which means the
first invoice issued for the subscription will have pro-rated charges between
the start_date and the first of the following month. Subsequent billing
periods will always start and end on a month boundary (e.g. subsequent month
starts for monthly billing).
Depending on the plan configuration, any flat recurring fees will be billed either at the beginning (in-advance) or end (in-arrears) of each billing cycle. Plans default to in-advance billing. Usage-based fees are billed in arrears as usage is accumulated. In the normal course of events, you can expect an invoice to contain usage-based charges for the previous period, and a recurring fee for the following period.
45 |
# File 'lib/orb/models/subscription_plan_version_changed_webhook_event.rb', line 45 required :subscription, -> { Orb::Subscription } |
#type ⇒ Symbol, Orb::Models::SubscriptionPlanVersionChangedWebhookEvent::Type
The event this payload describes.
51 |
# File 'lib/orb/models/subscription_plan_version_changed_webhook_event.rb', line 51 required :type, enum: -> { Orb::SubscriptionPlanVersionChangedWebhookEvent::Type } |
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/orb/models/subscription_plan_version_changed_webhook_event.rbs', line 31
def to_hash: -> {
|