Class: Orb::Models::SubscriptionPriceIntervalsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionPriceIntervalsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/orb/models/subscription_price_intervals_params.rb,
sig/orb/models/subscription_price_intervals_params.rbs
Overview
Defined Under Namespace
Classes: Add, AddAdjustment, Edit, EditAdjustment
Instance Attribute Summary collapse
-
#add ⇒ Array<Orb::Models::SubscriptionPriceIntervalsParams::Add>?
A list of price intervals to add to the subscription.
-
#add_adjustments ⇒ Array<Orb::Models::SubscriptionPriceIntervalsParams::AddAdjustment>?
A list of adjustments to add to the subscription.
-
#allow_invoice_credit_or_void ⇒ Boolean?
If false, this request will fail if it would void an issued invoice or create a credit note.
-
#can_defer_billing ⇒ Boolean?
If set, the default value to use for added/edited price intervals with an end_date set.
-
#edit ⇒ Array<Orb::Models::SubscriptionPriceIntervalsParams::Edit>?
A list of price intervals to edit on the subscription.
-
#edit_adjustments ⇒ Array<Orb::Models::SubscriptionPriceIntervalsParams::EditAdjustment>?
A list of adjustments to edit on the subscription.
- #subscription_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(unit_rating_key:, default_unit_rate: nil, grouping_key: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Add::Price::EventOutput::EventOutputConfig for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(unit_rating_key:, default_unit_rate: nil, grouping_key: nil) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::EventOutput::EventOutputConfig for more details.
Configuration for event_output pricing
|
|
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2352
|
Instance Attribute Details
#add ⇒ Array<Orb::Models::SubscriptionPriceIntervalsParams::Add>?
A list of price intervals to add to the subscription.
19 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 19 optional :add, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionPriceIntervalsParams::Add] } |
#add_adjustments ⇒ Array<Orb::Models::SubscriptionPriceIntervalsParams::AddAdjustment>?
A list of adjustments to add to the subscription.
25 26 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 25 optional :add_adjustments, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionPriceIntervalsParams::AddAdjustment] } |
#allow_invoice_credit_or_void ⇒ Boolean?
If false, this request will fail if it would void an issued invoice or create a credit note. Consider using this as a safety mechanism if you do not expect existing invoices to be changed.
34 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 34 optional :allow_invoice_credit_or_void, Orb::Internal::Type::Boolean, nil?: true |
#can_defer_billing ⇒ Boolean?
If set, the default value to use for added/edited price intervals with an end_date set.
41 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 41 optional :can_defer_billing, Orb::Internal::Type::Boolean, nil?: true |
#edit ⇒ Array<Orb::Models::SubscriptionPriceIntervalsParams::Edit>?
A list of price intervals to edit on the subscription.
47 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 47 optional :edit, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionPriceIntervalsParams::Edit] } |
#edit_adjustments ⇒ Array<Orb::Models::SubscriptionPriceIntervalsParams::EditAdjustment>?
A list of adjustments to edit on the subscription.
53 54 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 53 optional :edit_adjustments, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionPriceIntervalsParams::EditAdjustment] } |
#subscription_id ⇒ String
13 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 13 required :subscription_id, String |
Class Method Details
.variants ⇒ Array(Time, Symbol, Orb::Models::BillingCycleRelativeDate)
|
|
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2367
|
Instance Method Details
#to_hash ⇒ {
60 |
# File 'sig/orb/models/subscription_price_intervals_params.rbs', line 60
def to_hash: -> {
|