Class: Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::DailyCreditAllowance

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/subscription_price_intervals_params.rb,
sig/orb/models/subscription_price_intervals_params.rbs

Defined Under Namespace

Modules: Cadence Classes: DailyCreditAllowanceConfig

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(cadence:, currency:, daily_credit_allowance_config:, item_id:, name:, billable_metric_id: nil, billed_in_advance: nil, billing_cycle_configuration: nil, conversion_rate: nil, conversion_rate_config: nil, dimensional_price_configuration: nil, external_price_id: nil, fixed_price_quantity: nil, invoice_grouping_key: nil, invoicing_cycle_configuration: nil, license_type_id: nil, metadata: nil, model_type: :daily_credit_allowance) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::DailyCreditAllowance for more details.

Parameters:

  • The cadence to bill for this price on.

  • An ISO 4217 currency string for which this price is billed in.

  • Configuration for daily_credit_allowance pricing

  • The id of the item the price will be associated with.

  • The name of the price.

  • (defaults to: nil)

    The id of the billable metric for the price. Only needed if the price is usage-b

  • (defaults to: nil)

    If the Price represents a fixed cost, the price will be billed in-advance if thi

  • (defaults to: nil)

    For custom cadence: specifies the duration of the billing period in days or mont

  • (defaults to: nil)

    The per unit conversion rate of the price currency to the invoicing currency.

  • (defaults to: nil)

    The configuration for the rate of the price currency to the invoicing currency.

  • (defaults to: nil)

    For dimensional price: specifies a price group and dimension values

  • (defaults to: nil)

    An alias for the price.

  • (defaults to: nil)

    If the Price represents a fixed cost, this represents the quantity of units appl

  • (defaults to: nil)

    The property used to group this price on an invoice

  • (defaults to: nil)

    Within each billing cycle, specifies the cadence at which invoices are produced.

  • (defaults to: nil)

    The ID of the license type to associate with this price. On a usage price this a

  • (defaults to: nil)

    User-specified key/value pairs for the resource. Individual keys can be removed

  • (defaults to: :daily_credit_allowance)

    The pricing model type



# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2081


Instance Attribute Details

#billable_metric_id ⇒ String?

The id of the billable metric for the price. Only needed if the price is usage-based.

Parameters:

Returns:



1999
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1999

optional :billable_metric_id, String, nil?: true

#billed_in_advance ⇒ Boolean?

If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.

Parameters:

Returns:



2006
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2006

optional :billed_in_advance, Orb::Internal::Type::Boolean, nil?: true

#billing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?

For custom cadence: specifies the duration of the billing period in days or months.

Parameters:

Returns:



2013
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2013

optional :billing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true

#cadence ⇒ Symbol, Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::DailyCreditAllowance::Cadence

The cadence to bill for this price on.

Parameters:

Returns:



1960
1961
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1960

required :cadence,
enum: -> { Orb::SubscriptionPriceIntervalsParams::Add::Price::DailyCreditAllowance::Cadence }

#conversion_rate ⇒ Float?

The per unit conversion rate of the price currency to the invoicing currency.

Parameters:

Returns:



2019
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2019

optional :conversion_rate, Float, nil?: true

#conversion_rate_config ⇒ Orb::Models::UnitConversionRateConfig, ...

The configuration for the rate of the price currency to the invoicing currency.

Parameters:

Returns:



2025
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2025

optional :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true

#currency ⇒ String

An ISO 4217 currency string for which this price is billed in.

Parameters:

Returns:



1967
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1967

required :currency, String

#daily_credit_allowance_config ⇒ Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::DailyCreditAllowance::DailyCreditAllowanceConfig

Configuration for daily_credit_allowance pricing

Parameters:

Returns:



1973
1974
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1973

required :daily_credit_allowance_config,
-> { Orb::SubscriptionPriceIntervalsParams::Add::Price::DailyCreditAllowance::DailyCreditAllowanceConfig }

#dimensional_price_configuration ⇒ Orb::Models::NewDimensionalPriceConfiguration?

For dimensional price: specifies a price group and dimension values

Parameters:

Returns:



2031
2032
2033
2034
2035
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2031

optional :dimensional_price_configuration,
-> {
  Orb::NewDimensionalPriceConfiguration
},
nil?: true

#external_price_id ⇒ String?

An alias for the price.

Parameters:

Returns:



2041
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2041

optional :external_price_id, String, nil?: true

#fixed_price_quantity ⇒ Float?

If the Price represents a fixed cost, this represents the quantity of units applied.

Parameters:

Returns:



2048
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2048

optional :fixed_price_quantity, Float, nil?: true

#invoice_grouping_key ⇒ String?

The property used to group this price on an invoice

Parameters:

Returns:



2054
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2054

optional :invoice_grouping_key, String, nil?: true

#invoicing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?

Within each billing cycle, specifies the cadence at which invoices are produced. If unspecified, a single invoice is produced per billing cycle.

Parameters:

Returns:



2061
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2061

optional :invoicing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true

#item_id ⇒ String

The id of the item the price will be associated with.

Parameters:

Returns:



1980
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1980

required :item_id, String

#license_type_id ⇒ String?

The ID of the license type to associate with this price. On a usage price this also marks the price as eligible to draw down from that license type's allocation; a usage price created without it is billed normally. Usage prices with a license type must use the unit model, and only draw down when their currency matches the allocation's.

Parameters:

Returns:



2071
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2071

optional :license_type_id, String, nil?: true

#metadata ⇒ Hash{Symbol=>String, nil}?

User-specified key/value pairs for the resource. Individual keys can be removed by setting the value to null, and the entire metadata mapping can be cleared by setting metadata to null.

Parameters:

Returns:



2079
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2079

optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true

#model_type ⇒ Symbol, :daily_credit_allowance

The pricing model type

Parameters:

Returns:



1986
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1986

required :model_type, const: :daily_credit_allowance

#name ⇒ String

The name of the price.

Parameters:

Returns:



1992
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1992

required :name, String

Class Method Details

.values ⇒ Array<Symbol>

Returns:



# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2135


Instance Method Details

#to_hash ⇒ {

Returns:



1437
# File 'sig/orb/models/subscription_price_intervals_params.rbs', line 1437

def to_hash: -> {