Class: Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::DailyCreditAllowance::DailyCreditAllowanceConfig::MatrixValue
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::DailyCreditAllowance::DailyCreditAllowanceConfig::MatrixValue
- Defined in:
- lib/orb/models/subscription_price_intervals_params.rb,
sig/orb/models/subscription_price_intervals_params.rbs
Instance Attribute Summary collapse
-
#dimension_values ⇒ Array<String, nil>
One or two matrix keys to filter usage to this value by.
-
#unit_amount ⇒ String
Credits charged per unit of usage matching the specified dimension_values.
Instance Method Summary collapse
-
#initialize(daily_allowance:, default_unit_amount:, dimensions:, event_day_property:, matrix_values:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::DailyCreditAllowance::DailyCreditAllowanceConfig for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(daily_allowance:, default_unit_amount:, dimensions:, event_day_property:, matrix_values:) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::DailyCreditAllowance::DailyCreditAllowanceConfig for more details.
Configuration for daily_credit_allowance pricing
matrix_
2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2197 class MatrixValue < Orb::Internal::Type::BaseModel # @!attribute dimension_values # One or two matrix keys to filter usage to this value by. For example, ["model"] # could be used to apply a different credit rate to each AI model. # # @return [Array<String, nil>] required :dimension_values, Orb::Internal::Type::ArrayOf[String, nil?: true] # @!attribute unit_amount # Credits charged per unit of usage matching the specified dimension_values # # @return [String] required :unit_amount, String # @!method initialize(dimension_values:, unit_amount:) # Some parameter documentations has been truncated, see # {Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::DailyCreditAllowance::DailyCreditAllowanceConfig::MatrixValue} # for more details. # # Per-dimension credit price for the daily credit allowance model. # # @param dimension_values [Array<String, nil>] One or two matrix keys to filter usage to this value by. For example, ["model"] # # @param unit_amount [String] Credits charged per unit of usage matching the specified dimension_values end |
Instance Attribute Details
#dimension_values ⇒ Array<String, nil>
One or two matrix keys to filter usage to this value by. For example, ["model"] could be used to apply a different credit rate to each AI model.
2203 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2203 required :dimension_values, Orb::Internal::Type::ArrayOf[String, nil?: true] |
#unit_amount ⇒ String
Credits charged per unit of usage matching the specified dimension_values
2209 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2209 required :unit_amount, String |
Instance Method Details
#to_hash ⇒ {
1528 |
# File 'sig/orb/models/subscription_price_intervals_params.rbs', line 1528
def to_hash: -> {
|