Class: Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::EventOutput::EventOutputConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/subscription_price_intervals_params.rb,
sig/orb/models/subscription_price_intervals_params.rbs

Overview

See Also:

  • Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::EventOutput#event_output_config

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



1998
# File 'sig/orb/models/subscription_price_intervals_params.rbs', line 1998

def initialize: (

Instance Attribute Details

#default_unit_rate ⇒ String?

If provided, this amount will be used as the unit rate when an event does not have a value for the unit_rating_key. If not provided, events missing a unit rate will be ignored.



2897
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2897

optional :default_unit_rate, String, nil?: true

#grouping_key ⇒ String?

An optional key in the event data to group by (e.g., event ID). All events will also be grouped by their unit rate.



2904
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2904

optional :grouping_key, String, nil?: true

#unit_rating_key ⇒ String

The key in the event data to extract the unit rate from.



2889
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2889

required :unit_rating_key, String

Instance Method Details

#to_hash ⇒ {



2004
# File 'sig/orb/models/subscription_price_intervals_params.rbs', line 2004

def to_hash: -> {