Class: Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::MeteredAllowance
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::MeteredAllowance
- Defined in:
- lib/orb/models/subscription_price_intervals_params.rb,
sig/orb/models/subscription_price_intervals_params.rbs
Defined Under Namespace
Modules: Cadence Classes: MeteredAllowanceConfig
Instance Attribute Summary collapse
-
#billable_metric_id ⇒ String?
The id of the billable metric for the price.
-
#billed_in_advance ⇒ Boolean?
If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.
-
#billing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
For custom cadence: specifies the duration of the billing period in days or months.
-
#cadence ⇒ Symbol, Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::MeteredAllowance::Cadence
The cadence to bill for this price on.
-
#conversion_rate ⇒ Float?
The per unit conversion rate of the price currency to the invoicing currency.
-
#conversion_rate_config ⇒ Orb::Models::UnitConversionRateConfig, ...
The configuration for the rate of the price currency to the invoicing currency.
-
#currency ⇒ String
An ISO 4217 currency string for which this price is billed in.
-
#dimensional_price_configuration ⇒ Orb::Models::NewDimensionalPriceConfiguration?
For dimensional price: specifies a price group and dimension values.
-
#external_price_id ⇒ String?
An alias for the price.
-
#fixed_price_quantity ⇒ Float?
If the Price represents a fixed cost, this represents the quantity of units applied.
-
#invoice_grouping_key ⇒ String?
The property used to group this price on an invoice.
-
#invoicing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
Within each billing cycle, specifies the cadence at which invoices are produced.
-
#item_id ⇒ String
The id of the item the price will be associated with.
-
#license_type_id ⇒ String?
The ID of the license type to associate with this price.
-
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource.
-
#metered_allowance_config ⇒ Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::MeteredAllowance::MeteredAllowanceConfig
Configuration for metered_allowance pricing.
-
#model_type ⇒ Symbol, :metered_allowance
The pricing model type.
-
#name ⇒ String
The name of the price.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(cadence:, currency:, item_id:, metered_allowance_config:, name:, billable_metric_id: nil, billed_in_advance: nil, billing_cycle_configuration: nil, conversion_rate: nil, conversion_rate_config: nil, dimensional_price_configuration: nil, external_price_id: nil, fixed_price_quantity: nil, invoice_grouping_key: nil, invoicing_cycle_configuration: nil, license_type_id: nil, metadata: nil, model_type: :metered_allowance) ⇒ Object
constructor
Some parameter documentations has been truncated, see MeteredAllowance for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cadence:, currency:, item_id:, metered_allowance_config:, name:, billable_metric_id: nil, billed_in_advance: nil, billing_cycle_configuration: nil, conversion_rate: nil, conversion_rate_config: nil, dimensional_price_configuration: nil, external_price_id: nil, fixed_price_quantity: nil, invoice_grouping_key: nil, invoicing_cycle_configuration: nil, license_type_id: nil, metadata: nil, model_type: :metered_allowance) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::MeteredAllowance for more details.
|
|
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1805
|
Instance Attribute Details
#billable_metric_id ⇒ String?
The id of the billable metric for the price. Only needed if the price is usage-based.
1727 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1727 optional :billable_metric_id, String, nil?: true |
#billed_in_advance ⇒ Boolean?
If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.
1734 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1734 optional :billed_in_advance, Orb::Internal::Type::Boolean, nil?: true |
#billing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
For custom cadence: specifies the duration of the billing period in days or months.
1741 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1741 optional :billing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true |
#cadence ⇒ Symbol, Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::MeteredAllowance::Cadence
The cadence to bill for this price on.
1688 1689 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1688 required :cadence, enum: -> { Orb::SubscriptionPriceIntervalsParams::Add::Price::MeteredAllowance::Cadence } |
#conversion_rate ⇒ Float?
The per unit conversion rate of the price currency to the invoicing currency.
1747 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1747 optional :conversion_rate, Float, nil?: true |
#conversion_rate_config ⇒ Orb::Models::UnitConversionRateConfig, ...
The configuration for the rate of the price currency to the invoicing currency.
1753 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1753 optional :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true |
#currency ⇒ String
An ISO 4217 currency string for which this price is billed in.
1695 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1695 required :currency, String |
#dimensional_price_configuration ⇒ Orb::Models::NewDimensionalPriceConfiguration?
For dimensional price: specifies a price group and dimension values
1759 1760 1761 1762 1763 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1759 optional :dimensional_price_configuration, -> { Orb::NewDimensionalPriceConfiguration }, nil?: true |
#external_price_id ⇒ String?
An alias for the price.
1769 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1769 optional :external_price_id, String, nil?: true |
#fixed_price_quantity ⇒ Float?
If the Price represents a fixed cost, this represents the quantity of units applied.
1776 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1776 optional :fixed_price_quantity, Float, nil?: true |
#invoice_grouping_key ⇒ String?
The property used to group this price on an invoice
1782 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1782 optional :invoice_grouping_key, String, nil?: true |
#invoicing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
Within each billing cycle, specifies the cadence at which invoices are produced. If unspecified, a single invoice is produced per billing cycle.
1789 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1789 optional :invoicing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true |
#item_id ⇒ String
The id of the item the price will be associated with.
1701 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1701 required :item_id, String |
#license_type_id ⇒ String?
The ID of the license type to associate with this price.
1795 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1795 optional :license_type_id, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource. Individual keys can be removed
by setting the value to null, and the entire metadata mapping can be cleared
by setting metadata to null.
1803 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1803 optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true |
#metered_allowance_config ⇒ Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::MeteredAllowance::MeteredAllowanceConfig
Configuration for metered_allowance pricing
1707 1708 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1707 required :metered_allowance_config, -> { Orb::SubscriptionPriceIntervalsParams::Add::Price::MeteredAllowance::MeteredAllowanceConfig } |
#model_type ⇒ Symbol, :metered_allowance
The pricing model type
1714 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1714 required :model_type, const: :metered_allowance |
#name ⇒ String
The name of the price.
1720 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1720 required :name, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1859
|
Instance Method Details
#to_hash ⇒ {
1255 |
# File 'sig/orb/models/subscription_price_intervals_params.rbs', line 1255
def to_hash: -> {
|