Class: Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig
- Defined in:
- lib/orb/models/subscription_price_intervals_params.rb,
sig/orb/models/subscription_price_intervals_params.rbs
Overview
Defined Under Namespace
Classes: Tier
Instance Attribute Summary collapse
-
#allocation ⇒ String
Usage allocation, pooled across all matrix cells.
-
#default_unit_amount ⇒ String
Per unit rate for usage whose matrix cell has no configured tiers.
-
#dimensions ⇒ Array<String>
One or two event property values to evaluate matrix cells by.
-
#tiers ⇒ Array<Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier>
Graduated tiers keyed by matrix cell; usage in a cell is tiered only against its own rows.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
776 |
# File 'sig/orb/models/subscription_price_intervals_params.rbs', line 776
def initialize: (
|
Instance Attribute Details
#allocation ⇒ String
Usage allocation, pooled across all matrix cells
1122 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1122 required :allocation, String |
#default_unit_amount ⇒ String
Per unit rate for usage whose matrix cell has no configured tiers
1128 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1128 required :default_unit_amount, String |
#dimensions ⇒ Array<String>
One or two event property values to evaluate matrix cells by
1134 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1134 required :dimensions, Orb::Internal::Type::ArrayOf[String] |
#tiers ⇒ Array<Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier>
Graduated tiers keyed by matrix cell; usage in a cell is tiered only against its own rows
1141 1142 1143 1144 1145 1146 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1141 required :tiers, -> do Orb::Internal::Type::ArrayOf[ Orb::SubscriptionPriceIntervalsParams::Add::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier ] end |
Instance Method Details
#to_hash ⇒ {
783 |
# File 'sig/orb/models/subscription_price_intervals_params.rbs', line 783
def to_hash: -> {
|