Class: Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/subscription_price_intervals_params.rb,
sig/orb/models/subscription_price_intervals_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(allocation:, default_unit_amount:, dimensions:, tiers:) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig for more details.

Configuration for tiered_matrix_with_allocation pricing

Parameters:



1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1163

class Tier < Orb::Internal::Type::BaseModel
  # @!attribute dimension_values
  #   The matrix cell this tier applies to, as one or two dimension values
  #
  #   @return [Array<String>]
  required :dimension_values, Orb::Internal::Type::ArrayOf[String]

  # @!attribute tier_lower_bound
  #   Exclusive tier starting value. The tier runs up to and including the next bound
  #   configured for the same matrix cell.
  #
  #   @return [String]
  required :tier_lower_bound, String

  # @!attribute unit_amount
  #   Per unit amount
  #
  #   @return [String]
  required :unit_amount, String

  # @!method initialize(dimension_values:, tier_lower_bound:, unit_amount:)
  #   Some parameter documentations has been truncated, see
  #   {Orb::Models::SubscriptionPriceIntervalsParams::Add::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier}
  #   for more details.
  #
  #   Configuration for a single tier scoped to one matrix cell
  #
  #   @param dimension_values [Array<String>] The matrix cell this tier applies to, as one or two dimension values
  #
  #   @param tier_lower_bound [String] Exclusive tier starting value. The tier runs up to and including the next bound
  #
  #   @param unit_amount [String] Per unit amount
end

Instance Attribute Details

#dimension_values ⇒ Array<String>

The matrix cell this tier applies to, as one or two dimension values

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


1168
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1168

required :dimension_values, Orb::Internal::Type::ArrayOf[String]

#tier_lower_bound ⇒ String

Exclusive tier starting value. The tier runs up to and including the next bound configured for the same matrix cell.

Parameters:

  • value (String)

Returns:

  • (String)


1175
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1175

required :tier_lower_bound, String

#unit_amount ⇒ String

Per unit amount

Parameters:

  • value (String)

Returns:

  • (String)


1181
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 1181

required :unit_amount, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


810
# File 'sig/orb/models/subscription_price_intervals_params.rbs', line 810

def to_hash: -> {