Module: Orb::Models::SubscriptionPriceIntervalsParams::AddAdjustment::EndDate

Extended by:
Internal::Type::Union
Defined in:
lib/orb/models/subscription_price_intervals_params.rb,
sig/orb/models/subscription_price_intervals_params.rbs

Overview

The end date of the adjustment interval. This is the date that the adjustment will stop affecting prices on the subscription. The adjustment will apply to invoice dates that overlap with this end_date.This end_date is treated as exclusive for in-advance prices, and inclusive for in-arrears prices.

See Also:

  • Orb::Models::SubscriptionPriceIntervalsParams::AddAdjustment#end_date

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.variants::Array[Orb::Models::SubscriptionPriceIntervalsParams::AddAdjustment::end_date]

Returns:

  • (::Array[Orb::Models::SubscriptionPriceIntervalsParams::AddAdjustment::end_date])


1881
# File 'sig/orb/models/subscription_price_intervals_params.rbs', line 1881

def self?.variants: -> ::Array[Orb::Models::SubscriptionPriceIntervalsParams::AddAdjustment::end_date]