Class: Orb::Models::SubscriptionPriceIntervalsParams::Edit

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/subscription_price_intervals_params.rb,
sig/orb/models/subscription_price_intervals_params.rbs

Defined Under Namespace

Modules: EndDate, StartDate Classes: FixedFeeQuantityTransition

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(effective_date:, quantity:) ⇒ Object

Parameters:

  • effective_date (Time) —

    The date that the fixed fee quantity transition should take effect.

  • quantity (Float) —

    The quantity of the fixed fee quantity transition.



# File 'lib/orb/models/subscription_price_intervals_params.rb', line 3317

Instance Attribute Details

#billing_cycle_day ⇒ Integer?

The updated billing cycle day for this price interval. If not specified, the billing cycle day will not be updated. Note that overlapping price intervals must have the same billing cycle day.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


3252
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 3252

optional :billing_cycle_day, Integer, nil?: true

#can_defer_billing ⇒ Boolean?

If true, an in-arrears price interval ending mid-cycle will defer billing the final line item until the next scheduled invoice. If false, it will be billed on its end date.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


3260
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 3260

optional :can_defer_billing, Orb::Internal::Type::Boolean, nil?: true

#end_date ⇒ Time, ...

The updated end date of this price interval. If not specified, the end date will not be updated.

Parameters:

  • value (Orb::Models::SubscriptionPriceIntervalsParams::Edit::end_date, nil)

Returns:



3267
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 3267

optional :end_date, union: -> { Orb::SubscriptionPriceIntervalsParams::Edit::EndDate }, nil?: true

#filter ⇒ String?

An additional filter to apply to usage queries. This filter must be expressed as a boolean computed property. If null, usage queries will not include any additional filter.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3276
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 3276

optional :filter, String, nil?: true

#fixed_fee_quantity_transitions ⇒ Array<Orb::Models::SubscriptionPriceIntervalsParams::Edit::FixedFeeQuantityTransition>?

A list of fixed fee quantity transitions to use for this price interval. Note that this list will overwrite all existing fixed fee quantity transitions on the price interval.

Parameters:

  • value (::Array[Orb::SubscriptionPriceIntervalsParams::Edit::FixedFeeQuantityTransition], nil)

Returns:



3284
3285
3286
3287
3288
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 3284

optional :fixed_fee_quantity_transitions,
-> {
  Orb::Internal::Type::ArrayOf[Orb::SubscriptionPriceIntervalsParams::Edit::FixedFeeQuantityTransition]
},
nil?: true

#metric_parameter_overrides ⇒ Hash{Symbol=>Object}?

Override values for parameterized billable metric variables. Keys are parameter names, values are the override values (number or string).

Parameters:

  • value (::Hash[Symbol, top], nil)

Returns:

  • (Hash{Symbol=>Object}, nil)


3295
3296
3297
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 3295

optional :metric_parameter_overrides,
Orb::Internal::Type::HashOf[Orb::Internal::Type::Unknown],
nil?: true

#price_interval_id ⇒ String

The id of the price interval to edit.

Parameters:

  • value (String)

Returns:

  • (String)


3244
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 3244

required :price_interval_id, String

#start_date ⇒ Time, ...

The updated start date of this price interval. If not specified, the start date will not be updated.

Returns:



3304
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 3304

optional :start_date, union: -> { Orb::SubscriptionPriceIntervalsParams::Edit::StartDate }

#usage_customer_ids ⇒ Array<String>?

A list of customer IDs whose usage events will be aggregated and billed under this subscription. By default, a subscription only considers usage events associated with its attached customer's customer_id. When usage_customer_ids is provided, the subscription includes usage events from the specified customers only. Provided usage_customer_ids must be either the customer for this subscription itself, or any of that customer's children.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


3315
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 3315

optional :usage_customer_ids, Orb::Internal::Type::ArrayOf[String], nil?: true

Class Method Details

.variants ⇒ Array(Time, Symbol, Orb::Models::BillingCycleRelativeDate)

Returns:



# File 'lib/orb/models/subscription_price_intervals_params.rb', line 3350

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


2294
# File 'sig/orb/models/subscription_price_intervals_params.rbs', line 2294

def to_hash: -> {