Class: Orb::Models::SubscriptionPriceIntervalsParams::Edit::FixedFeeQuantityTransition
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionPriceIntervalsParams::Edit::FixedFeeQuantityTransition
- Defined in:
- lib/orb/models/subscription_price_intervals_params.rb,
sig/orb/models/subscription_price_intervals_params.rbs
Instance Attribute Summary collapse
-
#effective_date ⇒ Time
The date that the fixed fee quantity transition should take effect.
-
#quantity ⇒ Integer
The quantity of the fixed fee quantity transition.
Instance Method Summary collapse
-
#initialize ⇒ FixedFeeQuantityTransition
constructor
A new instance of FixedFeeQuantityTransition.
- #to_hash ⇒ { effective_date: Time, quantity: Integer }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ FixedFeeQuantityTransition
Returns a new instance of FixedFeeQuantityTransition.
1961 |
# File 'sig/orb/models/subscription_price_intervals_params.rbs', line 1961
def initialize: (effective_date: Time, quantity: Integer) -> void
|
Instance Attribute Details
#effective_date ⇒ Time
The date that the fixed fee quantity transition should take effect.
2805 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2805 required :effective_date, Time |
#quantity ⇒ Integer
The quantity of the fixed fee quantity transition.
2811 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2811 required :quantity, Integer |
Instance Method Details
#to_hash ⇒ { effective_date: Time, quantity: Integer }
1963 |
# File 'sig/orb/models/subscription_price_intervals_params.rbs', line 1963
def to_hash: -> { effective_date: Time, quantity: Integer }
|