Class: Orb::Models::SubscriptionPriceIntervalsParams::EditAdjustment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionPriceIntervalsParams::EditAdjustment
- Defined in:
- lib/orb/models/subscription_price_intervals_params.rb,
sig/orb/models/subscription_price_intervals_params.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#adjustment_interval_id ⇒ String
The id of the adjustment interval to edit.
-
#end_date ⇒ Time, ...
The updated end date of this adjustment interval.
-
#start_date ⇒ Time, ...
The updated start date of this adjustment interval.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(adjustment_interval_id:, end_date: nil, start_date: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see EditAdjustment for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(adjustment_interval_id:, end_date: nil, start_date: nil) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::SubscriptionPriceIntervalsParams::EditAdjustment for more details.
|
|
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2858
|
Instance Attribute Details
#adjustment_interval_id ⇒ String
The id of the adjustment interval to edit.
2840 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2840 required :adjustment_interval_id, String |
#end_date ⇒ Time, ...
The updated end date of this adjustment interval. If not specified, the end date will not be updated.
2847 2848 2849 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2847 optional :end_date, union: -> { Orb::SubscriptionPriceIntervalsParams::EditAdjustment::EndDate }, nil?: true |
#start_date ⇒ Time, ...
The updated start date of this adjustment interval. If not specified, the start date will not be updated.
2856 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2856 optional :start_date, union: -> { Orb::SubscriptionPriceIntervalsParams::EditAdjustment::StartDate } |
Class Method Details
.variants ⇒ Array(Time, Symbol, Orb::Models::BillingCycleRelativeDate)
|
|
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2880
|
Instance Method Details
#to_hash ⇒ {
1999 |
# File 'sig/orb/models/subscription_price_intervals_params.rbs', line 1999
def to_hash: -> {
|