Class: Orb::Models::SubscriptionRedeemCouponParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionRedeemCouponParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/orb/models/subscription_redeem_coupon_params.rb,
sig/orb/models/subscription_redeem_coupon_params.rbs
Overview
Defined Under Namespace
Modules: ChangeOption
Instance Attribute Summary collapse
-
#allow_invoice_credit_or_void ⇒ Boolean?
If false, this request will fail if it would void an issued invoice or create a credit note.
-
#change_date ⇒ Time?
The date that the coupon discount should take effect.
- #change_option ⇒ Symbol, Orb::Models::SubscriptionRedeemCouponParams::ChangeOption
-
#coupon_id ⇒ String?
Coupon ID to be redeemed for this subscription.
-
#coupon_redemption_code ⇒ String?
Redemption code of the coupon to be redeemed for this subscription.
- #subscription_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
30 |
# File 'sig/orb/models/subscription_redeem_coupon_params.rbs', line 30
def initialize: (
|
Instance Attribute Details
#allow_invoice_credit_or_void ⇒ Boolean?
If false, this request will fail if it would void an issued invoice or create a credit note. Consider using this as a safety mechanism if you do not expect existing invoices to be changed.
26 |
# File 'lib/orb/models/subscription_redeem_coupon_params.rb', line 26 optional :allow_invoice_credit_or_void, Orb::Internal::Type::Boolean, nil?: true |
#change_date ⇒ Time?
The date that the coupon discount should take effect. This parameter can only be
passed if the change_option is requested_date.
33 |
# File 'lib/orb/models/subscription_redeem_coupon_params.rb', line 33 optional :change_date, Time, nil?: true |
#change_option ⇒ Symbol, Orb::Models::SubscriptionRedeemCouponParams::ChangeOption
18 |
# File 'lib/orb/models/subscription_redeem_coupon_params.rb', line 18 required :change_option, enum: -> { Orb::SubscriptionRedeemCouponParams::ChangeOption } |
#coupon_id ⇒ String?
Coupon ID to be redeemed for this subscription.
39 |
# File 'lib/orb/models/subscription_redeem_coupon_params.rb', line 39 optional :coupon_id, String, nil?: true |
#coupon_redemption_code ⇒ String?
Redemption code of the coupon to be redeemed for this subscription.
45 |
# File 'lib/orb/models/subscription_redeem_coupon_params.rb', line 45 optional :coupon_redemption_code, String, nil?: true |
#subscription_id ⇒ String
13 |
# File 'lib/orb/models/subscription_redeem_coupon_params.rb', line 13 required :subscription_id, String |
Instance Method Details
#to_hash ⇒ {
40 |
# File 'sig/orb/models/subscription_redeem_coupon_params.rbs', line 40
def to_hash: -> {
|