Class: Orb::Models::SubscriptionSchedulePlanChangeParams::AddAdjustment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/subscription_schedule_plan_change_params.rb,
sig/orb/models/subscription_schedule_plan_change_params.rbs

Defined Under Namespace

Modules: Adjustment

Constant Summary collapse

Orb =

Returns:

  • (:NewPercentageDiscount)

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(adjustment:, end_date: nil, plan_phase_order: nil, start_date: nil) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::SubscriptionSchedulePlanChangeParams::AddAdjustment for more details.

Parameters:



# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 333

Instance Attribute Details

#adjustmentOrb::Models::NewPercentageDiscount, ...

The definition of a new adjustment to create and add to the subscription.



310
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 310

required :adjustment, union: -> { Orb::SubscriptionSchedulePlanChangeParams::AddAdjustment::Adjustment }

#end_dateTime?

The end date of the adjustment interval. This is the date that the adjustment will stop affecting prices on the subscription.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


317
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 317

optional :end_date, Time, nil?: true

#plan_phase_orderInteger?

The phase to add this adjustment to.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


323
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 323

optional :plan_phase_order, Integer, nil?: true

#start_dateTime?

The start date of the adjustment interval. This is the date that the adjustment will start affecting prices on the subscription. If null, the adjustment will start when the phase or subscription starts.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


331
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 331

optional :start_date, Time, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


197
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 197

def to_hash: -> {