Class: Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/subscription_schedule_plan_change_params.rb,
sig/orb/models/subscription_schedule_plan_change_params.rbs

Defined Under Namespace

Modules: Price

Constant Summary collapse

Orb =

Returns:

  • (:NewSubscriptionUnitPrice)

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(allocation_price: nil, discounts: nil, end_date: nil, external_price_id: nil, maximum_amount: nil, metric_parameter_overrides: nil, minimum_amount: nil, plan_phase_order: nil, price: nil, price_id: nil, start_date: nil) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice for more details.

Parameters:



# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 659

Instance Attribute Details

#allocation_priceOrb::Models::NewAllocationPrice?

The definition of a new allocation price to create and add to the subscription.

Parameters:

Returns:



581
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 581

optional :allocation_price, -> { Orb::NewAllocationPrice }, nil?: true

#discountsArray<Orb::Models::DiscountOverride>?

Deprecated.

[DEPRECATED] Use add_adjustments instead. The subscription's discounts for this price.

Parameters:

Returns:



590
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 590

optional :discounts, -> { Orb::Internal::Type::ArrayOf[Orb::DiscountOverride] }, nil?: true

#end_dateTime?

The end date of the price interval. This is the date that the price will stop billing on the subscription. If null, billing will end when the phase or subscription ends.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


598
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 598

optional :end_date, Time, nil?: true

#external_price_idString?

The external price id of the price to add to the subscription.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


604
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 604

optional :external_price_id, String, nil?: true

#maximum_amountString?

Deprecated.

[DEPRECATED] Use add_adjustments instead. The subscription's maximum amount for this price.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


613
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 613

optional :maximum_amount, String, nil?: true

#metric_parameter_overridesHash{Symbol=>Object}?

Override values for parameterized billable metric variables. Keys are parameter names, values are the override values.

Parameters:

  • value (::Hash[Symbol, top], nil)

Returns:

  • (Hash{Symbol=>Object}, nil)


620
621
622
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 620

optional :metric_parameter_overrides,
Orb::Internal::Type::HashOf[Orb::Internal::Type::Unknown],
nil?: true

#minimum_amountString?

Deprecated.

[DEPRECATED] Use add_adjustments instead. The subscription's minimum amount for this price.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


631
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 631

optional :minimum_amount, String, nil?: true

#plan_phase_orderInteger?

The phase to add this price to.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


637
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 637

optional :plan_phase_order, Integer, nil?: true

#priceOrb::Models::NewSubscriptionUnitPrice, ...

New subscription price request body params.

Parameters:

  • value (Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::price, nil)

Returns:



643
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 643

optional :price, union: -> { Orb::SubscriptionSchedulePlanChangeParams::AddPrice::Price }, nil?: true

#price_idString?

The id of the price to add to the subscription.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


649
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 649

optional :price_id, String, nil?: true

#start_dateTime?

The start date of the price interval. This is the date that the price will start billing on the subscription. If null, billing will start when the phase or subscription starts.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


657
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 657

optional :start_date, Time, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


439
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 439

def to_hash: -> {