Class: Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::CumulativeGroupedAllocation::CumulativeGroupedAllocationConfig

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/subscription_schedule_plan_change_params.rb,
sig/orb/models/subscription_schedule_plan_change_params.rbs

Overview

See Also:

  • Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::CumulativeGroupedAllocation#cumulative_grouped_allocation_config

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



1375
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 1375

def initialize: (

Instance Attribute Details

#cumulative_allocationString

The overall allocation across all groups

Parameters:

  • value (String)

Returns:

  • (String)


2003
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 2003

required :cumulative_allocation, String

#group_allocationString

The allocation per individual group

Parameters:

  • value (String)

Returns:

  • (String)


2009
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 2009

required :group_allocation, String

#grouping_keyString

The event property used to group usage before applying allocations

Parameters:

  • value (String)

Returns:

  • (String)


2015
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 2015

required :grouping_key, String

#unit_amountString

The amount to charge for each unit outside of the allocation

Parameters:

  • value (String)

Returns:

  • (String)


2021
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 2021

required :unit_amount, String

Instance Method Details

#to_hash{

Returns:

  • ({)


1382
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 1382

def to_hash: -> {