Class: Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::DailyCreditAllowance::DailyCreditAllowanceConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::DailyCreditAllowance::DailyCreditAllowanceConfig
- Defined in:
- lib/orb/models/subscription_schedule_plan_change_params.rb,
sig/orb/models/subscription_schedule_plan_change_params.rbs
Overview
Defined Under Namespace
Classes: MatrixValue
Instance Attribute Summary collapse
-
#daily_allowance ⇒ String
Credits granted per day.
-
#default_unit_amount ⇒ String
Default per-unit credit rate for any usage not bucketed into a specified matrix_value.
-
#dimensions ⇒ Array<String, nil>
One or two event property values to evaluate matrix groups by.
-
#event_day_property ⇒ String
Event property whose value identifies the day bucket the event belongs to (e.g. 'event_day' set to an ISO date string in the customer's timezone).
-
#matrix_values ⇒ Array<Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::DailyCreditAllowance::DailyCreditAllowanceConfig::MatrixValue>
Per-dimension credit rates.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
1538 |
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 1538
def initialize: (
|
Instance Attribute Details
#daily_allowance ⇒ String
Credits granted per day. Lose-it-or-use-it; does not roll over.
2232 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 2232 required :daily_allowance, String |
#default_unit_amount ⇒ String
Default per-unit credit rate for any usage not bucketed into a specified matrix_value
2239 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 2239 required :default_unit_amount, String |
#dimensions ⇒ Array<String, nil>
One or two event property values to evaluate matrix groups by
2245 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 2245 required :dimensions, Orb::Internal::Type::ArrayOf[String, nil?: true] |
#event_day_property ⇒ String
Event property whose value identifies the day bucket the event belongs to (e.g. 'event_day' set to an ISO date string in the customer's timezone). The allowance resets per distinct value of this property.
2253 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 2253 required :event_day_property, String |
#matrix_values ⇒ Array<Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::DailyCreditAllowance::DailyCreditAllowanceConfig::MatrixValue>
Per-dimension credit rates
2259 2260 2261 2262 2263 2264 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 2259 required :matrix_values, -> do Orb::Internal::Type::ArrayOf[ Orb::SubscriptionSchedulePlanChangeParams::AddPrice::Price::DailyCreditAllowance::DailyCreditAllowanceConfig::MatrixValue ] end |
Instance Method Details
#to_hash ⇒ {
1546 |
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 1546
def to_hash: -> {
|