Class: Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::GroupedWithMinMaxThresholds::GroupedWithMinMaxThresholdsConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::GroupedWithMinMaxThresholds::GroupedWithMinMaxThresholdsConfig
- Defined in:
- lib/orb/models/subscription_schedule_plan_change_params.rb,
sig/orb/models/subscription_schedule_plan_change_params.rbs
Overview
Instance Attribute Summary collapse
-
#grouping_key ⇒ String
The event property used to group before applying thresholds.
-
#maximum_charge ⇒ String
The maximum amount to charge each group.
-
#minimum_charge ⇒ String
The minimum amount to charge each group, regardless of usage.
-
#per_unit_rate ⇒ String
The base price charged per group.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
1215 |
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 1215
def initialize: (
|
Instance Attribute Details
#grouping_key ⇒ String
The event property used to group before applying thresholds
1774 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 1774 required :grouping_key, String |
#maximum_charge ⇒ String
The maximum amount to charge each group
1780 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 1780 required :maximum_charge, String |
#minimum_charge ⇒ String
The minimum amount to charge each group, regardless of usage
1786 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 1786 required :minimum_charge, String |
#per_unit_rate ⇒ String
The base price charged per group
1792 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 1792 required :per_unit_rate, String |
Instance Method Details
#to_hash ⇒ {
1222 |
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 1222
def to_hash: -> {
|