Class: Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig
- Defined in:
- lib/orb/models/subscription_schedule_plan_change_params.rb,
sig/orb/models/subscription_schedule_plan_change_params.rbs
Overview
Defined Under Namespace
Classes: MatrixValue, ThresholdDiscountGroup
Instance Attribute Summary collapse
-
#default_unit_amount ⇒ String
Unit price used for usage that does not match any defined matrix cell.
-
#first_dimension ⇒ String
First matrix dimension key.
-
#matrix_values ⇒ Array<Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::MatrixValue>
Per-cell unit prices.
-
#second_dimension ⇒ String?
Optional second matrix dimension key.
- #threshold_discount_groups ⇒ Array<Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::ThresholdDiscountGroup>?
Instance Method Summary collapse
- #initialize(first_dimension_value:, unit_amount:, second_dimension_value: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(first_dimension_value:, unit_amount:, second_dimension_value: nil) ⇒ Object
|
|
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 1286
|
Instance Attribute Details
#default_unit_amount ⇒ String
Unit price used for usage that does not match any defined matrix cell.
1222 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 1222 required :default_unit_amount, String |
#first_dimension ⇒ String
First matrix dimension key.
1228 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 1228 required :first_dimension, String |
#matrix_values ⇒ Array<Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::MatrixValue>
Per-cell unit prices.
1234 1235 1236 1237 1238 1239 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 1234 required :matrix_values, -> do Orb::Internal::Type::ArrayOf[ Orb::SubscriptionSchedulePlanChangeParams::AddPrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::MatrixValue ] end |
#second_dimension ⇒ String?
Optional second matrix dimension key.
1245 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 1245 optional :second_dimension, String, nil?: true |
#threshold_discount_groups ⇒ Array<Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::ThresholdDiscountGroup>?
1250 1251 1252 1253 1254 1255 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 1250 optional :threshold_discount_groups, -> do Orb::Internal::Type::ArrayOf[ Orb::SubscriptionSchedulePlanChangeParams::AddPrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::ThresholdDiscountGroup ] end |
Instance Method Details
#to_hash ⇒ {
834 |
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 834
def to_hash: -> {
|