Class: Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::ThresholdDiscountGroup
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::ThresholdDiscountGroup
- Defined in:
- lib/orb/models/subscription_schedule_plan_change_params.rb,
sig/orb/models/subscription_schedule_plan_change_params.rbs
Instance Attribute Summary collapse
-
#above_threshold_discount_percentage ⇒ String
Discount rate applied to spend above the threshold.
-
#below_threshold_discount_percentage ⇒ String
Discount rate applied to spend at or below the threshold.
-
#cell_coordinates ⇒ String
Semicolon-separated list of matrix cell coordinates targeted by this group.
- #description ⇒ String?
- #threshold_amount ⇒ String
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
889 |
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 889
def initialize: (
|
Instance Attribute Details
#above_threshold_discount_percentage ⇒ String
Discount rate applied to spend above the threshold.
1297 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 1297 required :above_threshold_discount_percentage, String |
#below_threshold_discount_percentage ⇒ String
Discount rate applied to spend at or below the threshold. Set to 0 for no baseline discount.
1304 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 1304 required :below_threshold_discount_percentage, String |
#cell_coordinates ⇒ String
Semicolon-separated list of matrix cell coordinates targeted by this group. Each
coordinate is first,second when the matrix has two dimensions, or just first
for a single-dimension matrix. Example: blue,circle;green,triangle.
1312 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 1312 required :cell_coordinates, String |
#description ⇒ String?
1322 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 1322 optional :description, String, nil?: true |
#threshold_amount ⇒ String
1317 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 1317 required :threshold_amount, String |
Instance Method Details
#to_hash ⇒ {
897 |
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 897
def to_hash: -> {
|