Class: Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::Percent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::Percent
- Defined in:
- lib/orb/models/subscription_schedule_plan_change_params.rb,
sig/orb/models/subscription_schedule_plan_change_params.rbs
Defined Under Namespace
Modules: Cadence Classes: PercentConfig
Instance Attribute Summary collapse
-
#billable_metric_id ⇒ String?
The id of the billable metric for the price.
-
#billed_in_advance ⇒ Boolean?
If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.
-
#billing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
For custom cadence: specifies the duration of the billing period in days or months.
-
#cadence ⇒ Symbol, Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::Percent::Cadence
The cadence to bill for this price on.
-
#conversion_rate ⇒ Float?
The per unit conversion rate of the price currency to the invoicing currency.
-
#conversion_rate_config ⇒ Orb::Models::UnitConversionRateConfig, ...
The configuration for the rate of the price currency to the invoicing currency.
-
#currency ⇒ String?
An ISO 4217 currency string, or custom pricing unit identifier, in which this price is billed.
-
#dimensional_price_configuration ⇒ Orb::Models::NewDimensionalPriceConfiguration?
For dimensional price: specifies a price group and dimension values.
-
#external_price_id ⇒ String?
An alias for the price.
-
#fixed_price_quantity ⇒ Float?
If the Price represents a fixed cost, this represents the quantity of units applied.
-
#invoice_grouping_key ⇒ String?
The property used to group this price on an invoice.
-
#invoicing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
Within each billing cycle, specifies the cadence at which invoices are produced.
-
#item_id ⇒ String
The id of the item the price will be associated with.
-
#license_type_id ⇒ String?
The ID of the license type to associate with this price.
-
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource.
-
#model_type ⇒ Symbol, :percent
The pricing model type.
-
#name ⇒ String
The name of the price.
-
#percent_config ⇒ Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::Percent::PercentConfig
Configuration for percent pricing.
-
#reference_id ⇒ String?
A transient ID that can be used to reference this price when adding adjustments in the same API call.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(cadence:, item_id:, name:, percent_config:, billable_metric_id: nil, billed_in_advance: nil, billing_cycle_configuration: nil, conversion_rate: nil, conversion_rate_config: nil, currency: nil, dimensional_price_configuration: nil, external_price_id: nil, fixed_price_quantity: nil, invoice_grouping_key: nil, invoicing_cycle_configuration: nil, license_type_id: nil, metadata: nil, reference_id: nil, model_type: :percent) ⇒ Object
constructor
Some parameter documentations has been truncated, see Percent for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cadence:, item_id:, name:, percent_config:, billable_metric_id: nil, billed_in_advance: nil, billing_cycle_configuration: nil, conversion_rate: nil, conversion_rate_config: nil, currency: nil, dimensional_price_configuration: nil, external_price_id: nil, fixed_price_quantity: nil, invoice_grouping_key: nil, invoicing_cycle_configuration: nil, license_type_id: nil, metadata: nil, reference_id: nil, model_type: :percent) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::Percent for more details.
|
|
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3274
|
Instance Attribute Details
#billable_metric_id ⇒ String?
The id of the billable metric for the price. Only needed if the price is usage-based.
3178 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3178 optional :billable_metric_id, String, nil?: true |
#billed_in_advance ⇒ Boolean?
If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.
3185 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3185 optional :billed_in_advance, Orb::Internal::Type::Boolean, nil?: true |
#billing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
For custom cadence: specifies the duration of the billing period in days or months.
3192 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3192 optional :billing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true |
#cadence ⇒ Symbol, Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::Percent::Cadence
The cadence to bill for this price on.
3145 3146 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3145 required :cadence, enum: -> { Orb::SubscriptionSchedulePlanChangeParams::AddPrice::Price::Percent::Cadence } |
#conversion_rate ⇒ Float?
The per unit conversion rate of the price currency to the invoicing currency.
3198 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3198 optional :conversion_rate, Float, nil?: true |
#conversion_rate_config ⇒ Orb::Models::UnitConversionRateConfig, ...
The configuration for the rate of the price currency to the invoicing currency.
3204 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3204 optional :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true |
#currency ⇒ String?
An ISO 4217 currency string, or custom pricing unit identifier, in which this price is billed.
3211 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3211 optional :currency, String, nil?: true |
#dimensional_price_configuration ⇒ Orb::Models::NewDimensionalPriceConfiguration?
For dimensional price: specifies a price group and dimension values
3217 3218 3219 3220 3221 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3217 optional :dimensional_price_configuration, -> { Orb::NewDimensionalPriceConfiguration }, nil?: true |
#external_price_id ⇒ String?
An alias for the price.
3227 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3227 optional :external_price_id, String, nil?: true |
#fixed_price_quantity ⇒ Float?
If the Price represents a fixed cost, this represents the quantity of units applied.
3234 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3234 optional :fixed_price_quantity, Float, nil?: true |
#invoice_grouping_key ⇒ String?
The property used to group this price on an invoice
3240 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3240 optional :invoice_grouping_key, String, nil?: true |
#invoicing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
Within each billing cycle, specifies the cadence at which invoices are produced. If unspecified, a single invoice is produced per billing cycle.
3247 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3247 optional :invoicing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true |
#item_id ⇒ String
The id of the item the price will be associated with.
3152 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3152 required :item_id, String |
#license_type_id ⇒ String?
The ID of the license type to associate with this price. On a usage price this
also marks the price as eligible to draw down from that license type's
allocation; a usage price created without it is billed normally. Usage prices
with a license type must use the unit model, and only draw down when their
currency matches the allocation's.
3257 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3257 optional :license_type_id, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource. Individual keys can be removed
by setting the value to null, and the entire metadata mapping can be cleared
by setting metadata to null.
3265 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3265 optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true |
#model_type ⇒ Symbol, :percent
The pricing model type
3158 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3158 required :model_type, const: :percent |
#name ⇒ String
The name of the price.
3164 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3164 required :name, String |
#percent_config ⇒ Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::Percent::PercentConfig
Configuration for percent pricing
3170 3171 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3170 required :percent_config, -> { Orb::SubscriptionSchedulePlanChangeParams::AddPrice::Price::Percent::PercentConfig } |
#reference_id ⇒ String?
A transient ID that can be used to reference this price when adding adjustments in the same API call.
3272 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3272 optional :reference_id, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3330
|
Instance Method Details
#to_hash ⇒ {
2204 |
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 2204
def to_hash: -> {
|