Class: Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::Percent::PercentConfig

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/subscription_schedule_plan_change_params.rb,
sig/orb/models/subscription_schedule_plan_change_params.rbs

Overview

See Also:

  • Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::Percent#percent_config

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



2266
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 2266

def initialize: (

Instance Attribute Details

#maximum_amount ⇒ String?

Maximum amount to charge. If unset, the fee has no upper bound.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3346
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3346

optional :maximum_amount, String, nil?: true

#minimum_amount ⇒ String?

Minimum amount to charge. If unset, the fee is bounded below by 0.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3352
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3352

optional :minimum_amount, String, nil?: true

#percent ⇒ Float

Fraction of the component subtotals to charge (0 < percent <= 1).

Parameters:

  • value (Float)

Returns:

  • (Float)


3340
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3340

required :percent, Float

#prorated ⇒ Boolean?

If true, the minimum_amount is prorated based on the service period. The maximum_amount is an absolute cap (never prorated), and the percent applied to upstream subtotals is never prorated either.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


3360
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3360

optional :prorated, Orb::Internal::Type::Boolean

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


2273
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 2273

def to_hash: -> {