Class: Orb::Models::SubscriptionSchedulePlanChangeParams::RemovePrice
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionSchedulePlanChangeParams::RemovePrice
- Defined in:
- lib/orb/models/subscription_schedule_plan_change_params.rb,
sig/orb/models/subscription_schedule_plan_change_params.rbs
Instance Attribute Summary collapse
-
#external_price_id ⇒ String?
The external price id of the price to remove on the subscription.
-
#price_id ⇒ String?
The id of the price to remove on the subscription.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
2100 |
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 2100
def initialize: (
|
Instance Attribute Details
#external_price_id ⇒ String?
The external price id of the price to remove on the subscription.
3064 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3064 optional :external_price_id, String, nil?: true |
#price_id ⇒ String?
The id of the price to remove on the subscription.
3070 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3070 optional :price_id, String, nil?: true |
Instance Method Details
#to_hash ⇒ { external_price_id: String?, price_id: String? }
2105 |
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 2105
def to_hash: -> { external_price_id: String?, price_id: String? }
|