Class: Orb::Models::SubscriptionSchedulePlanChangeParams::ReplacePrice

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/subscription_schedule_plan_change_params.rb,
sig/orb/models/subscription_schedule_plan_change_params.rbs

Defined Under Namespace

Modules: Price

Constant Summary collapse

Orb =

Returns:

  • (:NewSubscriptionUnitPrice)

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(replaces_price_id:, allocation_price: nil, discounts: nil, external_price_id: nil, fixed_price_quantity: nil, maximum_amount: nil, metric_parameter_overrides: nil, minimum_amount: nil, price: nil, price_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::SubscriptionSchedulePlanChangeParams::ReplacePrice for more details.

Parameters:



# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3986


Instance Attribute Details

#allocation_price ⇒ Orb::Models::NewAllocationPrice?

The definition of a new allocation price to create and add to the subscription.

Parameters:

Returns:



3920
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3920

optional :allocation_price, -> { Orb::NewAllocationPrice }, nil?: true

#discounts ⇒ Array<Orb::Models::DiscountOverride>?

Deprecated.

[DEPRECATED] Use add_adjustments instead. The subscription's discounts for the replacement price.

Parameters:

Returns:



3929
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3929

optional :discounts, -> { Orb::Internal::Type::ArrayOf[Orb::DiscountOverride] }, nil?: true

#external_price_id ⇒ String?

The external price id of the price to add to the subscription.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3935
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3935

optional :external_price_id, String, nil?: true

#fixed_price_quantity ⇒ Float?

The new quantity of the price, if the price is a fixed price.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


3941
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3941

optional :fixed_price_quantity, Float, nil?: true

#maximum_amount ⇒ String?

Deprecated.

[DEPRECATED] Use add_adjustments instead. The subscription's maximum amount for the replacement price.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3950
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3950

optional :maximum_amount, String, nil?: true

#metric_parameter_overrides ⇒ Hash{Symbol=>Object}?

Override values for parameterized billable metric variables. Keys are parameter names, values are the override values.

Parameters:

  • value (::Hash[Symbol, top], nil)

Returns:

  • (Hash{Symbol=>Object}, nil)


3957
3958
3959
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3957

optional :metric_parameter_overrides,
Orb::Internal::Type::HashOf[Orb::Internal::Type::Unknown],
nil?: true

#minimum_amount ⇒ String?

Deprecated.

[DEPRECATED] Use add_adjustments instead. The subscription's minimum amount for the replacement price.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3968
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3968

optional :minimum_amount, String, nil?: true

#price ⇒ Orb::Models::NewSubscriptionUnitPrice, ...

New subscription price request body params.

Parameters:

  • value (Orb::Models::SubscriptionSchedulePlanChangeParams::ReplacePrice::price, nil)

Returns:



3974
3975
3976
3977
3978
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3974

optional :price,
union: -> {
  Orb::SubscriptionSchedulePlanChangeParams::ReplacePrice::Price
},
nil?: true

#price_id ⇒ String?

The id of the price to add to the subscription.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3984
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3984

optional :price_id, String, nil?: true

#replaces_price_id ⇒ String

The id of the price on the plan to replace in the subscription.

Parameters:

  • value (String)

Returns:

  • (String)


3914
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3914

required :replaces_price_id, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


2731
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 2731

def to_hash: -> {