Class: Orb::Models::SubscriptionSchedulePlanChangeParams::ReplacePrice::Price::DailyCreditAllowance::DailyCreditAllowanceConfig

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/subscription_schedule_plan_change_params.rb,
sig/orb/models/subscription_schedule_plan_change_params.rbs

Overview

See Also:

  • Orb::Models::SubscriptionSchedulePlanChangeParams::ReplacePrice::Price::DailyCreditAllowance#daily_credit_allowance_config

Defined Under Namespace

Classes: MatrixValue

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



3458
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 3458

def initialize: (

Instance Attribute Details

#daily_allowanceString

Credits granted per day. Lose-it-or-use-it; does not roll over.

Parameters:

  • value (String)

Returns:

  • (String)


4984
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 4984

required :daily_allowance, String

#default_unit_amountString

Default per-unit credit rate for any usage not bucketed into a specified matrix_value

Parameters:

  • value (String)

Returns:

  • (String)


4991
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 4991

required :default_unit_amount, String

#dimensionsArray<String, nil>

One or two event property values to evaluate matrix groups by

Parameters:

  • value (::Array[String?])

Returns:

  • (Array<String, nil>)


4997
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 4997

required :dimensions, Orb::Internal::Type::ArrayOf[String, nil?: true]

#event_day_propertyString

Event property whose value identifies the day bucket the event belongs to (e.g. 'event_day' set to an ISO date string in the customer's timezone). The allowance resets per distinct value of this property.

Parameters:

  • value (String)

Returns:

  • (String)


5005
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 5005

required :event_day_property, String

#matrix_valuesArray<Orb::Models::SubscriptionSchedulePlanChangeParams::ReplacePrice::Price::DailyCreditAllowance::DailyCreditAllowanceConfig::MatrixValue>

Per-dimension credit rates

Parameters:

  • value (::Array[Orb::SubscriptionSchedulePlanChangeParams::ReplacePrice::Price::DailyCreditAllowance::DailyCreditAllowanceConfig::MatrixValue])

Returns:



5011
5012
5013
5014
5015
5016
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 5011

required :matrix_values,
-> do
  Orb::Internal::Type::ArrayOf[
    Orb::SubscriptionSchedulePlanChangeParams::ReplacePrice::Price::DailyCreditAllowance::DailyCreditAllowanceConfig::MatrixValue
  ]
end

Instance Method Details

#to_hash{

Returns:

  • ({)


3466
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 3466

def to_hash: -> {