Class: Orb::Models::SubscriptionSchedulePlanChangeParams::ReplacePrice::Price::GroupedTieredMatrix::GroupedTieredMatrixConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionSchedulePlanChangeParams::ReplacePrice::Price::GroupedTieredMatrix::GroupedTieredMatrixConfig
- Defined in:
- lib/orb/models/subscription_schedule_plan_change_params.rb,
sig/orb/models/subscription_schedule_plan_change_params.rbs
Overview
Defined Under Namespace
Classes: Tier
Instance Attribute Summary collapse
-
#default_unit_amount ⇒ String
Per unit rate for usage whose dimension value has no configured tiers.
-
#dimension ⇒ String
The billable metric property used to group usage before tiering.
-
#tiers ⇒ Array<Orb::Models::SubscriptionSchedulePlanChangeParams::ReplacePrice::Price::GroupedTieredMatrix::GroupedTieredMatrixConfig::Tier>
Graduated tiers keyed by dimension value; usage for a value is tiered only against its own rows.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
2920 |
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 2920
def initialize: (
|
Instance Attribute Details
#default_unit_amount ⇒ String
Per unit rate for usage whose dimension value has no configured tiers
4239 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 4239 required :default_unit_amount, String |
#dimension ⇒ String
The billable metric property used to group usage before tiering
4245 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 4245 required :dimension, String |
#tiers ⇒ Array<Orb::Models::SubscriptionSchedulePlanChangeParams::ReplacePrice::Price::GroupedTieredMatrix::GroupedTieredMatrixConfig::Tier>
Graduated tiers keyed by dimension value; usage for a value is tiered only against its own rows
4252 4253 4254 4255 4256 4257 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 4252 required :tiers, -> do Orb::Internal::Type::ArrayOf[ Orb::SubscriptionSchedulePlanChangeParams::ReplacePrice::Price::GroupedTieredMatrix::GroupedTieredMatrixConfig::Tier ] end |
Instance Method Details
#to_hash ⇒ {
2926 |
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 2926
def to_hash: -> {
|