Class: Orb::Models::SubscriptionSchedulePlanChangeParams::ReplacePrice::Price::Percent::PercentConfig

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/subscription_schedule_plan_change_params.rb,
sig/orb/models/subscription_schedule_plan_change_params.rbs

Overview

See Also:

  • Orb::Models::SubscriptionSchedulePlanChangeParams::ReplacePrice::Price::Percent#percent_config

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



3815
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 3815

def initialize: (

Instance Attribute Details

#maximum_amountString?

Maximum amount to charge. If unset, the fee has no upper bound.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


5520
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 5520

optional :maximum_amount, String, nil?: true

#minimum_amountString?

Minimum amount to charge. If unset, the fee is bounded below by 0.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


5526
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 5526

optional :minimum_amount, String, nil?: true

#percentFloat

Fraction of the component subtotals to charge (0 < percent <= 1).

Parameters:

  • value (Float)

Returns:

  • (Float)


5514
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 5514

required :percent, Float

#proratedBoolean?

If true, the minimum_amount is prorated based on the service period. The maximum_amount is an absolute cap (never prorated), and the percent applied to upstream subtotals is never prorated either.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


5534
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 5534

optional :prorated, Orb::Internal::Type::Boolean

Instance Method Details

#to_hash{

Returns:

  • ({)


3822
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 3822

def to_hash: -> {