Class: Orb::Models::SubscriptionSchedulePlanChangeParams::ReplacePrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionSchedulePlanChangeParams::ReplacePrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier
- Defined in:
- lib/orb/models/subscription_schedule_plan_change_params.rb,
sig/orb/models/subscription_schedule_plan_change_params.rbs
Instance Attribute Summary collapse
-
#dimension_values ⇒ Array<String>
The matrix cell this tier applies to, as one or two dimension values.
-
#tier_lower_bound ⇒ String
Exclusive tier starting value.
-
#unit_amount ⇒ String
Per unit amount.
Instance Method Summary collapse
-
#initialize(allocation:, default_unit_amount:, dimensions:, tiers:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Orb::Models::SubscriptionSchedulePlanChangeParams::ReplacePrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(allocation:, default_unit_amount:, dimensions:, tiers:) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::SubscriptionSchedulePlanChangeParams::ReplacePrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig for more details.
Configuration for tiered_matrix_with_allocation pricing
4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 4892 4893 4894 4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 4874 class Tier < Orb::Internal::Type::BaseModel # @!attribute dimension_values # The matrix cell this tier applies to, as one or two dimension values # # @return [Array<String>] required :dimension_values, Orb::Internal::Type::ArrayOf[String] # @!attribute tier_lower_bound # Exclusive tier starting value. The tier runs up to and including the next bound # configured for the same matrix cell. # # @return [String] required :tier_lower_bound, String # @!attribute unit_amount # Per unit amount # # @return [String] required :unit_amount, String # @!method initialize(dimension_values:, tier_lower_bound:, unit_amount:) # Some parameter documentations has been truncated, see # {Orb::Models::SubscriptionSchedulePlanChangeParams::ReplacePrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier} # for more details. # # Configuration for a single tier scoped to one matrix cell # # @param dimension_values [Array<String>] The matrix cell this tier applies to, as one or two dimension values # # @param tier_lower_bound [String] Exclusive tier starting value. The tier runs up to and including the next bound # # @param unit_amount [String] Per unit amount end |
Instance Attribute Details
#dimension_values ⇒ Array<String>
The matrix cell this tier applies to, as one or two dimension values
4879 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 4879 required :dimension_values, Orb::Internal::Type::ArrayOf[String] |
#tier_lower_bound ⇒ String
Exclusive tier starting value. The tier runs up to and including the next bound configured for the same matrix cell.
4886 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 4886 required :tier_lower_bound, String |
#unit_amount ⇒ String
Per unit amount
4892 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 4892 required :unit_amount, String |
Instance Method Details
#to_hash ⇒ {
3328 |
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 3328
def to_hash: -> {
|