Class: Orb::Models::SubscriptionSpendExceededWebhookEvent::Properties
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionSpendExceededWebhookEvent::Properties
- Defined in:
- lib/orb/models/subscription_spend_exceeded_webhook_event.rb,
sig/orb/models/subscription_spend_exceeded_webhook_event.rbs
Overview
Defined Under Namespace
Classes: AlertConfiguration
Instance Attribute Summary collapse
-
#alert_configuration ⇒ Orb::Models::SubscriptionSpendExceededWebhookEvent::Properties::AlertConfiguration
Alerts within Orb monitor spending, usage, or credit balance and trigger webhooks when a threshold is exceeded.
- #amount_threshold ⇒ String?
- #evaluated_amount ⇒ String?
- #timeframe_end ⇒ Time
- #timeframe_start ⇒ Time
Instance Method Summary collapse
-
#initialize(alert_configuration:, amount_threshold:, evaluated_amount:, timeframe_end:, timeframe_start:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Properties for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(alert_configuration:, amount_threshold:, evaluated_amount:, timeframe_end:, timeframe_start:) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::SubscriptionSpendExceededWebhookEvent::Properties for more details.
|
|
# File 'lib/orb/models/subscription_spend_exceeded_webhook_event.rb', line 103
|
Instance Attribute Details
#alert_configuration ⇒ Orb::Models::SubscriptionSpendExceededWebhookEvent::Properties::AlertConfiguration
Alerts within Orb monitor spending, usage, or credit balance and trigger webhooks when a threshold is exceeded.
Alerts created through the API can be scoped to either customers or subscriptions.
80 81 |
# File 'lib/orb/models/subscription_spend_exceeded_webhook_event.rb', line 80 required :alert_configuration, -> { Orb::SubscriptionSpendExceededWebhookEvent::Properties::AlertConfiguration } |
#amount_threshold ⇒ String?
86 |
# File 'lib/orb/models/subscription_spend_exceeded_webhook_event.rb', line 86 required :amount_threshold, String, nil?: true |
#evaluated_amount ⇒ String?
91 |
# File 'lib/orb/models/subscription_spend_exceeded_webhook_event.rb', line 91 required :evaluated_amount, String, nil?: true |
#timeframe_end ⇒ Time
96 |
# File 'lib/orb/models/subscription_spend_exceeded_webhook_event.rb', line 96 required :timeframe_end, Time |
#timeframe_start ⇒ Time
101 |
# File 'lib/orb/models/subscription_spend_exceeded_webhook_event.rb', line 101 required :timeframe_start, Time |
Instance Method Details
#to_hash ⇒ {
67 |
# File 'sig/orb/models/subscription_spend_exceeded_webhook_event.rbs', line 67
def to_hash: -> {
|