Class: Orb::Models::SubscriptionStartedWebhookEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/subscription_started_webhook_event.rb,
sig/orb/models/subscription_started_webhook_event.rbs

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, properties:, subscription:, type:) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::SubscriptionStartedWebhookEvent for more details.

Issued when a subscription begins.

Parameters:



# File 'lib/orb/models/subscription_started_webhook_event.rb', line 53

Instance Attribute Details

#created_at ⇒ Time

The time at which this event was created, to the second.

Parameters:

  • value (Time)

Returns:

  • (Time)


16
# File 'lib/orb/models/subscription_started_webhook_event.rb', line 16

required :created_at, Time

#id ⇒ String

The ID of this webhook event.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/orb/models/subscription_started_webhook_event.rb', line 10

required :id, String

#properties ⇒ Object

Parameters:

  • value (top)

Returns:

  • (Object)


21
# File 'lib/orb/models/subscription_started_webhook_event.rb', line 21

required :properties, Orb::Internal::Type::Unknown

#subscription ⇒ Orb::Models::Subscription

A subscription represents the purchase of a plan by a customer.

By default, subscriptions begin on the day that they're created and renew automatically for each billing cycle at the cadence that's configured in the plan definition.

Subscriptions also default to beginning of month alignment, which means the first invoice issued for the subscription will have pro-rated charges between the start_date and the first of the following month. Subsequent billing periods will always start and end on a month boundary (e.g. subsequent month starts for monthly billing).

Depending on the plan configuration, any flat recurring fees will be billed either at the beginning (in-advance) or end (in-arrears) of each billing cycle. Plans default to in-advance billing. Usage-based fees are billed in arrears as usage is accumulated. In the normal course of events, you can expect an invoice to contain usage-based charges for the previous period, and a recurring fee for the following period.

Parameters:

Returns:



45
# File 'lib/orb/models/subscription_started_webhook_event.rb', line 45

required :subscription, -> { Orb::Subscription }

#type ⇒ Symbol, Orb::Models::SubscriptionStartedWebhookEvent::Type

The event this payload describes.

Parameters:

  • value (Orb::Models::SubscriptionStartedWebhookEvent::type_)

Returns:



51
# File 'lib/orb/models/subscription_started_webhook_event.rb', line 51

required :type, enum: -> { Orb::SubscriptionStartedWebhookEvent::Type }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


31
# File 'sig/orb/models/subscription_started_webhook_event.rbs', line 31

def to_hash: -> {