Class: Orb::Models::SubscriptionUpdateFixedFeeQuantityParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/orb/models/subscription_update_fixed_fee_quantity_params.rb,
sig/orb/models/subscription_update_fixed_fee_quantity_params.rbs

Overview

See Also:

  • Orb::Resources::Subscriptions#update_fixed_fee_quantity

Defined Under Namespace

Modules: ChangeOption

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(subscription_id:, price_id:, quantity:, allow_invoice_credit_or_void: nil, change_option: nil, effective_date: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::SubscriptionUpdateFixedFeeQuantityParams for more details.

Parameters:

  • subscription_id (String)
  • price_id (String)

    Price for which the quantity should be updated. Must be a fixed fee.

  • quantity (Float)
  • allow_invoice_credit_or_void (Boolean, nil) (defaults to: nil)

    If false, this request will fail if it would void an issued invoice or create a

  • change_option (Symbol, Orb::Models::SubscriptionUpdateFixedFeeQuantityParams::ChangeOption) (defaults to: nil)

    Determines when the change takes effect. Note that if effective_date is specif

  • effective_date (Date, nil) (defaults to: nil)

    The date that the quantity change should take effect, localized to the customer'

  • request_options (Orb::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/orb/models/subscription_update_fixed_fee_quantity_params.rb', line 50

Instance Attribute Details

#allow_invoice_credit_or_voidBoolean?

If false, this request will fail if it would void an issued invoice or create a credit note. Consider using this as a safety mechanism if you do not expect existing invoices to be changed.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


32
# File 'lib/orb/models/subscription_update_fixed_fee_quantity_params.rb', line 32

optional :allow_invoice_credit_or_void, Orb::Internal::Type::Boolean, nil?: true

#change_optionSymbol, ...

Determines when the change takes effect. Note that if effective_date is specified, this defaults to effective_date. Otherwise, this defaults to immediate unless it's explicitly set to upcoming_invoice.



40
# File 'lib/orb/models/subscription_update_fixed_fee_quantity_params.rb', line 40

optional :change_option, enum: -> { Orb::SubscriptionUpdateFixedFeeQuantityParams::ChangeOption }

#effective_dateDate?

The date that the quantity change should take effect, localized to the customer's timezone. If this parameter is not passed in, the quantity change is effective according to change_option.

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


48
# File 'lib/orb/models/subscription_update_fixed_fee_quantity_params.rb', line 48

optional :effective_date, Date, nil?: true

#price_idString

Price for which the quantity should be updated. Must be a fixed fee.

Parameters:

  • value (String)

Returns:

  • (String)


19
# File 'lib/orb/models/subscription_update_fixed_fee_quantity_params.rb', line 19

required :price_id, String

#quantityFloat

Parameters:

  • value (Float)

Returns:

  • (Float)


24
# File 'lib/orb/models/subscription_update_fixed_fee_quantity_params.rb', line 24

required :quantity, Float

#subscription_idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/orb/models/subscription_update_fixed_fee_quantity_params.rb', line 13

required :subscription_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


44
# File 'sig/orb/models/subscription_update_fixed_fee_quantity_params.rbs', line 44

def to_hash: -> {