Class: Orb::Models::TransactionAccountingSyncFailedWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::TransactionAccountingSyncFailedWebhookEvent
- Defined in:
- lib/orb/models/transaction_accounting_sync_failed_webhook_event.rb,
sig/orb/models/transaction_accounting_sync_failed_webhook_event.rbs
Defined Under Namespace
Modules: Type Classes: AccountingSyncRecord, Properties, Transaction
Instance Attribute Summary collapse
- #accounting_sync_record ⇒ Orb::Models::TransactionAccountingSyncFailedWebhookEvent::AccountingSyncRecord
-
#created_at ⇒ Time
The time at which this event was created, to the second.
-
#id ⇒ String
The ID of this webhook event.
- #properties ⇒ Orb::Models::TransactionAccountingSyncFailedWebhookEvent::Properties
- #transaction ⇒ Orb::Models::TransactionAccountingSyncFailedWebhookEvent::Transaction
-
#type ⇒ Symbol, Orb::Models::TransactionAccountingSyncFailedWebhookEvent::Type
The event this payload describes.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(connection_type:, failure_reason:) ⇒ Object
|
|
# File 'lib/orb/models/transaction_accounting_sync_failed_webhook_event.rb', line 40
|
Instance Attribute Details
#accounting_sync_record ⇒ Orb::Models::TransactionAccountingSyncFailedWebhookEvent::AccountingSyncRecord
15 16 |
# File 'lib/orb/models/transaction_accounting_sync_failed_webhook_event.rb', line 15 required :accounting_sync_record, -> { Orb::TransactionAccountingSyncFailedWebhookEvent::AccountingSyncRecord } |
#created_at ⇒ Time
The time at which this event was created, to the second.
22 |
# File 'lib/orb/models/transaction_accounting_sync_failed_webhook_event.rb', line 22 required :created_at, Time |
#id ⇒ String
The ID of this webhook event.
10 |
# File 'lib/orb/models/transaction_accounting_sync_failed_webhook_event.rb', line 10 required :id, String |
#properties ⇒ Orb::Models::TransactionAccountingSyncFailedWebhookEvent::Properties
27 |
# File 'lib/orb/models/transaction_accounting_sync_failed_webhook_event.rb', line 27 required :properties, -> { Orb::TransactionAccountingSyncFailedWebhookEvent::Properties } |
#transaction ⇒ Orb::Models::TransactionAccountingSyncFailedWebhookEvent::Transaction
32 |
# File 'lib/orb/models/transaction_accounting_sync_failed_webhook_event.rb', line 32 required :transaction, -> { Orb::TransactionAccountingSyncFailedWebhookEvent::Transaction } |
#type ⇒ Symbol, Orb::Models::TransactionAccountingSyncFailedWebhookEvent::Type
The event this payload describes.
38 |
# File 'lib/orb/models/transaction_accounting_sync_failed_webhook_event.rb', line 38 required :type, enum: -> { Orb::TransactionAccountingSyncFailedWebhookEvent::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/transaction_accounting_sync_failed_webhook_event.rb', line 121
|
Instance Method Details
#to_hash ⇒ {
35 |
# File 'sig/orb/models/transaction_accounting_sync_failed_webhook_event.rbs', line 35
def to_hash: -> {
|