Class: Orb::Models::UsageDiscount::Filter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::UsageDiscount::Filter
- Defined in:
- lib/orb/models/usage_discount.rb,
sig/orb/models/usage_discount.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#field ⇒ Symbol, Orb::Models::UsageDiscount::Filter::Field
The property of the price to filter on.
-
#operator ⇒ Symbol, Orb::Models::UsageDiscount::Filter::Operator
Should prices that match the filter be included or excluded.
-
#values ⇒ Array<String>
The IDs or values that match this filter.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(field:, operator:, values:) ⇒ Object
|
|
# File 'lib/orb/models/usage_discount.rb', line 79
|
Instance Attribute Details
#field ⇒ Symbol, Orb::Models::UsageDiscount::Filter::Field
The property of the price to filter on.
65 |
# File 'lib/orb/models/usage_discount.rb', line 65 required :field, enum: -> { Orb::UsageDiscount::Filter::Field } |
#operator ⇒ Symbol, Orb::Models::UsageDiscount::Filter::Operator
Should prices that match the filter be included or excluded.
71 |
# File 'lib/orb/models/usage_discount.rb', line 71 required :operator, enum: -> { Orb::UsageDiscount::Filter::Operator } |
#values ⇒ Array<String>
The IDs or values that match this filter.
77 |
# File 'lib/orb/models/usage_discount.rb', line 77 required :values, Orb::Internal::Type::ArrayOf[String] |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/usage_discount.rb', line 98
|
Instance Method Details
#to_hash ⇒ {
69 |
# File 'sig/orb/models/usage_discount.rbs', line 69
def to_hash: -> {
|