Class: Orb::Resources::DimensionalPriceGroups::ExternalDimensionalPriceGroupID
- Inherits:
-
Object
- Object
- Orb::Resources::DimensionalPriceGroups::ExternalDimensionalPriceGroupID
- Defined in:
- lib/orb/resources/dimensional_price_groups/external_dimensional_price_group_id.rb,
sig/orb/resources/dimensional_price_groups/external_dimensional_price_group_id.rbs
Instance Method Summary collapse
-
#initialize(client:) ⇒ ExternalDimensionalPriceGroupID
constructor
private
A new instance of ExternalDimensionalPriceGroupID.
-
#retrieve(external_dimensional_price_group_id, request_options: {}) ⇒ Orb::Models::DimensionalPriceGroup
This endpoint returns a dimensional price group identified by the external ID you assigned it, rather than by its Orb ID.
-
#update(path_external_dimensional_price_group_id, body_external_dimensional_price_group_id: nil, metadata: nil, request_options: {}) ⇒ Orb::Models::DimensionalPriceGroup
Some parameter documentations has been truncated, see Models::DimensionalPriceGroups::ExternalDimensionalPriceGroupIDUpdateParams for more details.
Constructor Details
#initialize(client:) ⇒ ExternalDimensionalPriceGroupID
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of ExternalDimensionalPriceGroupID.
71 72 73 |
# File 'lib/orb/resources/dimensional_price_groups/external_dimensional_price_group_id.rb', line 71 def initialize(client:) @client = client end |
Instance Method Details
#retrieve(external_dimensional_price_group_id, request_options: {}) ⇒ Orb::Models::DimensionalPriceGroup
This endpoint returns a dimensional price group identified by the external ID you assigned it, rather than by its Orb ID. A dimensional price group partitions the result of a billable metric by a set of dimensions, and the prices in the group specify which partition their usage is derived from.
20 21 22 23 24 25 26 27 28 29 30 |
# File 'lib/orb/resources/dimensional_price_groups/external_dimensional_price_group_id.rb', line 20 def retrieve(external_dimensional_price_group_id, params = {}) @client.request( method: :get, path: [ "dimensional_price_groups/external_dimensional_price_group_id/%1$s", external_dimensional_price_group_id ], model: Orb::DimensionalPriceGroup, options: params[:request_options] ) end |
#update(path_external_dimensional_price_group_id, body_external_dimensional_price_group_id: nil, metadata: nil, request_options: {}) ⇒ Orb::Models::DimensionalPriceGroup
Some parameter documentations has been truncated, see Models::DimensionalPriceGroups::ExternalDimensionalPriceGroupIDUpdateParams for more details.
This endpoint can be used to update the external_dimensional_price_group_id
and metadata of an existing dimensional price group. Other fields on a
dimensional price group are currently immutable.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/orb/resources/dimensional_price_groups/external_dimensional_price_group_id.rb', line 53 def update(path_external_dimensional_price_group_id, params = {}) parsed, = Orb::DimensionalPriceGroups::ExternalDimensionalPriceGroupIDUpdateParams.dump_request(params) @client.request( method: :put, path: [ "dimensional_price_groups/external_dimensional_price_group_id/%1$s", path_external_dimensional_price_group_id ], body: parsed, model: Orb::DimensionalPriceGroup, options: ) end |