Class: Orb::Models::Alert
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Alert
- Defined in:
- lib/orb/models/alert.rb,
sig/orb/models/alert.rbs
Overview
Defined Under Namespace
Modules: Type Classes: BalanceAlertStatus, LicenseType, Metric, Plan, PriceFilter, ThresholdOverride
Instance Attribute Summary collapse
-
#balance_alert_status ⇒ Array<Orb::Models::Alert::BalanceAlertStatus>?
The current status of the alert.
-
#created_at ⇒ Time
The creation time of the resource in Orb.
-
#currency ⇒ String?
The name of the currency the credit balance or invoice cost is denominated in.
-
#customer ⇒ Orb::Models::CustomerMinified?
The customer the alert applies to.
-
#enabled ⇒ Boolean
Whether the alert is enabled or disabled.
-
#grouping_keys ⇒ Array<String>?
The property keys to group cost alerts by.
-
#id ⇒ String
Also referred to as alert_id in this documentation.
-
#license_type ⇒ Orb::Models::Alert::LicenseType?
Minified license type for alert serialization.
-
#metric ⇒ Orb::Models::Alert::Metric?
The metric the alert applies to.
-
#plan ⇒ Orb::Models::Alert::Plan?
The plan the alert applies to.
-
#price_filters ⇒ Array<Orb::Models::Alert::PriceFilter>?
Filters scoping which prices are included in grouped cost alert evaluation.
-
#subscription ⇒ Orb::Models::SubscriptionMinified?
The subscription the alert applies to.
-
#threshold_overrides ⇒ Array<Orb::Models::Alert::ThresholdOverride>?
Per-group threshold overrides.
-
#thresholds ⇒ Array<Orb::Models::Threshold>?
The thresholds that define the conditions under which the alert will be triggered.
-
#type ⇒ Symbol, Orb::Models::Alert::Type
The type of alert.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:) ⇒ Object
constructor
Minified license type for alert serialization.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:) ⇒ Object
Minified license type for alert serialization.
|
|
# File 'lib/orb/models/alert.rb', line 106
|
Instance Attribute Details
#balance_alert_status ⇒ Array<Orb::Models::Alert::BalanceAlertStatus>?
The current status of the alert. This field is only present for credit balance alerts.
73 74 75 |
# File 'lib/orb/models/alert.rb', line 73 optional :balance_alert_status, -> { Orb::Internal::Type::ArrayOf[Orb::Alert::BalanceAlertStatus] }, nil?: true |
#created_at ⇒ Time
The creation time of the resource in Orb.
17 |
# File 'lib/orb/models/alert.rb', line 17 required :created_at, Time |
#currency ⇒ String?
The name of the currency the credit balance or invoice cost is denominated in.
23 |
# File 'lib/orb/models/alert.rb', line 23 required :currency, String, nil?: true |
#customer ⇒ Orb::Models::CustomerMinified?
The customer the alert applies to.
29 |
# File 'lib/orb/models/alert.rb', line 29 required :customer, -> { Orb::CustomerMinified }, nil?: true |
#enabled ⇒ Boolean
Whether the alert is enabled or disabled.
35 |
# File 'lib/orb/models/alert.rb', line 35 required :enabled, Orb::Internal::Type::Boolean |
#grouping_keys ⇒ Array<String>?
The property keys to group cost alerts by. Only present for cost alerts with grouping enabled.
82 |
# File 'lib/orb/models/alert.rb', line 82 optional :grouping_keys, Orb::Internal::Type::ArrayOf[String], nil?: true |
#id ⇒ String
Also referred to as alert_id in this documentation.
11 |
# File 'lib/orb/models/alert.rb', line 11 required :id, String |
#license_type ⇒ Orb::Models::Alert::LicenseType?
Minified license type for alert serialization.
88 |
# File 'lib/orb/models/alert.rb', line 88 optional :license_type, -> { Orb::Alert::LicenseType }, nil?: true |
#metric ⇒ Orb::Models::Alert::Metric?
The metric the alert applies to.
41 |
# File 'lib/orb/models/alert.rb', line 41 required :metric, -> { Orb::Alert::Metric }, nil?: true |
#plan ⇒ Orb::Models::Alert::Plan?
The plan the alert applies to.
47 |
# File 'lib/orb/models/alert.rb', line 47 required :plan, -> { Orb::Alert::Plan }, nil?: true |
#price_filters ⇒ Array<Orb::Models::Alert::PriceFilter>?
Filters scoping which prices are included in grouped cost alert evaluation.
94 |
# File 'lib/orb/models/alert.rb', line 94 optional :price_filters, -> { Orb::Internal::Type::ArrayOf[Orb::Alert::PriceFilter] }, nil?: true |
#subscription ⇒ Orb::Models::SubscriptionMinified?
The subscription the alert applies to.
53 |
# File 'lib/orb/models/alert.rb', line 53 required :subscription, -> { Orb::SubscriptionMinified }, nil?: true |
#threshold_overrides ⇒ Array<Orb::Models::Alert::ThresholdOverride>?
Per-group threshold overrides. Each override maps a specific combination of grouping_keys values to a replacement threshold list. Only present for grouped cost alerts that have at least one override.
102 103 104 |
# File 'lib/orb/models/alert.rb', line 102 optional :threshold_overrides, -> { Orb::Internal::Type::ArrayOf[Orb::Alert::ThresholdOverride] }, nil?: true |
#thresholds ⇒ Array<Orb::Models::Threshold>?
The thresholds that define the conditions under which the alert will be triggered.
60 |
# File 'lib/orb/models/alert.rb', line 60 required :thresholds, -> { Orb::Internal::Type::ArrayOf[Orb::Threshold] }, nil?: true |
#type ⇒ Symbol, Orb::Models::Alert::Type
The type of alert. This must be a valid alert type.
66 |
# File 'lib/orb/models/alert.rb', line 66 required :type, enum: -> { Orb::Alert::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/alert.rb', line 212
|
Instance Method Details
#to_hash ⇒ {
71 |
# File 'sig/orb/models/alert.rbs', line 71
def to_hash: -> {
|