Class: Orb::Models::Alert::ThresholdOverride

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/alert.rb,
sig/orb/models/alert.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(group_values:, thresholds:) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::Alert::ThresholdOverride for more details.

A per-group threshold override on a grouped cost alert.

An empty thresholds list means the group is silenced (never fires). A non-empty list fully replaces the default thresholds for that group.

Parameters:

  • group_values (Array<String>)

    The values of the grouping keys that identify this group. The list length matche

  • thresholds (Array<Orb::Models::Threshold>)

    The thresholds applied to this group. An empty list means the group is silenced.



# File 'lib/orb/models/alert.rb', line 320

Instance Attribute Details

#group_valuesArray<String>

The values of the grouping keys that identify this group. The list length matches the alert's grouping_keys.

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


312
# File 'lib/orb/models/alert.rb', line 312

required :group_values, Orb::Internal::Type::ArrayOf[String]

#thresholdsArray<Orb::Models::Threshold>

The thresholds applied to this group. An empty list means the group is silenced.

Parameters:

Returns:



318
# File 'lib/orb/models/alert.rb', line 318

required :thresholds, -> { Orb::Internal::Type::ArrayOf[Orb::Threshold] }

Instance Method Details

#to_hash{

Returns:

  • ({)


240
# File 'sig/orb/models/alert.rbs', line 240

def to_hash: -> {