Class: Orb::Models::AlertCreateForSubscriptionParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::AlertCreateForSubscriptionParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/orb/models/alert_create_for_subscription_params.rb,
sig/orb/models/alert_create_for_subscription_params.rbs
Overview
Defined Under Namespace
Modules: Type Classes: PriceFilter, ThresholdOverride
Instance Attribute Summary collapse
-
#currency ⇒ String?
The case sensitive currency or custom pricing unit to use for grouped cost alerts.
-
#grouping_keys ⇒ Array<String>?
The property keys to group cost alerts by.
-
#metric_id ⇒ String?
The metric to track usage for.
-
#price_filters ⇒ Array<Orb::Models::AlertCreateForSubscriptionParams::PriceFilter>?
Filters to scope which prices are included in grouped cost alert evaluation.
- #subscription_id ⇒ String
-
#threshold_overrides ⇒ Array<Orb::Models::AlertCreateForSubscriptionParams::ThresholdOverride>?
Per-group threshold overrides.
-
#thresholds ⇒ Array<Orb::Models::Threshold>
The thresholds that define the values at which the alert will be triggered.
-
#type ⇒ Symbol, Orb::Models::AlertCreateForSubscriptionParams::Type
The type of alert to create.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(subscription_id:, thresholds:, type:, currency: nil, grouping_keys: nil, metric_id: nil, price_filters: nil, threshold_overrides: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see AlertCreateForSubscriptionParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(subscription_id:, thresholds:, type:, currency: nil, grouping_keys: nil, metric_id: nil, price_filters: nil, threshold_overrides: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::AlertCreateForSubscriptionParams for more details.
|
|
# File 'lib/orb/models/alert_create_for_subscription_params.rb', line 69
|
Instance Attribute Details
#currency ⇒ String?
The case sensitive currency or custom pricing unit to use for grouped cost alerts. Required when grouping_keys is set.
32 |
# File 'lib/orb/models/alert_create_for_subscription_params.rb', line 32 optional :currency, String, nil?: true |
#grouping_keys ⇒ Array<String>?
The property keys to group cost alerts by. Only applicable for cost_exceeded alerts.
39 |
# File 'lib/orb/models/alert_create_for_subscription_params.rb', line 39 optional :grouping_keys, Orb::Internal::Type::ArrayOf[String], nil?: true |
#metric_id ⇒ String?
The metric to track usage for.
45 |
# File 'lib/orb/models/alert_create_for_subscription_params.rb', line 45 optional :metric_id, String, nil?: true |
#price_filters ⇒ Array<Orb::Models::AlertCreateForSubscriptionParams::PriceFilter>?
Filters to scope which prices are included in grouped cost alert evaluation. Supports filtering by price_id, item_id, or price_type with includes/excludes operators. Only applicable when grouping_keys is set.
53 54 55 |
# File 'lib/orb/models/alert_create_for_subscription_params.rb', line 53 optional :price_filters, -> { Orb::Internal::Type::ArrayOf[Orb::AlertCreateForSubscriptionParams::PriceFilter] }, nil?: true |
#subscription_id ⇒ String
13 |
# File 'lib/orb/models/alert_create_for_subscription_params.rb', line 13 required :subscription_id, String |
#threshold_overrides ⇒ Array<Orb::Models::AlertCreateForSubscriptionParams::ThresholdOverride>?
Per-group threshold overrides. Each override maps a specific combination of grouping_keys values to a list of thresholds that fully replaces the default thresholds for that group. An empty thresholds list silences the group. Groups without an override use the default thresholds. Only applicable when grouping_keys is set.
65 66 67 |
# File 'lib/orb/models/alert_create_for_subscription_params.rb', line 65 optional :threshold_overrides, -> { Orb::Internal::Type::ArrayOf[Orb::AlertCreateForSubscriptionParams::ThresholdOverride] }, nil?: true |
#thresholds ⇒ Array<Orb::Models::Threshold>
The thresholds that define the values at which the alert will be triggered.
19 |
# File 'lib/orb/models/alert_create_for_subscription_params.rb', line 19 required :thresholds, -> { Orb::Internal::Type::ArrayOf[Orb::Threshold] } |
#type ⇒ Symbol, Orb::Models::AlertCreateForSubscriptionParams::Type
The type of alert to create. This must be a valid alert type.
25 |
# File 'lib/orb/models/alert_create_for_subscription_params.rb', line 25 required :type, enum: -> { Orb::AlertCreateForSubscriptionParams::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/alert_create_for_subscription_params.rb', line 98
|
Instance Method Details
#to_hash ⇒ {
48 |
# File 'sig/orb/models/alert_create_for_subscription_params.rbs', line 48
def to_hash: -> {
|