Class: Orb::Models::BackfillRevertedWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::BackfillRevertedWebhookEvent
- Defined in:
- lib/orb/models/backfill_reverted_webhook_event.rb,
sig/orb/models/backfill_reverted_webhook_event.rbs
Defined Under Namespace
Modules: Type Classes: Backfill
Instance Attribute Summary collapse
-
#backfill ⇒ Orb::Models::BackfillRevertedWebhookEvent::Backfill
A backfill represents an update to historical usage data, adding or replacing events in a timeframe.
-
#created_at ⇒ Time
The time at which this event was created, to the second.
-
#id ⇒ String
The ID of this webhook event.
- #properties ⇒ Object
-
#type ⇒ Symbol, Orb::Models::BackfillRevertedWebhookEvent::Type
The event this payload describes.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, backfill:, created_at:, properties:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see BackfillRevertedWebhookEvent for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, backfill:, created_at:, properties:, type:) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::BackfillRevertedWebhookEvent for more details.
Issued when a backfill is reverted, removing its events from usage.
|
|
# File 'lib/orb/models/backfill_reverted_webhook_event.rb', line 36
|
Instance Attribute Details
#backfill ⇒ Orb::Models::BackfillRevertedWebhookEvent::Backfill
A backfill represents an update to historical usage data, adding or replacing events in a timeframe.
17 |
# File 'lib/orb/models/backfill_reverted_webhook_event.rb', line 17 required :backfill, -> { Orb::BackfillRevertedWebhookEvent::Backfill } |
#created_at ⇒ Time
The time at which this event was created, to the second.
23 |
# File 'lib/orb/models/backfill_reverted_webhook_event.rb', line 23 required :created_at, Time |
#id ⇒ String
The ID of this webhook event.
10 |
# File 'lib/orb/models/backfill_reverted_webhook_event.rb', line 10 required :id, String |
#properties ⇒ Object
28 |
# File 'lib/orb/models/backfill_reverted_webhook_event.rb', line 28 required :properties, Orb::Internal::Type::Unknown |
#type ⇒ Symbol, Orb::Models::BackfillRevertedWebhookEvent::Type
The event this payload describes.
34 |
# File 'lib/orb/models/backfill_reverted_webhook_event.rb', line 34 required :type, enum: -> { Orb::BackfillRevertedWebhookEvent::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/backfill_reverted_webhook_event.rb', line 162
|
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/orb/models/backfill_reverted_webhook_event.rbs', line 31
def to_hash: -> {
|