Class: Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::LicenseAllocationPrice

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/orb/models/beta/external_plan_id_create_plan_version_params.rb,
sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs

Overview

See Also:

  • Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice#license_allocation_price

Defined Under Namespace

Modules: Cadence, ModelType Classes: LicenseAllocation

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, currency:, write_off_overage: nil) ⇒ Object

Parameters:

  • amount (String)

    The amount of credits granted per active license per cadence.

  • currency (String)

    The currency of the license allocation.

  • write_off_overage (Boolean, nil) (defaults to: nil)

    When True, overage beyond the allocation is written off.



# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3492

Instance Attribute Details

#billable_metric_idString?

The id of the billable metric for the price. Only needed if the price is usage-based.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3400
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3400

optional :billable_metric_id, String, nil?: true

#billed_in_advanceBoolean?

If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


3407
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3407

optional :billed_in_advance, Orb::Internal::Type::Boolean, nil?: true

#billing_cycle_configurationOrb::Models::NewBillingCycleConfiguration?

For custom cadence: specifies the duration of the billing period in days or months.



3414
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3414

optional :billing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true

#cadenceSymbol, Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::LicenseAllocationPrice::Cadence

The cadence to bill for this price on.

Parameters:

  • value (Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::LicenseAllocationPrice::cadence)

Returns:



3358
3359
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3358

required :cadence,
enum: -> { Orb::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::LicenseAllocationPrice::Cadence }

#conversion_rateFloat?

The per unit conversion rate of the price currency to the invoicing currency.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


3420
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3420

optional :conversion_rate, Float, nil?: true

#conversion_rate_configOrb::Models::UnitConversionRateConfig, ...

The configuration for the rate of the price currency to the invoicing currency.

Parameters:

  • value (Orb::Models::conversion_rate_config, nil)

Returns:



3426
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3426

optional :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true

#currencyString?

An ISO 4217 currency string, or custom pricing unit identifier, in which this price is billed.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3433
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3433

optional :currency, String, nil?: true

#dimensional_price_configurationOrb::Models::NewDimensionalPriceConfiguration?

For dimensional price: specifies a price group and dimension values



3439
3440
3441
3442
3443
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3439

optional :dimensional_price_configuration,
-> {
  Orb::NewDimensionalPriceConfiguration
},
nil?: true

#external_price_idString?

An alias for the price.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3449
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3449

optional :external_price_id, String, nil?: true

#fixed_price_quantityFloat?

If the Price represents a fixed cost, this represents the quantity of units applied.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


3456
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3456

optional :fixed_price_quantity, Float, nil?: true

#invoice_grouping_keyString?

The property used to group this price on an invoice

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3462
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3462

optional :invoice_grouping_key, String, nil?: true

#invoicing_cycle_configurationOrb::Models::NewBillingCycleConfiguration?

Within each billing cycle, specifies the cadence at which invoices are produced. If unspecified, a single invoice is produced per billing cycle.



3469
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3469

optional :invoicing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true

#item_idString

The id of the item the price will be associated with.

Parameters:

  • value (String)

Returns:

  • (String)


3365
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3365

required :item_id, String

#license_allocationsArray<Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::LicenseAllocationPrice::LicenseAllocation>

License allocations to associate with this price. Each entry defines a per-license credit pool granted each cadence. Requires license_type_id or license_type_configuration to be set.

Parameters:

  • value (::Array[Orb::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::LicenseAllocationPrice::LicenseAllocation])

Returns:



3373
3374
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3373

required :license_allocations,
-> { Orb::Internal::Type::ArrayOf[Orb::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::LicenseAllocationPrice::LicenseAllocation] }

#license_type_idString?

The ID of the license type to associate with this price.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3475
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3475

optional :license_type_id, String, nil?: true

#metadataHash{Symbol=>String, nil}?

User-specified key/value pairs for the resource. Individual keys can be removed by setting the value to null, and the entire metadata mapping can be cleared by setting metadata to null.

Parameters:

  • value (::Hash[Symbol, String?], nil)

Returns:

  • (Hash{Symbol=>String, nil}, nil)


3483
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3483

optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true

#model_typeSymbol, Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::LicenseAllocationPrice::ModelType

The pricing model type

Parameters:

  • value (Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::LicenseAllocationPrice::model_type)

Returns:



3380
3381
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3380

required :model_type,
enum: -> { Orb::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::LicenseAllocationPrice::ModelType }

#nameString

The name of the price.

Parameters:

  • value (String)

Returns:

  • (String)


3387
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3387

required :name, String

#reference_idString?

A transient ID that can be used to reference this price when adding adjustments in the same API call.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3490
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3490

optional :reference_id, String, nil?: true

#unit_configOrb::Models::UnitConfig

Configuration for unit pricing

Parameters:

Returns:



3393
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3393

required :unit_config, -> { Orb::UnitConfig }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 3552

Instance Method Details

#to_hash{

Returns:

  • ({)


2451
# File 'sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs', line 2451

def to_hash: -> {