Class: Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::Price::DailyCreditAllowance::DailyCreditAllowanceConfig::MatrixValue
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::Price::DailyCreditAllowance::DailyCreditAllowanceConfig::MatrixValue
- Defined in:
- lib/orb/models/beta/external_plan_id_create_plan_version_params.rb,
sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs
Instance Attribute Summary collapse
-
#dimension_values ⇒ Array<String, nil>
One or two matrix keys to filter usage to this value by.
-
#unit_amount ⇒ String
Credits charged per unit of usage matching the specified dimension_values.
Instance Method Summary collapse
-
#initialize(daily_allowance:, default_unit_amount:, dimensions:, event_day_property:, matrix_values:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::Price::DailyCreditAllowance::DailyCreditAllowanceConfig for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(daily_allowance:, default_unit_amount:, dimensions:, event_day_property:, matrix_values:) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::Price::DailyCreditAllowance::DailyCreditAllowanceConfig for more details.
Configuration for daily_credit_allowance pricing
matrix_
5203 5204 5205 5206 5207 5208 5209 5210 5211 5212 5213 5214 5215 5216 5217 5218 5219 5220 5221 5222 5223 5224 5225 5226 5227 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 5203 class MatrixValue < Orb::Internal::Type::BaseModel # @!attribute dimension_values # One or two matrix keys to filter usage to this value by. For example, ["model"] # could be used to apply a different credit rate to each AI model. # # @return [Array<String, nil>] required :dimension_values, Orb::Internal::Type::ArrayOf[String, nil?: true] # @!attribute unit_amount # Credits charged per unit of usage matching the specified dimension_values # # @return [String] required :unit_amount, String # @!method initialize(dimension_values:, unit_amount:) # Some parameter documentations has been truncated, see # {Orb::Models::Beta::ExternalPlanIDCreatePlanVersionParams::ReplacePrice::Price::DailyCreditAllowance::DailyCreditAllowanceConfig::MatrixValue} # for more details. # # Per-dimension credit price for the daily credit allowance model. # # @param dimension_values [Array<String, nil>] One or two matrix keys to filter usage to this value by. For example, ["model"] # # @param unit_amount [String] Credits charged per unit of usage matching the specified dimension_values end |
Instance Attribute Details
#dimension_values ⇒ Array<String, nil>
One or two matrix keys to filter usage to this value by. For example, ["model"] could be used to apply a different credit rate to each AI model.
5209 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 5209 required :dimension_values, Orb::Internal::Type::ArrayOf[String, nil?: true] |
#unit_amount ⇒ String
Credits charged per unit of usage matching the specified dimension_values
5215 |
# File 'lib/orb/models/beta/external_plan_id_create_plan_version_params.rb', line 5215 required :unit_amount, String |
Instance Method Details
#to_hash ⇒ {
3646 |
# File 'sig/orb/models/beta/external_plan_id_create_plan_version_params.rbs', line 3646
def to_hash: -> {
|