Class: Orb::Models::BetaCreatePlanVersionParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::BetaCreatePlanVersionParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/orb/models/beta_create_plan_version_params.rb,
sig/orb/models/beta_create_plan_version_params.rbs
Overview
Defined Under Namespace
Classes: AddAdjustment, AddPrice, RemoveAdjustment, RemovePrice, ReplaceAdjustment, ReplacePrice
Instance Attribute Summary collapse
-
#add_adjustments ⇒ Array<Orb::Models::BetaCreatePlanVersionParams::AddAdjustment>?
Additional adjustments to be added to the plan.
-
#add_prices ⇒ Array<Orb::Models::BetaCreatePlanVersionParams::AddPrice>?
Additional prices to be added to the plan.
- #plan_id ⇒ String
-
#remove_adjustments ⇒ Array<Orb::Models::BetaCreatePlanVersionParams::RemoveAdjustment>?
Adjustments to be removed from the plan.
-
#remove_prices ⇒ Array<Orb::Models::BetaCreatePlanVersionParams::RemovePrice>?
Prices to be removed from the plan.
-
#replace_adjustments ⇒ Array<Orb::Models::BetaCreatePlanVersionParams::ReplaceAdjustment>?
Adjustments to be replaced with additional adjustments on the plan.
-
#replace_prices ⇒ Array<Orb::Models::BetaCreatePlanVersionParams::ReplacePrice>?
Prices to be replaced with additional prices on the plan.
-
#set_as_default ⇒ Boolean?
Set this new plan version as the default.
-
#version ⇒ Integer
New version number.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(Orb::Models::NewPercentageDiscount, Orb::Models::NewUsageDiscount, Orb::Models::NewAmountDiscount, Orb::Models::NewMinimum, Orb::Models::NewMaximum, Orb::Models::BetaCreatePlanVersionParams::ReplaceAdjustment::Adjustment::TieredPercentageDiscount)
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(price_id:, plan_phase_order: nil) ⇒ Object
|
|
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 2939
|
Instance Attribute Details
#add_adjustments ⇒ Array<Orb::Models::BetaCreatePlanVersionParams::AddAdjustment>?
Additional adjustments to be added to the plan.
25 26 27 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 25 optional :add_adjustments, -> { Orb::Internal::Type::ArrayOf[Orb::BetaCreatePlanVersionParams::AddAdjustment] }, nil?: true |
#add_prices ⇒ Array<Orb::Models::BetaCreatePlanVersionParams::AddPrice>?
Additional prices to be added to the plan.
33 34 35 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 33 optional :add_prices, -> { Orb::Internal::Type::ArrayOf[Orb::BetaCreatePlanVersionParams::AddPrice] }, nil?: true |
#plan_id ⇒ String
13 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 13 required :plan_id, String |
#remove_adjustments ⇒ Array<Orb::Models::BetaCreatePlanVersionParams::RemoveAdjustment>?
Adjustments to be removed from the plan.
41 42 43 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 41 optional :remove_adjustments, -> { Orb::Internal::Type::ArrayOf[Orb::BetaCreatePlanVersionParams::RemoveAdjustment] }, nil?: true |
#remove_prices ⇒ Array<Orb::Models::BetaCreatePlanVersionParams::RemovePrice>?
Prices to be removed from the plan.
49 50 51 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 49 optional :remove_prices, -> { Orb::Internal::Type::ArrayOf[Orb::BetaCreatePlanVersionParams::RemovePrice] }, nil?: true |
#replace_adjustments ⇒ Array<Orb::Models::BetaCreatePlanVersionParams::ReplaceAdjustment>?
Adjustments to be replaced with additional adjustments on the plan.
57 58 59 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 57 optional :replace_adjustments, -> { Orb::Internal::Type::ArrayOf[Orb::BetaCreatePlanVersionParams::ReplaceAdjustment] }, nil?: true |
#replace_prices ⇒ Array<Orb::Models::BetaCreatePlanVersionParams::ReplacePrice>?
Prices to be replaced with additional prices on the plan.
65 66 67 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 65 optional :replace_prices, -> { Orb::Internal::Type::ArrayOf[Orb::BetaCreatePlanVersionParams::ReplacePrice] }, nil?: true |
#set_as_default ⇒ Boolean?
Set this new plan version as the default
73 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 73 optional :set_as_default, Orb::Internal::Type::Boolean, nil?: true |
#version ⇒ Integer
New version number.
19 |
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 19 required :version, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 334
|
.variants ⇒ Array(Orb::Models::NewPercentageDiscount, Orb::Models::NewUsageDiscount, Orb::Models::NewAmountDiscount, Orb::Models::NewMinimum, Orb::Models::NewMaximum, Orb::Models::BetaCreatePlanVersionParams::ReplaceAdjustment::Adjustment::TieredPercentageDiscount)
|
|
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 339
|
Instance Method Details
#to_hash ⇒ {
52 |
# File 'sig/orb/models/beta_create_plan_version_params.rbs', line 52
def to_hash: -> {
|