Class: Orb::Models::BetaCreatePlanVersionParams::ReplacePrice::LicenseAllocationPrice

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/beta_create_plan_version_params.rb,
sig/orb/models/beta_create_plan_version_params.rbs

Overview

See Also:

  • Orb::Models::BetaCreatePlanVersionParams::ReplacePrice#license_allocation_price

Defined Under Namespace

Modules: Cadence, ModelType Classes: LicenseAllocation

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, currency:, write_off_overage: nil) ⇒ Object

Parameters:

  • amount (String)

    The amount of credits granted per active license per cadence.

  • currency (String)

    The currency of the license allocation.

  • write_off_overage (Boolean, nil) (defaults to: nil)

    When True, overage beyond the allocation is written off.



# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3433

Instance Attribute Details

#billable_metric_idString?

The id of the billable metric for the price. Only needed if the price is usage-based.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3345
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3345

optional :billable_metric_id, String, nil?: true

#billed_in_advanceBoolean?

If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


3352
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3352

optional :billed_in_advance, Orb::Internal::Type::Boolean, nil?: true

#billing_cycle_configurationOrb::Models::NewBillingCycleConfiguration?

For custom cadence: specifies the duration of the billing period in days or months.



3359
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3359

optional :billing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true

#cadenceSymbol, Orb::Models::BetaCreatePlanVersionParams::ReplacePrice::LicenseAllocationPrice::Cadence

The cadence to bill for this price on.

Parameters:

  • value (Orb::Models::BetaCreatePlanVersionParams::ReplacePrice::LicenseAllocationPrice::cadence)

Returns:



3303
3304
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3303

required :cadence,
enum: -> { Orb::BetaCreatePlanVersionParams::ReplacePrice::LicenseAllocationPrice::Cadence }

#conversion_rateFloat?

The per unit conversion rate of the price currency to the invoicing currency.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


3365
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3365

optional :conversion_rate, Float, nil?: true

#conversion_rate_configOrb::Models::UnitConversionRateConfig, ...

The configuration for the rate of the price currency to the invoicing currency.

Parameters:

  • value (Orb::Models::conversion_rate_config, nil)

Returns:



3371
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3371

optional :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true

#currencyString?

An ISO 4217 currency string, or custom pricing unit identifier, in which this price is billed.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3378
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3378

optional :currency, String, nil?: true

#dimensional_price_configurationOrb::Models::NewDimensionalPriceConfiguration?

For dimensional price: specifies a price group and dimension values



3384
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3384

optional :dimensional_price_configuration, -> { Orb::NewDimensionalPriceConfiguration }, nil?: true

#external_price_idString?

An alias for the price.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3390
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3390

optional :external_price_id, String, nil?: true

#fixed_price_quantityFloat?

If the Price represents a fixed cost, this represents the quantity of units applied.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


3397
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3397

optional :fixed_price_quantity, Float, nil?: true

#invoice_grouping_keyString?

The property used to group this price on an invoice

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3403
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3403

optional :invoice_grouping_key, String, nil?: true

#invoicing_cycle_configurationOrb::Models::NewBillingCycleConfiguration?

Within each billing cycle, specifies the cadence at which invoices are produced. If unspecified, a single invoice is produced per billing cycle.



3410
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3410

optional :invoicing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true

#item_idString

The id of the item the price will be associated with.

Parameters:

  • value (String)

Returns:

  • (String)


3310
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3310

required :item_id, String

#license_allocationsArray<Orb::Models::BetaCreatePlanVersionParams::ReplacePrice::LicenseAllocationPrice::LicenseAllocation>

License allocations to associate with this price. Each entry defines a per-license credit pool granted each cadence. Requires license_type_id or license_type_configuration to be set.

Parameters:

  • value (::Array[Orb::BetaCreatePlanVersionParams::ReplacePrice::LicenseAllocationPrice::LicenseAllocation])

Returns:



3318
3319
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3318

required :license_allocations,
-> { Orb::Internal::Type::ArrayOf[Orb::BetaCreatePlanVersionParams::ReplacePrice::LicenseAllocationPrice::LicenseAllocation] }

#license_type_idString?

The ID of the license type to associate with this price.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3416
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3416

optional :license_type_id, String, nil?: true

#metadataHash{Symbol=>String, nil}?

User-specified key/value pairs for the resource. Individual keys can be removed by setting the value to null, and the entire metadata mapping can be cleared by setting metadata to null.

Parameters:

  • value (::Hash[Symbol, String?], nil)

Returns:

  • (Hash{Symbol=>String, nil}, nil)


3424
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3424

optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true

#model_typeSymbol, Orb::Models::BetaCreatePlanVersionParams::ReplacePrice::LicenseAllocationPrice::ModelType

The pricing model type

Parameters:

  • value (Orb::Models::BetaCreatePlanVersionParams::ReplacePrice::LicenseAllocationPrice::model_type)

Returns:



3325
3326
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3325

required :model_type,
enum: -> { Orb::BetaCreatePlanVersionParams::ReplacePrice::LicenseAllocationPrice::ModelType }

#nameString

The name of the price.

Parameters:

  • value (String)

Returns:

  • (String)


3332
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3332

required :name, String

#reference_idString?

A transient ID that can be used to reference this price when adding adjustments in the same API call.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3431
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3431

optional :reference_id, String, nil?: true

#unit_configOrb::Models::UnitConfig

Configuration for unit pricing

Parameters:

Returns:



3338
# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3338

required :unit_config, -> { Orb::UnitConfig }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/orb/models/beta_create_plan_version_params.rb', line 3493

Instance Method Details

#to_hash{

Returns:

  • ({)


2439
# File 'sig/orb/models/beta_create_plan_version_params.rbs', line 2439

def to_hash: -> {