Class: Orb::Models::BillableMetricEditedWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::BillableMetricEditedWebhookEvent
- Defined in:
- lib/orb/models/billable_metric_edited_webhook_event.rb,
sig/orb/models/billable_metric_edited_webhook_event.rbs
Defined Under Namespace
Modules: Type Classes: Properties
Instance Attribute Summary collapse
-
#billable_metric ⇒ Orb::Models::BillableMetric
The Metric resource represents a calculation of a quantity based on events.
-
#created_at ⇒ Time
The time at which this event was created, to the second.
-
#id ⇒ String
The ID of this webhook event.
- #properties ⇒ Orb::Models::BillableMetricEditedWebhookEvent::Properties
-
#type ⇒ Symbol, Orb::Models::BillableMetricEditedWebhookEvent::Type
The event this payload describes.
Instance Method Summary collapse
-
#initialize(description: nil, metadata: nil, name: nil) ⇒ Object
constructor
metadata values are non-null on the wire, as on the price event.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(description: nil, metadata: nil, name: nil) ⇒ Object
metadata values are non-null on the wire, as on the price event.
|
|
# File 'lib/orb/models/billable_metric_edited_webhook_event.rb', line 37
|
Instance Attribute Details
#billable_metric ⇒ Orb::Models::BillableMetric
The Metric resource represents a calculation of a quantity based on events. Metrics are defined by the query that transforms raw usage events into meaningful values for your customers.
18 |
# File 'lib/orb/models/billable_metric_edited_webhook_event.rb', line 18 required :billable_metric, -> { Orb::BillableMetric } |
#created_at ⇒ Time
The time at which this event was created, to the second.
24 |
# File 'lib/orb/models/billable_metric_edited_webhook_event.rb', line 24 required :created_at, Time |
#id ⇒ String
The ID of this webhook event.
10 |
# File 'lib/orb/models/billable_metric_edited_webhook_event.rb', line 10 required :id, String |
#properties ⇒ Orb::Models::BillableMetricEditedWebhookEvent::Properties
29 |
# File 'lib/orb/models/billable_metric_edited_webhook_event.rb', line 29 required :properties, -> { Orb::BillableMetricEditedWebhookEvent::Properties } |
#type ⇒ Symbol, Orb::Models::BillableMetricEditedWebhookEvent::Type
The event this payload describes.
35 |
# File 'lib/orb/models/billable_metric_edited_webhook_event.rb', line 35 required :type, enum: -> { Orb::BillableMetricEditedWebhookEvent::Type } |
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/orb/models/billable_metric_edited_webhook_event.rbs', line 31
def to_hash: -> {
|