Class: Orb::Models::ChangedSubscriptionResources
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::ChangedSubscriptionResources
- Defined in:
- lib/orb/models/changed_subscription_resources.rb,
sig/orb/models/changed_subscription_resources.rbs
Defined Under Namespace
Classes: CreatedInvoice
Instance Attribute Summary collapse
-
#created_credit_notes ⇒ Array<Orb::Models::CreditNote>
The credit notes that were created as part of this operation.
-
#created_invoices ⇒ Array<Orb::Models::ChangedSubscriptionResources::CreatedInvoice>
The invoices that were created as part of this operation.
-
#voided_credit_notes ⇒ Array<Orb::Models::CreditNote>
The credit notes that were voided as part of this operation.
-
#voided_invoices ⇒ Array<Orb::Models::Invoice>
The invoices that were voided as part of this operation.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
20 |
# File 'sig/orb/models/changed_subscription_resources.rbs', line 20
def initialize: (
|
Instance Attribute Details
#created_credit_notes ⇒ Array<Orb::Models::CreditNote>
The credit notes that were created as part of this operation.
10 |
# File 'lib/orb/models/changed_subscription_resources.rb', line 10 required :created_credit_notes, -> { Orb::Internal::Type::ArrayOf[Orb::CreditNote] } |
#created_invoices ⇒ Array<Orb::Models::ChangedSubscriptionResources::CreatedInvoice>
The invoices that were created as part of this operation.
16 17 |
# File 'lib/orb/models/changed_subscription_resources.rb', line 16 required :created_invoices, -> { Orb::Internal::Type::ArrayOf[Orb::ChangedSubscriptionResources::CreatedInvoice] } |
#voided_credit_notes ⇒ Array<Orb::Models::CreditNote>
The credit notes that were voided as part of this operation.
23 |
# File 'lib/orb/models/changed_subscription_resources.rb', line 23 required :voided_credit_notes, -> { Orb::Internal::Type::ArrayOf[Orb::CreditNote] } |
#voided_invoices ⇒ Array<Orb::Models::Invoice>
The invoices that were voided as part of this operation.
29 |
# File 'lib/orb/models/changed_subscription_resources.rb', line 29 required :voided_invoices, -> { Orb::Internal::Type::ArrayOf[Orb::Invoice] } |
Instance Method Details
#to_hash ⇒ {
27 |
# File 'sig/orb/models/changed_subscription_resources.rbs', line 27
def to_hash: -> {
|