Class: Orb::Models::ChangedSubscriptionResources::CreatedInvoice::CreditNote

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/changed_subscription_resources.rb,
sig/orb/models/changed_subscription_resources.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



313
# File 'sig/orb/models/changed_subscription_resources.rbs', line 313

def initialize: (

Instance Attribute Details

#credit_note_numberString

Parameters:

  • value (String)

Returns:

  • (String)


601
# File 'lib/orb/models/changed_subscription_resources.rb', line 601

required :credit_note_number, String

#idString

Parameters:

  • value (String)

Returns:

  • (String)


596
# File 'lib/orb/models/changed_subscription_resources.rb', line 596

required :id, String

#memoString?

An optional memo supplied on the credit note.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


607
# File 'lib/orb/models/changed_subscription_resources.rb', line 607

required :memo, String, nil?: true

#reasonString

Parameters:

  • value (String)

Returns:

  • (String)


612
# File 'lib/orb/models/changed_subscription_resources.rb', line 612

required :reason, String

#totalString

Parameters:

  • value (String)

Returns:

  • (String)


617
# File 'lib/orb/models/changed_subscription_resources.rb', line 617

required :total, String

#typeString

Parameters:

  • value (String)

Returns:

  • (String)


622
# File 'lib/orb/models/changed_subscription_resources.rb', line 622

required :type, String

#voided_atTime?

If the credit note has a status of void, this gives a timestamp when the credit note was voided.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


629
# File 'lib/orb/models/changed_subscription_resources.rb', line 629

required :voided_at, Time, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


323
# File 'sig/orb/models/changed_subscription_resources.rbs', line 323

def to_hash: -> {