Class: Orb::Models::CreditBlockListInvoicesResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::CreditBlockListInvoicesResponse
- Defined in:
- lib/orb/models/credit_block_list_invoices_response.rb,
sig/orb/models/credit_block_list_invoices_response.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#block ⇒ Orb::Models::CreditBlockListInvoicesResponse::Block
The Credit Block resource models prepaid credits within Orb.
- #invoices ⇒ Array<Orb::Models::CreditBlockListInvoicesResponse::Invoice>
Instance Method Summary collapse
-
#initialize(id:, subscription_id: nil) ⇒ Object
constructor
The subscription commitment whose true-up rolled forward into this credit block.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, subscription_id: nil) ⇒ Object
The subscription commitment whose true-up rolled forward into this credit block.
Present only when credit_block_source is commitment.
|
|
# File 'lib/orb/models/credit_block_list_invoices_response.rb', line 19
|
Instance Attribute Details
#block ⇒ Orb::Models::CreditBlockListInvoicesResponse::Block
The Credit Block resource models prepaid credits within Orb.
11 |
# File 'lib/orb/models/credit_block_list_invoices_response.rb', line 11 required :block, -> { Orb::Models::CreditBlockListInvoicesResponse::Block } |
#invoices ⇒ Array<Orb::Models::CreditBlockListInvoicesResponse::Invoice>
16 17 |
# File 'lib/orb/models/credit_block_list_invoices_response.rb', line 16 required :invoices, -> { Orb::Internal::Type::ArrayOf[Orb::Models::CreditBlockListInvoicesResponse::Invoice] } |
Instance Method Details
#to_hash ⇒ {
19 |
# File 'sig/orb/models/credit_block_list_invoices_response.rbs', line 19
def to_hash: -> {
|