Class: Orb::Models::CreditBlockRetrieveResponse::CreditAllocation::Filter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::CreditBlockRetrieveResponse::CreditAllocation::Filter
- Defined in:
- lib/orb/models/credit_block_retrieve_response.rb,
sig/orb/models/credit_block_retrieve_response.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#field ⇒ Symbol, Orb::Models::CreditBlockRetrieveResponse::CreditAllocation::Filter::Field
The property of the price to filter on.
-
#operator ⇒ Symbol, Orb::Models::CreditBlockRetrieveResponse::CreditAllocation::Filter::Operator
Should prices that match the filter be included or excluded.
-
#values ⇒ Array<String>
The IDs or values that match this filter.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(field:, operator:, values:) ⇒ Object
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/orb/models/credit_block_retrieve_response.rb', line 250 class Filter < Orb::Internal::Type::BaseModel # @!attribute field # The property of the price to filter on. # # @return [Symbol, Orb::Models::CreditBlockRetrieveResponse::CreditAllocation::Filter::Field] required :field, enum: -> { Orb::Models::CreditBlockRetrieveResponse::CreditAllocation::Filter::Field } # @!attribute operator # Should prices that match the filter be included or excluded. # # @return [Symbol, Orb::Models::CreditBlockRetrieveResponse::CreditAllocation::Filter::Operator] required :operator, enum: -> { Orb::Models::CreditBlockRetrieveResponse::CreditAllocation::Filter::Operator } # @!attribute values # The IDs or values that match this filter. # # @return [Array<String>] required :values, Orb::Internal::Type::ArrayOf[String] # @!method initialize(field:, operator:, values:) # @param field [Symbol, Orb::Models::CreditBlockRetrieveResponse::CreditAllocation::Filter::Field] The property of the price to filter on. # # @param operator [Symbol, Orb::Models::CreditBlockRetrieveResponse::CreditAllocation::Filter::Operator] Should prices that match the filter be included or excluded. # # @param values [Array<String>] The IDs or values that match this filter. # The property of the price to filter on. # # @see Orb::Models::CreditBlockRetrieveResponse::CreditAllocation::Filter#field module Field extend Orb::Internal::Type::Enum PRICE_ID = :price_id ITEM_ID = :item_id PRICE_TYPE = :price_type CURRENCY = :currency PRICING_UNIT_ID = :pricing_unit_id # @!method self.values # @return [Array<Symbol>] end # Should prices that match the filter be included or excluded. # # @see Orb::Models::CreditBlockRetrieveResponse::CreditAllocation::Filter#operator module Operator extend Orb::Internal::Type::Enum INCLUDES = :includes EXCLUDES = :excludes # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#field ⇒ Symbol, Orb::Models::CreditBlockRetrieveResponse::CreditAllocation::Filter::Field
The property of the price to filter on.
255 |
# File 'lib/orb/models/credit_block_retrieve_response.rb', line 255 required :field, enum: -> { Orb::Models::CreditBlockRetrieveResponse::CreditAllocation::Filter::Field } |
#operator ⇒ Symbol, Orb::Models::CreditBlockRetrieveResponse::CreditAllocation::Filter::Operator
Should prices that match the filter be included or excluded.
261 262 |
# File 'lib/orb/models/credit_block_retrieve_response.rb', line 261 required :operator, enum: -> { Orb::Models::CreditBlockRetrieveResponse::CreditAllocation::Filter::Operator } |
#values ⇒ Array<String>
The IDs or values that match this filter.
268 |
# File 'lib/orb/models/credit_block_retrieve_response.rb', line 268 required :values, Orb::Internal::Type::ArrayOf[String] |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/credit_block_retrieve_response.rb', line 289
|
Instance Method Details
#to_hash ⇒ {
216 |
# File 'sig/orb/models/credit_block_retrieve_response.rbs', line 216 def to_hash: -> { |