Class: Orb::Models::CustomerBalanceTransactionCreatedWebhookEvent::Properties::BalanceTransaction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::CustomerBalanceTransactionCreatedWebhookEvent::Properties::BalanceTransaction
- Defined in:
- lib/orb/models/customer_balance_transaction_created_webhook_event.rb,
sig/orb/models/customer_balance_transaction_created_webhook_event.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
- #action ⇒ Symbol, Orb::Models::CustomerBalanceTransactionCreatedWebhookEvent::Properties::BalanceTransaction::Action
-
#amount ⇒ String
The value of the amount changed in the transaction.
-
#created_at ⇒ Time
The creation time of this transaction.
- #credit_note ⇒ Orb::Models::CreditNoteTiny?
-
#description ⇒ String?
An optional description provided for manual customer balance adjustments.
-
#ending_balance ⇒ String
The new value of the customer's balance prior to the transaction, in the customer's currency.
-
#id ⇒ String
A unique id for this transaction.
- #invoice ⇒ Orb::Models::InvoiceTiny?
-
#starting_balance ⇒ String
The original value of the customer's balance prior to the transaction, in the customer's currency.
- #type ⇒ Symbol, Orb::Models::CustomerBalanceTransactionCreatedWebhookEvent::Properties::BalanceTransaction::Type
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, action:, amount:, created_at:, credit_note:, description:, ending_balance:, invoice:, starting_balance:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see BalanceTransaction for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, action:, amount:, created_at:, credit_note:, description:, ending_balance:, invoice:, starting_balance:, type:) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::CustomerBalanceTransactionCreatedWebhookEvent::Properties::BalanceTransaction for more details.
|
|
# File 'lib/orb/models/customer_balance_transaction_created_webhook_event.rb', line 141
|
Instance Attribute Details
#action ⇒ Symbol, Orb::Models::CustomerBalanceTransactionCreatedWebhookEvent::Properties::BalanceTransaction::Action
90 91 |
# File 'lib/orb/models/customer_balance_transaction_created_webhook_event.rb', line 90 required :action, enum: -> { Orb::CustomerBalanceTransactionCreatedWebhookEvent::Properties::BalanceTransaction::Action } |
#amount ⇒ String
The value of the amount changed in the transaction.
97 |
# File 'lib/orb/models/customer_balance_transaction_created_webhook_event.rb', line 97 required :amount, String |
#created_at ⇒ Time
The creation time of this transaction.
103 |
# File 'lib/orb/models/customer_balance_transaction_created_webhook_event.rb', line 103 required :created_at, Time |
#credit_note ⇒ Orb::Models::CreditNoteTiny?
108 |
# File 'lib/orb/models/customer_balance_transaction_created_webhook_event.rb', line 108 required :credit_note, -> { Orb::CreditNoteTiny }, nil?: true |
#description ⇒ String?
An optional description provided for manual customer balance adjustments.
114 |
# File 'lib/orb/models/customer_balance_transaction_created_webhook_event.rb', line 114 required :description, String, nil?: true |
#ending_balance ⇒ String
The new value of the customer's balance prior to the transaction, in the customer's currency.
121 |
# File 'lib/orb/models/customer_balance_transaction_created_webhook_event.rb', line 121 required :ending_balance, String |
#id ⇒ String
A unique id for this transaction.
85 |
# File 'lib/orb/models/customer_balance_transaction_created_webhook_event.rb', line 85 required :id, String |
#invoice ⇒ Orb::Models::InvoiceTiny?
126 |
# File 'lib/orb/models/customer_balance_transaction_created_webhook_event.rb', line 126 required :invoice, -> { Orb::InvoiceTiny }, nil?: true |
#starting_balance ⇒ String
The original value of the customer's balance prior to the transaction, in the customer's currency.
133 |
# File 'lib/orb/models/customer_balance_transaction_created_webhook_event.rb', line 133 required :starting_balance, String |
#type ⇒ Symbol, Orb::Models::CustomerBalanceTransactionCreatedWebhookEvent::Properties::BalanceTransaction::Type
138 139 |
# File 'lib/orb/models/customer_balance_transaction_created_webhook_event.rb', line 138 required :type, enum: -> { Orb::CustomerBalanceTransactionCreatedWebhookEvent::Properties::BalanceTransaction::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/customer_balance_transaction_created_webhook_event.rb', line 182
|
Instance Method Details
#to_hash ⇒ {
103 |
# File 'sig/orb/models/customer_balance_transaction_created_webhook_event.rbs', line 103
def to_hash: -> {
|