Class: Orb::Models::CustomerCreditBalanceDroppedWebhookEvent::Properties::AlertConfiguration::Plan
- Inherits:
-
Internal::Type::BaseModel
show all
- Defined in:
- lib/orb/models/customer_credit_balance_dropped_webhook_event.rb,
sig/orb/models/customer_credit_balance_dropped_webhook_event.rbs
Overview
Instance Attribute Summary collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
178
|
# File 'sig/orb/models/customer_credit_balance_dropped_webhook_event.rbs', line 178
def initialize: (
|
Instance Attribute Details
#external_plan_id ⇒ String?
An optional user-defined ID for this plan resource, used throughout the system
as an alias for this Plan. Use this field to identify a plan by an existing
identifier in your system.
299
|
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 299
required :external_plan_id, String, nil?: true
|
#id ⇒ String?
291
|
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 291
required :id, String, nil?: true
|
#name ⇒ String?
304
|
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 304
required :name, String, nil?: true
|
#plan_version ⇒ String
309
|
# File 'lib/orb/models/customer_credit_balance_dropped_webhook_event.rb', line 309
required :plan_version, String
|
Instance Method Details
#to_hash ⇒ {
185
|
# File 'sig/orb/models/customer_credit_balance_dropped_webhook_event.rbs', line 185
def to_hash: -> {
|