Class: Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties
- Defined in:
- lib/orb/models/customer_credit_balance_recovered_webhook_event.rb,
sig/orb/models/customer_credit_balance_recovered_webhook_event.rbs
Overview
Defined Under Namespace
Classes: AlertConfiguration, PricingUnit
Instance Attribute Summary collapse
-
#alert_configuration ⇒ Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration
Alerts within Orb monitor spending, usage, or credit balance and trigger webhooks when a threshold is exceeded.
-
#pricing_unit ⇒ Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties::PricingUnit?
A currency or custom credit unit, as embedded in webhook payloads.
Instance Method Summary collapse
-
#initialize(value:) ⇒ Object
constructor
Some parameter documentations has been truncated, see AlertConfiguration::ThresholdOverride::Threshold for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(value:) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration::ThresholdOverride::Threshold for more details.
Thresholds are used to define the conditions under which an alert will be triggered.
|
|
# File 'lib/orb/models/customer_credit_balance_recovered_webhook_event.rb', line 89
|
Instance Attribute Details
#alert_configuration ⇒ Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration
Alerts within Orb monitor spending, usage, or credit balance and trigger webhooks when a threshold is exceeded.
Alerts created through the API can be scoped to either customers or subscriptions.
78 79 |
# File 'lib/orb/models/customer_credit_balance_recovered_webhook_event.rb', line 78 required :alert_configuration, -> { Orb::CustomerCreditBalanceRecoveredWebhookEvent::Properties::AlertConfiguration } |
#pricing_unit ⇒ Orb::Models::CustomerCreditBalanceRecoveredWebhookEvent::Properties::PricingUnit?
A currency or custom credit unit, as embedded in webhook payloads.
85 86 87 |
# File 'lib/orb/models/customer_credit_balance_recovered_webhook_event.rb', line 85 required :pricing_unit, -> { Orb::CustomerCreditBalanceRecoveredWebhookEvent::Properties::PricingUnit }, nil?: true |
Instance Method Details
#to_hash ⇒ {
55 |
# File 'sig/orb/models/customer_credit_balance_recovered_webhook_event.rbs', line 55
def to_hash: -> {
|