Class: Orb::Models::CustomerCreditLedgerIncrementedWebhookEvent::Properties
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::CustomerCreditLedgerIncrementedWebhookEvent::Properties
- Defined in:
- lib/orb/models/customer_credit_ledger_incremented_webhook_event.rb,
sig/orb/models/customer_credit_ledger_incremented_webhook_event.rbs
Overview
Defined Under Namespace
Classes: Block, PricingUnit
Instance Attribute Summary collapse
-
#block ⇒ Orb::Models::CustomerCreditLedgerIncrementedWebhookEvent::Properties::Block
The Credit Block resource models prepaid credits within Orb.
-
#pricing_unit ⇒ Orb::Models::CustomerCreditLedgerIncrementedWebhookEvent::Properties::PricingUnit
A currency or custom credit unit, as embedded in webhook payloads.
Instance Method Summary collapse
-
#initialize(id:, subscription_id: nil) ⇒ Object
constructor
The subscription commitment whose true-up rolled forward into this credit block.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, subscription_id: nil) ⇒ Object
The subscription commitment whose true-up rolled forward into this credit block.
Present only when credit_block_source is commitment.
|
|
# File 'lib/orb/models/customer_credit_ledger_incremented_webhook_event.rb', line 82
|
Instance Attribute Details
#block ⇒ Orb::Models::CustomerCreditLedgerIncrementedWebhookEvent::Properties::Block
The Credit Block resource models prepaid credits within Orb.
74 |
# File 'lib/orb/models/customer_credit_ledger_incremented_webhook_event.rb', line 74 required :block, -> { Orb::CustomerCreditLedgerIncrementedWebhookEvent::Properties::Block } |
#pricing_unit ⇒ Orb::Models::CustomerCreditLedgerIncrementedWebhookEvent::Properties::PricingUnit
A currency or custom credit unit, as embedded in webhook payloads.
80 |
# File 'lib/orb/models/customer_credit_ledger_incremented_webhook_event.rb', line 80 required :pricing_unit, -> { Orb::CustomerCreditLedgerIncrementedWebhookEvent::Properties::PricingUnit } |
Instance Method Details
#to_hash ⇒ {
55 |
# File 'sig/orb/models/customer_credit_ledger_incremented_webhook_event.rbs', line 55
def to_hash: -> {
|