Class: Orb::Models::CustomerUpdateByExternalIDParams::PaymentConfiguration::PaymentProvider
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::CustomerUpdateByExternalIDParams::PaymentConfiguration::PaymentProvider
- Defined in:
- lib/orb/models/customer_update_by_external_id_params.rb,
sig/orb/models/customer_update_by_external_id_params.rbs
Defined Under Namespace
Modules: ProviderType
Instance Attribute Summary collapse
-
#default_shared_payment_token ⇒ String?
The ID of a shared payment token granted by an agent to use as the default payment instrument for this customer.
-
#excluded_payment_method_types ⇒ Array<String>?
List of Stripe payment method types to exclude for this customer.
-
#provider_type ⇒ Symbol, Orb::Models::CustomerUpdateByExternalIDParams::PaymentConfiguration::PaymentProvider::ProviderType
The payment provider to configure.
Instance Method Summary collapse
-
#initialize(provider_type:, default_shared_payment_token: nil, excluded_payment_method_types: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PaymentProvider for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(provider_type:, default_shared_payment_token: nil, excluded_payment_method_types: nil) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::CustomerUpdateByExternalIDParams::PaymentConfiguration::PaymentProvider for more details.
371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 |
# File 'lib/orb/models/customer_update_by_external_id_params.rb', line 371 class PaymentProvider < Orb::Internal::Type::BaseModel # @!attribute provider_type # The payment provider to configure. # # @return [Symbol, Orb::Models::CustomerUpdateByExternalIDParams::PaymentConfiguration::PaymentProvider::ProviderType] required :provider_type, enum: -> { Orb::CustomerUpdateByExternalIDParams::PaymentConfiguration::PaymentProvider::ProviderType } # @!attribute default_shared_payment_token # The ID of a shared payment token granted by an agent to use as the default # payment instrument for this customer. When set, auto-collection will use this # token instead of the customer's default payment method. # # @return [String, nil] optional :default_shared_payment_token, String, nil?: true # @!attribute excluded_payment_method_types # List of Stripe payment method types to exclude for this customer. Excluded # payment methods will not be available for the customer to select during payment, # and will not be used for auto-collection. If a customer's default payment method # becomes excluded, Orb will attempt to use the next available compatible payment # method for auto-collection. # # @return [Array<String>, nil] optional :excluded_payment_method_types, Orb::Internal::Type::ArrayOf[String] # @!method initialize(provider_type:, default_shared_payment_token: nil, excluded_payment_method_types: nil) # Some parameter documentations has been truncated, see # {Orb::Models::CustomerUpdateByExternalIDParams::PaymentConfiguration::PaymentProvider} # for more details. # # @param provider_type [Symbol, Orb::Models::CustomerUpdateByExternalIDParams::PaymentConfiguration::PaymentProvider::ProviderType] The payment provider to configure. # # @param default_shared_payment_token [String, nil] The ID of a shared payment token granted by an agent to use as the default payme # # @param excluded_payment_method_types [Array<String>] List of Stripe payment method types to exclude for this customer. Excluded payme # The payment provider to configure. # # @see Orb::Models::CustomerUpdateByExternalIDParams::PaymentConfiguration::PaymentProvider#provider_type module ProviderType extend Orb::Internal::Type::Enum STRIPE = :stripe # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#default_shared_payment_token ⇒ String?
The ID of a shared payment token granted by an agent to use as the default payment instrument for this customer. When set, auto-collection will use this token instead of the customer's default payment method.
385 |
# File 'lib/orb/models/customer_update_by_external_id_params.rb', line 385 optional :default_shared_payment_token, String, nil?: true |
#excluded_payment_method_types ⇒ Array<String>?
List of Stripe payment method types to exclude for this customer. Excluded payment methods will not be available for the customer to select during payment, and will not be used for auto-collection. If a customer's default payment method becomes excluded, Orb will attempt to use the next available compatible payment method for auto-collection.
395 |
# File 'lib/orb/models/customer_update_by_external_id_params.rb', line 395 optional :excluded_payment_method_types, Orb::Internal::Type::ArrayOf[String] |
#provider_type ⇒ Symbol, Orb::Models::CustomerUpdateByExternalIDParams::PaymentConfiguration::PaymentProvider::ProviderType
The payment provider to configure.
376 377 |
# File 'lib/orb/models/customer_update_by_external_id_params.rb', line 376 required :provider_type, enum: -> { Orb::CustomerUpdateByExternalIDParams::PaymentConfiguration::PaymentProvider::ProviderType } |
Instance Method Details
#to_hash ⇒ {
169 |
# File 'sig/orb/models/customer_update_by_external_id_params.rbs', line 169
def to_hash: -> {
|