Class: Orb::Models::Customers::CreditListByExternalIDResponse
- Inherits:
-
Internal::Type::BaseModel
show all
- Defined in:
- lib/orb/models/customers/credit_list_by_external_id_response.rb,
sig/orb/models/customers/credit_list_by_external_id_response.rbs
Overview
Defined Under Namespace
Modules: CreditBlockSource, Status
Classes: CreditAllocation, CreditCommitment, Filter
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
-
#initialize(id:, balance:, credit_block_source:, effective_date:, expiry_date:, filters:, maximum_initial_balance:, metadata:, per_unit_cost_basis:, status:, credit_allocation: nil, credit_commitment: nil) ⇒ Object
constructor
-
#to_hash ⇒ {
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, balance:, credit_block_source:, effective_date:, expiry_date:, filters:, maximum_initial_balance:, metadata:, per_unit_cost_basis:, status:, credit_allocation: nil, credit_commitment: nil) ⇒ Object
|
# File 'lib/orb/models/customers/credit_list_by_external_id_response.rb', line 87
|
Instance Attribute Details
#balance ⇒ Float
16
|
# File 'lib/orb/models/customers/credit_list_by_external_id_response.rb', line 16
required :balance, Float
|
The credit allocation that funded a block. Extends the allocation resource
serialized on prices with the catalog-item attribution of the funding price.
74
75
76
|
# File 'lib/orb/models/customers/credit_list_by_external_id_response.rb', line 74
optional :credit_allocation,
-> { Orb::Models::Customers::CreditListByExternalIDResponse::CreditAllocation },
nil?: true
|
How this credit block was created: allocation (a subscription's recurring
credit allocation), top_up (an automatic balance-threshold top-up),
commitment (a subscription commitment true-up rolled forward as credit), or
manual (a manual credit ledger increment, including credits voided or expired
off another block).
26
27
|
# File 'lib/orb/models/customers/credit_list_by_external_id_response.rb', line 26
required :credit_block_source,
enum: -> { Orb::Models::Customers::CreditListByExternalIDResponse::CreditBlockSource }
|
The subscription commitment whose true-up rolled forward into this credit block.
Present only when credit_block_source is commitment.
83
84
85
|
# File 'lib/orb/models/customers/credit_list_by_external_id_response.rb', line 83
optional :credit_commitment,
-> { Orb::Models::Customers::CreditListByExternalIDResponse::CreditCommitment },
nil?: true
|
#effective_date ⇒ Time?
32
|
# File 'lib/orb/models/customers/credit_list_by_external_id_response.rb', line 32
required :effective_date, Time, nil?: true
|
#expiry_date ⇒ Time?
37
|
# File 'lib/orb/models/customers/credit_list_by_external_id_response.rb', line 37
required :expiry_date, Time, nil?: true
|
42
43
|
# File 'lib/orb/models/customers/credit_list_by_external_id_response.rb', line 42
required :filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Models::Customers::CreditListByExternalIDResponse::Filter] }
|
#id ⇒ String
11
|
# File 'lib/orb/models/customers/credit_list_by_external_id_response.rb', line 11
required :id, String
|
#maximum_initial_balance ⇒ Float?
48
|
# File 'lib/orb/models/customers/credit_list_by_external_id_response.rb', line 48
required :maximum_initial_balance, Float, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
57
|
# File 'lib/orb/models/customers/credit_list_by_external_id_response.rb', line 57
required :metadata, Orb::Internal::Type::HashOf[String]
|
#per_unit_cost_basis ⇒ String?
62
|
# File 'lib/orb/models/customers/credit_list_by_external_id_response.rb', line 62
required :per_unit_cost_basis, String, nil?: true
|
67
|
# File 'lib/orb/models/customers/credit_list_by_external_id_response.rb', line 67
required :status, enum: -> { Orb::Models::Customers::CreditListByExternalIDResponse::Status }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/customers/credit_list_by_external_id_response.rb', line 130
|
Instance Method Details
#to_hash ⇒ {
60
|
# File 'sig/orb/models/customers/credit_list_by_external_id_response.rbs', line 60
def to_hash: -> {
|