Class: Orb::Models::DimensionalPriceGroup
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::DimensionalPriceGroup
- Defined in:
- lib/orb/models/dimensional_price_group.rb,
sig/orb/models/dimensional_price_group.rbs
Overview
Instance Attribute Summary collapse
-
#billable_metric_id ⇒ String
The billable metric associated with this dimensional price group.
-
#dimensions ⇒ Array<String>
The dimensions that this dimensional price group is defined over.
-
#external_dimensional_price_group_id ⇒ String?
An alias for the dimensional price group.
- #id ⇒ String
-
#metadata ⇒ Hash{Symbol=>String}
User specified key-value pairs for the resource.
-
#name ⇒ String
The name of the dimensional price group.
Instance Method Summary collapse
-
#initialize(id:, billable_metric_id:, dimensions:, external_dimensional_price_group_id:, metadata:, name:) ⇒ Object
constructor
Some parameter documentations has been truncated, see DimensionalPriceGroup for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, billable_metric_id:, dimensions:, external_dimensional_price_group_id:, metadata:, name:) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::DimensionalPriceGroup for more details.
A dimensional price group is used to partition the result of a billable metric by a set of dimensions. Prices in a price group must specify the partition used to derive their usage.
|
|
# File 'lib/orb/models/dimensional_price_group.rb', line 47
|
Instance Attribute Details
#billable_metric_id ⇒ String
The billable metric associated with this dimensional price group. All prices associated with this dimensional price group will be computed using this billable metric.
18 |
# File 'lib/orb/models/dimensional_price_group.rb', line 18 required :billable_metric_id, String |
#dimensions ⇒ Array<String>
The dimensions that this dimensional price group is defined over
24 |
# File 'lib/orb/models/dimensional_price_group.rb', line 24 required :dimensions, Orb::Internal::Type::ArrayOf[String] |
#external_dimensional_price_group_id ⇒ String?
An alias for the dimensional price group
30 |
# File 'lib/orb/models/dimensional_price_group.rb', line 30 required :external_dimensional_price_group_id, String, nil?: true |
#id ⇒ String
10 |
# File 'lib/orb/models/dimensional_price_group.rb', line 10 required :id, String |
#metadata ⇒ Hash{Symbol=>String}
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
39 |
# File 'lib/orb/models/dimensional_price_group.rb', line 39 required :metadata, Orb::Internal::Type::HashOf[String] |
#name ⇒ String
The name of the dimensional price group
45 |
# File 'lib/orb/models/dimensional_price_group.rb', line 45 required :name, String |
Instance Method Details
#to_hash ⇒ {
35 |
# File 'sig/orb/models/dimensional_price_group.rbs', line 35
def to_hash: -> {
|