Class: Orb::Models::InvoiceAutomationScheduleStepExecutedWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::InvoiceAutomationScheduleStepExecutedWebhookEvent
- Defined in:
- lib/orb/models/invoice_automation_schedule_step_executed_webhook_event.rb,
sig/orb/models/invoice_automation_schedule_step_executed_webhook_event.rbs
Defined Under Namespace
Modules: Type Classes: Invoice, Properties
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The time at which this event was created, to the second.
-
#id ⇒ String
The ID of this webhook event.
-
#invoice ⇒ Orb::Models::InvoiceAutomationScheduleStepExecutedWebhookEvent::Invoice
The invoice fields a consumer needs to run their own notification flows without a follow-up API call, mirroring the variables Orb's own automation emails render against.
- #properties ⇒ Orb::Models::InvoiceAutomationScheduleStepExecutedWebhookEvent::Properties
-
#type ⇒ Symbol, Orb::Models::InvoiceAutomationScheduleStepExecutedWebhookEvent::Type
The event this payload describes.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(Orb::Models::InvoiceAutomationScheduleStepExecutedWebhookEvent::Properties::Action::SendEmail, Orb::Models::InvoiceAutomationScheduleStepExecutedWebhookEvent::Properties::Action::RetryPayment)
Instance Method Summary collapse
-
#initialize(id:, amount_due:, currency:, customer_id:, customer_name:, due_date:, external_customer_id:, hosted_invoice_url:, invoice_date:, invoice_number:, issued_at:, memo:, payment_method_last_four_digits:, status:, subscription_id:) ⇒ Object
constructor
The invoice fields a consumer needs to run their own notification flows without a follow-up API call, mirroring the variables Orb's own automation emails render against.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, amount_due:, currency:, customer_id:, customer_name:, due_date:, external_customer_id:, hosted_invoice_url:, invoice_date:, invoice_number:, issued_at:, memo:, payment_method_last_four_digits:, status:, subscription_id:) ⇒ Object
The invoice fields a consumer needs to run their own notification flows without a follow-up API call, mirroring the variables Orb's own automation emails render against.
|
|
# File 'lib/orb/models/invoice_automation_schedule_step_executed_webhook_event.rb', line 37
|
Instance Attribute Details
#created_at ⇒ Time
The time at which this event was created, to the second.
16 |
# File 'lib/orb/models/invoice_automation_schedule_step_executed_webhook_event.rb', line 16 required :created_at, Time |
#id ⇒ String
The ID of this webhook event.
10 |
# File 'lib/orb/models/invoice_automation_schedule_step_executed_webhook_event.rb', line 10 required :id, String |
#invoice ⇒ Orb::Models::InvoiceAutomationScheduleStepExecutedWebhookEvent::Invoice
The invoice fields a consumer needs to run their own notification flows without a follow-up API call, mirroring the variables Orb's own automation emails render against.
24 |
# File 'lib/orb/models/invoice_automation_schedule_step_executed_webhook_event.rb', line 24 required :invoice, -> { Orb::InvoiceAutomationScheduleStepExecutedWebhookEvent::Invoice } |
#properties ⇒ Orb::Models::InvoiceAutomationScheduleStepExecutedWebhookEvent::Properties
29 |
# File 'lib/orb/models/invoice_automation_schedule_step_executed_webhook_event.rb', line 29 required :properties, -> { Orb::InvoiceAutomationScheduleStepExecutedWebhookEvent::Properties } |
#type ⇒ Symbol, Orb::Models::InvoiceAutomationScheduleStepExecutedWebhookEvent::Type
The event this payload describes.
35 |
# File 'lib/orb/models/invoice_automation_schedule_step_executed_webhook_event.rb', line 35 required :type, enum: -> { Orb::InvoiceAutomationScheduleStepExecutedWebhookEvent::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/invoice_automation_schedule_step_executed_webhook_event.rb', line 315
|
.variants ⇒ Array(Orb::Models::InvoiceAutomationScheduleStepExecutedWebhookEvent::Properties::Action::SendEmail, Orb::Models::InvoiceAutomationScheduleStepExecutedWebhookEvent::Properties::Action::RetryPayment)
|
|
# File 'lib/orb/models/invoice_automation_schedule_step_executed_webhook_event.rb', line 320
|
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/orb/models/invoice_automation_schedule_step_executed_webhook_event.rbs', line 31
def to_hash: -> {
|