Class: Orb::Models::InvoiceLineItemCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::InvoiceLineItemCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/orb/models/invoice_line_item_create_params.rb,
sig/orb/models/invoice_line_item_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#amount ⇒ String
The total amount in the invoice's currency to add to the line item.
-
#end_date ⇒ Date
A date string to specify the line item's end date in the customer's timezone.
-
#invoice_id ⇒ String
The id of the Invoice to add this line item.
-
#item_id ⇒ String?
The id of the item to associate with this line item.
-
#name ⇒ String?
The name to use for the line item.
-
#quantity ⇒ Float
The number of units on the line item.
-
#start_date ⇒ Date
A date string to specify the line item's start date in the customer's timezone.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(amount:, end_date:, invoice_id:, quantity:, start_date:, item_id: nil, name: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see InvoiceLineItemCreateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, end_date:, invoice_id:, quantity:, start_date:, item_id: nil, name: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::InvoiceLineItemCreateParams for more details.
|
|
# File 'lib/orb/models/invoice_line_item_create_params.rb', line 60
|
Instance Attribute Details
#amount ⇒ String
The total amount in the invoice's currency to add to the line item.
14 |
# File 'lib/orb/models/invoice_line_item_create_params.rb', line 14 required :amount, String |
#end_date ⇒ Date
A date string to specify the line item's end date in the customer's timezone.
20 |
# File 'lib/orb/models/invoice_line_item_create_params.rb', line 20 required :end_date, Date |
#invoice_id ⇒ String
The id of the Invoice to add this line item.
26 |
# File 'lib/orb/models/invoice_line_item_create_params.rb', line 26 required :invoice_id, String |
#item_id ⇒ String?
The id of the item to associate with this line item. If provided without name,
the item's name will be used for the price/line item. If provided with name,
the item will be associated but name will be used for the line item. At least
one of name or item_id must be provided.
47 |
# File 'lib/orb/models/invoice_line_item_create_params.rb', line 47 optional :item_id, String, nil?: true |
#name ⇒ String?
The name to use for the line item. If item_id is not provided, Orb will search
for an item with this name. If found, that item will be associated with the line
item. If not found, a new item will be created with this name. If item_id is
provided, this name will be used for the line item, but the item association
will be based on item_id. At least one of name or item_id must be
provided.
58 |
# File 'lib/orb/models/invoice_line_item_create_params.rb', line 58 optional :name, String, nil?: true |
#quantity ⇒ Float
The number of units on the line item
32 |
# File 'lib/orb/models/invoice_line_item_create_params.rb', line 32 required :quantity, Float |
#start_date ⇒ Date
A date string to specify the line item's start date in the customer's timezone.
38 |
# File 'lib/orb/models/invoice_line_item_create_params.rb', line 38 required :start_date, Date |
Instance Method Details
#to_hash ⇒ {
44 |
# File 'sig/orb/models/invoice_line_item_create_params.rbs', line 44
def to_hash: -> {
|