Module: Orb::Models::InvoiceLineItemCreateResponse::Adjustment
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/orb/models/invoice_line_item_create_response.rb,
sig/orb/models/invoice_line_item_create_response.rbs
Defined Under Namespace
Classes: TieredPercentageDiscount
Instance Method Summary collapse
-
#initialize(id:, adjusted_subtotal:, adjustments:, amount:, credits_applied:, end_date:, filter:, grouping:, name:, partially_invoiced_amount:, price:, quantity:, start_date:, sub_line_items:, subtotal:, tax_amounts:, usage_customer_ids:) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::InvoiceLineItemCreateResponse for more details.
- #self?.variants ⇒ ::Array[Orb::Models::InvoiceLineItemCreateResponse::adjustment]
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#initialize(id:, adjusted_subtotal:, adjustments:, amount:, credits_applied:, end_date:, filter:, grouping:, name:, partially_invoiced_amount:, price:, quantity:, start_date:, sub_line_items:, subtotal:, tax_amounts:, usage_customer_ids:) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::InvoiceLineItemCreateResponse for more details.
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/orb/models/invoice_line_item_create_response.rb', line 166 module Adjustment extend Orb::Internal::Type::Union discriminator :adjustment_type variant :usage_discount, -> { Orb::MonetaryUsageDiscountAdjustment } variant :amount_discount, -> { Orb::MonetaryAmountDiscountAdjustment } variant :percentage_discount, -> { Orb::MonetaryPercentageDiscountAdjustment } variant :tiered_percentage_discount, -> { Orb::Models::InvoiceLineItemCreateResponse::Adjustment::TieredPercentageDiscount } variant :minimum, -> { Orb::MonetaryMinimumAdjustment } variant :maximum, -> { Orb::MonetaryMaximumAdjustment } class TieredPercentageDiscount < Orb::Internal::Type::BaseModel # @!attribute id # # @return [String] required :id, String # @!attribute adjustment_type # # @return [Symbol, :tiered_percentage_discount] required :adjustment_type, const: :tiered_percentage_discount # @!attribute amount # The value applied by an adjustment. # # @return [String] required :amount, String # @!attribute applies_to_price_ids # @deprecated # # The price IDs that this adjustment applies to. # # @return [Array<String>] required :applies_to_price_ids, Orb::Internal::Type::ArrayOf[String] # @!attribute filters # The filters that determine which prices to apply this adjustment to. # # @return [Array<Orb::Models::InvoiceLineItemCreateResponse::Adjustment::TieredPercentageDiscount::Filter>] required :filters, -> { Orb::Internal::Type::ArrayOf[Orb::Models::InvoiceLineItemCreateResponse::Adjustment::TieredPercentageDiscount::Filter] } # @!attribute is_invoice_level # True for adjustments that apply to an entire invoice, false for adjustments that # apply to only one price. # # @return [Boolean] required :is_invoice_level, Orb::Internal::Type::Boolean # @!attribute reason # The reason for the adjustment. # # @return [String, nil] required :reason, String, nil?: true # @!attribute replaces_adjustment_id # The adjustment id this adjustment replaces. This adjustment will take the place # of the replaced adjustment in plan version migrations. # # @return [String, nil] required :replaces_adjustment_id, String, nil?: true # @!attribute tiers # The ordered, contiguous bands of cumulative eligible spend, each discounted at # its own percentage (progressive fill-a-tier), applied to the prices this # adjustment covers in a given billing period. # # @return [Array<Orb::Models::InvoiceLineItemCreateResponse::Adjustment::TieredPercentageDiscount::Tier>] required :tiers, -> { Orb::Internal::Type::ArrayOf[Orb::Models::InvoiceLineItemCreateResponse::Adjustment::TieredPercentageDiscount::Tier] } # @!method initialize(id:, amount:, applies_to_price_ids:, filters:, is_invoice_level:, reason:, replaces_adjustment_id:, tiers:, adjustment_type: :tiered_percentage_discount) # Some parameter documentations has been truncated, see # {Orb::Models::InvoiceLineItemCreateResponse::Adjustment::TieredPercentageDiscount} # for more details. # # @param id [String] # # @param amount [String] The value applied by an adjustment. # # @param applies_to_price_ids [Array<String>] The price IDs that this adjustment applies to. # # @param filters [Array<Orb::Models::InvoiceLineItemCreateResponse::Adjustment::TieredPercentageDiscount::Filter>] The filters that determine which prices to apply this adjustment to. # # @param is_invoice_level [Boolean] True for adjustments that apply to an entire invoice, false for adjustments that # # @param reason [String, nil] The reason for the adjustment. # # @param replaces_adjustment_id [String, nil] The adjustment id this adjustment replaces. This adjustment will take the place # # @param tiers [Array<Orb::Models::InvoiceLineItemCreateResponse::Adjustment::TieredPercentageDiscount::Tier>] The ordered, contiguous bands of cumulative eligible spend, each discounted at i # # @param adjustment_type [Symbol, :tiered_percentage_discount] class Filter < Orb::Internal::Type::BaseModel # @!attribute field # The property of the price to filter on. # # @return [Symbol, Orb::Models::InvoiceLineItemCreateResponse::Adjustment::TieredPercentageDiscount::Filter::Field] required :field, enum: -> { Orb::Models::InvoiceLineItemCreateResponse::Adjustment::TieredPercentageDiscount::Filter::Field } # @!attribute operator # Should prices that match the filter be included or excluded. # # @return [Symbol, Orb::Models::InvoiceLineItemCreateResponse::Adjustment::TieredPercentageDiscount::Filter::Operator] required :operator, enum: -> { Orb::Models::InvoiceLineItemCreateResponse::Adjustment::TieredPercentageDiscount::Filter::Operator } # @!attribute values # The IDs or values that match this filter. # # @return [Array<String>] required :values, Orb::Internal::Type::ArrayOf[String] # @!method initialize(field:, operator:, values:) # @param field [Symbol, Orb::Models::InvoiceLineItemCreateResponse::Adjustment::TieredPercentageDiscount::Filter::Field] The property of the price to filter on. # # @param operator [Symbol, Orb::Models::InvoiceLineItemCreateResponse::Adjustment::TieredPercentageDiscount::Filter::Operator] Should prices that match the filter be included or excluded. # # @param values [Array<String>] The IDs or values that match this filter. # The property of the price to filter on. # # @see Orb::Models::InvoiceLineItemCreateResponse::Adjustment::TieredPercentageDiscount::Filter#field module Field extend Orb::Internal::Type::Enum PRICE_ID = :price_id ITEM_ID = :item_id PRICE_TYPE = :price_type CURRENCY = :currency PRICING_UNIT_ID = :pricing_unit_id # @!method self.values # @return [Array<Symbol>] end # Should prices that match the filter be included or excluded. # # @see Orb::Models::InvoiceLineItemCreateResponse::Adjustment::TieredPercentageDiscount::Filter#operator module Operator extend Orb::Internal::Type::Enum INCLUDES = :includes EXCLUDES = :excludes # @!method self.values # @return [Array<Symbol>] end end class Tier < Orb::Internal::Type::BaseModel # @!attribute lower_bound # Exclusive lower bound of cumulative spend for this tier. # # @return [Float] required :lower_bound, Float # @!attribute percentage # The percentage (between 0 and 1) discounted from spend that falls within this # tier. # # @return [Float] required :percentage, Float # @!attribute upper_bound # Inclusive upper bound of cumulative spend for this tier; null for the final # open-ended tier. # # @return [Float, nil] optional :upper_bound, Float, nil?: true # @!method initialize(lower_bound:, percentage:, upper_bound: nil) # Some parameter documentations has been truncated, see # {Orb::Models::InvoiceLineItemCreateResponse::Adjustment::TieredPercentageDiscount::Tier} # for more details. # # One band of a tiered percentage discount. Bounds are denominated in the # discount's currency. `lower_bound` is the exclusive start of the band and # `upper_bound` is the inclusive end; `upper_bound` is null only for the # open-ended final tier. # # @param lower_bound [Float] Exclusive lower bound of cumulative spend for this tier. # # @param percentage [Float] The percentage (between 0 and 1) discounted from spend that falls within this ti # # @param upper_bound [Float, nil] Inclusive upper bound of cumulative spend for this tier; null for the final open end end # @!method self.variants # @return [Array(Orb::Models::MonetaryUsageDiscountAdjustment, Orb::Models::MonetaryAmountDiscountAdjustment, Orb::Models::MonetaryPercentageDiscountAdjustment, Orb::Models::InvoiceLineItemCreateResponse::Adjustment::TieredPercentageDiscount, Orb::Models::MonetaryMinimumAdjustment, Orb::Models::MonetaryMaximumAdjustment)] end |
#self?.variants ⇒ ::Array[Orb::Models::InvoiceLineItemCreateResponse::adjustment]
243 |
# File 'sig/orb/models/invoice_line_item_create_response.rbs', line 243
def self?.variants: -> ::Array[Orb::Models::InvoiceLineItemCreateResponse::adjustment]
|