Class: Orb::Models::InvoiceListSummaryResponse::PaymentAttempt
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::InvoiceListSummaryResponse::PaymentAttempt
- Defined in:
- lib/orb/models/invoice_list_summary_response.rb,
sig/orb/models/invoice_list_summary_response.rbs
Defined Under Namespace
Modules: PaymentProvider
Instance Attribute Summary collapse
-
#amount ⇒ String
The amount of the payment attempt.
-
#created_at ⇒ Time
The time at which the payment attempt was created.
-
#id ⇒ String
The ID of the payment attempt.
-
#payment_provider ⇒ Symbol, ...
The payment provider that attempted to collect the payment.
-
#payment_provider_id ⇒ String?
The ID of the payment attempt in the payment provider.
-
#receipt_pdf ⇒ String?
URL to the downloadable PDF version of the receipt.
-
#succeeded ⇒ Boolean
Whether the payment attempt succeeded.
Instance Method Summary collapse
-
#initialize(id:, amount:, created_at:, payment_provider:, payment_provider_id:, receipt_pdf:, succeeded:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PaymentAttempt for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, amount:, created_at:, payment_provider:, payment_provider_id:, receipt_pdf:, succeeded:) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::InvoiceListSummaryResponse::PaymentAttempt for more details.
|
|
# File 'lib/orb/models/invoice_list_summary_response.rb', line 718
|
Instance Attribute Details
#amount ⇒ String
The amount of the payment attempt.
683 |
# File 'lib/orb/models/invoice_list_summary_response.rb', line 683 required :amount, String |
#created_at ⇒ Time
The time at which the payment attempt was created.
689 |
# File 'lib/orb/models/invoice_list_summary_response.rb', line 689 required :created_at, Time |
#id ⇒ String
The ID of the payment attempt.
677 |
# File 'lib/orb/models/invoice_list_summary_response.rb', line 677 required :id, String |
#payment_provider ⇒ Symbol, ...
The payment provider that attempted to collect the payment.
695 696 697 |
# File 'lib/orb/models/invoice_list_summary_response.rb', line 695 required :payment_provider, enum: -> { Orb::Models::InvoiceListSummaryResponse::PaymentAttempt::PaymentProvider }, nil?: true |
#payment_provider_id ⇒ String?
The ID of the payment attempt in the payment provider.
703 |
# File 'lib/orb/models/invoice_list_summary_response.rb', line 703 required :payment_provider_id, String, nil?: true |
#receipt_pdf ⇒ String?
URL to the downloadable PDF version of the receipt. This field will be null
for payment attempts that did not succeed.
710 |
# File 'lib/orb/models/invoice_list_summary_response.rb', line 710 required :receipt_pdf, String, nil?: true |
#succeeded ⇒ Boolean
Whether the payment attempt succeeded.
716 |
# File 'lib/orb/models/invoice_list_summary_response.rb', line 716 required :succeeded, Orb::Internal::Type::Boolean |
Instance Method Details
#to_hash ⇒ {
408 |
# File 'sig/orb/models/invoice_list_summary_response.rbs', line 408
def to_hash: -> {
|