Class: Orb::Models::Item
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::Item
- Defined in:
- lib/orb/models/item.rb,
sig/orb/models/item.rbs
Overview
Defined Under Namespace
Classes: ExternalConnection
Instance Attribute Summary collapse
-
#archived_at ⇒ Time?
The time at which the item was archived.
-
#created_at ⇒ Time
The time at which the item was created.
-
#external_connections ⇒ Array<Orb::Models::Item::ExternalConnection>
A list of external connections for this item, used to sync with external invoicing and tax systems.
-
#id ⇒ String
The Orb-assigned unique identifier for the item.
-
#metadata ⇒ Hash{Symbol=>String}
User specified key-value pairs for the resource.
-
#name ⇒ String
The name of the item.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
26 |
# File 'sig/orb/models/item.rbs', line 26
def initialize: (
|
Instance Attribute Details
#archived_at ⇒ Time?
The time at which the item was archived. If null, the item is not archived.
45 |
# File 'lib/orb/models/item.rb', line 45 optional :archived_at, Time, nil?: true |
#created_at ⇒ Time
The time at which the item was created.
17 |
# File 'lib/orb/models/item.rb', line 17 required :created_at, Time |
#external_connections ⇒ Array<Orb::Models::Item::ExternalConnection>
A list of external connections for this item, used to sync with external invoicing and tax systems.
24 |
# File 'lib/orb/models/item.rb', line 24 required :external_connections, -> { Orb::Internal::Type::ArrayOf[Orb::Item::ExternalConnection] } |
#id ⇒ String
The Orb-assigned unique identifier for the item.
11 |
# File 'lib/orb/models/item.rb', line 11 required :id, String |
#metadata ⇒ Hash{Symbol=>String}
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
33 |
# File 'lib/orb/models/item.rb', line 33 required :metadata, Orb::Internal::Type::HashOf[String] |
#name ⇒ String
The name of the item.
39 |
# File 'lib/orb/models/item.rb', line 39 required :name, String |
Instance Method Details
#to_hash ⇒ {
35 |
# File 'sig/orb/models/item.rbs', line 35
def to_hash: -> {
|