Class: Orb::Models::LicenseCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::LicenseCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/orb/models/license_create_params.rb,
sig/orb/models/license_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#end_date ⇒ Date?
The end date of the license.
-
#external_license_id ⇒ String
The external identifier for the license.
- #license_type_id ⇒ String
-
#start_date ⇒ Date?
The start date of the license.
- #subscription_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(external_license_id:, license_type_id:, subscription_id:, end_date: nil, start_date: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see LicenseCreateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(external_license_id:, license_type_id:, subscription_id:, end_date: nil, start_date: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::LicenseCreateParams for more details.
|
|
# File 'lib/orb/models/license_create_params.rb', line 40
|
Instance Attribute Details
#end_date ⇒ Date?
The end date of the license. If not provided, the license will remain active until deactivated.
31 |
# File 'lib/orb/models/license_create_params.rb', line 31 optional :end_date, Date, nil?: true |
#external_license_id ⇒ String
The external identifier for the license.
14 |
# File 'lib/orb/models/license_create_params.rb', line 14 required :external_license_id, String |
#license_type_id ⇒ String
19 |
# File 'lib/orb/models/license_create_params.rb', line 19 required :license_type_id, String |
#start_date ⇒ Date?
The start date of the license. If not provided, defaults to start of day today in the customer's timezone.
38 |
# File 'lib/orb/models/license_create_params.rb', line 38 optional :start_date, Date, nil?: true |
#subscription_id ⇒ String
24 |
# File 'lib/orb/models/license_create_params.rb', line 24 required :subscription_id, String |
Instance Method Details
#to_hash ⇒ {
36 |
# File 'sig/orb/models/license_create_params.rbs', line 36
def to_hash: -> {
|