Class: Orb::Models::LicenseTypeCreateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::LicenseTypeCreateResponse
- Defined in:
- lib/orb/models/license_type_create_response.rb,
sig/orb/models/license_type_create_response.rbs
Overview
Instance Attribute Summary collapse
-
#grouping_key ⇒ String
The key used for grouping licenses of this type.
-
#id ⇒ String
The Orb-assigned unique identifier for the license type.
-
#name ⇒ String
The name of the license type.
Instance Method Summary collapse
-
#initialize(id:, grouping_key:, name:) ⇒ LicenseTypeCreateResponse
constructor
Some parameter documentations has been truncated, see LicenseTypeCreateResponse for more details.
- #to_hash ⇒ { id: String, grouping_key: String, name: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, grouping_key:, name:) ⇒ LicenseTypeCreateResponse
Some parameter documentations has been truncated, see Orb::Models::LicenseTypeCreateResponse for more details.
The LicenseType resource represents a type of license that can be assigned to users. License types are used during billing by grouping metrics on the configured grouping key.
|
|
# File 'lib/orb/models/license_type_create_response.rb', line 26
|
Instance Attribute Details
#grouping_key ⇒ String
The key used for grouping licenses of this type. This is typically a user identifier field.
18 |
# File 'lib/orb/models/license_type_create_response.rb', line 18 required :grouping_key, String |
#id ⇒ String
The Orb-assigned unique identifier for the license type.
11 |
# File 'lib/orb/models/license_type_create_response.rb', line 11 required :id, String |
#name ⇒ String
The name of the license type.
24 |
# File 'lib/orb/models/license_type_create_response.rb', line 24 required :name, String |
Instance Method Details
#to_hash ⇒ { id: String, grouping_key: String, name: String }
15 |
# File 'sig/orb/models/license_type_create_response.rbs', line 15
def to_hash: -> { id: String, grouping_key: String, name: String }
|