Class: Orb::Models::MatrixWithAllocationConfig::MatrixValue
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::MatrixWithAllocationConfig::MatrixValue
- Defined in:
- lib/orb/models/matrix_with_allocation_config.rb,
sig/orb/models/matrix_with_allocation_config.rbs
Instance Attribute Summary collapse
-
#dimension_values ⇒ Array<String, nil>
One or two matrix keys to filter usage to this Matrix value by.
-
#unit_amount ⇒ String
Unit price for the specified dimension_values.
Instance Method Summary collapse
-
#initialize(dimension_values:, unit_amount:) ⇒ Object
constructor
Some parameter documentations has been truncated, see MatrixValue for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(dimension_values:, unit_amount:) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::MatrixWithAllocationConfig::MatrixValue for more details.
Configuration for a single matrix value
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/orb/models/matrix_with_allocation_config.rb', line 41 class MatrixValue < Orb::Internal::Type::BaseModel # @!attribute dimension_values # One or two matrix keys to filter usage to this Matrix value by. For example, # ["region", "tier"] could be used to filter cloud usage by a cloud region and an # instance tier. # # @return [Array<String, nil>] required :dimension_values, Orb::Internal::Type::ArrayOf[String, nil?: true] # @!attribute unit_amount # Unit price for the specified dimension_values # # @return [String] required :unit_amount, String # @!method initialize(dimension_values:, unit_amount:) # Some parameter documentations has been truncated, see # {Orb::Models::MatrixWithAllocationConfig::MatrixValue} for more details. # # Configuration for a single matrix value # # @param dimension_values [Array<String, nil>] One or two matrix keys to filter usage to this Matrix value by. For example, ["r # # @param unit_amount [String] Unit price for the specified dimension_values end |
Instance Attribute Details
#dimension_values ⇒ Array<String, nil>
One or two matrix keys to filter usage to this Matrix value by. For example, ["region", "tier"] could be used to filter cloud usage by a cloud region and an instance tier.
48 |
# File 'lib/orb/models/matrix_with_allocation_config.rb', line 48 required :dimension_values, Orb::Internal::Type::ArrayOf[String, nil?: true] |
#unit_amount ⇒ String
Unit price for the specified dimension_values
54 |
# File 'lib/orb/models/matrix_with_allocation_config.rb', line 54 required :unit_amount, String |
Instance Method Details
#to_hash ⇒ {
47 |
# File 'sig/orb/models/matrix_with_allocation_config.rbs', line 47
def to_hash: -> {
|