Class: Orb::Models::NewFloatingGroupedTieredPrice
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::NewFloatingGroupedTieredPrice
- Defined in:
- lib/orb/models/new_floating_grouped_tiered_price.rb,
sig/orb/models/new_floating_grouped_tiered_price.rbs
Defined Under Namespace
Modules: Cadence, ModelType Classes: GroupedTieredConfig
Instance Attribute Summary collapse
-
#billable_metric_id ⇒ String?
The id of the billable metric for the price.
-
#billed_in_advance ⇒ Boolean?
If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.
-
#billing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
For custom cadence: specifies the duration of the billing period in days or months.
-
#cadence ⇒ Symbol, Orb::Models::NewFloatingGroupedTieredPrice::Cadence
The cadence to bill for this price on.
-
#conversion_rate ⇒ Float?
The per unit conversion rate of the price currency to the invoicing currency.
-
#conversion_rate_config ⇒ Orb::Models::UnitConversionRateConfig, ...
The configuration for the rate of the price currency to the invoicing currency.
-
#currency ⇒ String
An ISO 4217 currency string for which this price is billed in.
-
#dimensional_price_configuration ⇒ Orb::Models::NewDimensionalPriceConfiguration?
For dimensional price: specifies a price group and dimension values.
-
#external_price_id ⇒ String?
An alias for the price.
-
#fixed_price_quantity ⇒ Float?
If the Price represents a fixed cost, this represents the quantity of units applied.
-
#grouped_tiered_config ⇒ Orb::Models::NewFloatingGroupedTieredPrice::GroupedTieredConfig
Configuration for grouped_tiered pricing.
-
#invoice_grouping_key ⇒ String?
The property used to group this price on an invoice.
-
#invoicing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
Within each billing cycle, specifies the cadence at which invoices are produced.
-
#item_id ⇒ String
The id of the item the price will be associated with.
-
#license_type_id ⇒ String?
The ID of the license type to associate with this price.
-
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource.
-
#model_type ⇒ Symbol, Orb::Models::NewFloatingGroupedTieredPrice::ModelType
The pricing model type.
-
#name ⇒ String
The name of the price.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(tier_lower_bound:, unit_amount:) ⇒ Object
constructor
Configuration for a single tier.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(tier_lower_bound:, unit_amount:) ⇒ Object
Configuration for a single tier
|
|
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 121
|
Instance Attribute Details
#billable_metric_id ⇒ String?
The id of the billable metric for the price. Only needed if the price is usage-based.
47 |
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 47 optional :billable_metric_id, String, nil?: true |
#billed_in_advance ⇒ Boolean?
If the Price represents a fixed cost, the price will be billed in-advance if this is true, and in-arrears if this is false.
54 |
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 54 optional :billed_in_advance, Orb::Internal::Type::Boolean, nil?: true |
#billing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
For custom cadence: specifies the duration of the billing period in days or months.
61 |
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 61 optional :billing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true |
#cadence ⇒ Symbol, Orb::Models::NewFloatingGroupedTieredPrice::Cadence
The cadence to bill for this price on.
10 |
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 10 required :cadence, enum: -> { Orb::NewFloatingGroupedTieredPrice::Cadence } |
#conversion_rate ⇒ Float?
The per unit conversion rate of the price currency to the invoicing currency.
67 |
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 67 optional :conversion_rate, Float, nil?: true |
#conversion_rate_config ⇒ Orb::Models::UnitConversionRateConfig, ...
The configuration for the rate of the price currency to the invoicing currency.
73 |
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 73 optional :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true |
#currency ⇒ String
An ISO 4217 currency string for which this price is billed in.
16 |
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 16 required :currency, String |
#dimensional_price_configuration ⇒ Orb::Models::NewDimensionalPriceConfiguration?
For dimensional price: specifies a price group and dimension values
79 |
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 79 optional :dimensional_price_configuration, -> { Orb::NewDimensionalPriceConfiguration }, nil?: true |
#external_price_id ⇒ String?
An alias for the price.
85 |
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 85 optional :external_price_id, String, nil?: true |
#fixed_price_quantity ⇒ Float?
If the Price represents a fixed cost, this represents the quantity of units applied.
92 |
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 92 optional :fixed_price_quantity, Float, nil?: true |
#grouped_tiered_config ⇒ Orb::Models::NewFloatingGroupedTieredPrice::GroupedTieredConfig
Configuration for grouped_tiered pricing
22 |
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 22 required :grouped_tiered_config, -> { Orb::NewFloatingGroupedTieredPrice::GroupedTieredConfig } |
#invoice_grouping_key ⇒ String?
The property used to group this price on an invoice
98 |
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 98 optional :invoice_grouping_key, String, nil?: true |
#invoicing_cycle_configuration ⇒ Orb::Models::NewBillingCycleConfiguration?
Within each billing cycle, specifies the cadence at which invoices are produced. If unspecified, a single invoice is produced per billing cycle.
105 |
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 105 optional :invoicing_cycle_configuration, -> { Orb::NewBillingCycleConfiguration }, nil?: true |
#item_id ⇒ String
The id of the item the price will be associated with.
28 |
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 28 required :item_id, String |
#license_type_id ⇒ String?
The ID of the license type to associate with this price.
111 |
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 111 optional :license_type_id, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource. Individual keys can be removed
by setting the value to null, and the entire metadata mapping can be cleared
by setting metadata to null.
119 |
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 119 optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true |
#model_type ⇒ Symbol, Orb::Models::NewFloatingGroupedTieredPrice::ModelType
The pricing model type
34 |
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 34 required :model_type, enum: -> { Orb::NewFloatingGroupedTieredPrice::ModelType } |
#name ⇒ String
The name of the price.
40 |
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 40 required :name, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/new_floating_grouped_tiered_price.rb', line 174
|
Instance Method Details
#to_hash ⇒ {
83 |
# File 'sig/orb/models/new_floating_grouped_tiered_price.rbs', line 83
def to_hash: -> {
|