Class: Orb::Models::PaymentMethodCreatedWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::PaymentMethodCreatedWebhookEvent
- Defined in:
- lib/orb/models/payment_method_created_webhook_event.rb,
sig/orb/models/payment_method_created_webhook_event.rbs
Defined Under Namespace
Modules: Type Classes: PaymentMethod
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The time at which this event was created, to the second.
-
#id ⇒ String
The ID of this webhook event.
-
#payment_method ⇒ Orb::Models::PaymentMethodCreatedWebhookEvent::PaymentMethod
A payment method represents a customer's stored payment instrument held with an external payment provider (such as Adyen or Stripe).
- #properties ⇒ Object
-
#type ⇒ Symbol, Orb::Models::PaymentMethodCreatedWebhookEvent::Type
The event this payload describes.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, created_at:, payment_method:, properties:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PaymentMethodCreatedWebhookEvent for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, payment_method:, properties:, type:) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::PaymentMethodCreatedWebhookEvent for more details.
Issued when a payment method is created.
|
|
# File 'lib/orb/models/payment_method_created_webhook_event.rb', line 39
|
Instance Attribute Details
#created_at ⇒ Time
The time at which this event was created, to the second.
16 |
# File 'lib/orb/models/payment_method_created_webhook_event.rb', line 16 required :created_at, Time |
#id ⇒ String
The ID of this webhook event.
10 |
# File 'lib/orb/models/payment_method_created_webhook_event.rb', line 10 required :id, String |
#payment_method ⇒ Orb::Models::PaymentMethodCreatedWebhookEvent::PaymentMethod
A payment method represents a customer's stored payment instrument held with an external payment provider (such as Adyen or Stripe).
The serialization is intentionally minimal for now; provider-pulled details (e.g. card display metadata) will be added over time.
26 |
# File 'lib/orb/models/payment_method_created_webhook_event.rb', line 26 required :payment_method, -> { Orb::PaymentMethodCreatedWebhookEvent::PaymentMethod } |
#properties ⇒ Object
31 |
# File 'lib/orb/models/payment_method_created_webhook_event.rb', line 31 required :properties, Orb::Internal::Type::Unknown |
#type ⇒ Symbol, Orb::Models::PaymentMethodCreatedWebhookEvent::Type
The event this payload describes.
37 |
# File 'lib/orb/models/payment_method_created_webhook_event.rb', line 37 required :type, enum: -> { Orb::PaymentMethodCreatedWebhookEvent::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/payment_method_created_webhook_event.rb', line 138
|
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/orb/models/payment_method_created_webhook_event.rbs', line 31
def to_hash: -> {
|