Class: Orb::Models::PlanCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::PlanCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/orb/models/plan_create_params.rb,
sig/orb/models/plan_create_params.rbs
Overview
Defined Under Namespace
Modules: Status Classes: Adjustment, PlanPhase, Price
Instance Attribute Summary collapse
-
#adjustments ⇒ Array<Orb::Models::PlanCreateParams::Adjustment>?
Adjustments for this plan.
-
#currency ⇒ String
An ISO 4217 currency string for invoices generated by subscriptions on this plan.
-
#default_invoice_memo ⇒ String?
Free-form text which is available on the invoice PDF and the Orb invoice portal.
-
#description ⇒ String?
An optional user-defined description of the plan.
- #external_plan_id ⇒ String?
-
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource.
- #name ⇒ String
-
#net_terms ⇒ Integer?
The net terms determines the difference between the invoice date and the issue date for the invoice.
-
#plan_phases ⇒ Array<Orb::Models::PlanCreateParams::PlanPhase>?
Configuration of pre-defined phases, each with their own prices and adjustments.
-
#prices ⇒ Array<Orb::Models::PlanCreateParams::Price>
Prices for this plan.
-
#status ⇒ Symbol, ...
The status of the plan to create (either active or draft).
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(Orb::Models::NewPercentageDiscount, Orb::Models::NewUsageDiscount, Orb::Models::NewAmountDiscount, Orb::Models::NewMinimum, Orb::Models::NewMaximum, Orb::Models::PlanCreateParams::Adjustment::Adjustment::TieredPercentageDiscount)
Instance Method Summary collapse
-
#initialize(unit_rating_key:, default_unit_rate: nil, grouping_key: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Price::Price::EventOutput::EventOutputConfig for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(unit_rating_key:, default_unit_rate: nil, grouping_key: nil) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::PlanCreateParams::Price::Price::EventOutput::EventOutputConfig for more details.
Configuration for event_output pricing
|
|
# File 'lib/orb/models/plan_create_params.rb', line 2690
|
Instance Attribute Details
#adjustments ⇒ Array<Orb::Models::PlanCreateParams::Adjustment>?
Adjustments for this plan. If the plan has phases, this includes adjustments across all phases of the plan.
34 35 36 37 38 |
# File 'lib/orb/models/plan_create_params.rb', line 34 optional :adjustments, -> { Orb::Internal::Type::ArrayOf[Orb::PlanCreateParams::Adjustment] }, nil?: true |
#currency ⇒ String
An ISO 4217 currency string for invoices generated by subscriptions on this plan.
15 |
# File 'lib/orb/models/plan_create_params.rb', line 15 required :currency, String |
#default_invoice_memo ⇒ String?
Free-form text which is available on the invoice PDF and the Orb invoice portal.
44 |
# File 'lib/orb/models/plan_create_params.rb', line 44 optional :default_invoice_memo, String, nil?: true |
#description ⇒ String?
An optional user-defined description of the plan.
50 |
# File 'lib/orb/models/plan_create_params.rb', line 50 optional :description, String, nil?: true |
#external_plan_id ⇒ String?
55 |
# File 'lib/orb/models/plan_create_params.rb', line 55 optional :external_plan_id, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource. Individual keys can be removed
by setting the value to null, and the entire metadata mapping can be cleared
by setting metadata to null.
63 |
# File 'lib/orb/models/plan_create_params.rb', line 63 optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true |
#name ⇒ String
20 |
# File 'lib/orb/models/plan_create_params.rb', line 20 required :name, String |
#net_terms ⇒ Integer?
The net terms determines the difference between the invoice date and the issue date for the invoice. If you intend the invoice to be due on issue, set this to 0.
71 |
# File 'lib/orb/models/plan_create_params.rb', line 71 optional :net_terms, Integer, nil?: true |
#plan_phases ⇒ Array<Orb::Models::PlanCreateParams::PlanPhase>?
Configuration of pre-defined phases, each with their own prices and adjustments. Leave unspecified for plans with a single phase.
78 |
# File 'lib/orb/models/plan_create_params.rb', line 78 optional :plan_phases, -> { Orb::Internal::Type::ArrayOf[Orb::PlanCreateParams::PlanPhase] }, nil?: true |
#prices ⇒ Array<Orb::Models::PlanCreateParams::Price>
Prices for this plan. If the plan has phases, this includes prices across all phases of the plan.
27 |
# File 'lib/orb/models/plan_create_params.rb', line 27 required :prices, -> { Orb::Internal::Type::ArrayOf[Orb::PlanCreateParams::Price] } |
#status ⇒ Symbol, ...
The status of the plan to create (either active or draft). If not specified, this defaults to active.
85 |
# File 'lib/orb/models/plan_create_params.rb', line 85 optional :status, enum: -> { Orb::PlanCreateParams::Status } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/plan_create_params.rb', line 2948
|
.variants ⇒ Array(Orb::Models::NewPercentageDiscount, Orb::Models::NewUsageDiscount, Orb::Models::NewAmountDiscount, Orb::Models::NewMinimum, Orb::Models::NewMaximum, Orb::Models::PlanCreateParams::Adjustment::Adjustment::TieredPercentageDiscount)
|
|
# File 'lib/orb/models/plan_create_params.rb', line 2705
|
Instance Method Details
#to_hash ⇒ {
64 |
# File 'sig/orb/models/plan_create_params.rbs', line 64
def to_hash: -> {
|