Class: Orb::Models::PlanCreateParams::PlanPhase
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::PlanCreateParams::PlanPhase
- Defined in:
- lib/orb/models/plan_create_params.rb,
sig/orb/models/plan_create_params.rbs
Defined Under Namespace
Modules: DurationUnit
Instance Attribute Summary collapse
-
#align_billing_with_phase_start_date ⇒ Boolean?
Align billing cycle day with phase start date.
-
#duration ⇒ Integer?
How many terms of length
duration_unitthis phase is active for. - #duration_unit ⇒ Symbol, ...
-
#order ⇒ Integer
Determines the ordering of the phase in a plan's lifecycle.
Instance Method Summary collapse
-
#initialize(order:, align_billing_with_phase_start_date: nil, duration: nil, duration_unit: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PlanPhase for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(order:, align_billing_with_phase_start_date: nil, duration: nil, duration_unit: nil) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::PlanCreateParams::PlanPhase for more details.
|
|
# File 'lib/orb/models/plan_create_params.rb', line 2983
|
Instance Attribute Details
#align_billing_with_phase_start_date ⇒ Boolean?
Align billing cycle day with phase start date.
2969 |
# File 'lib/orb/models/plan_create_params.rb', line 2969 optional :align_billing_with_phase_start_date, Orb::Internal::Type::Boolean, nil?: true |
#duration ⇒ Integer?
How many terms of length duration_unit this phase is active for. If null, this
phase is evergreen and active indefinitely
2976 |
# File 'lib/orb/models/plan_create_params.rb', line 2976 optional :duration, Integer, nil?: true |
#duration_unit ⇒ Symbol, ...
2981 |
# File 'lib/orb/models/plan_create_params.rb', line 2981 optional :duration_unit, enum: -> { Orb::PlanCreateParams::PlanPhase::DurationUnit }, nil?: true |
#order ⇒ Integer
Determines the ordering of the phase in a plan's lifecycle. 1 = first phase.
2963 |
# File 'lib/orb/models/plan_create_params.rb', line 2963 required :order, Integer |
Instance Method Details
#to_hash ⇒ {
2116 |
# File 'sig/orb/models/plan_create_params.rbs', line 2116
def to_hash: -> {
|