Class: Orb::Models::PlanPhaseAmountDiscountAdjustment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::PlanPhaseAmountDiscountAdjustment
- Defined in:
- lib/orb/models/plan_phase_amount_discount_adjustment.rb,
sig/orb/models/plan_phase_amount_discount_adjustment.rbs
Defined Under Namespace
Modules: AdjustmentType Classes: Filter
Instance Attribute Summary collapse
- #adjustment_type ⇒ Symbol, Orb::Models::PlanPhaseAmountDiscountAdjustment::AdjustmentType
-
#amount_discount ⇒ String
The amount by which to discount the prices this adjustment applies to in a given billing period.
- #applies_to_price_ids ⇒ Array<String> deprecated Deprecated.
-
#filters ⇒ Array<Orb::Models::PlanPhaseAmountDiscountAdjustment::Filter>
The filters that determine which prices to apply this adjustment to.
- #id ⇒ String
-
#is_invoice_level ⇒ Boolean
True for adjustments that apply to an entire invoice, false for adjustments that apply to only one price.
-
#plan_phase_order ⇒ Integer?
The plan phase in which this adjustment is active.
-
#reason ⇒ String?
The reason for the adjustment.
-
#replaces_adjustment_id ⇒ String?
The adjustment id this adjustment replaces.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, adjustment_type:, amount_discount:, applies_to_price_ids:, filters:, is_invoice_level:, plan_phase_order:, reason:, replaces_adjustment_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PlanPhaseAmountDiscountAdjustment for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, adjustment_type:, amount_discount:, applies_to_price_ids:, filters:, is_invoice_level:, plan_phase_order:, reason:, replaces_adjustment_id:) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::PlanPhaseAmountDiscountAdjustment for more details.
|
|
# File 'lib/orb/models/plan_phase_amount_discount_adjustment.rb', line 63
|
Instance Attribute Details
#adjustment_type ⇒ Symbol, Orb::Models::PlanPhaseAmountDiscountAdjustment::AdjustmentType
14 |
# File 'lib/orb/models/plan_phase_amount_discount_adjustment.rb', line 14 required :adjustment_type, enum: -> { Orb::PlanPhaseAmountDiscountAdjustment::AdjustmentType } |
#amount_discount ⇒ String
The amount by which to discount the prices this adjustment applies to in a given billing period.
21 |
# File 'lib/orb/models/plan_phase_amount_discount_adjustment.rb', line 21 required :amount_discount, String |
#applies_to_price_ids ⇒ Array<String>
The price IDs that this adjustment applies to.
29 |
# File 'lib/orb/models/plan_phase_amount_discount_adjustment.rb', line 29 required :applies_to_price_ids, Orb::Internal::Type::ArrayOf[String] |
#filters ⇒ Array<Orb::Models::PlanPhaseAmountDiscountAdjustment::Filter>
The filters that determine which prices to apply this adjustment to.
35 |
# File 'lib/orb/models/plan_phase_amount_discount_adjustment.rb', line 35 required :filters, -> { Orb::Internal::Type::ArrayOf[Orb::PlanPhaseAmountDiscountAdjustment::Filter] } |
#id ⇒ String
9 |
# File 'lib/orb/models/plan_phase_amount_discount_adjustment.rb', line 9 required :id, String |
#is_invoice_level ⇒ Boolean
True for adjustments that apply to an entire invoice, false for adjustments that apply to only one price.
42 |
# File 'lib/orb/models/plan_phase_amount_discount_adjustment.rb', line 42 required :is_invoice_level, Orb::Internal::Type::Boolean |
#plan_phase_order ⇒ Integer?
The plan phase in which this adjustment is active.
48 |
# File 'lib/orb/models/plan_phase_amount_discount_adjustment.rb', line 48 required :plan_phase_order, Integer, nil?: true |
#reason ⇒ String?
The reason for the adjustment.
54 |
# File 'lib/orb/models/plan_phase_amount_discount_adjustment.rb', line 54 required :reason, String, nil?: true |
#replaces_adjustment_id ⇒ String?
The adjustment id this adjustment replaces. This adjustment will take the place of the replaced adjustment in plan version migrations.
61 |
# File 'lib/orb/models/plan_phase_amount_discount_adjustment.rb', line 61 required :replaces_adjustment_id, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/plan_phase_amount_discount_adjustment.rb', line 91
|
Instance Method Details
#to_hash ⇒ {
47 |
# File 'sig/orb/models/plan_phase_amount_discount_adjustment.rbs', line 47
def to_hash: -> {
|