Module: Orb::Models::Price
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/orb/models/price.rb,
sig/orb/models/price.rbs
Overview
The Price resource represents a price that can be billed on a subscription, resulting in a charge on an invoice in the form of an invoice line item. Prices take a quantity and determine an amount to bill.
Orb supports a few different pricing models out of the box. Each of these models is serialized differently in a given Price object. The model_type field determines the key for the configuration object that is present.
For more on the types of prices, see the core concepts documentation
Defined Under Namespace
Classes: Bulk, BulkWithFilters, BulkWithProration, CumulativeGroupedAllocation, CumulativeGroupedBulk, DailyCreditAllowance, EventOutput, GroupedAllocation, GroupedTiered, GroupedTieredPackage, GroupedWithMeteredMinimum, GroupedWithMinMaxThresholds, GroupedWithProratedMinimum, Matrix, MatrixWithAllocation, MatrixWithDisplayName, MatrixWithThresholdDiscounts, MaxGroupTieredPackage, MeteredAllowance, MinimumComposite, Package, PackageWithAllocation, Percent, ScalableMatrixWithTieredPricing, ScalableMatrixWithUnitPricing, ThresholdTotalAmount, Tiered, TieredPackage, TieredPackageWithMinimum, TieredWithMinimum, TieredWithProration, Unit, UnitWithPercent, UnitWithProration
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, grouping_key:, name:) ⇒ Object
Some parameter documentations has been truncated, see Percent::LicenseType for more details.
- #self?.variants ⇒ ::Array[Orb::Models::price]
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(Orb::Models::Price::Unit, Orb::Models::Price::Tiered, Orb::Models::Price::Bulk, Orb::Models::Price::BulkWithFilters, Orb::Models::Price::Package, Orb::Models::Price::Matrix, Orb::Models::Price::ThresholdTotalAmount, Orb::Models::Price::TieredPackage, Orb::Models::Price::TieredWithMinimum, Orb::Models::Price::GroupedTiered, Orb::Models::Price::TieredPackageWithMinimum, Orb::Models::Price::PackageWithAllocation, Orb::Models::Price::UnitWithPercent, Orb::Models::Price::MatrixWithAllocation, Orb::Models::Price::MatrixWithThresholdDiscounts, Orb::Models::Price::TieredWithProration, Orb::Models::Price::UnitWithProration, Orb::Models::Price::GroupedAllocation, Orb::Models::Price::BulkWithProration, Orb::Models::Price::GroupedWithProratedMinimum, Orb::Models::Price::GroupedWithMeteredMinimum, Orb::Models::Price::GroupedWithMinMaxThresholds, Orb::Models::Price::MatrixWithDisplayName, Orb::Models::Price::GroupedTieredPackage, Orb::Models::Price::MaxGroupTieredPackage, Orb::Models::Price::ScalableMatrixWithUnitPricing, Orb::Models::Price::ScalableMatrixWithTieredPricing, Orb::Models::Price::CumulativeGroupedBulk, Orb::Models::Price::CumulativeGroupedAllocation, Orb::Models::Price::DailyCreditAllowance, Orb::Models::Price::MeteredAllowance, Orb::Models::Price::MinimumComposite, Orb::Models::Price::Percent, Orb::Models::Price::EventOutput)
|
|
# File 'lib/orb/models/price.rb', line 13995
|
Instance Method Details
#initialize(id:, grouping_key:, name:) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::Price::Percent::LicenseType for more details.
The LicenseType resource represents a type of license that can be assigned to users. License types are used during billing by grouping metrics on the configured grouping key.
|
|
# File 'lib/orb/models/price.rb', line 438
|
#self?.variants ⇒ ::Array[Orb::Models::price]
10452 |
# File 'sig/orb/models/price.rbs', line 10452
def self?.variants: -> ::Array[Orb::Models::price]
|