Class: Orb::Models::Price::CumulativeGroupedAllocation
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, CumulativeGroupedAllocationConfig, LicenseType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cumulative_allocation:, group_allocation:, grouping_key:, unit_amount:) ⇒ Object
Configuration for cumulative_grouped_allocation pricing
|
# File 'lib/orb/models/price.rb', line 12119
|
Instance Attribute Details
11954
|
# File 'lib/orb/models/price.rb', line 11954
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
11959
|
# File 'lib/orb/models/price.rb', line 11959
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
11964
|
# File 'lib/orb/models/price.rb', line 11964
required :billing_mode, enum: -> { Orb::Price::CumulativeGroupedAllocation::BillingMode }
|
11969
|
# File 'lib/orb/models/price.rb', line 11969
required :cadence, enum: -> { Orb::Price::CumulativeGroupedAllocation::Cadence }
|
11974
11975
11976
11977
11978
|
# File 'lib/orb/models/price.rb', line 11974
required :composite_price_filters,
-> {
Orb::Internal::Type::ArrayOf[Orb::Price::CumulativeGroupedAllocation::CompositePriceFilter]
},
nil?: true
|
#conversion_rate ⇒ Float?
11983
|
# File 'lib/orb/models/price.rb', line 11983
required :conversion_rate, Float, nil?: true
|
11988
|
# File 'lib/orb/models/price.rb', line 11988
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
11993
|
# File 'lib/orb/models/price.rb', line 11993
required :created_at, Time
|
11998
|
# File 'lib/orb/models/price.rb', line 11998
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
Configuration for cumulative_grouped_allocation pricing
12004
12005
|
# File 'lib/orb/models/price.rb', line 12004
required :cumulative_grouped_allocation_config,
-> { Orb::Price::CumulativeGroupedAllocation::CumulativeGroupedAllocationConfig }
|
#currency ⇒ String
12010
|
# File 'lib/orb/models/price.rb', line 12010
required :currency, String
|
12109
|
# File 'lib/orb/models/price.rb', line 12109
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
12016
|
# File 'lib/orb/models/price.rb', line 12016
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
12021
|
# File 'lib/orb/models/price.rb', line 12021
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
12026
|
# File 'lib/orb/models/price.rb', line 12026
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
11949
|
# File 'lib/orb/models/price.rb', line 11949
required :id, String
|
#invoice_grouping_key ⇒ String?
12031
|
# File 'lib/orb/models/price.rb', line 12031
required :invoice_grouping_key, String, nil?: true
|
12036
|
# File 'lib/orb/models/price.rb', line 12036
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
12043
|
# File 'lib/orb/models/price.rb', line 12043
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
12117
|
# File 'lib/orb/models/price.rb', line 12117
optional :license_type, -> { Orb::Price::CumulativeGroupedAllocation::LicenseType }, nil?: true
|
12049
|
# File 'lib/orb/models/price.rb', line 12049
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
12055
|
# File 'lib/orb/models/price.rb', line 12055
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
12064
|
# File 'lib/orb/models/price.rb', line 12064
required :metadata, Orb::Internal::Type::HashOf[String]
|
12070
|
# File 'lib/orb/models/price.rb', line 12070
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
12076
|
# File 'lib/orb/models/price.rb', line 12076
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :cumulative_grouped_allocation
12082
|
# File 'lib/orb/models/price.rb', line 12082
required :model_type, const: :cumulative_grouped_allocation
|
#name ⇒ String
12087
|
# File 'lib/orb/models/price.rb', line 12087
required :name, String
|
#plan_phase_order ⇒ Integer?
12092
|
# File 'lib/orb/models/price.rb', line 12092
required :plan_phase_order, Integer, nil?: true
|
12097
|
# File 'lib/orb/models/price.rb', line 12097
required :price_type, enum: -> { Orb::Price::CumulativeGroupedAllocation::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
12104
|
# File 'lib/orb/models/price.rb', line 12104
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 12190
|
Instance Method Details
#to_hash ⇒ {
9065
|
# File 'sig/orb/models/price.rbs', line 9065
def to_hash: -> {
|