Class: Orb::Models::Price::CumulativeGroupedAllocation
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, CumulativeGroupedAllocationConfig, LicenseType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cumulative_allocation:, group_allocation:, grouping_key:, unit_amount:) ⇒ Object
Configuration for cumulative_grouped_allocation pricing
|
# File 'lib/orb/models/price.rb', line 11687
|
Instance Attribute Details
11522
|
# File 'lib/orb/models/price.rb', line 11522
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
11527
|
# File 'lib/orb/models/price.rb', line 11527
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
11532
|
# File 'lib/orb/models/price.rb', line 11532
required :billing_mode, enum: -> { Orb::Price::CumulativeGroupedAllocation::BillingMode }
|
11537
|
# File 'lib/orb/models/price.rb', line 11537
required :cadence, enum: -> { Orb::Price::CumulativeGroupedAllocation::Cadence }
|
11542
11543
11544
11545
11546
|
# File 'lib/orb/models/price.rb', line 11542
required :composite_price_filters,
-> {
Orb::Internal::Type::ArrayOf[Orb::Price::CumulativeGroupedAllocation::CompositePriceFilter]
},
nil?: true
|
#conversion_rate ⇒ Float?
11551
|
# File 'lib/orb/models/price.rb', line 11551
required :conversion_rate, Float, nil?: true
|
11556
|
# File 'lib/orb/models/price.rb', line 11556
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
11561
|
# File 'lib/orb/models/price.rb', line 11561
required :created_at, Time
|
11566
|
# File 'lib/orb/models/price.rb', line 11566
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
Configuration for cumulative_grouped_allocation pricing
11572
11573
|
# File 'lib/orb/models/price.rb', line 11572
required :cumulative_grouped_allocation_config,
-> { Orb::Price::CumulativeGroupedAllocation::CumulativeGroupedAllocationConfig }
|
#currency ⇒ String
11578
|
# File 'lib/orb/models/price.rb', line 11578
required :currency, String
|
11677
|
# File 'lib/orb/models/price.rb', line 11677
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
11584
|
# File 'lib/orb/models/price.rb', line 11584
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
11589
|
# File 'lib/orb/models/price.rb', line 11589
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
11594
|
# File 'lib/orb/models/price.rb', line 11594
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
11517
|
# File 'lib/orb/models/price.rb', line 11517
required :id, String
|
#invoice_grouping_key ⇒ String?
11599
|
# File 'lib/orb/models/price.rb', line 11599
required :invoice_grouping_key, String, nil?: true
|
11604
|
# File 'lib/orb/models/price.rb', line 11604
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
11611
|
# File 'lib/orb/models/price.rb', line 11611
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
11685
|
# File 'lib/orb/models/price.rb', line 11685
optional :license_type, -> { Orb::Price::CumulativeGroupedAllocation::LicenseType }, nil?: true
|
11617
|
# File 'lib/orb/models/price.rb', line 11617
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
11623
|
# File 'lib/orb/models/price.rb', line 11623
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
11632
|
# File 'lib/orb/models/price.rb', line 11632
required :metadata, Orb::Internal::Type::HashOf[String]
|
11638
|
# File 'lib/orb/models/price.rb', line 11638
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
11644
|
# File 'lib/orb/models/price.rb', line 11644
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :cumulative_grouped_allocation
11650
|
# File 'lib/orb/models/price.rb', line 11650
required :model_type, const: :cumulative_grouped_allocation
|
#name ⇒ String
11655
|
# File 'lib/orb/models/price.rb', line 11655
required :name, String
|
#plan_phase_order ⇒ Integer?
11660
|
# File 'lib/orb/models/price.rb', line 11660
required :plan_phase_order, Integer, nil?: true
|
11665
|
# File 'lib/orb/models/price.rb', line 11665
required :price_type, enum: -> { Orb::Price::CumulativeGroupedAllocation::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
11672
|
# File 'lib/orb/models/price.rb', line 11672
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 11758
|
Instance Method Details
#to_hash ⇒ {
8738
|
# File 'sig/orb/models/price.rbs', line 8738
def to_hash: -> {
|