Class: Orb::Models::Price::EventOutput
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, EventOutputConfig, LicenseType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(unit_rating_key:, default_unit_rate: nil, grouping_key: nil) ⇒ Object
Some parameter documentations has been truncated, see
EventOutputConfig for more details.
Configuration for event_output pricing
|
# File 'lib/orb/models/price.rb', line 14196
|
Instance Attribute Details
14034
|
# File 'lib/orb/models/price.rb', line 14034
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
14039
|
# File 'lib/orb/models/price.rb', line 14039
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
14044
|
# File 'lib/orb/models/price.rb', line 14044
required :billing_mode, enum: -> { Orb::Price::EventOutput::BillingMode }
|
14049
|
# File 'lib/orb/models/price.rb', line 14049
required :cadence, enum: -> { Orb::Price::EventOutput::Cadence }
|
14054
14055
14056
|
# File 'lib/orb/models/price.rb', line 14054
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::EventOutput::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
14061
|
# File 'lib/orb/models/price.rb', line 14061
required :conversion_rate, Float, nil?: true
|
14066
|
# File 'lib/orb/models/price.rb', line 14066
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
14071
|
# File 'lib/orb/models/price.rb', line 14071
required :created_at, Time
|
14076
|
# File 'lib/orb/models/price.rb', line 14076
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
14081
|
# File 'lib/orb/models/price.rb', line 14081
required :currency, String
|
14186
|
# File 'lib/orb/models/price.rb', line 14186
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
14087
|
# File 'lib/orb/models/price.rb', line 14087
required :discount, union: -> { Orb::Discount }, nil?: true
|
Configuration for event_output pricing
14093
|
# File 'lib/orb/models/price.rb', line 14093
required :event_output_config, -> { Orb::Price::EventOutput::EventOutputConfig }
|
#external_price_id ⇒ String?
14098
|
# File 'lib/orb/models/price.rb', line 14098
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
14103
|
# File 'lib/orb/models/price.rb', line 14103
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
14029
|
# File 'lib/orb/models/price.rb', line 14029
required :id, String
|
#invoice_grouping_key ⇒ String?
14108
|
# File 'lib/orb/models/price.rb', line 14108
required :invoice_grouping_key, String, nil?: true
|
14113
|
# File 'lib/orb/models/price.rb', line 14113
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
14120
|
# File 'lib/orb/models/price.rb', line 14120
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
14194
|
# File 'lib/orb/models/price.rb', line 14194
optional :license_type, -> { Orb::Price::EventOutput::LicenseType }, nil?: true
|
14126
|
# File 'lib/orb/models/price.rb', line 14126
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
14132
|
# File 'lib/orb/models/price.rb', line 14132
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
14141
|
# File 'lib/orb/models/price.rb', line 14141
required :metadata, Orb::Internal::Type::HashOf[String]
|
14147
|
# File 'lib/orb/models/price.rb', line 14147
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
14153
|
# File 'lib/orb/models/price.rb', line 14153
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :event_output
14159
|
# File 'lib/orb/models/price.rb', line 14159
required :model_type, const: :event_output
|
#name ⇒ String
14164
|
# File 'lib/orb/models/price.rb', line 14164
required :name, String
|
#plan_phase_order ⇒ Integer?
14169
|
# File 'lib/orb/models/price.rb', line 14169
required :plan_phase_order, Integer, nil?: true
|
14174
|
# File 'lib/orb/models/price.rb', line 14174
required :price_type, enum: -> { Orb::Price::EventOutput::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
14181
|
# File 'lib/orb/models/price.rb', line 14181
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 14267
|
Instance Method Details
#to_hash ⇒ {
10608
|
# File 'sig/orb/models/price.rbs', line 10608
def to_hash: -> {
|