Class: Orb::Models::Price::EventOutput
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, EventOutputConfig, LicenseType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(unit_rating_key:, default_unit_rate: nil, grouping_key: nil) ⇒ Object
Some parameter documentations has been truncated, see
EventOutputConfig for more details.
Configuration for event_output pricing
|
# File 'lib/orb/models/price.rb', line 13764
|
Instance Attribute Details
13602
|
# File 'lib/orb/models/price.rb', line 13602
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
13607
|
# File 'lib/orb/models/price.rb', line 13607
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
13612
|
# File 'lib/orb/models/price.rb', line 13612
required :billing_mode, enum: -> { Orb::Price::EventOutput::BillingMode }
|
13617
|
# File 'lib/orb/models/price.rb', line 13617
required :cadence, enum: -> { Orb::Price::EventOutput::Cadence }
|
13622
13623
13624
|
# File 'lib/orb/models/price.rb', line 13622
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::EventOutput::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
13629
|
# File 'lib/orb/models/price.rb', line 13629
required :conversion_rate, Float, nil?: true
|
13634
|
# File 'lib/orb/models/price.rb', line 13634
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
13639
|
# File 'lib/orb/models/price.rb', line 13639
required :created_at, Time
|
13644
|
# File 'lib/orb/models/price.rb', line 13644
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
13649
|
# File 'lib/orb/models/price.rb', line 13649
required :currency, String
|
13754
|
# File 'lib/orb/models/price.rb', line 13754
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
13655
|
# File 'lib/orb/models/price.rb', line 13655
required :discount, union: -> { Orb::Discount }, nil?: true
|
Configuration for event_output pricing
13661
|
# File 'lib/orb/models/price.rb', line 13661
required :event_output_config, -> { Orb::Price::EventOutput::EventOutputConfig }
|
#external_price_id ⇒ String?
13666
|
# File 'lib/orb/models/price.rb', line 13666
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
13671
|
# File 'lib/orb/models/price.rb', line 13671
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
13597
|
# File 'lib/orb/models/price.rb', line 13597
required :id, String
|
#invoice_grouping_key ⇒ String?
13676
|
# File 'lib/orb/models/price.rb', line 13676
required :invoice_grouping_key, String, nil?: true
|
13681
|
# File 'lib/orb/models/price.rb', line 13681
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
13688
|
# File 'lib/orb/models/price.rb', line 13688
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
13762
|
# File 'lib/orb/models/price.rb', line 13762
optional :license_type, -> { Orb::Price::EventOutput::LicenseType }, nil?: true
|
13694
|
# File 'lib/orb/models/price.rb', line 13694
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
13700
|
# File 'lib/orb/models/price.rb', line 13700
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
13709
|
# File 'lib/orb/models/price.rb', line 13709
required :metadata, Orb::Internal::Type::HashOf[String]
|
13715
|
# File 'lib/orb/models/price.rb', line 13715
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
13721
|
# File 'lib/orb/models/price.rb', line 13721
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :event_output
13727
|
# File 'lib/orb/models/price.rb', line 13727
required :model_type, const: :event_output
|
#name ⇒ String
13732
|
# File 'lib/orb/models/price.rb', line 13732
required :name, String
|
#plan_phase_order ⇒ Integer?
13737
|
# File 'lib/orb/models/price.rb', line 13737
required :plan_phase_order, Integer, nil?: true
|
13742
|
# File 'lib/orb/models/price.rb', line 13742
required :price_type, enum: -> { Orb::Price::EventOutput::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
13749
|
# File 'lib/orb/models/price.rb', line 13749
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 13835
|
Instance Method Details
#to_hash ⇒ {
10281
|
# File 'sig/orb/models/price.rbs', line 10281
def to_hash: -> {
|