Class: Orb::Models::Price::GroupedAllocation
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, GroupedAllocationConfig, LicenseType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(allocation:, grouping_key:, overage_unit_rate:) ⇒ Object
Configuration for grouped_allocation pricing
|
# File 'lib/orb/models/price.rb', line 7462
|
Instance Attribute Details
7300
|
# File 'lib/orb/models/price.rb', line 7300
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
7305
|
# File 'lib/orb/models/price.rb', line 7305
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
7310
|
# File 'lib/orb/models/price.rb', line 7310
required :billing_mode, enum: -> { Orb::Price::GroupedAllocation::BillingMode }
|
7315
|
# File 'lib/orb/models/price.rb', line 7315
required :cadence, enum: -> { Orb::Price::GroupedAllocation::Cadence }
|
7320
7321
7322
|
# File 'lib/orb/models/price.rb', line 7320
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::GroupedAllocation::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
7327
|
# File 'lib/orb/models/price.rb', line 7327
required :conversion_rate, Float, nil?: true
|
7332
|
# File 'lib/orb/models/price.rb', line 7332
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
7337
|
# File 'lib/orb/models/price.rb', line 7337
required :created_at, Time
|
7342
|
# File 'lib/orb/models/price.rb', line 7342
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
7347
|
# File 'lib/orb/models/price.rb', line 7347
required :currency, String
|
7452
|
# File 'lib/orb/models/price.rb', line 7452
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
7353
|
# File 'lib/orb/models/price.rb', line 7353
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
7358
|
# File 'lib/orb/models/price.rb', line 7358
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
7363
|
# File 'lib/orb/models/price.rb', line 7363
required :fixed_price_quantity, Float, nil?: true
|
Configuration for grouped_allocation pricing
7369
|
# File 'lib/orb/models/price.rb', line 7369
required :grouped_allocation_config, -> { Orb::Price::GroupedAllocation::GroupedAllocationConfig }
|
#id ⇒ String
7295
|
# File 'lib/orb/models/price.rb', line 7295
required :id, String
|
#invoice_grouping_key ⇒ String?
7374
|
# File 'lib/orb/models/price.rb', line 7374
required :invoice_grouping_key, String, nil?: true
|
7379
|
# File 'lib/orb/models/price.rb', line 7379
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
7386
|
# File 'lib/orb/models/price.rb', line 7386
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
7460
|
# File 'lib/orb/models/price.rb', line 7460
optional :license_type, -> { Orb::Price::GroupedAllocation::LicenseType }, nil?: true
|
7392
|
# File 'lib/orb/models/price.rb', line 7392
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
7398
|
# File 'lib/orb/models/price.rb', line 7398
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
7407
|
# File 'lib/orb/models/price.rb', line 7407
required :metadata, Orb::Internal::Type::HashOf[String]
|
7413
|
# File 'lib/orb/models/price.rb', line 7413
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
7419
|
# File 'lib/orb/models/price.rb', line 7419
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :grouped_allocation
7425
|
# File 'lib/orb/models/price.rb', line 7425
required :model_type, const: :grouped_allocation
|
#name ⇒ String
7430
|
# File 'lib/orb/models/price.rb', line 7430
required :name, String
|
#plan_phase_order ⇒ Integer?
7435
|
# File 'lib/orb/models/price.rb', line 7435
required :plan_phase_order, Integer, nil?: true
|
7440
|
# File 'lib/orb/models/price.rb', line 7440
required :price_type, enum: -> { Orb::Price::GroupedAllocation::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
7447
|
# File 'lib/orb/models/price.rb', line 7447
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 7533
|
Instance Method Details
#to_hash ⇒ {
5567
|
# File 'sig/orb/models/price.rbs', line 5567
def to_hash: -> {
|