Class: Orb::Models::Price::GroupedAllocation
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, GroupedAllocationConfig, LicenseType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(allocation:, grouping_key:, overage_unit_rate:) ⇒ Object
Configuration for grouped_allocation pricing
|
# File 'lib/orb/models/price.rb', line 7030
|
Instance Attribute Details
6868
|
# File 'lib/orb/models/price.rb', line 6868
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
6873
|
# File 'lib/orb/models/price.rb', line 6873
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
6878
|
# File 'lib/orb/models/price.rb', line 6878
required :billing_mode, enum: -> { Orb::Price::GroupedAllocation::BillingMode }
|
6883
|
# File 'lib/orb/models/price.rb', line 6883
required :cadence, enum: -> { Orb::Price::GroupedAllocation::Cadence }
|
6888
6889
6890
|
# File 'lib/orb/models/price.rb', line 6888
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::GroupedAllocation::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
6895
|
# File 'lib/orb/models/price.rb', line 6895
required :conversion_rate, Float, nil?: true
|
6900
|
# File 'lib/orb/models/price.rb', line 6900
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
6905
|
# File 'lib/orb/models/price.rb', line 6905
required :created_at, Time
|
6910
|
# File 'lib/orb/models/price.rb', line 6910
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
6915
|
# File 'lib/orb/models/price.rb', line 6915
required :currency, String
|
7020
|
# File 'lib/orb/models/price.rb', line 7020
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
6921
|
# File 'lib/orb/models/price.rb', line 6921
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
6926
|
# File 'lib/orb/models/price.rb', line 6926
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
6931
|
# File 'lib/orb/models/price.rb', line 6931
required :fixed_price_quantity, Float, nil?: true
|
Configuration for grouped_allocation pricing
6937
|
# File 'lib/orb/models/price.rb', line 6937
required :grouped_allocation_config, -> { Orb::Price::GroupedAllocation::GroupedAllocationConfig }
|
#id ⇒ String
6863
|
# File 'lib/orb/models/price.rb', line 6863
required :id, String
|
#invoice_grouping_key ⇒ String?
6942
|
# File 'lib/orb/models/price.rb', line 6942
required :invoice_grouping_key, String, nil?: true
|
6947
|
# File 'lib/orb/models/price.rb', line 6947
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
6954
|
# File 'lib/orb/models/price.rb', line 6954
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
7028
|
# File 'lib/orb/models/price.rb', line 7028
optional :license_type, -> { Orb::Price::GroupedAllocation::LicenseType }, nil?: true
|
6960
|
# File 'lib/orb/models/price.rb', line 6960
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
6966
|
# File 'lib/orb/models/price.rb', line 6966
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
6975
|
# File 'lib/orb/models/price.rb', line 6975
required :metadata, Orb::Internal::Type::HashOf[String]
|
6981
|
# File 'lib/orb/models/price.rb', line 6981
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
6987
|
# File 'lib/orb/models/price.rb', line 6987
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :grouped_allocation
6993
|
# File 'lib/orb/models/price.rb', line 6993
required :model_type, const: :grouped_allocation
|
#name ⇒ String
6998
|
# File 'lib/orb/models/price.rb', line 6998
required :name, String
|
#plan_phase_order ⇒ Integer?
7003
|
# File 'lib/orb/models/price.rb', line 7003
required :plan_phase_order, Integer, nil?: true
|
7008
|
# File 'lib/orb/models/price.rb', line 7008
required :price_type, enum: -> { Orb::Price::GroupedAllocation::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
7015
|
# File 'lib/orb/models/price.rb', line 7015
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 7101
|
Instance Method Details
#to_hash ⇒ {
5240
|
# File 'sig/orb/models/price.rbs', line 5240
def to_hash: -> {
|