Class: Orb::Models::Price::GroupedTiered
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, GroupedTieredConfig, LicenseType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(tier_lower_bound:, unit_amount:) ⇒ Object
Configuration for a single tier
|
# File 'lib/orb/models/price.rb', line 3780
|
Instance Attribute Details
3618
|
# File 'lib/orb/models/price.rb', line 3618
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
3623
|
# File 'lib/orb/models/price.rb', line 3623
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
3628
|
# File 'lib/orb/models/price.rb', line 3628
required :billing_mode, enum: -> { Orb::Price::GroupedTiered::BillingMode }
|
3633
|
# File 'lib/orb/models/price.rb', line 3633
required :cadence, enum: -> { Orb::Price::GroupedTiered::Cadence }
|
3638
3639
3640
|
# File 'lib/orb/models/price.rb', line 3638
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::GroupedTiered::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
3645
|
# File 'lib/orb/models/price.rb', line 3645
required :conversion_rate, Float, nil?: true
|
3650
|
# File 'lib/orb/models/price.rb', line 3650
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
3655
|
# File 'lib/orb/models/price.rb', line 3655
required :created_at, Time
|
3660
|
# File 'lib/orb/models/price.rb', line 3660
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
3665
|
# File 'lib/orb/models/price.rb', line 3665
required :currency, String
|
3770
|
# File 'lib/orb/models/price.rb', line 3770
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
3671
|
# File 'lib/orb/models/price.rb', line 3671
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
3676
|
# File 'lib/orb/models/price.rb', line 3676
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
3681
|
# File 'lib/orb/models/price.rb', line 3681
required :fixed_price_quantity, Float, nil?: true
|
Configuration for grouped_tiered pricing
3687
|
# File 'lib/orb/models/price.rb', line 3687
required :grouped_tiered_config, -> { Orb::Price::GroupedTiered::GroupedTieredConfig }
|
#id ⇒ String
3613
|
# File 'lib/orb/models/price.rb', line 3613
required :id, String
|
#invoice_grouping_key ⇒ String?
3692
|
# File 'lib/orb/models/price.rb', line 3692
required :invoice_grouping_key, String, nil?: true
|
3697
|
# File 'lib/orb/models/price.rb', line 3697
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
3704
|
# File 'lib/orb/models/price.rb', line 3704
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
3778
|
# File 'lib/orb/models/price.rb', line 3778
optional :license_type, -> { Orb::Price::GroupedTiered::LicenseType }, nil?: true
|
3710
|
# File 'lib/orb/models/price.rb', line 3710
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
3716
|
# File 'lib/orb/models/price.rb', line 3716
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
3725
|
# File 'lib/orb/models/price.rb', line 3725
required :metadata, Orb::Internal::Type::HashOf[String]
|
3731
|
# File 'lib/orb/models/price.rb', line 3731
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
3737
|
# File 'lib/orb/models/price.rb', line 3737
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :grouped_tiered
3743
|
# File 'lib/orb/models/price.rb', line 3743
required :model_type, const: :grouped_tiered
|
#name ⇒ String
3748
|
# File 'lib/orb/models/price.rb', line 3748
required :name, String
|
#plan_phase_order ⇒ Integer?
3753
|
# File 'lib/orb/models/price.rb', line 3753
required :plan_phase_order, Integer, nil?: true
|
3758
|
# File 'lib/orb/models/price.rb', line 3758
required :price_type, enum: -> { Orb::Price::GroupedTiered::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
3765
|
# File 'lib/orb/models/price.rb', line 3765
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 3851
|
Instance Method Details
#to_hash ⇒ {
2797
|
# File 'sig/orb/models/price.rbs', line 2797
def to_hash: -> {
|