Class: Orb::Models::Price::GroupedTiered
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, GroupedTieredConfig, LicenseType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(tier_lower_bound:, unit_amount:) ⇒ Object
Configuration for a single tier
|
# File 'lib/orb/models/price.rb', line 3778
|
Instance Attribute Details
3616
|
# File 'lib/orb/models/price.rb', line 3616
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
3621
|
# File 'lib/orb/models/price.rb', line 3621
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
3626
|
# File 'lib/orb/models/price.rb', line 3626
required :billing_mode, enum: -> { Orb::Price::GroupedTiered::BillingMode }
|
3631
|
# File 'lib/orb/models/price.rb', line 3631
required :cadence, enum: -> { Orb::Price::GroupedTiered::Cadence }
|
3636
3637
3638
|
# File 'lib/orb/models/price.rb', line 3636
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::GroupedTiered::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
3643
|
# File 'lib/orb/models/price.rb', line 3643
required :conversion_rate, Float, nil?: true
|
3648
|
# File 'lib/orb/models/price.rb', line 3648
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
3653
|
# File 'lib/orb/models/price.rb', line 3653
required :created_at, Time
|
3658
|
# File 'lib/orb/models/price.rb', line 3658
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
3663
|
# File 'lib/orb/models/price.rb', line 3663
required :currency, String
|
3768
|
# File 'lib/orb/models/price.rb', line 3768
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
3669
|
# File 'lib/orb/models/price.rb', line 3669
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
3674
|
# File 'lib/orb/models/price.rb', line 3674
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
3679
|
# File 'lib/orb/models/price.rb', line 3679
required :fixed_price_quantity, Float, nil?: true
|
Configuration for grouped_tiered pricing
3685
|
# File 'lib/orb/models/price.rb', line 3685
required :grouped_tiered_config, -> { Orb::Price::GroupedTiered::GroupedTieredConfig }
|
#id ⇒ String
3611
|
# File 'lib/orb/models/price.rb', line 3611
required :id, String
|
#invoice_grouping_key ⇒ String?
3690
|
# File 'lib/orb/models/price.rb', line 3690
required :invoice_grouping_key, String, nil?: true
|
3695
|
# File 'lib/orb/models/price.rb', line 3695
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
3702
|
# File 'lib/orb/models/price.rb', line 3702
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
3776
|
# File 'lib/orb/models/price.rb', line 3776
optional :license_type, -> { Orb::Price::GroupedTiered::LicenseType }, nil?: true
|
3708
|
# File 'lib/orb/models/price.rb', line 3708
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
3714
|
# File 'lib/orb/models/price.rb', line 3714
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
3723
|
# File 'lib/orb/models/price.rb', line 3723
required :metadata, Orb::Internal::Type::HashOf[String]
|
3729
|
# File 'lib/orb/models/price.rb', line 3729
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
3735
|
# File 'lib/orb/models/price.rb', line 3735
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :grouped_tiered
3741
|
# File 'lib/orb/models/price.rb', line 3741
required :model_type, const: :grouped_tiered
|
#name ⇒ String
3746
|
# File 'lib/orb/models/price.rb', line 3746
required :name, String
|
#plan_phase_order ⇒ Integer?
3751
|
# File 'lib/orb/models/price.rb', line 3751
required :plan_phase_order, Integer, nil?: true
|
3756
|
# File 'lib/orb/models/price.rb', line 3756
required :price_type, enum: -> { Orb::Price::GroupedTiered::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
3763
|
# File 'lib/orb/models/price.rb', line 3763
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 3849
|
Instance Method Details
#to_hash ⇒ {
2796
|
# File 'sig/orb/models/price.rbs', line 2796
def to_hash: -> {
|