Class: Orb::Models::Price::GroupedTieredMatrix
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, GroupedTieredMatrixConfig, LicenseType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(dimension_value:, tier_lower_bound:, unit_amount:) ⇒ Object
Configuration for a single tier scoped to a dimension value
|
# File 'lib/orb/models/price.rb', line 4192
|
Instance Attribute Details
4030
|
# File 'lib/orb/models/price.rb', line 4030
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
4035
|
# File 'lib/orb/models/price.rb', line 4035
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
4040
|
# File 'lib/orb/models/price.rb', line 4040
required :billing_mode, enum: -> { Orb::Price::GroupedTieredMatrix::BillingMode }
|
4045
|
# File 'lib/orb/models/price.rb', line 4045
required :cadence, enum: -> { Orb::Price::GroupedTieredMatrix::Cadence }
|
4050
4051
4052
|
# File 'lib/orb/models/price.rb', line 4050
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::GroupedTieredMatrix::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
4057
|
# File 'lib/orb/models/price.rb', line 4057
required :conversion_rate, Float, nil?: true
|
4062
|
# File 'lib/orb/models/price.rb', line 4062
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
4067
|
# File 'lib/orb/models/price.rb', line 4067
required :created_at, Time
|
4072
|
# File 'lib/orb/models/price.rb', line 4072
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
4077
|
# File 'lib/orb/models/price.rb', line 4077
required :currency, String
|
4182
|
# File 'lib/orb/models/price.rb', line 4182
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
4083
|
# File 'lib/orb/models/price.rb', line 4083
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
4088
|
# File 'lib/orb/models/price.rb', line 4088
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
4093
|
# File 'lib/orb/models/price.rb', line 4093
required :fixed_price_quantity, Float, nil?: true
|
Configuration for grouped_tiered_matrix pricing
4099
|
# File 'lib/orb/models/price.rb', line 4099
required :grouped_tiered_matrix_config, -> { Orb::Price::GroupedTieredMatrix::GroupedTieredMatrixConfig }
|
#id ⇒ String
4025
|
# File 'lib/orb/models/price.rb', line 4025
required :id, String
|
#invoice_grouping_key ⇒ String?
4104
|
# File 'lib/orb/models/price.rb', line 4104
required :invoice_grouping_key, String, nil?: true
|
4109
|
# File 'lib/orb/models/price.rb', line 4109
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
4116
|
# File 'lib/orb/models/price.rb', line 4116
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
4190
|
# File 'lib/orb/models/price.rb', line 4190
optional :license_type, -> { Orb::Price::GroupedTieredMatrix::LicenseType }, nil?: true
|
4122
|
# File 'lib/orb/models/price.rb', line 4122
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
4128
|
# File 'lib/orb/models/price.rb', line 4128
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
4137
|
# File 'lib/orb/models/price.rb', line 4137
required :metadata, Orb::Internal::Type::HashOf[String]
|
4143
|
# File 'lib/orb/models/price.rb', line 4143
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
4149
|
# File 'lib/orb/models/price.rb', line 4149
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :grouped_tiered_matrix
4155
|
# File 'lib/orb/models/price.rb', line 4155
required :model_type, const: :grouped_tiered_matrix
|
#name ⇒ String
4160
|
# File 'lib/orb/models/price.rb', line 4160
required :name, String
|
#plan_phase_order ⇒ Integer?
4165
|
# File 'lib/orb/models/price.rb', line 4165
required :plan_phase_order, Integer, nil?: true
|
4170
|
# File 'lib/orb/models/price.rb', line 4170
required :price_type, enum: -> { Orb::Price::GroupedTieredMatrix::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
4177
|
# File 'lib/orb/models/price.rb', line 4177
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 4263
|
Instance Method Details
#to_hash ⇒ {
3106
|
# File 'sig/orb/models/price.rbs', line 3106
def to_hash: -> {
|