Class: Orb::Models::Price::GroupedTieredPackage
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, GroupedTieredPackageConfig, LicenseType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(per_unit:, tier_lower_bound:) ⇒ Object
Configuration for a single tier
|
# File 'lib/orb/models/price.rb', line 9955
|
Instance Attribute Details
9792
|
# File 'lib/orb/models/price.rb', line 9792
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
9797
|
# File 'lib/orb/models/price.rb', line 9797
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
9802
|
# File 'lib/orb/models/price.rb', line 9802
required :billing_mode, enum: -> { Orb::Price::GroupedTieredPackage::BillingMode }
|
9807
|
# File 'lib/orb/models/price.rb', line 9807
required :cadence, enum: -> { Orb::Price::GroupedTieredPackage::Cadence }
|
9812
9813
9814
|
# File 'lib/orb/models/price.rb', line 9812
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::GroupedTieredPackage::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
9819
|
# File 'lib/orb/models/price.rb', line 9819
required :conversion_rate, Float, nil?: true
|
9824
|
# File 'lib/orb/models/price.rb', line 9824
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
9829
|
# File 'lib/orb/models/price.rb', line 9829
required :created_at, Time
|
9834
|
# File 'lib/orb/models/price.rb', line 9834
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
9839
|
# File 'lib/orb/models/price.rb', line 9839
required :currency, String
|
9945
|
# File 'lib/orb/models/price.rb', line 9945
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
9845
|
# File 'lib/orb/models/price.rb', line 9845
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
9850
|
# File 'lib/orb/models/price.rb', line 9850
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
9855
|
# File 'lib/orb/models/price.rb', line 9855
required :fixed_price_quantity, Float, nil?: true
|
Configuration for grouped_tiered_package pricing
9861
9862
|
# File 'lib/orb/models/price.rb', line 9861
required :grouped_tiered_package_config,
-> { Orb::Price::GroupedTieredPackage::GroupedTieredPackageConfig }
|
#id ⇒ String
9787
|
# File 'lib/orb/models/price.rb', line 9787
required :id, String
|
#invoice_grouping_key ⇒ String?
9867
|
# File 'lib/orb/models/price.rb', line 9867
required :invoice_grouping_key, String, nil?: true
|
9872
|
# File 'lib/orb/models/price.rb', line 9872
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
9879
|
# File 'lib/orb/models/price.rb', line 9879
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
9953
|
# File 'lib/orb/models/price.rb', line 9953
optional :license_type, -> { Orb::Price::GroupedTieredPackage::LicenseType }, nil?: true
|
9885
|
# File 'lib/orb/models/price.rb', line 9885
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
9891
|
# File 'lib/orb/models/price.rb', line 9891
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
9900
|
# File 'lib/orb/models/price.rb', line 9900
required :metadata, Orb::Internal::Type::HashOf[String]
|
9906
|
# File 'lib/orb/models/price.rb', line 9906
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
9912
|
# File 'lib/orb/models/price.rb', line 9912
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :grouped_tiered_package
9918
|
# File 'lib/orb/models/price.rb', line 9918
required :model_type, const: :grouped_tiered_package
|
#name ⇒ String
9923
|
# File 'lib/orb/models/price.rb', line 9923
required :name, String
|
#plan_phase_order ⇒ Integer?
9928
|
# File 'lib/orb/models/price.rb', line 9928
required :plan_phase_order, Integer, nil?: true
|
9933
|
# File 'lib/orb/models/price.rb', line 9933
required :price_type, enum: -> { Orb::Price::GroupedTieredPackage::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
9940
|
# File 'lib/orb/models/price.rb', line 9940
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 10026
|
Instance Method Details
#to_hash ⇒ {
7432
|
# File 'sig/orb/models/price.rbs', line 7432
def to_hash: -> {
|