Class: Orb::Models::Price::GroupedTieredPackage
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, GroupedTieredPackageConfig, LicenseType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(per_unit:, tier_lower_bound:) ⇒ Object
Configuration for a single tier
|
# File 'lib/orb/models/price.rb', line 9523
|
Instance Attribute Details
9360
|
# File 'lib/orb/models/price.rb', line 9360
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
9365
|
# File 'lib/orb/models/price.rb', line 9365
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
9370
|
# File 'lib/orb/models/price.rb', line 9370
required :billing_mode, enum: -> { Orb::Price::GroupedTieredPackage::BillingMode }
|
9375
|
# File 'lib/orb/models/price.rb', line 9375
required :cadence, enum: -> { Orb::Price::GroupedTieredPackage::Cadence }
|
9380
9381
9382
|
# File 'lib/orb/models/price.rb', line 9380
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::GroupedTieredPackage::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
9387
|
# File 'lib/orb/models/price.rb', line 9387
required :conversion_rate, Float, nil?: true
|
9392
|
# File 'lib/orb/models/price.rb', line 9392
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
9397
|
# File 'lib/orb/models/price.rb', line 9397
required :created_at, Time
|
9402
|
# File 'lib/orb/models/price.rb', line 9402
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
9407
|
# File 'lib/orb/models/price.rb', line 9407
required :currency, String
|
9513
|
# File 'lib/orb/models/price.rb', line 9513
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
9413
|
# File 'lib/orb/models/price.rb', line 9413
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
9418
|
# File 'lib/orb/models/price.rb', line 9418
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
9423
|
# File 'lib/orb/models/price.rb', line 9423
required :fixed_price_quantity, Float, nil?: true
|
Configuration for grouped_tiered_package pricing
9429
9430
|
# File 'lib/orb/models/price.rb', line 9429
required :grouped_tiered_package_config,
-> { Orb::Price::GroupedTieredPackage::GroupedTieredPackageConfig }
|
#id ⇒ String
9355
|
# File 'lib/orb/models/price.rb', line 9355
required :id, String
|
#invoice_grouping_key ⇒ String?
9435
|
# File 'lib/orb/models/price.rb', line 9435
required :invoice_grouping_key, String, nil?: true
|
9440
|
# File 'lib/orb/models/price.rb', line 9440
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
9447
|
# File 'lib/orb/models/price.rb', line 9447
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
9521
|
# File 'lib/orb/models/price.rb', line 9521
optional :license_type, -> { Orb::Price::GroupedTieredPackage::LicenseType }, nil?: true
|
9453
|
# File 'lib/orb/models/price.rb', line 9453
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
9459
|
# File 'lib/orb/models/price.rb', line 9459
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
9468
|
# File 'lib/orb/models/price.rb', line 9468
required :metadata, Orb::Internal::Type::HashOf[String]
|
9474
|
# File 'lib/orb/models/price.rb', line 9474
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
9480
|
# File 'lib/orb/models/price.rb', line 9480
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :grouped_tiered_package
9486
|
# File 'lib/orb/models/price.rb', line 9486
required :model_type, const: :grouped_tiered_package
|
#name ⇒ String
9491
|
# File 'lib/orb/models/price.rb', line 9491
required :name, String
|
#plan_phase_order ⇒ Integer?
9496
|
# File 'lib/orb/models/price.rb', line 9496
required :plan_phase_order, Integer, nil?: true
|
9501
|
# File 'lib/orb/models/price.rb', line 9501
required :price_type, enum: -> { Orb::Price::GroupedTieredPackage::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
9508
|
# File 'lib/orb/models/price.rb', line 9508
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 9594
|
Instance Method Details
#to_hash ⇒ {
7105
|
# File 'sig/orb/models/price.rbs', line 7105
def to_hash: -> {
|