Class: Orb::Models::Price::GroupedWithMinMaxThresholds
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, GroupedWithMinMaxThresholdsConfig, LicenseType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(grouping_key:, maximum_charge:, minimum_charge:, per_unit_rate:) ⇒ Object
Configuration for grouped_with_min_max_thresholds pricing
|
# File 'lib/orb/models/price.rb', line 9131
|
Instance Attribute Details
8966
|
# File 'lib/orb/models/price.rb', line 8966
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
8971
|
# File 'lib/orb/models/price.rb', line 8971
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
8976
|
# File 'lib/orb/models/price.rb', line 8976
required :billing_mode, enum: -> { Orb::Price::GroupedWithMinMaxThresholds::BillingMode }
|
8981
|
# File 'lib/orb/models/price.rb', line 8981
required :cadence, enum: -> { Orb::Price::GroupedWithMinMaxThresholds::Cadence }
|
8986
8987
8988
8989
8990
|
# File 'lib/orb/models/price.rb', line 8986
required :composite_price_filters,
-> {
Orb::Internal::Type::ArrayOf[Orb::Price::GroupedWithMinMaxThresholds::CompositePriceFilter]
},
nil?: true
|
#conversion_rate ⇒ Float?
8995
|
# File 'lib/orb/models/price.rb', line 8995
required :conversion_rate, Float, nil?: true
|
9000
|
# File 'lib/orb/models/price.rb', line 9000
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
9005
|
# File 'lib/orb/models/price.rb', line 9005
required :created_at, Time
|
9010
|
# File 'lib/orb/models/price.rb', line 9010
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
9015
|
# File 'lib/orb/models/price.rb', line 9015
required :currency, String
|
9121
|
# File 'lib/orb/models/price.rb', line 9121
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
9021
|
# File 'lib/orb/models/price.rb', line 9021
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
9026
|
# File 'lib/orb/models/price.rb', line 9026
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
9031
|
# File 'lib/orb/models/price.rb', line 9031
required :fixed_price_quantity, Float, nil?: true
|
Configuration for grouped_with_min_max_thresholds pricing
9037
9038
|
# File 'lib/orb/models/price.rb', line 9037
required :grouped_with_min_max_thresholds_config,
-> { Orb::Price::GroupedWithMinMaxThresholds::GroupedWithMinMaxThresholdsConfig }
|
#id ⇒ String
8961
|
# File 'lib/orb/models/price.rb', line 8961
required :id, String
|
#invoice_grouping_key ⇒ String?
9043
|
# File 'lib/orb/models/price.rb', line 9043
required :invoice_grouping_key, String, nil?: true
|
9048
|
# File 'lib/orb/models/price.rb', line 9048
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
9055
|
# File 'lib/orb/models/price.rb', line 9055
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
9129
|
# File 'lib/orb/models/price.rb', line 9129
optional :license_type, -> { Orb::Price::GroupedWithMinMaxThresholds::LicenseType }, nil?: true
|
9061
|
# File 'lib/orb/models/price.rb', line 9061
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
9067
|
# File 'lib/orb/models/price.rb', line 9067
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
9076
|
# File 'lib/orb/models/price.rb', line 9076
required :metadata, Orb::Internal::Type::HashOf[String]
|
9082
|
# File 'lib/orb/models/price.rb', line 9082
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
9088
|
# File 'lib/orb/models/price.rb', line 9088
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :grouped_with_min_max_thresholds
9094
|
# File 'lib/orb/models/price.rb', line 9094
required :model_type, const: :grouped_with_min_max_thresholds
|
#name ⇒ String
9099
|
# File 'lib/orb/models/price.rb', line 9099
required :name, String
|
#plan_phase_order ⇒ Integer?
9104
|
# File 'lib/orb/models/price.rb', line 9104
required :plan_phase_order, Integer, nil?: true
|
9109
|
# File 'lib/orb/models/price.rb', line 9109
required :price_type, enum: -> { Orb::Price::GroupedWithMinMaxThresholds::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
9116
|
# File 'lib/orb/models/price.rb', line 9116
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 9202
|
Instance Method Details
#to_hash ⇒ {
6807
|
# File 'sig/orb/models/price.rbs', line 6807
def to_hash: -> {
|