Class: Orb::Models::Price::GroupedWithMinMaxThresholds
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, GroupedWithMinMaxThresholdsConfig, LicenseType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(grouping_key:, maximum_charge:, minimum_charge:, per_unit_rate:) ⇒ Object
Configuration for grouped_with_min_max_thresholds pricing
|
# File 'lib/orb/models/price.rb', line 8699
|
Instance Attribute Details
8534
|
# File 'lib/orb/models/price.rb', line 8534
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
8539
|
# File 'lib/orb/models/price.rb', line 8539
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
8544
|
# File 'lib/orb/models/price.rb', line 8544
required :billing_mode, enum: -> { Orb::Price::GroupedWithMinMaxThresholds::BillingMode }
|
8549
|
# File 'lib/orb/models/price.rb', line 8549
required :cadence, enum: -> { Orb::Price::GroupedWithMinMaxThresholds::Cadence }
|
8554
8555
8556
8557
8558
|
# File 'lib/orb/models/price.rb', line 8554
required :composite_price_filters,
-> {
Orb::Internal::Type::ArrayOf[Orb::Price::GroupedWithMinMaxThresholds::CompositePriceFilter]
},
nil?: true
|
#conversion_rate ⇒ Float?
8563
|
# File 'lib/orb/models/price.rb', line 8563
required :conversion_rate, Float, nil?: true
|
8568
|
# File 'lib/orb/models/price.rb', line 8568
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
8573
|
# File 'lib/orb/models/price.rb', line 8573
required :created_at, Time
|
8578
|
# File 'lib/orb/models/price.rb', line 8578
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
8583
|
# File 'lib/orb/models/price.rb', line 8583
required :currency, String
|
8689
|
# File 'lib/orb/models/price.rb', line 8689
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
8589
|
# File 'lib/orb/models/price.rb', line 8589
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
8594
|
# File 'lib/orb/models/price.rb', line 8594
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
8599
|
# File 'lib/orb/models/price.rb', line 8599
required :fixed_price_quantity, Float, nil?: true
|
Configuration for grouped_with_min_max_thresholds pricing
8605
8606
|
# File 'lib/orb/models/price.rb', line 8605
required :grouped_with_min_max_thresholds_config,
-> { Orb::Price::GroupedWithMinMaxThresholds::GroupedWithMinMaxThresholdsConfig }
|
#id ⇒ String
8529
|
# File 'lib/orb/models/price.rb', line 8529
required :id, String
|
#invoice_grouping_key ⇒ String?
8611
|
# File 'lib/orb/models/price.rb', line 8611
required :invoice_grouping_key, String, nil?: true
|
8616
|
# File 'lib/orb/models/price.rb', line 8616
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
8623
|
# File 'lib/orb/models/price.rb', line 8623
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
8697
|
# File 'lib/orb/models/price.rb', line 8697
optional :license_type, -> { Orb::Price::GroupedWithMinMaxThresholds::LicenseType }, nil?: true
|
8629
|
# File 'lib/orb/models/price.rb', line 8629
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
8635
|
# File 'lib/orb/models/price.rb', line 8635
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
8644
|
# File 'lib/orb/models/price.rb', line 8644
required :metadata, Orb::Internal::Type::HashOf[String]
|
8650
|
# File 'lib/orb/models/price.rb', line 8650
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
8656
|
# File 'lib/orb/models/price.rb', line 8656
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :grouped_with_min_max_thresholds
8662
|
# File 'lib/orb/models/price.rb', line 8662
required :model_type, const: :grouped_with_min_max_thresholds
|
#name ⇒ String
8667
|
# File 'lib/orb/models/price.rb', line 8667
required :name, String
|
#plan_phase_order ⇒ Integer?
8672
|
# File 'lib/orb/models/price.rb', line 8672
required :plan_phase_order, Integer, nil?: true
|
8677
|
# File 'lib/orb/models/price.rb', line 8677
required :price_type, enum: -> { Orb::Price::GroupedWithMinMaxThresholds::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
8684
|
# File 'lib/orb/models/price.rb', line 8684
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 8770
|
Instance Method Details
#to_hash ⇒ {
6480
|
# File 'sig/orb/models/price.rbs', line 6480
def to_hash: -> {
|