Class: Orb::Models::Price::GroupedWithMinMaxThresholds
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, GroupedWithMinMaxThresholdsConfig, LicenseType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(grouping_key:, maximum_charge:, minimum_charge:, per_unit_rate:) ⇒ Object
Configuration for grouped_with_min_max_thresholds pricing
|
# File 'lib/orb/models/price.rb', line 9580
|
Instance Attribute Details
9415
|
# File 'lib/orb/models/price.rb', line 9415
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
9420
|
# File 'lib/orb/models/price.rb', line 9420
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
9425
|
# File 'lib/orb/models/price.rb', line 9425
required :billing_mode, enum: -> { Orb::Price::GroupedWithMinMaxThresholds::BillingMode }
|
9430
|
# File 'lib/orb/models/price.rb', line 9430
required :cadence, enum: -> { Orb::Price::GroupedWithMinMaxThresholds::Cadence }
|
9435
9436
9437
9438
9439
|
# File 'lib/orb/models/price.rb', line 9435
required :composite_price_filters,
-> {
Orb::Internal::Type::ArrayOf[Orb::Price::GroupedWithMinMaxThresholds::CompositePriceFilter]
},
nil?: true
|
#conversion_rate ⇒ Float?
9444
|
# File 'lib/orb/models/price.rb', line 9444
required :conversion_rate, Float, nil?: true
|
9449
|
# File 'lib/orb/models/price.rb', line 9449
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
9454
|
# File 'lib/orb/models/price.rb', line 9454
required :created_at, Time
|
9459
|
# File 'lib/orb/models/price.rb', line 9459
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
9464
|
# File 'lib/orb/models/price.rb', line 9464
required :currency, String
|
9570
|
# File 'lib/orb/models/price.rb', line 9570
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
9470
|
# File 'lib/orb/models/price.rb', line 9470
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
9475
|
# File 'lib/orb/models/price.rb', line 9475
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
9480
|
# File 'lib/orb/models/price.rb', line 9480
required :fixed_price_quantity, Float, nil?: true
|
Configuration for grouped_with_min_max_thresholds pricing
9486
9487
|
# File 'lib/orb/models/price.rb', line 9486
required :grouped_with_min_max_thresholds_config,
-> { Orb::Price::GroupedWithMinMaxThresholds::GroupedWithMinMaxThresholdsConfig }
|
#id ⇒ String
9410
|
# File 'lib/orb/models/price.rb', line 9410
required :id, String
|
#invoice_grouping_key ⇒ String?
9492
|
# File 'lib/orb/models/price.rb', line 9492
required :invoice_grouping_key, String, nil?: true
|
9497
|
# File 'lib/orb/models/price.rb', line 9497
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
9504
|
# File 'lib/orb/models/price.rb', line 9504
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
9578
|
# File 'lib/orb/models/price.rb', line 9578
optional :license_type, -> { Orb::Price::GroupedWithMinMaxThresholds::LicenseType }, nil?: true
|
9510
|
# File 'lib/orb/models/price.rb', line 9510
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
9516
|
# File 'lib/orb/models/price.rb', line 9516
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
9525
|
# File 'lib/orb/models/price.rb', line 9525
required :metadata, Orb::Internal::Type::HashOf[String]
|
9531
|
# File 'lib/orb/models/price.rb', line 9531
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
9537
|
# File 'lib/orb/models/price.rb', line 9537
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :grouped_with_min_max_thresholds
9543
|
# File 'lib/orb/models/price.rb', line 9543
required :model_type, const: :grouped_with_min_max_thresholds
|
#name ⇒ String
9548
|
# File 'lib/orb/models/price.rb', line 9548
required :name, String
|
#plan_phase_order ⇒ Integer?
9553
|
# File 'lib/orb/models/price.rb', line 9553
required :plan_phase_order, Integer, nil?: true
|
9558
|
# File 'lib/orb/models/price.rb', line 9558
required :price_type, enum: -> { Orb::Price::GroupedWithMinMaxThresholds::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
9565
|
# File 'lib/orb/models/price.rb', line 9565
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 9651
|
Instance Method Details
#to_hash ⇒ {
7139
|
# File 'sig/orb/models/price.rbs', line 7139
def to_hash: -> {
|