Class: Orb::Models::Price::MatrixWithAllocation
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
-
#initialize(id:, billable_metric:, billing_cycle_configuration:, billing_mode:, cadence:, composite_price_filters:, conversion_rate:, conversion_rate_config:, created_at:, credit_allocation:, currency:, discount:, external_price_id:, fixed_price_quantity:, invoice_grouping_key:, invoicing_cycle_configuration:, item:, matrix_with_allocation_config:, maximum:, maximum_amount:, metadata:, minimum:, minimum_amount:, name:, plan_phase_order:, price_type:, replaces_price_id:, dimensional_price_configuration: nil, license_type: nil, model_type: :matrix_with_allocation) ⇒ Object
constructor
-
#to_hash ⇒ {
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, billable_metric:, billing_cycle_configuration:, billing_mode:, cadence:, composite_price_filters:, conversion_rate:, conversion_rate_config:, created_at:, credit_allocation:, currency:, discount:, external_price_id:, fixed_price_quantity:, invoice_grouping_key:, invoicing_cycle_configuration:, item:, matrix_with_allocation_config:, maximum:, maximum_amount:, metadata:, minimum:, minimum_amount:, name:, plan_phase_order:, price_type:, replaces_price_id:, dimensional_price_configuration: nil, license_type: nil, model_type: :matrix_with_allocation) ⇒ Object
|
# File 'lib/orb/models/price.rb', line 5822
|
Instance Attribute Details
5660
|
# File 'lib/orb/models/price.rb', line 5660
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
5665
|
# File 'lib/orb/models/price.rb', line 5665
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
5670
|
# File 'lib/orb/models/price.rb', line 5670
required :billing_mode, enum: -> { Orb::Price::MatrixWithAllocation::BillingMode }
|
5675
|
# File 'lib/orb/models/price.rb', line 5675
required :cadence, enum: -> { Orb::Price::MatrixWithAllocation::Cadence }
|
5680
5681
5682
|
# File 'lib/orb/models/price.rb', line 5680
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::MatrixWithAllocation::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
5687
|
# File 'lib/orb/models/price.rb', line 5687
required :conversion_rate, Float, nil?: true
|
5692
|
# File 'lib/orb/models/price.rb', line 5692
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
5697
|
# File 'lib/orb/models/price.rb', line 5697
required :created_at, Time
|
5702
|
# File 'lib/orb/models/price.rb', line 5702
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
5707
|
# File 'lib/orb/models/price.rb', line 5707
required :currency, String
|
5812
|
# File 'lib/orb/models/price.rb', line 5812
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
5713
|
# File 'lib/orb/models/price.rb', line 5713
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
5718
|
# File 'lib/orb/models/price.rb', line 5718
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
5723
|
# File 'lib/orb/models/price.rb', line 5723
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
5655
|
# File 'lib/orb/models/price.rb', line 5655
required :id, String
|
#invoice_grouping_key ⇒ String?
5728
|
# File 'lib/orb/models/price.rb', line 5728
required :invoice_grouping_key, String, nil?: true
|
5733
|
# File 'lib/orb/models/price.rb', line 5733
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
5740
|
# File 'lib/orb/models/price.rb', line 5740
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
5820
|
# File 'lib/orb/models/price.rb', line 5820
optional :license_type, -> { Orb::Price::MatrixWithAllocation::LicenseType }, nil?: true
|
Configuration for matrix_with_allocation pricing
5746
|
# File 'lib/orb/models/price.rb', line 5746
required :matrix_with_allocation_config, -> { Orb::MatrixWithAllocationConfig }
|
5752
|
# File 'lib/orb/models/price.rb', line 5752
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
5758
|
# File 'lib/orb/models/price.rb', line 5758
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
5767
|
# File 'lib/orb/models/price.rb', line 5767
required :metadata, Orb::Internal::Type::HashOf[String]
|
5773
|
# File 'lib/orb/models/price.rb', line 5773
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
5779
|
# File 'lib/orb/models/price.rb', line 5779
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :matrix_with_allocation
5785
|
# File 'lib/orb/models/price.rb', line 5785
required :model_type, const: :matrix_with_allocation
|
#name ⇒ String
5790
|
# File 'lib/orb/models/price.rb', line 5790
required :name, String
|
#plan_phase_order ⇒ Integer?
5795
|
# File 'lib/orb/models/price.rb', line 5795
required :plan_phase_order, Integer, nil?: true
|
5800
|
# File 'lib/orb/models/price.rb', line 5800
required :price_type, enum: -> { Orb::Price::MatrixWithAllocation::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
5807
|
# File 'lib/orb/models/price.rb', line 5807
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 5893
|
Instance Method Details
#to_hash ⇒ {
4332
|
# File 'sig/orb/models/price.rbs', line 4332
def to_hash: -> {
|