Class: Orb::Models::Price::MatrixWithAllocation
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
-
#initialize(id:, billable_metric:, billing_cycle_configuration:, billing_mode:, cadence:, composite_price_filters:, conversion_rate:, conversion_rate_config:, created_at:, credit_allocation:, currency:, discount:, external_price_id:, fixed_price_quantity:, invoice_grouping_key:, invoicing_cycle_configuration:, item:, matrix_with_allocation_config:, maximum:, maximum_amount:, metadata:, minimum:, minimum_amount:, name:, plan_phase_order:, price_type:, replaces_price_id:, dimensional_price_configuration: nil, license_type: nil, model_type: :matrix_with_allocation) ⇒ Object
constructor
-
#to_hash ⇒ {
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, billable_metric:, billing_cycle_configuration:, billing_mode:, cadence:, composite_price_filters:, conversion_rate:, conversion_rate_config:, created_at:, credit_allocation:, currency:, discount:, external_price_id:, fixed_price_quantity:, invoice_grouping_key:, invoicing_cycle_configuration:, item:, matrix_with_allocation_config:, maximum:, maximum_amount:, metadata:, minimum:, minimum_amount:, name:, plan_phase_order:, price_type:, replaces_price_id:, dimensional_price_configuration: nil, license_type: nil, model_type: :matrix_with_allocation) ⇒ Object
|
# File 'lib/orb/models/price.rb', line 5390
|
Instance Attribute Details
5228
|
# File 'lib/orb/models/price.rb', line 5228
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
5233
|
# File 'lib/orb/models/price.rb', line 5233
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
5238
|
# File 'lib/orb/models/price.rb', line 5238
required :billing_mode, enum: -> { Orb::Price::MatrixWithAllocation::BillingMode }
|
5243
|
# File 'lib/orb/models/price.rb', line 5243
required :cadence, enum: -> { Orb::Price::MatrixWithAllocation::Cadence }
|
5248
5249
5250
|
# File 'lib/orb/models/price.rb', line 5248
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::MatrixWithAllocation::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
5255
|
# File 'lib/orb/models/price.rb', line 5255
required :conversion_rate, Float, nil?: true
|
5260
|
# File 'lib/orb/models/price.rb', line 5260
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
5265
|
# File 'lib/orb/models/price.rb', line 5265
required :created_at, Time
|
5270
|
# File 'lib/orb/models/price.rb', line 5270
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
5275
|
# File 'lib/orb/models/price.rb', line 5275
required :currency, String
|
5380
|
# File 'lib/orb/models/price.rb', line 5380
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
5281
|
# File 'lib/orb/models/price.rb', line 5281
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
5286
|
# File 'lib/orb/models/price.rb', line 5286
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
5291
|
# File 'lib/orb/models/price.rb', line 5291
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
5223
|
# File 'lib/orb/models/price.rb', line 5223
required :id, String
|
#invoice_grouping_key ⇒ String?
5296
|
# File 'lib/orb/models/price.rb', line 5296
required :invoice_grouping_key, String, nil?: true
|
5301
|
# File 'lib/orb/models/price.rb', line 5301
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
5308
|
# File 'lib/orb/models/price.rb', line 5308
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
5388
|
# File 'lib/orb/models/price.rb', line 5388
optional :license_type, -> { Orb::Price::MatrixWithAllocation::LicenseType }, nil?: true
|
Configuration for matrix_with_allocation pricing
5314
|
# File 'lib/orb/models/price.rb', line 5314
required :matrix_with_allocation_config, -> { Orb::MatrixWithAllocationConfig }
|
5320
|
# File 'lib/orb/models/price.rb', line 5320
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
5326
|
# File 'lib/orb/models/price.rb', line 5326
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
5335
|
# File 'lib/orb/models/price.rb', line 5335
required :metadata, Orb::Internal::Type::HashOf[String]
|
5341
|
# File 'lib/orb/models/price.rb', line 5341
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
5347
|
# File 'lib/orb/models/price.rb', line 5347
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :matrix_with_allocation
5353
|
# File 'lib/orb/models/price.rb', line 5353
required :model_type, const: :matrix_with_allocation
|
#name ⇒ String
5358
|
# File 'lib/orb/models/price.rb', line 5358
required :name, String
|
#plan_phase_order ⇒ Integer?
5363
|
# File 'lib/orb/models/price.rb', line 5363
required :plan_phase_order, Integer, nil?: true
|
5368
|
# File 'lib/orb/models/price.rb', line 5368
required :price_type, enum: -> { Orb::Price::MatrixWithAllocation::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
5375
|
# File 'lib/orb/models/price.rb', line 5375
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 5461
|
Instance Method Details
#to_hash ⇒ {
4005
|
# File 'sig/orb/models/price.rbs', line 4005
def to_hash: -> {
|