Class: Orb::Models::Price::MatrixWithThresholdDiscounts
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, MatrixWithThresholdDiscountsConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(above_threshold_discount_percentage:, below_threshold_discount_percentage:, cell_coordinates:, threshold_amount:, description: nil) ⇒ Object
|
# File 'lib/orb/models/price.rb', line 6191
|
Instance Attribute Details
6026
|
# File 'lib/orb/models/price.rb', line 6026
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
6031
|
# File 'lib/orb/models/price.rb', line 6031
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
6036
|
# File 'lib/orb/models/price.rb', line 6036
required :billing_mode, enum: -> { Orb::Price::MatrixWithThresholdDiscounts::BillingMode }
|
6041
|
# File 'lib/orb/models/price.rb', line 6041
required :cadence, enum: -> { Orb::Price::MatrixWithThresholdDiscounts::Cadence }
|
6046
6047
6048
6049
6050
|
# File 'lib/orb/models/price.rb', line 6046
required :composite_price_filters,
-> {
Orb::Internal::Type::ArrayOf[Orb::Price::MatrixWithThresholdDiscounts::CompositePriceFilter]
},
nil?: true
|
#conversion_rate ⇒ Float?
6055
|
# File 'lib/orb/models/price.rb', line 6055
required :conversion_rate, Float, nil?: true
|
6060
|
# File 'lib/orb/models/price.rb', line 6060
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
6065
|
# File 'lib/orb/models/price.rb', line 6065
required :created_at, Time
|
6070
|
# File 'lib/orb/models/price.rb', line 6070
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
6075
|
# File 'lib/orb/models/price.rb', line 6075
required :currency, String
|
6181
|
# File 'lib/orb/models/price.rb', line 6181
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
6081
|
# File 'lib/orb/models/price.rb', line 6081
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
6086
|
# File 'lib/orb/models/price.rb', line 6086
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
6091
|
# File 'lib/orb/models/price.rb', line 6091
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
6021
|
# File 'lib/orb/models/price.rb', line 6021
required :id, String
|
#invoice_grouping_key ⇒ String?
6096
|
# File 'lib/orb/models/price.rb', line 6096
required :invoice_grouping_key, String, nil?: true
|
6101
|
# File 'lib/orb/models/price.rb', line 6101
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
6108
|
# File 'lib/orb/models/price.rb', line 6108
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
6189
|
# File 'lib/orb/models/price.rb', line 6189
optional :license_type, -> { Orb::Price::MatrixWithThresholdDiscounts::LicenseType }, nil?: true
|
Configuration for matrix_with_threshold_discounts pricing
6114
6115
|
# File 'lib/orb/models/price.rb', line 6114
required :matrix_with_threshold_discounts_config,
-> { Orb::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig }
|
6121
|
# File 'lib/orb/models/price.rb', line 6121
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
6127
|
# File 'lib/orb/models/price.rb', line 6127
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
6136
|
# File 'lib/orb/models/price.rb', line 6136
required :metadata, Orb::Internal::Type::HashOf[String]
|
6142
|
# File 'lib/orb/models/price.rb', line 6142
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
6148
|
# File 'lib/orb/models/price.rb', line 6148
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :matrix_with_threshold_discounts
6154
|
# File 'lib/orb/models/price.rb', line 6154
required :model_type, const: :matrix_with_threshold_discounts
|
#name ⇒ String
6159
|
# File 'lib/orb/models/price.rb', line 6159
required :name, String
|
#plan_phase_order ⇒ Integer?
6164
|
# File 'lib/orb/models/price.rb', line 6164
required :plan_phase_order, Integer, nil?: true
|
6169
|
# File 'lib/orb/models/price.rb', line 6169
required :price_type, enum: -> { Orb::Price::MatrixWithThresholdDiscounts::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
6176
|
# File 'lib/orb/models/price.rb', line 6176
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 6262
|
Instance Method Details
#to_hash ⇒ {
4604
|
# File 'sig/orb/models/price.rbs', line 4604
def to_hash: -> {
|