Class: Orb::Models::Price::MatrixWithThresholdDiscounts

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/price.rb,
sig/orb/models/price.rbs

Defined Under Namespace

Modules: BillingMode, Cadence, PriceType Classes: CompositePriceFilter, LicenseType, MatrixWithThresholdDiscountsConfig

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(above_threshold_discount_percentage:, below_threshold_discount_percentage:, cell_coordinates:, threshold_amount:, description: nil) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig::ThresholdDiscountGroup for more details.

Parameters:

  • above_threshold_discount_percentage (String)

    Discount rate applied to spend above the threshold.

  • below_threshold_discount_percentage (String)

    Discount rate applied to spend at or below the threshold. Set to 0 for no baseli

  • cell_coordinates (String)

    Semicolon-separated list of matrix cell coordinates targeted by this group. Each

  • threshold_amount (String)
  • description (String, nil) (defaults to: nil)


# File 'lib/orb/models/price.rb', line 5759

Instance Attribute Details

#billable_metricOrb::Models::BillableMetricTiny?

Parameters:

Returns:



5594
# File 'lib/orb/models/price.rb', line 5594

required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true

#billing_cycle_configurationOrb::Models::BillingCycleConfiguration



5599
# File 'lib/orb/models/price.rb', line 5599

required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }

#billing_modeSymbol, Orb::Models::Price::MatrixWithThresholdDiscounts::BillingMode

Parameters:

  • value (Orb::Models::Price::MatrixWithThresholdDiscounts::billing_mode)

Returns:



5604
# File 'lib/orb/models/price.rb', line 5604

required :billing_mode, enum: -> { Orb::Price::MatrixWithThresholdDiscounts::BillingMode }

#cadenceSymbol, Orb::Models::Price::MatrixWithThresholdDiscounts::Cadence

Parameters:

  • value (Orb::Models::Price::MatrixWithThresholdDiscounts::cadence)

Returns:



5609
# File 'lib/orb/models/price.rb', line 5609

required :cadence, enum: -> { Orb::Price::MatrixWithThresholdDiscounts::Cadence }

#composite_price_filtersArray<Orb::Models::Price::MatrixWithThresholdDiscounts::CompositePriceFilter>?

Parameters:

  • value (::Array[Orb::Price::MatrixWithThresholdDiscounts::CompositePriceFilter], nil)

Returns:



5614
5615
5616
5617
5618
# File 'lib/orb/models/price.rb', line 5614

required :composite_price_filters,
-> {
  Orb::Internal::Type::ArrayOf[Orb::Price::MatrixWithThresholdDiscounts::CompositePriceFilter]
},
nil?: true

#conversion_rateFloat?

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


5623
# File 'lib/orb/models/price.rb', line 5623

required :conversion_rate, Float, nil?: true

#conversion_rate_configOrb::Models::UnitConversionRateConfig, ...

Parameters:

  • value (Orb::Models::conversion_rate_config, nil)

Returns:



5628
# File 'lib/orb/models/price.rb', line 5628

required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true

#created_atTime

Parameters:

  • value (Time)

Returns:

  • (Time)


5633
# File 'lib/orb/models/price.rb', line 5633

required :created_at, Time

#credit_allocationOrb::Models::Allocation?

Parameters:

Returns:



5638
# File 'lib/orb/models/price.rb', line 5638

required :credit_allocation, -> { Orb::Allocation }, nil?: true

#currencyString

Parameters:

  • value (String)

Returns:

  • (String)


5643
# File 'lib/orb/models/price.rb', line 5643

required :currency, String

#dimensional_price_configurationOrb::Models::DimensionalPriceConfiguration?



5749
# File 'lib/orb/models/price.rb', line 5749

optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true

#discountOrb::Models::PercentageDiscount, ...

Deprecated.


5649
# File 'lib/orb/models/price.rb', line 5649

required :discount, union: -> { Orb::Discount }, nil?: true

#external_price_idString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


5654
# File 'lib/orb/models/price.rb', line 5654

required :external_price_id, String, nil?: true

#fixed_price_quantityFloat?

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


5659
# File 'lib/orb/models/price.rb', line 5659

required :fixed_price_quantity, Float, nil?: true

#idString

Parameters:

  • value (String)

Returns:

  • (String)


5589
# File 'lib/orb/models/price.rb', line 5589

required :id, String

#invoice_grouping_keyString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


5664
# File 'lib/orb/models/price.rb', line 5664

required :invoice_grouping_key, String, nil?: true

#invoicing_cycle_configurationOrb::Models::BillingCycleConfiguration?



5669
# File 'lib/orb/models/price.rb', line 5669

required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true

#itemOrb::Models::ItemSlim

A minimal representation of an Item containing only the essential identifying information.

Parameters:

Returns:



5676
# File 'lib/orb/models/price.rb', line 5676

required :item, -> { Orb::ItemSlim }

#license_typeOrb::Models::Price::MatrixWithThresholdDiscounts::LicenseType?

The LicenseType resource represents a type of license that can be assigned to users. License types are used during billing by grouping metrics on the configured grouping key.

Parameters:

  • value (Orb::Price::MatrixWithThresholdDiscounts::LicenseType, nil)

Returns:



5757
# File 'lib/orb/models/price.rb', line 5757

optional :license_type, -> { Orb::Price::MatrixWithThresholdDiscounts::LicenseType }, nil?: true

#matrix_with_threshold_discounts_configOrb::Models::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig

Configuration for matrix_with_threshold_discounts pricing

Parameters:

  • value (Orb::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig)

Returns:



5682
5683
# File 'lib/orb/models/price.rb', line 5682

required :matrix_with_threshold_discounts_config,
-> { Orb::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig }

#maximumOrb::Models::Maximum?

Deprecated.

Parameters:

Returns:



5689
# File 'lib/orb/models/price.rb', line 5689

required :maximum, -> { Orb::Maximum }, nil?: true

#maximum_amountString?

Deprecated.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


5695
# File 'lib/orb/models/price.rb', line 5695

required :maximum_amount, String, nil?: true

#metadataHash{Symbol=>String}

User specified key-value pairs for the resource. If not present, this defaults to an empty dictionary. Individual keys can be removed by setting the value to null, and the entire metadata mapping can be cleared by setting metadata to null.

Parameters:

  • value (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String})


5704
# File 'lib/orb/models/price.rb', line 5704

required :metadata, Orb::Internal::Type::HashOf[String]

#minimumOrb::Models::Minimum?

Deprecated.

Parameters:

Returns:



5710
# File 'lib/orb/models/price.rb', line 5710

required :minimum, -> { Orb::Minimum }, nil?: true

#minimum_amountString?

Deprecated.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


5716
# File 'lib/orb/models/price.rb', line 5716

required :minimum_amount, String, nil?: true

#model_typeSymbol, :matrix_with_threshold_discounts

The pricing model type

Parameters:

  • value (:matrix_with_threshold_discounts)

Returns:

  • (Symbol, :matrix_with_threshold_discounts)


5722
# File 'lib/orb/models/price.rb', line 5722

required :model_type, const: :matrix_with_threshold_discounts

#nameString

Parameters:

  • value (String)

Returns:

  • (String)


5727
# File 'lib/orb/models/price.rb', line 5727

required :name, String

#plan_phase_orderInteger?

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


5732
# File 'lib/orb/models/price.rb', line 5732

required :plan_phase_order, Integer, nil?: true

#price_typeSymbol, Orb::Models::Price::MatrixWithThresholdDiscounts::PriceType

Parameters:

  • value (Orb::Models::Price::MatrixWithThresholdDiscounts::price_type)

Returns:



5737
# File 'lib/orb/models/price.rb', line 5737

required :price_type, enum: -> { Orb::Price::MatrixWithThresholdDiscounts::PriceType }

#replaces_price_idString?

The price id this price replaces. This price will take the place of the replaced price in plan version migrations.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


5744
# File 'lib/orb/models/price.rb', line 5744

required :replaces_price_id, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/orb/models/price.rb', line 5830

Instance Method Details

#to_hash{

Returns:

  • ({)


4277
# File 'sig/orb/models/price.rbs', line 4277

def to_hash: -> {