Class: Orb::Models::Price::MatrixWithThresholdDiscounts
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, MatrixWithThresholdDiscountsConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(above_threshold_discount_percentage:, below_threshold_discount_percentage:, cell_coordinates:, threshold_amount:, description: nil) ⇒ Object
|
# File 'lib/orb/models/price.rb', line 5759
|
Instance Attribute Details
5594
|
# File 'lib/orb/models/price.rb', line 5594
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
5599
|
# File 'lib/orb/models/price.rb', line 5599
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
5604
|
# File 'lib/orb/models/price.rb', line 5604
required :billing_mode, enum: -> { Orb::Price::MatrixWithThresholdDiscounts::BillingMode }
|
5609
|
# File 'lib/orb/models/price.rb', line 5609
required :cadence, enum: -> { Orb::Price::MatrixWithThresholdDiscounts::Cadence }
|
5614
5615
5616
5617
5618
|
# File 'lib/orb/models/price.rb', line 5614
required :composite_price_filters,
-> {
Orb::Internal::Type::ArrayOf[Orb::Price::MatrixWithThresholdDiscounts::CompositePriceFilter]
},
nil?: true
|
#conversion_rate ⇒ Float?
5623
|
# File 'lib/orb/models/price.rb', line 5623
required :conversion_rate, Float, nil?: true
|
5628
|
# File 'lib/orb/models/price.rb', line 5628
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
5633
|
# File 'lib/orb/models/price.rb', line 5633
required :created_at, Time
|
5638
|
# File 'lib/orb/models/price.rb', line 5638
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
5643
|
# File 'lib/orb/models/price.rb', line 5643
required :currency, String
|
5749
|
# File 'lib/orb/models/price.rb', line 5749
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
5649
|
# File 'lib/orb/models/price.rb', line 5649
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
5654
|
# File 'lib/orb/models/price.rb', line 5654
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
5659
|
# File 'lib/orb/models/price.rb', line 5659
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
5589
|
# File 'lib/orb/models/price.rb', line 5589
required :id, String
|
#invoice_grouping_key ⇒ String?
5664
|
# File 'lib/orb/models/price.rb', line 5664
required :invoice_grouping_key, String, nil?: true
|
5669
|
# File 'lib/orb/models/price.rb', line 5669
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
5676
|
# File 'lib/orb/models/price.rb', line 5676
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
5757
|
# File 'lib/orb/models/price.rb', line 5757
optional :license_type, -> { Orb::Price::MatrixWithThresholdDiscounts::LicenseType }, nil?: true
|
Configuration for matrix_with_threshold_discounts pricing
5682
5683
|
# File 'lib/orb/models/price.rb', line 5682
required :matrix_with_threshold_discounts_config,
-> { Orb::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig }
|
5689
|
# File 'lib/orb/models/price.rb', line 5689
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
5695
|
# File 'lib/orb/models/price.rb', line 5695
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
5704
|
# File 'lib/orb/models/price.rb', line 5704
required :metadata, Orb::Internal::Type::HashOf[String]
|
5710
|
# File 'lib/orb/models/price.rb', line 5710
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
5716
|
# File 'lib/orb/models/price.rb', line 5716
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :matrix_with_threshold_discounts
5722
|
# File 'lib/orb/models/price.rb', line 5722
required :model_type, const: :matrix_with_threshold_discounts
|
#name ⇒ String
5727
|
# File 'lib/orb/models/price.rb', line 5727
required :name, String
|
#plan_phase_order ⇒ Integer?
5732
|
# File 'lib/orb/models/price.rb', line 5732
required :plan_phase_order, Integer, nil?: true
|
5737
|
# File 'lib/orb/models/price.rb', line 5737
required :price_type, enum: -> { Orb::Price::MatrixWithThresholdDiscounts::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
5744
|
# File 'lib/orb/models/price.rb', line 5744
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 5830
|
Instance Method Details
#to_hash ⇒ {
4277
|
# File 'sig/orb/models/price.rbs', line 4277
def to_hash: -> {
|