Class: Orb::Models::Price::MatrixWithThresholdDiscounts
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, MatrixWithThresholdDiscountsConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(above_threshold_discount_percentage:, below_threshold_discount_percentage:, cell_coordinates:, threshold_amount:, description: nil) ⇒ Object
|
# File 'lib/orb/models/price.rb', line 6640
|
Instance Attribute Details
6475
|
# File 'lib/orb/models/price.rb', line 6475
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
6480
|
# File 'lib/orb/models/price.rb', line 6480
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
6485
|
# File 'lib/orb/models/price.rb', line 6485
required :billing_mode, enum: -> { Orb::Price::MatrixWithThresholdDiscounts::BillingMode }
|
6490
|
# File 'lib/orb/models/price.rb', line 6490
required :cadence, enum: -> { Orb::Price::MatrixWithThresholdDiscounts::Cadence }
|
6495
6496
6497
6498
6499
|
# File 'lib/orb/models/price.rb', line 6495
required :composite_price_filters,
-> {
Orb::Internal::Type::ArrayOf[Orb::Price::MatrixWithThresholdDiscounts::CompositePriceFilter]
},
nil?: true
|
#conversion_rate ⇒ Float?
6504
|
# File 'lib/orb/models/price.rb', line 6504
required :conversion_rate, Float, nil?: true
|
6509
|
# File 'lib/orb/models/price.rb', line 6509
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
6514
|
# File 'lib/orb/models/price.rb', line 6514
required :created_at, Time
|
6519
|
# File 'lib/orb/models/price.rb', line 6519
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
6524
|
# File 'lib/orb/models/price.rb', line 6524
required :currency, String
|
6630
|
# File 'lib/orb/models/price.rb', line 6630
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
6530
|
# File 'lib/orb/models/price.rb', line 6530
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
6535
|
# File 'lib/orb/models/price.rb', line 6535
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
6540
|
# File 'lib/orb/models/price.rb', line 6540
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
6470
|
# File 'lib/orb/models/price.rb', line 6470
required :id, String
|
#invoice_grouping_key ⇒ String?
6545
|
# File 'lib/orb/models/price.rb', line 6545
required :invoice_grouping_key, String, nil?: true
|
6550
|
# File 'lib/orb/models/price.rb', line 6550
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
6557
|
# File 'lib/orb/models/price.rb', line 6557
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
6638
|
# File 'lib/orb/models/price.rb', line 6638
optional :license_type, -> { Orb::Price::MatrixWithThresholdDiscounts::LicenseType }, nil?: true
|
Configuration for matrix_with_threshold_discounts pricing
6563
6564
|
# File 'lib/orb/models/price.rb', line 6563
required :matrix_with_threshold_discounts_config,
-> { Orb::Price::MatrixWithThresholdDiscounts::MatrixWithThresholdDiscountsConfig }
|
6570
|
# File 'lib/orb/models/price.rb', line 6570
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
6576
|
# File 'lib/orb/models/price.rb', line 6576
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
6585
|
# File 'lib/orb/models/price.rb', line 6585
required :metadata, Orb::Internal::Type::HashOf[String]
|
6591
|
# File 'lib/orb/models/price.rb', line 6591
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
6597
|
# File 'lib/orb/models/price.rb', line 6597
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :matrix_with_threshold_discounts
6603
|
# File 'lib/orb/models/price.rb', line 6603
required :model_type, const: :matrix_with_threshold_discounts
|
#name ⇒ String
6608
|
# File 'lib/orb/models/price.rb', line 6608
required :name, String
|
#plan_phase_order ⇒ Integer?
6613
|
# File 'lib/orb/models/price.rb', line 6613
required :plan_phase_order, Integer, nil?: true
|
6618
|
# File 'lib/orb/models/price.rb', line 6618
required :price_type, enum: -> { Orb::Price::MatrixWithThresholdDiscounts::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
6625
|
# File 'lib/orb/models/price.rb', line 6625
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 6711
|
Instance Method Details
#to_hash ⇒ {
4936
|
# File 'sig/orb/models/price.rbs', line 4936
def to_hash: -> {
|