Class: Orb::Models::Price::PackageWithAllocation
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, PackageWithAllocationConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(allocation:, package_amount:, package_size:) ⇒ Object
Configuration for package_with_allocation pricing
|
# File 'lib/orb/models/price.rb', line 5043
|
Instance Attribute Details
4880
|
# File 'lib/orb/models/price.rb', line 4880
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
4885
|
# File 'lib/orb/models/price.rb', line 4885
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
4890
|
# File 'lib/orb/models/price.rb', line 4890
required :billing_mode, enum: -> { Orb::Price::PackageWithAllocation::BillingMode }
|
4895
|
# File 'lib/orb/models/price.rb', line 4895
required :cadence, enum: -> { Orb::Price::PackageWithAllocation::Cadence }
|
4900
4901
4902
|
# File 'lib/orb/models/price.rb', line 4900
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::PackageWithAllocation::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
4907
|
# File 'lib/orb/models/price.rb', line 4907
required :conversion_rate, Float, nil?: true
|
4912
|
# File 'lib/orb/models/price.rb', line 4912
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
4917
|
# File 'lib/orb/models/price.rb', line 4917
required :created_at, Time
|
4922
|
# File 'lib/orb/models/price.rb', line 4922
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
4927
|
# File 'lib/orb/models/price.rb', line 4927
required :currency, String
|
5033
|
# File 'lib/orb/models/price.rb', line 5033
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
4933
|
# File 'lib/orb/models/price.rb', line 4933
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
4938
|
# File 'lib/orb/models/price.rb', line 4938
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
4943
|
# File 'lib/orb/models/price.rb', line 4943
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
4875
|
# File 'lib/orb/models/price.rb', line 4875
required :id, String
|
#invoice_grouping_key ⇒ String?
4948
|
# File 'lib/orb/models/price.rb', line 4948
required :invoice_grouping_key, String, nil?: true
|
4953
|
# File 'lib/orb/models/price.rb', line 4953
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
4960
|
# File 'lib/orb/models/price.rb', line 4960
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
5041
|
# File 'lib/orb/models/price.rb', line 5041
optional :license_type, -> { Orb::Price::PackageWithAllocation::LicenseType }, nil?: true
|
4966
|
# File 'lib/orb/models/price.rb', line 4966
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
4972
|
# File 'lib/orb/models/price.rb', line 4972
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
4981
|
# File 'lib/orb/models/price.rb', line 4981
required :metadata, Orb::Internal::Type::HashOf[String]
|
4987
|
# File 'lib/orb/models/price.rb', line 4987
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
4993
|
# File 'lib/orb/models/price.rb', line 4993
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :package_with_allocation
4999
|
# File 'lib/orb/models/price.rb', line 4999
required :model_type, const: :package_with_allocation
|
#name ⇒ String
5004
|
# File 'lib/orb/models/price.rb', line 5004
required :name, String
|
Configuration for package_with_allocation pricing
5010
5011
|
# File 'lib/orb/models/price.rb', line 5010
required :package_with_allocation_config,
-> { Orb::Price::PackageWithAllocation::PackageWithAllocationConfig }
|
#plan_phase_order ⇒ Integer?
5016
|
# File 'lib/orb/models/price.rb', line 5016
required :plan_phase_order, Integer, nil?: true
|
5021
|
# File 'lib/orb/models/price.rb', line 5021
required :price_type, enum: -> { Orb::Price::PackageWithAllocation::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
5028
|
# File 'lib/orb/models/price.rb', line 5028
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 5114
|
Instance Method Details
#to_hash ⇒ {
3753
|
# File 'sig/orb/models/price.rbs', line 3753
def to_hash: -> {
|