Class: Orb::Models::Price::PackageWithAllocation
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, PackageWithAllocationConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(allocation:, package_amount:, package_size:) ⇒ Object
Configuration for package_with_allocation pricing
|
# File 'lib/orb/models/price.rb', line 4611
|
Instance Attribute Details
4448
|
# File 'lib/orb/models/price.rb', line 4448
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
4453
|
# File 'lib/orb/models/price.rb', line 4453
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
4458
|
# File 'lib/orb/models/price.rb', line 4458
required :billing_mode, enum: -> { Orb::Price::PackageWithAllocation::BillingMode }
|
4463
|
# File 'lib/orb/models/price.rb', line 4463
required :cadence, enum: -> { Orb::Price::PackageWithAllocation::Cadence }
|
4468
4469
4470
|
# File 'lib/orb/models/price.rb', line 4468
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::PackageWithAllocation::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
4475
|
# File 'lib/orb/models/price.rb', line 4475
required :conversion_rate, Float, nil?: true
|
4480
|
# File 'lib/orb/models/price.rb', line 4480
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
4485
|
# File 'lib/orb/models/price.rb', line 4485
required :created_at, Time
|
4490
|
# File 'lib/orb/models/price.rb', line 4490
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
4495
|
# File 'lib/orb/models/price.rb', line 4495
required :currency, String
|
4601
|
# File 'lib/orb/models/price.rb', line 4601
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
4501
|
# File 'lib/orb/models/price.rb', line 4501
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
4506
|
# File 'lib/orb/models/price.rb', line 4506
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
4511
|
# File 'lib/orb/models/price.rb', line 4511
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
4443
|
# File 'lib/orb/models/price.rb', line 4443
required :id, String
|
#invoice_grouping_key ⇒ String?
4516
|
# File 'lib/orb/models/price.rb', line 4516
required :invoice_grouping_key, String, nil?: true
|
4521
|
# File 'lib/orb/models/price.rb', line 4521
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
4528
|
# File 'lib/orb/models/price.rb', line 4528
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
4609
|
# File 'lib/orb/models/price.rb', line 4609
optional :license_type, -> { Orb::Price::PackageWithAllocation::LicenseType }, nil?: true
|
4534
|
# File 'lib/orb/models/price.rb', line 4534
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
4540
|
# File 'lib/orb/models/price.rb', line 4540
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
4549
|
# File 'lib/orb/models/price.rb', line 4549
required :metadata, Orb::Internal::Type::HashOf[String]
|
4555
|
# File 'lib/orb/models/price.rb', line 4555
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
4561
|
# File 'lib/orb/models/price.rb', line 4561
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :package_with_allocation
4567
|
# File 'lib/orb/models/price.rb', line 4567
required :model_type, const: :package_with_allocation
|
#name ⇒ String
4572
|
# File 'lib/orb/models/price.rb', line 4572
required :name, String
|
Configuration for package_with_allocation pricing
4578
4579
|
# File 'lib/orb/models/price.rb', line 4578
required :package_with_allocation_config,
-> { Orb::Price::PackageWithAllocation::PackageWithAllocationConfig }
|
#plan_phase_order ⇒ Integer?
4584
|
# File 'lib/orb/models/price.rb', line 4584
required :plan_phase_order, Integer, nil?: true
|
4589
|
# File 'lib/orb/models/price.rb', line 4589
required :price_type, enum: -> { Orb::Price::PackageWithAllocation::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
4596
|
# File 'lib/orb/models/price.rb', line 4596
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 4682
|
Instance Method Details
#to_hash ⇒ {
3426
|
# File 'sig/orb/models/price.rbs', line 3426
def to_hash: -> {
|