Class: Orb::Models::Price::PackageWithAllocation
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, PackageWithAllocationConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(allocation:, package_amount:, package_size:) ⇒ Object
Configuration for package_with_allocation pricing
|
# File 'lib/orb/models/price.rb', line 5045
|
Instance Attribute Details
4882
|
# File 'lib/orb/models/price.rb', line 4882
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
4887
|
# File 'lib/orb/models/price.rb', line 4887
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
4892
|
# File 'lib/orb/models/price.rb', line 4892
required :billing_mode, enum: -> { Orb::Price::PackageWithAllocation::BillingMode }
|
4897
|
# File 'lib/orb/models/price.rb', line 4897
required :cadence, enum: -> { Orb::Price::PackageWithAllocation::Cadence }
|
4902
4903
4904
|
# File 'lib/orb/models/price.rb', line 4902
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::PackageWithAllocation::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
4909
|
# File 'lib/orb/models/price.rb', line 4909
required :conversion_rate, Float, nil?: true
|
4914
|
# File 'lib/orb/models/price.rb', line 4914
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
4919
|
# File 'lib/orb/models/price.rb', line 4919
required :created_at, Time
|
4924
|
# File 'lib/orb/models/price.rb', line 4924
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
4929
|
# File 'lib/orb/models/price.rb', line 4929
required :currency, String
|
5035
|
# File 'lib/orb/models/price.rb', line 5035
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
4935
|
# File 'lib/orb/models/price.rb', line 4935
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
4940
|
# File 'lib/orb/models/price.rb', line 4940
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
4945
|
# File 'lib/orb/models/price.rb', line 4945
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
4877
|
# File 'lib/orb/models/price.rb', line 4877
required :id, String
|
#invoice_grouping_key ⇒ String?
4950
|
# File 'lib/orb/models/price.rb', line 4950
required :invoice_grouping_key, String, nil?: true
|
4955
|
# File 'lib/orb/models/price.rb', line 4955
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
4962
|
# File 'lib/orb/models/price.rb', line 4962
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
5043
|
# File 'lib/orb/models/price.rb', line 5043
optional :license_type, -> { Orb::Price::PackageWithAllocation::LicenseType }, nil?: true
|
4968
|
# File 'lib/orb/models/price.rb', line 4968
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
4974
|
# File 'lib/orb/models/price.rb', line 4974
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
4983
|
# File 'lib/orb/models/price.rb', line 4983
required :metadata, Orb::Internal::Type::HashOf[String]
|
4989
|
# File 'lib/orb/models/price.rb', line 4989
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
4995
|
# File 'lib/orb/models/price.rb', line 4995
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :package_with_allocation
5001
|
# File 'lib/orb/models/price.rb', line 5001
required :model_type, const: :package_with_allocation
|
#name ⇒ String
5006
|
# File 'lib/orb/models/price.rb', line 5006
required :name, String
|
Configuration for package_with_allocation pricing
5012
5013
|
# File 'lib/orb/models/price.rb', line 5012
required :package_with_allocation_config,
-> { Orb::Price::PackageWithAllocation::PackageWithAllocationConfig }
|
#plan_phase_order ⇒ Integer?
5018
|
# File 'lib/orb/models/price.rb', line 5018
required :plan_phase_order, Integer, nil?: true
|
5023
|
# File 'lib/orb/models/price.rb', line 5023
required :price_type, enum: -> { Orb::Price::PackageWithAllocation::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
5030
|
# File 'lib/orb/models/price.rb', line 5030
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 5116
|
Instance Method Details
#to_hash ⇒ {
3754
|
# File 'sig/orb/models/price.rbs', line 3754
def to_hash: -> {
|