Class: Orb::Models::Price::Percent
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, PercentConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(percent:, maximum_amount: nil, minimum_amount: nil, prorated: nil) ⇒ Object
Some parameter documentations has been truncated, see
PercentConfig for more details.
Configuration for percent pricing
|
# File 'lib/orb/models/price.rb', line 13787
|
Instance Attribute Details
13625
|
# File 'lib/orb/models/price.rb', line 13625
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
13630
|
# File 'lib/orb/models/price.rb', line 13630
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
13635
|
# File 'lib/orb/models/price.rb', line 13635
required :billing_mode, enum: -> { Orb::Price::Percent::BillingMode }
|
13640
|
# File 'lib/orb/models/price.rb', line 13640
required :cadence, enum: -> { Orb::Price::Percent::Cadence }
|
13645
13646
13647
|
# File 'lib/orb/models/price.rb', line 13645
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::Percent::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
13652
|
# File 'lib/orb/models/price.rb', line 13652
required :conversion_rate, Float, nil?: true
|
13657
|
# File 'lib/orb/models/price.rb', line 13657
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
13662
|
# File 'lib/orb/models/price.rb', line 13662
required :created_at, Time
|
13667
|
# File 'lib/orb/models/price.rb', line 13667
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
13672
|
# File 'lib/orb/models/price.rb', line 13672
required :currency, String
|
13777
|
# File 'lib/orb/models/price.rb', line 13777
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
13678
|
# File 'lib/orb/models/price.rb', line 13678
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
13683
|
# File 'lib/orb/models/price.rb', line 13683
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
13688
|
# File 'lib/orb/models/price.rb', line 13688
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
13620
|
# File 'lib/orb/models/price.rb', line 13620
required :id, String
|
#invoice_grouping_key ⇒ String?
13693
|
# File 'lib/orb/models/price.rb', line 13693
required :invoice_grouping_key, String, nil?: true
|
13698
|
# File 'lib/orb/models/price.rb', line 13698
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
13705
|
# File 'lib/orb/models/price.rb', line 13705
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
13785
|
# File 'lib/orb/models/price.rb', line 13785
optional :license_type, -> { Orb::Price::Percent::LicenseType }, nil?: true
|
13711
|
# File 'lib/orb/models/price.rb', line 13711
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
13717
|
# File 'lib/orb/models/price.rb', line 13717
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
13726
|
# File 'lib/orb/models/price.rb', line 13726
required :metadata, Orb::Internal::Type::HashOf[String]
|
13732
|
# File 'lib/orb/models/price.rb', line 13732
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
13738
|
# File 'lib/orb/models/price.rb', line 13738
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :percent
13744
|
# File 'lib/orb/models/price.rb', line 13744
required :model_type, const: :percent
|
#name ⇒ String
13749
|
# File 'lib/orb/models/price.rb', line 13749
required :name, String
|
Configuration for percent pricing
13755
|
# File 'lib/orb/models/price.rb', line 13755
required :percent_config, -> { Orb::Price::Percent::PercentConfig }
|
#plan_phase_order ⇒ Integer?
13760
|
# File 'lib/orb/models/price.rb', line 13760
required :plan_phase_order, Integer, nil?: true
|
13765
|
# File 'lib/orb/models/price.rb', line 13765
required :price_type, enum: -> { Orb::Price::Percent::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
13772
|
# File 'lib/orb/models/price.rb', line 13772
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 13858
|
Instance Method Details
#to_hash ⇒ {
10302
|
# File 'sig/orb/models/price.rbs', line 10302
def to_hash: -> {
|