Class: Orb::Models::Price::Percent
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, PercentConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(percent:, maximum_amount: nil, minimum_amount: nil, prorated: nil) ⇒ Object
Some parameter documentations has been truncated, see
PercentConfig for more details.
Configuration for percent pricing
|
# File 'lib/orb/models/price.rb', line 13355
|
Instance Attribute Details
13193
|
# File 'lib/orb/models/price.rb', line 13193
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
13198
|
# File 'lib/orb/models/price.rb', line 13198
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
13203
|
# File 'lib/orb/models/price.rb', line 13203
required :billing_mode, enum: -> { Orb::Price::Percent::BillingMode }
|
13208
|
# File 'lib/orb/models/price.rb', line 13208
required :cadence, enum: -> { Orb::Price::Percent::Cadence }
|
13213
13214
13215
|
# File 'lib/orb/models/price.rb', line 13213
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::Percent::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
13220
|
# File 'lib/orb/models/price.rb', line 13220
required :conversion_rate, Float, nil?: true
|
13225
|
# File 'lib/orb/models/price.rb', line 13225
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
13230
|
# File 'lib/orb/models/price.rb', line 13230
required :created_at, Time
|
13235
|
# File 'lib/orb/models/price.rb', line 13235
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
13240
|
# File 'lib/orb/models/price.rb', line 13240
required :currency, String
|
13345
|
# File 'lib/orb/models/price.rb', line 13345
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
13246
|
# File 'lib/orb/models/price.rb', line 13246
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
13251
|
# File 'lib/orb/models/price.rb', line 13251
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
13256
|
# File 'lib/orb/models/price.rb', line 13256
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
13188
|
# File 'lib/orb/models/price.rb', line 13188
required :id, String
|
#invoice_grouping_key ⇒ String?
13261
|
# File 'lib/orb/models/price.rb', line 13261
required :invoice_grouping_key, String, nil?: true
|
13266
|
# File 'lib/orb/models/price.rb', line 13266
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
13273
|
# File 'lib/orb/models/price.rb', line 13273
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
13353
|
# File 'lib/orb/models/price.rb', line 13353
optional :license_type, -> { Orb::Price::Percent::LicenseType }, nil?: true
|
13279
|
# File 'lib/orb/models/price.rb', line 13279
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
13285
|
# File 'lib/orb/models/price.rb', line 13285
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
13294
|
# File 'lib/orb/models/price.rb', line 13294
required :metadata, Orb::Internal::Type::HashOf[String]
|
13300
|
# File 'lib/orb/models/price.rb', line 13300
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
13306
|
# File 'lib/orb/models/price.rb', line 13306
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :percent
13312
|
# File 'lib/orb/models/price.rb', line 13312
required :model_type, const: :percent
|
#name ⇒ String
13317
|
# File 'lib/orb/models/price.rb', line 13317
required :name, String
|
Configuration for percent pricing
13323
|
# File 'lib/orb/models/price.rb', line 13323
required :percent_config, -> { Orb::Price::Percent::PercentConfig }
|
#plan_phase_order ⇒ Integer?
13328
|
# File 'lib/orb/models/price.rb', line 13328
required :plan_phase_order, Integer, nil?: true
|
13333
|
# File 'lib/orb/models/price.rb', line 13333
required :price_type, enum: -> { Orb::Price::Percent::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
13340
|
# File 'lib/orb/models/price.rb', line 13340
required :replaces_price_id, String, nil?: true
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 13426
|
Instance Method Details
#to_hash ⇒ {
9975
|
# File 'sig/orb/models/price.rbs', line 9975
def to_hash: -> {
|