Class: Orb::Models::Price::ScalableMatrixWithTieredPricing
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, ScalableMatrixWithTieredPricingConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(tier_lower_bound:, unit_amount:) ⇒ Object
Configuration for a single tier entry with business logic
|
# File 'lib/orb/models/price.rb', line 11249
|
Instance Attribute Details
11084
|
# File 'lib/orb/models/price.rb', line 11084
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
11089
|
# File 'lib/orb/models/price.rb', line 11089
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
11094
|
# File 'lib/orb/models/price.rb', line 11094
required :billing_mode, enum: -> { Orb::Price::ScalableMatrixWithTieredPricing::BillingMode }
|
11099
|
# File 'lib/orb/models/price.rb', line 11099
required :cadence, enum: -> { Orb::Price::ScalableMatrixWithTieredPricing::Cadence }
|
11104
11105
11106
11107
11108
|
# File 'lib/orb/models/price.rb', line 11104
required :composite_price_filters,
-> {
Orb::Internal::Type::ArrayOf[Orb::Price::ScalableMatrixWithTieredPricing::CompositePriceFilter]
},
nil?: true
|
#conversion_rate ⇒ Float?
11113
|
# File 'lib/orb/models/price.rb', line 11113
required :conversion_rate, Float, nil?: true
|
11118
|
# File 'lib/orb/models/price.rb', line 11118
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
11123
|
# File 'lib/orb/models/price.rb', line 11123
required :created_at, Time
|
11128
|
# File 'lib/orb/models/price.rb', line 11128
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
11133
|
# File 'lib/orb/models/price.rb', line 11133
required :currency, String
|
11239
|
# File 'lib/orb/models/price.rb', line 11239
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
11139
|
# File 'lib/orb/models/price.rb', line 11139
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
11144
|
# File 'lib/orb/models/price.rb', line 11144
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
11149
|
# File 'lib/orb/models/price.rb', line 11149
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
11079
|
# File 'lib/orb/models/price.rb', line 11079
required :id, String
|
#invoice_grouping_key ⇒ String?
11154
|
# File 'lib/orb/models/price.rb', line 11154
required :invoice_grouping_key, String, nil?: true
|
11159
|
# File 'lib/orb/models/price.rb', line 11159
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
11166
|
# File 'lib/orb/models/price.rb', line 11166
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
11247
|
# File 'lib/orb/models/price.rb', line 11247
optional :license_type, -> { Orb::Price::ScalableMatrixWithTieredPricing::LicenseType }, nil?: true
|
11172
|
# File 'lib/orb/models/price.rb', line 11172
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
11178
|
# File 'lib/orb/models/price.rb', line 11178
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
11187
|
# File 'lib/orb/models/price.rb', line 11187
required :metadata, Orb::Internal::Type::HashOf[String]
|
11193
|
# File 'lib/orb/models/price.rb', line 11193
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
11199
|
# File 'lib/orb/models/price.rb', line 11199
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :scalable_matrix_with_tiered_pricing
11205
|
# File 'lib/orb/models/price.rb', line 11205
required :model_type, const: :scalable_matrix_with_tiered_pricing
|
#name ⇒ String
11210
|
# File 'lib/orb/models/price.rb', line 11210
required :name, String
|
#plan_phase_order ⇒ Integer?
11215
|
# File 'lib/orb/models/price.rb', line 11215
required :plan_phase_order, Integer, nil?: true
|
11220
|
# File 'lib/orb/models/price.rb', line 11220
required :price_type, enum: -> { Orb::Price::ScalableMatrixWithTieredPricing::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
11227
|
# File 'lib/orb/models/price.rb', line 11227
required :replaces_price_id, String, nil?: true
|
Configuration for scalable_matrix_with_tiered_pricing pricing
11233
11234
|
# File 'lib/orb/models/price.rb', line 11233
required :scalable_matrix_with_tiered_pricing_config,
-> { Orb::Price::ScalableMatrixWithTieredPricing::ScalableMatrixWithTieredPricingConfig }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 11320
|
Instance Method Details
#to_hash ⇒ {
8398
|
# File 'sig/orb/models/price.rbs', line 8398
def to_hash: -> {
|