Class: Orb::Models::Price::ScalableMatrixWithTieredPricing
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, ScalableMatrixWithTieredPricingConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(tier_lower_bound:, unit_amount:) ⇒ Object
Configuration for a single tier entry with business logic
|
# File 'lib/orb/models/price.rb', line 10817
|
Instance Attribute Details
10652
|
# File 'lib/orb/models/price.rb', line 10652
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
10657
|
# File 'lib/orb/models/price.rb', line 10657
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
10662
|
# File 'lib/orb/models/price.rb', line 10662
required :billing_mode, enum: -> { Orb::Price::ScalableMatrixWithTieredPricing::BillingMode }
|
10667
|
# File 'lib/orb/models/price.rb', line 10667
required :cadence, enum: -> { Orb::Price::ScalableMatrixWithTieredPricing::Cadence }
|
10672
10673
10674
10675
10676
|
# File 'lib/orb/models/price.rb', line 10672
required :composite_price_filters,
-> {
Orb::Internal::Type::ArrayOf[Orb::Price::ScalableMatrixWithTieredPricing::CompositePriceFilter]
},
nil?: true
|
#conversion_rate ⇒ Float?
10681
|
# File 'lib/orb/models/price.rb', line 10681
required :conversion_rate, Float, nil?: true
|
10686
|
# File 'lib/orb/models/price.rb', line 10686
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
10691
|
# File 'lib/orb/models/price.rb', line 10691
required :created_at, Time
|
10696
|
# File 'lib/orb/models/price.rb', line 10696
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
10701
|
# File 'lib/orb/models/price.rb', line 10701
required :currency, String
|
10807
|
# File 'lib/orb/models/price.rb', line 10807
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
10707
|
# File 'lib/orb/models/price.rb', line 10707
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
10712
|
# File 'lib/orb/models/price.rb', line 10712
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
10717
|
# File 'lib/orb/models/price.rb', line 10717
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
10647
|
# File 'lib/orb/models/price.rb', line 10647
required :id, String
|
#invoice_grouping_key ⇒ String?
10722
|
# File 'lib/orb/models/price.rb', line 10722
required :invoice_grouping_key, String, nil?: true
|
10727
|
# File 'lib/orb/models/price.rb', line 10727
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
10734
|
# File 'lib/orb/models/price.rb', line 10734
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
10815
|
# File 'lib/orb/models/price.rb', line 10815
optional :license_type, -> { Orb::Price::ScalableMatrixWithTieredPricing::LicenseType }, nil?: true
|
10740
|
# File 'lib/orb/models/price.rb', line 10740
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
10746
|
# File 'lib/orb/models/price.rb', line 10746
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
10755
|
# File 'lib/orb/models/price.rb', line 10755
required :metadata, Orb::Internal::Type::HashOf[String]
|
10761
|
# File 'lib/orb/models/price.rb', line 10761
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
10767
|
# File 'lib/orb/models/price.rb', line 10767
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :scalable_matrix_with_tiered_pricing
10773
|
# File 'lib/orb/models/price.rb', line 10773
required :model_type, const: :scalable_matrix_with_tiered_pricing
|
#name ⇒ String
10778
|
# File 'lib/orb/models/price.rb', line 10778
required :name, String
|
#plan_phase_order ⇒ Integer?
10783
|
# File 'lib/orb/models/price.rb', line 10783
required :plan_phase_order, Integer, nil?: true
|
10788
|
# File 'lib/orb/models/price.rb', line 10788
required :price_type, enum: -> { Orb::Price::ScalableMatrixWithTieredPricing::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
10795
|
# File 'lib/orb/models/price.rb', line 10795
required :replaces_price_id, String, nil?: true
|
Configuration for scalable_matrix_with_tiered_pricing pricing
10801
10802
|
# File 'lib/orb/models/price.rb', line 10801
required :scalable_matrix_with_tiered_pricing_config,
-> { Orb::Price::ScalableMatrixWithTieredPricing::ScalableMatrixWithTieredPricingConfig }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 10888
|
Instance Method Details
#to_hash ⇒ {
8071
|
# File 'sig/orb/models/price.rbs', line 8071
def to_hash: -> {
|