Class: Orb::Models::Price::ScalableMatrixWithUnitPricing::ScalableMatrixWithUnitPricingConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/price.rb,
sig/orb/models/price.rbs

Overview

See Also:

  • Orb::Models::Price::ScalableMatrixWithUnitPricing#scalable_matrix_with_unit_pricing_config

Defined Under Namespace

Classes: MatrixScalingFactor

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



7878
# File 'sig/orb/models/price.rbs', line 7878

def initialize: (

Instance Attribute Details

#first_dimensionString

Used to determine the unit rate

Parameters:

  • value (String)

Returns:

  • (String)


10532
# File 'lib/orb/models/price.rb', line 10532

required :first_dimension, String

#grouping_keyString?

The property used to group this price

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


10551
# File 'lib/orb/models/price.rb', line 10551

optional :grouping_key, String, nil?: true

#matrix_scaling_factorsArray<Orb::Models::Price::ScalableMatrixWithUnitPricing::ScalableMatrixWithUnitPricingConfig::MatrixScalingFactor>

Apply a scaling factor to each dimension

Parameters:

  • value (::Array[Orb::Price::ScalableMatrixWithUnitPricing::ScalableMatrixWithUnitPricingConfig::MatrixScalingFactor])

Returns:



10538
10539
# File 'lib/orb/models/price.rb', line 10538

required :matrix_scaling_factors,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::ScalableMatrixWithUnitPricing::ScalableMatrixWithUnitPricingConfig::MatrixScalingFactor] }

#prorateBoolean?

If true, the unit price will be prorated to the billing period

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


10557
# File 'lib/orb/models/price.rb', line 10557

optional :prorate, Orb::Internal::Type::Boolean, nil?: true

#second_dimensionString?

Used to determine the unit rate (optional)

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


10563
# File 'lib/orb/models/price.rb', line 10563

optional :second_dimension, String, nil?: true

#unit_priceString

The final unit price to rate against the output of the matrix

Parameters:

  • value (String)

Returns:

  • (String)


10545
# File 'lib/orb/models/price.rb', line 10545

required :unit_price, String

Instance Method Details

#to_hash{

Returns:

  • ({)


7887
# File 'sig/orb/models/price.rbs', line 7887

def to_hash: -> {