Class: Orb::Models::Price::ThresholdTotalAmount
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, ThresholdTotalAmountConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(threshold:, total_amount:) ⇒ Object
Configuration for a single threshold
|
# File 'lib/orb/models/price.rb', line 2524
|
Instance Attribute Details
2361
|
# File 'lib/orb/models/price.rb', line 2361
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
2366
|
# File 'lib/orb/models/price.rb', line 2366
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
2371
|
# File 'lib/orb/models/price.rb', line 2371
required :billing_mode, enum: -> { Orb::Price::ThresholdTotalAmount::BillingMode }
|
2376
|
# File 'lib/orb/models/price.rb', line 2376
required :cadence, enum: -> { Orb::Price::ThresholdTotalAmount::Cadence }
|
2381
2382
2383
|
# File 'lib/orb/models/price.rb', line 2381
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::ThresholdTotalAmount::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
2388
|
# File 'lib/orb/models/price.rb', line 2388
required :conversion_rate, Float, nil?: true
|
2393
|
# File 'lib/orb/models/price.rb', line 2393
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
2398
|
# File 'lib/orb/models/price.rb', line 2398
required :created_at, Time
|
2403
|
# File 'lib/orb/models/price.rb', line 2403
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
2408
|
# File 'lib/orb/models/price.rb', line 2408
required :currency, String
|
2514
|
# File 'lib/orb/models/price.rb', line 2514
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
2414
|
# File 'lib/orb/models/price.rb', line 2414
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
2419
|
# File 'lib/orb/models/price.rb', line 2419
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
2424
|
# File 'lib/orb/models/price.rb', line 2424
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
2356
|
# File 'lib/orb/models/price.rb', line 2356
required :id, String
|
#invoice_grouping_key ⇒ String?
2429
|
# File 'lib/orb/models/price.rb', line 2429
required :invoice_grouping_key, String, nil?: true
|
2434
|
# File 'lib/orb/models/price.rb', line 2434
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
2441
|
# File 'lib/orb/models/price.rb', line 2441
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
2522
|
# File 'lib/orb/models/price.rb', line 2522
optional :license_type, -> { Orb::Price::ThresholdTotalAmount::LicenseType }, nil?: true
|
2447
|
# File 'lib/orb/models/price.rb', line 2447
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
2453
|
# File 'lib/orb/models/price.rb', line 2453
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
2462
|
# File 'lib/orb/models/price.rb', line 2462
required :metadata, Orb::Internal::Type::HashOf[String]
|
2468
|
# File 'lib/orb/models/price.rb', line 2468
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
2474
|
# File 'lib/orb/models/price.rb', line 2474
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :threshold_total_amount
2480
|
# File 'lib/orb/models/price.rb', line 2480
required :model_type, const: :threshold_total_amount
|
#name ⇒ String
2485
|
# File 'lib/orb/models/price.rb', line 2485
required :name, String
|
#plan_phase_order ⇒ Integer?
2490
|
# File 'lib/orb/models/price.rb', line 2490
required :plan_phase_order, Integer, nil?: true
|
2495
|
# File 'lib/orb/models/price.rb', line 2495
required :price_type, enum: -> { Orb::Price::ThresholdTotalAmount::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
2502
|
# File 'lib/orb/models/price.rb', line 2502
required :replaces_price_id, String, nil?: true
|
Configuration for threshold_total_amount pricing
2508
2509
|
# File 'lib/orb/models/price.rb', line 2508
required :threshold_total_amount_config,
-> { Orb::Price::ThresholdTotalAmount::ThresholdTotalAmountConfig }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 2595
|
Instance Method Details
#to_hash ⇒ {
1855
|
# File 'sig/orb/models/price.rbs', line 1855
def to_hash: -> {
|