Class: Orb::Models::Price::ThresholdTotalAmount
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, ThresholdTotalAmountConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(threshold:, total_amount:) ⇒ Object
Configuration for a single threshold
|
# File 'lib/orb/models/price.rb', line 2522
|
Instance Attribute Details
2359
|
# File 'lib/orb/models/price.rb', line 2359
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
2364
|
# File 'lib/orb/models/price.rb', line 2364
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
2369
|
# File 'lib/orb/models/price.rb', line 2369
required :billing_mode, enum: -> { Orb::Price::ThresholdTotalAmount::BillingMode }
|
2374
|
# File 'lib/orb/models/price.rb', line 2374
required :cadence, enum: -> { Orb::Price::ThresholdTotalAmount::Cadence }
|
2379
2380
2381
|
# File 'lib/orb/models/price.rb', line 2379
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::ThresholdTotalAmount::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
2386
|
# File 'lib/orb/models/price.rb', line 2386
required :conversion_rate, Float, nil?: true
|
2391
|
# File 'lib/orb/models/price.rb', line 2391
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
2396
|
# File 'lib/orb/models/price.rb', line 2396
required :created_at, Time
|
2401
|
# File 'lib/orb/models/price.rb', line 2401
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
2406
|
# File 'lib/orb/models/price.rb', line 2406
required :currency, String
|
2512
|
# File 'lib/orb/models/price.rb', line 2512
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
2412
|
# File 'lib/orb/models/price.rb', line 2412
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
2417
|
# File 'lib/orb/models/price.rb', line 2417
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
2422
|
# File 'lib/orb/models/price.rb', line 2422
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
2354
|
# File 'lib/orb/models/price.rb', line 2354
required :id, String
|
#invoice_grouping_key ⇒ String?
2427
|
# File 'lib/orb/models/price.rb', line 2427
required :invoice_grouping_key, String, nil?: true
|
2432
|
# File 'lib/orb/models/price.rb', line 2432
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
2439
|
# File 'lib/orb/models/price.rb', line 2439
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
2520
|
# File 'lib/orb/models/price.rb', line 2520
optional :license_type, -> { Orb::Price::ThresholdTotalAmount::LicenseType }, nil?: true
|
2445
|
# File 'lib/orb/models/price.rb', line 2445
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
2451
|
# File 'lib/orb/models/price.rb', line 2451
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
2460
|
# File 'lib/orb/models/price.rb', line 2460
required :metadata, Orb::Internal::Type::HashOf[String]
|
2466
|
# File 'lib/orb/models/price.rb', line 2466
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
2472
|
# File 'lib/orb/models/price.rb', line 2472
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :threshold_total_amount
2478
|
# File 'lib/orb/models/price.rb', line 2478
required :model_type, const: :threshold_total_amount
|
#name ⇒ String
2483
|
# File 'lib/orb/models/price.rb', line 2483
required :name, String
|
#plan_phase_order ⇒ Integer?
2488
|
# File 'lib/orb/models/price.rb', line 2488
required :plan_phase_order, Integer, nil?: true
|
2493
|
# File 'lib/orb/models/price.rb', line 2493
required :price_type, enum: -> { Orb::Price::ThresholdTotalAmount::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
2500
|
# File 'lib/orb/models/price.rb', line 2500
required :replaces_price_id, String, nil?: true
|
Configuration for threshold_total_amount pricing
2506
2507
|
# File 'lib/orb/models/price.rb', line 2506
required :threshold_total_amount_config,
-> { Orb::Price::ThresholdTotalAmount::ThresholdTotalAmountConfig }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 2593
|
Instance Method Details
#to_hash ⇒ {
1854
|
# File 'sig/orb/models/price.rbs', line 1854
def to_hash: -> {
|