Class: Orb::Models::Price::TieredMatrixWithAllocation
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, TieredMatrixWithAllocationConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(dimension_values:, tier_lower_bound:, unit_amount:) ⇒ Object
|
# File 'lib/orb/models/price.rb', line 6193
|
Instance Attribute Details
6028
|
# File 'lib/orb/models/price.rb', line 6028
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
6033
|
# File 'lib/orb/models/price.rb', line 6033
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
6038
|
# File 'lib/orb/models/price.rb', line 6038
required :billing_mode, enum: -> { Orb::Price::TieredMatrixWithAllocation::BillingMode }
|
6043
|
# File 'lib/orb/models/price.rb', line 6043
required :cadence, enum: -> { Orb::Price::TieredMatrixWithAllocation::Cadence }
|
6048
6049
6050
6051
6052
|
# File 'lib/orb/models/price.rb', line 6048
required :composite_price_filters,
-> {
Orb::Internal::Type::ArrayOf[Orb::Price::TieredMatrixWithAllocation::CompositePriceFilter]
},
nil?: true
|
#conversion_rate ⇒ Float?
6057
|
# File 'lib/orb/models/price.rb', line 6057
required :conversion_rate, Float, nil?: true
|
6062
|
# File 'lib/orb/models/price.rb', line 6062
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
6067
|
# File 'lib/orb/models/price.rb', line 6067
required :created_at, Time
|
6072
|
# File 'lib/orb/models/price.rb', line 6072
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
6077
|
# File 'lib/orb/models/price.rb', line 6077
required :currency, String
|
6183
|
# File 'lib/orb/models/price.rb', line 6183
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
6083
|
# File 'lib/orb/models/price.rb', line 6083
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
6088
|
# File 'lib/orb/models/price.rb', line 6088
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
6093
|
# File 'lib/orb/models/price.rb', line 6093
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
6023
|
# File 'lib/orb/models/price.rb', line 6023
required :id, String
|
#invoice_grouping_key ⇒ String?
6098
|
# File 'lib/orb/models/price.rb', line 6098
required :invoice_grouping_key, String, nil?: true
|
6103
|
# File 'lib/orb/models/price.rb', line 6103
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
6110
|
# File 'lib/orb/models/price.rb', line 6110
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
6191
|
# File 'lib/orb/models/price.rb', line 6191
optional :license_type, -> { Orb::Price::TieredMatrixWithAllocation::LicenseType }, nil?: true
|
6116
|
# File 'lib/orb/models/price.rb', line 6116
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
6122
|
# File 'lib/orb/models/price.rb', line 6122
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
6131
|
# File 'lib/orb/models/price.rb', line 6131
required :metadata, Orb::Internal::Type::HashOf[String]
|
6137
|
# File 'lib/orb/models/price.rb', line 6137
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
6143
|
# File 'lib/orb/models/price.rb', line 6143
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :tiered_matrix_with_allocation
6149
|
# File 'lib/orb/models/price.rb', line 6149
required :model_type, const: :tiered_matrix_with_allocation
|
#name ⇒ String
6154
|
# File 'lib/orb/models/price.rb', line 6154
required :name, String
|
#plan_phase_order ⇒ Integer?
6159
|
# File 'lib/orb/models/price.rb', line 6159
required :plan_phase_order, Integer, nil?: true
|
6164
|
# File 'lib/orb/models/price.rb', line 6164
required :price_type, enum: -> { Orb::Price::TieredMatrixWithAllocation::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
6171
|
# File 'lib/orb/models/price.rb', line 6171
required :replaces_price_id, String, nil?: true
|
Configuration for tiered_matrix_with_allocation pricing
6177
6178
|
# File 'lib/orb/models/price.rb', line 6177
required :tiered_matrix_with_allocation_config,
-> { Orb::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 6264
|
Instance Method Details
#to_hash ⇒ {
4605
|
# File 'sig/orb/models/price.rbs', line 4605
def to_hash: -> {
|