Class: Orb::Models::Price::TieredPackage
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, TieredPackageConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(per_unit:, tier_lower_bound:) ⇒ Object
Configuration for a single tier with business logic
|
# File 'lib/orb/models/price.rb', line 2938
|
Instance Attribute Details
2776
|
# File 'lib/orb/models/price.rb', line 2776
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
2781
|
# File 'lib/orb/models/price.rb', line 2781
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
2786
|
# File 'lib/orb/models/price.rb', line 2786
required :billing_mode, enum: -> { Orb::Price::TieredPackage::BillingMode }
|
2791
|
# File 'lib/orb/models/price.rb', line 2791
required :cadence, enum: -> { Orb::Price::TieredPackage::Cadence }
|
2796
2797
2798
|
# File 'lib/orb/models/price.rb', line 2796
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::TieredPackage::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
2803
|
# File 'lib/orb/models/price.rb', line 2803
required :conversion_rate, Float, nil?: true
|
2808
|
# File 'lib/orb/models/price.rb', line 2808
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
2813
|
# File 'lib/orb/models/price.rb', line 2813
required :created_at, Time
|
2818
|
# File 'lib/orb/models/price.rb', line 2818
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
2823
|
# File 'lib/orb/models/price.rb', line 2823
required :currency, String
|
2928
|
# File 'lib/orb/models/price.rb', line 2928
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
2829
|
# File 'lib/orb/models/price.rb', line 2829
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
2834
|
# File 'lib/orb/models/price.rb', line 2834
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
2839
|
# File 'lib/orb/models/price.rb', line 2839
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
2771
|
# File 'lib/orb/models/price.rb', line 2771
required :id, String
|
#invoice_grouping_key ⇒ String?
2844
|
# File 'lib/orb/models/price.rb', line 2844
required :invoice_grouping_key, String, nil?: true
|
2849
|
# File 'lib/orb/models/price.rb', line 2849
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
2856
|
# File 'lib/orb/models/price.rb', line 2856
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
2936
|
# File 'lib/orb/models/price.rb', line 2936
optional :license_type, -> { Orb::Price::TieredPackage::LicenseType }, nil?: true
|
2862
|
# File 'lib/orb/models/price.rb', line 2862
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
2868
|
# File 'lib/orb/models/price.rb', line 2868
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
2877
|
# File 'lib/orb/models/price.rb', line 2877
required :metadata, Orb::Internal::Type::HashOf[String]
|
2883
|
# File 'lib/orb/models/price.rb', line 2883
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
2889
|
# File 'lib/orb/models/price.rb', line 2889
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :tiered_package
2895
|
# File 'lib/orb/models/price.rb', line 2895
required :model_type, const: :tiered_package
|
#name ⇒ String
2900
|
# File 'lib/orb/models/price.rb', line 2900
required :name, String
|
#plan_phase_order ⇒ Integer?
2905
|
# File 'lib/orb/models/price.rb', line 2905
required :plan_phase_order, Integer, nil?: true
|
2910
|
# File 'lib/orb/models/price.rb', line 2910
required :price_type, enum: -> { Orb::Price::TieredPackage::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
2917
|
# File 'lib/orb/models/price.rb', line 2917
required :replaces_price_id, String, nil?: true
|
Configuration for tiered_package pricing
2923
|
# File 'lib/orb/models/price.rb', line 2923
required :tiered_package_config, -> { Orb::Price::TieredPackage::TieredPackageConfig }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 3009
|
Instance Method Details
#to_hash ⇒ {
2161
|
# File 'sig/orb/models/price.rbs', line 2161
def to_hash: -> {
|