Class: Orb::Models::Price::TieredPackage
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, TieredPackageConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(per_unit:, tier_lower_bound:) ⇒ Object
Configuration for a single tier with business logic
|
# File 'lib/orb/models/price.rb', line 2936
|
Instance Attribute Details
2774
|
# File 'lib/orb/models/price.rb', line 2774
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
2779
|
# File 'lib/orb/models/price.rb', line 2779
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
2784
|
# File 'lib/orb/models/price.rb', line 2784
required :billing_mode, enum: -> { Orb::Price::TieredPackage::BillingMode }
|
2789
|
# File 'lib/orb/models/price.rb', line 2789
required :cadence, enum: -> { Orb::Price::TieredPackage::Cadence }
|
2794
2795
2796
|
# File 'lib/orb/models/price.rb', line 2794
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::TieredPackage::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
2801
|
# File 'lib/orb/models/price.rb', line 2801
required :conversion_rate, Float, nil?: true
|
2806
|
# File 'lib/orb/models/price.rb', line 2806
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
2811
|
# File 'lib/orb/models/price.rb', line 2811
required :created_at, Time
|
2816
|
# File 'lib/orb/models/price.rb', line 2816
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
2821
|
# File 'lib/orb/models/price.rb', line 2821
required :currency, String
|
2926
|
# File 'lib/orb/models/price.rb', line 2926
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
2827
|
# File 'lib/orb/models/price.rb', line 2827
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
2832
|
# File 'lib/orb/models/price.rb', line 2832
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
2837
|
# File 'lib/orb/models/price.rb', line 2837
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
2769
|
# File 'lib/orb/models/price.rb', line 2769
required :id, String
|
#invoice_grouping_key ⇒ String?
2842
|
# File 'lib/orb/models/price.rb', line 2842
required :invoice_grouping_key, String, nil?: true
|
2847
|
# File 'lib/orb/models/price.rb', line 2847
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
2854
|
# File 'lib/orb/models/price.rb', line 2854
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
2934
|
# File 'lib/orb/models/price.rb', line 2934
optional :license_type, -> { Orb::Price::TieredPackage::LicenseType }, nil?: true
|
2860
|
# File 'lib/orb/models/price.rb', line 2860
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
2866
|
# File 'lib/orb/models/price.rb', line 2866
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
2875
|
# File 'lib/orb/models/price.rb', line 2875
required :metadata, Orb::Internal::Type::HashOf[String]
|
2881
|
# File 'lib/orb/models/price.rb', line 2881
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
2887
|
# File 'lib/orb/models/price.rb', line 2887
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :tiered_package
2893
|
# File 'lib/orb/models/price.rb', line 2893
required :model_type, const: :tiered_package
|
#name ⇒ String
2898
|
# File 'lib/orb/models/price.rb', line 2898
required :name, String
|
#plan_phase_order ⇒ Integer?
2903
|
# File 'lib/orb/models/price.rb', line 2903
required :plan_phase_order, Integer, nil?: true
|
2908
|
# File 'lib/orb/models/price.rb', line 2908
required :price_type, enum: -> { Orb::Price::TieredPackage::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
2915
|
# File 'lib/orb/models/price.rb', line 2915
required :replaces_price_id, String, nil?: true
|
Configuration for tiered_package pricing
2921
|
# File 'lib/orb/models/price.rb', line 2921
required :tiered_package_config, -> { Orb::Price::TieredPackage::TieredPackageConfig }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 3007
|
Instance Method Details
#to_hash ⇒ {
2160
|
# File 'sig/orb/models/price.rbs', line 2160
def to_hash: -> {
|