Class: Orb::Models::Price::TieredWithMinimum
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, TieredWithMinimumConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(minimum_amount:, tier_lower_bound:, unit_amount:) ⇒ Object
Configuration for a single tier
|
# File 'lib/orb/models/price.rb', line 3351
|
Instance Attribute Details
3189
|
# File 'lib/orb/models/price.rb', line 3189
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
3194
|
# File 'lib/orb/models/price.rb', line 3194
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
3199
|
# File 'lib/orb/models/price.rb', line 3199
required :billing_mode, enum: -> { Orb::Price::TieredWithMinimum::BillingMode }
|
3204
|
# File 'lib/orb/models/price.rb', line 3204
required :cadence, enum: -> { Orb::Price::TieredWithMinimum::Cadence }
|
3209
3210
3211
|
# File 'lib/orb/models/price.rb', line 3209
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::TieredWithMinimum::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
3216
|
# File 'lib/orb/models/price.rb', line 3216
required :conversion_rate, Float, nil?: true
|
3221
|
# File 'lib/orb/models/price.rb', line 3221
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
3226
|
# File 'lib/orb/models/price.rb', line 3226
required :created_at, Time
|
3231
|
# File 'lib/orb/models/price.rb', line 3231
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
3236
|
# File 'lib/orb/models/price.rb', line 3236
required :currency, String
|
3341
|
# File 'lib/orb/models/price.rb', line 3341
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
3242
|
# File 'lib/orb/models/price.rb', line 3242
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
3247
|
# File 'lib/orb/models/price.rb', line 3247
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
3252
|
# File 'lib/orb/models/price.rb', line 3252
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
3184
|
# File 'lib/orb/models/price.rb', line 3184
required :id, String
|
#invoice_grouping_key ⇒ String?
3257
|
# File 'lib/orb/models/price.rb', line 3257
required :invoice_grouping_key, String, nil?: true
|
3262
|
# File 'lib/orb/models/price.rb', line 3262
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
3269
|
# File 'lib/orb/models/price.rb', line 3269
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
3349
|
# File 'lib/orb/models/price.rb', line 3349
optional :license_type, -> { Orb::Price::TieredWithMinimum::LicenseType }, nil?: true
|
3275
|
# File 'lib/orb/models/price.rb', line 3275
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
3281
|
# File 'lib/orb/models/price.rb', line 3281
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
3290
|
# File 'lib/orb/models/price.rb', line 3290
required :metadata, Orb::Internal::Type::HashOf[String]
|
3296
|
# File 'lib/orb/models/price.rb', line 3296
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
3302
|
# File 'lib/orb/models/price.rb', line 3302
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :tiered_with_minimum
3308
|
# File 'lib/orb/models/price.rb', line 3308
required :model_type, const: :tiered_with_minimum
|
#name ⇒ String
3313
|
# File 'lib/orb/models/price.rb', line 3313
required :name, String
|
#plan_phase_order ⇒ Integer?
3318
|
# File 'lib/orb/models/price.rb', line 3318
required :plan_phase_order, Integer, nil?: true
|
3323
|
# File 'lib/orb/models/price.rb', line 3323
required :price_type, enum: -> { Orb::Price::TieredWithMinimum::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
3330
|
# File 'lib/orb/models/price.rb', line 3330
required :replaces_price_id, String, nil?: true
|
Configuration for tiered_with_minimum pricing
3336
|
# File 'lib/orb/models/price.rb', line 3336
required :tiered_with_minimum_config, -> { Orb::Price::TieredWithMinimum::TieredWithMinimumConfig }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 3422
|
Instance Method Details
#to_hash ⇒ {
2467
|
# File 'sig/orb/models/price.rbs', line 2467
def to_hash: -> {
|