Class: Orb::Models::Price::TieredWithMinimum
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, TieredWithMinimumConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(minimum_amount:, tier_lower_bound:, unit_amount:) ⇒ Object
Configuration for a single tier
|
# File 'lib/orb/models/price.rb', line 3349
|
Instance Attribute Details
3187
|
# File 'lib/orb/models/price.rb', line 3187
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
3192
|
# File 'lib/orb/models/price.rb', line 3192
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
3197
|
# File 'lib/orb/models/price.rb', line 3197
required :billing_mode, enum: -> { Orb::Price::TieredWithMinimum::BillingMode }
|
3202
|
# File 'lib/orb/models/price.rb', line 3202
required :cadence, enum: -> { Orb::Price::TieredWithMinimum::Cadence }
|
3207
3208
3209
|
# File 'lib/orb/models/price.rb', line 3207
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::TieredWithMinimum::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
3214
|
# File 'lib/orb/models/price.rb', line 3214
required :conversion_rate, Float, nil?: true
|
3219
|
# File 'lib/orb/models/price.rb', line 3219
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
3224
|
# File 'lib/orb/models/price.rb', line 3224
required :created_at, Time
|
3229
|
# File 'lib/orb/models/price.rb', line 3229
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
3234
|
# File 'lib/orb/models/price.rb', line 3234
required :currency, String
|
3339
|
# File 'lib/orb/models/price.rb', line 3339
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
3240
|
# File 'lib/orb/models/price.rb', line 3240
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
3245
|
# File 'lib/orb/models/price.rb', line 3245
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
3250
|
# File 'lib/orb/models/price.rb', line 3250
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
3182
|
# File 'lib/orb/models/price.rb', line 3182
required :id, String
|
#invoice_grouping_key ⇒ String?
3255
|
# File 'lib/orb/models/price.rb', line 3255
required :invoice_grouping_key, String, nil?: true
|
3260
|
# File 'lib/orb/models/price.rb', line 3260
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
3267
|
# File 'lib/orb/models/price.rb', line 3267
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
3347
|
# File 'lib/orb/models/price.rb', line 3347
optional :license_type, -> { Orb::Price::TieredWithMinimum::LicenseType }, nil?: true
|
3273
|
# File 'lib/orb/models/price.rb', line 3273
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
3279
|
# File 'lib/orb/models/price.rb', line 3279
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
3288
|
# File 'lib/orb/models/price.rb', line 3288
required :metadata, Orb::Internal::Type::HashOf[String]
|
3294
|
# File 'lib/orb/models/price.rb', line 3294
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
3300
|
# File 'lib/orb/models/price.rb', line 3300
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :tiered_with_minimum
3306
|
# File 'lib/orb/models/price.rb', line 3306
required :model_type, const: :tiered_with_minimum
|
#name ⇒ String
3311
|
# File 'lib/orb/models/price.rb', line 3311
required :name, String
|
#plan_phase_order ⇒ Integer?
3316
|
# File 'lib/orb/models/price.rb', line 3316
required :plan_phase_order, Integer, nil?: true
|
3321
|
# File 'lib/orb/models/price.rb', line 3321
required :price_type, enum: -> { Orb::Price::TieredWithMinimum::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
3328
|
# File 'lib/orb/models/price.rb', line 3328
required :replaces_price_id, String, nil?: true
|
Configuration for tiered_with_minimum pricing
3334
|
# File 'lib/orb/models/price.rb', line 3334
required :tiered_with_minimum_config, -> { Orb::Price::TieredWithMinimum::TieredWithMinimumConfig }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 3420
|
Instance Method Details
#to_hash ⇒ {
2466
|
# File 'sig/orb/models/price.rbs', line 2466
def to_hash: -> {
|