Class: Orb::Models::Price::TieredWithProration
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, TieredWithProrationConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(tier_lower_bound:, unit_amount:) ⇒ Object
Configuration for a single tiered with proration tier
|
# File 'lib/orb/models/price.rb', line 6675
|
Instance Attribute Details
6513
|
# File 'lib/orb/models/price.rb', line 6513
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
6518
|
# File 'lib/orb/models/price.rb', line 6518
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
6523
|
# File 'lib/orb/models/price.rb', line 6523
required :billing_mode, enum: -> { Orb::Price::TieredWithProration::BillingMode }
|
6528
|
# File 'lib/orb/models/price.rb', line 6528
required :cadence, enum: -> { Orb::Price::TieredWithProration::Cadence }
|
6533
6534
6535
|
# File 'lib/orb/models/price.rb', line 6533
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::TieredWithProration::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
6540
|
# File 'lib/orb/models/price.rb', line 6540
required :conversion_rate, Float, nil?: true
|
6545
|
# File 'lib/orb/models/price.rb', line 6545
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
6550
|
# File 'lib/orb/models/price.rb', line 6550
required :created_at, Time
|
6555
|
# File 'lib/orb/models/price.rb', line 6555
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
6560
|
# File 'lib/orb/models/price.rb', line 6560
required :currency, String
|
6665
|
# File 'lib/orb/models/price.rb', line 6665
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
6566
|
# File 'lib/orb/models/price.rb', line 6566
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
6571
|
# File 'lib/orb/models/price.rb', line 6571
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
6576
|
# File 'lib/orb/models/price.rb', line 6576
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
6508
|
# File 'lib/orb/models/price.rb', line 6508
required :id, String
|
#invoice_grouping_key ⇒ String?
6581
|
# File 'lib/orb/models/price.rb', line 6581
required :invoice_grouping_key, String, nil?: true
|
6586
|
# File 'lib/orb/models/price.rb', line 6586
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
6593
|
# File 'lib/orb/models/price.rb', line 6593
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
6673
|
# File 'lib/orb/models/price.rb', line 6673
optional :license_type, -> { Orb::Price::TieredWithProration::LicenseType }, nil?: true
|
6599
|
# File 'lib/orb/models/price.rb', line 6599
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
6605
|
# File 'lib/orb/models/price.rb', line 6605
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
6614
|
# File 'lib/orb/models/price.rb', line 6614
required :metadata, Orb::Internal::Type::HashOf[String]
|
6620
|
# File 'lib/orb/models/price.rb', line 6620
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
6626
|
# File 'lib/orb/models/price.rb', line 6626
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :tiered_with_proration
6632
|
# File 'lib/orb/models/price.rb', line 6632
required :model_type, const: :tiered_with_proration
|
#name ⇒ String
6637
|
# File 'lib/orb/models/price.rb', line 6637
required :name, String
|
#plan_phase_order ⇒ Integer?
6642
|
# File 'lib/orb/models/price.rb', line 6642
required :plan_phase_order, Integer, nil?: true
|
6647
|
# File 'lib/orb/models/price.rb', line 6647
required :price_type, enum: -> { Orb::Price::TieredWithProration::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
6654
|
# File 'lib/orb/models/price.rb', line 6654
required :replaces_price_id, String, nil?: true
|
Configuration for tiered_with_proration pricing
6660
|
# File 'lib/orb/models/price.rb', line 6660
required :tiered_with_proration_config, -> { Orb::Price::TieredWithProration::TieredWithProrationConfig }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 6746
|
Instance Method Details
#to_hash ⇒ {
4981
|
# File 'sig/orb/models/price.rbs', line 4981
def to_hash: -> {
|