Class: Orb::Models::Price::TieredWithProration
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, TieredWithProrationConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(tier_lower_bound:, unit_amount:) ⇒ Object
Configuration for a single tiered with proration tier
|
# File 'lib/orb/models/price.rb', line 6243
|
Instance Attribute Details
6081
|
# File 'lib/orb/models/price.rb', line 6081
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
6086
|
# File 'lib/orb/models/price.rb', line 6086
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
6091
|
# File 'lib/orb/models/price.rb', line 6091
required :billing_mode, enum: -> { Orb::Price::TieredWithProration::BillingMode }
|
6096
|
# File 'lib/orb/models/price.rb', line 6096
required :cadence, enum: -> { Orb::Price::TieredWithProration::Cadence }
|
6101
6102
6103
|
# File 'lib/orb/models/price.rb', line 6101
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::TieredWithProration::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
6108
|
# File 'lib/orb/models/price.rb', line 6108
required :conversion_rate, Float, nil?: true
|
6113
|
# File 'lib/orb/models/price.rb', line 6113
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
6118
|
# File 'lib/orb/models/price.rb', line 6118
required :created_at, Time
|
6123
|
# File 'lib/orb/models/price.rb', line 6123
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
6128
|
# File 'lib/orb/models/price.rb', line 6128
required :currency, String
|
6233
|
# File 'lib/orb/models/price.rb', line 6233
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
6134
|
# File 'lib/orb/models/price.rb', line 6134
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
6139
|
# File 'lib/orb/models/price.rb', line 6139
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
6144
|
# File 'lib/orb/models/price.rb', line 6144
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
6076
|
# File 'lib/orb/models/price.rb', line 6076
required :id, String
|
#invoice_grouping_key ⇒ String?
6149
|
# File 'lib/orb/models/price.rb', line 6149
required :invoice_grouping_key, String, nil?: true
|
6154
|
# File 'lib/orb/models/price.rb', line 6154
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
6161
|
# File 'lib/orb/models/price.rb', line 6161
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
6241
|
# File 'lib/orb/models/price.rb', line 6241
optional :license_type, -> { Orb::Price::TieredWithProration::LicenseType }, nil?: true
|
6167
|
# File 'lib/orb/models/price.rb', line 6167
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
6173
|
# File 'lib/orb/models/price.rb', line 6173
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
6182
|
# File 'lib/orb/models/price.rb', line 6182
required :metadata, Orb::Internal::Type::HashOf[String]
|
6188
|
# File 'lib/orb/models/price.rb', line 6188
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
6194
|
# File 'lib/orb/models/price.rb', line 6194
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :tiered_with_proration
6200
|
# File 'lib/orb/models/price.rb', line 6200
required :model_type, const: :tiered_with_proration
|
#name ⇒ String
6205
|
# File 'lib/orb/models/price.rb', line 6205
required :name, String
|
#plan_phase_order ⇒ Integer?
6210
|
# File 'lib/orb/models/price.rb', line 6210
required :plan_phase_order, Integer, nil?: true
|
6215
|
# File 'lib/orb/models/price.rb', line 6215
required :price_type, enum: -> { Orb::Price::TieredWithProration::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
6222
|
# File 'lib/orb/models/price.rb', line 6222
required :replaces_price_id, String, nil?: true
|
Configuration for tiered_with_proration pricing
6228
|
# File 'lib/orb/models/price.rb', line 6228
required :tiered_with_proration_config, -> { Orb::Price::TieredWithProration::TieredWithProrationConfig }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 6314
|
Instance Method Details
#to_hash ⇒ {
4654
|
# File 'sig/orb/models/price.rbs', line 4654
def to_hash: -> {
|