Class: Orb::Models::Price::Unit
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
-
#initialize(id:, billable_metric:, billing_cycle_configuration:, billing_mode:, cadence:, composite_price_filters:, conversion_rate:, conversion_rate_config:, created_at:, credit_allocation:, currency:, discount:, external_price_id:, fixed_price_quantity:, invoice_grouping_key:, invoicing_cycle_configuration:, item:, maximum:, maximum_amount:, metadata:, minimum:, minimum_amount:, name:, plan_phase_order:, price_type:, replaces_price_id:, unit_config:, dimensional_price_configuration: nil, license_type: nil, model_type: :unit) ⇒ Object
constructor
Some parameter documentations has been truncated, see Unit for more details.
-
#to_hash ⇒ {
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, billable_metric:, billing_cycle_configuration:, billing_mode:, cadence:, composite_price_filters:, conversion_rate:, conversion_rate_config:, created_at:, credit_allocation:, currency:, discount:, external_price_id:, fixed_price_quantity:, invoice_grouping_key:, invoicing_cycle_configuration:, item:, maximum:, maximum_amount:, metadata:, minimum:, minimum_amount:, name:, plan_phase_order:, price_type:, replaces_price_id:, unit_config:, dimensional_price_configuration: nil, license_type: nil, model_type: :unit) ⇒ Object
|
# File 'lib/orb/models/price.rb', line 261
|
Instance Attribute Details
99
|
# File 'lib/orb/models/price.rb', line 99
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
104
|
# File 'lib/orb/models/price.rb', line 104
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
109
|
# File 'lib/orb/models/price.rb', line 109
required :billing_mode, enum: -> { Orb::Price::Unit::BillingMode }
|
114
|
# File 'lib/orb/models/price.rb', line 114
required :cadence, enum: -> { Orb::Price::Unit::Cadence }
|
119
120
121
|
# File 'lib/orb/models/price.rb', line 119
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::Unit::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
126
|
# File 'lib/orb/models/price.rb', line 126
required :conversion_rate, Float, nil?: true
|
131
|
# File 'lib/orb/models/price.rb', line 131
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
136
|
# File 'lib/orb/models/price.rb', line 136
required :created_at, Time
|
141
|
# File 'lib/orb/models/price.rb', line 141
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
146
|
# File 'lib/orb/models/price.rb', line 146
required :currency, String
|
251
|
# File 'lib/orb/models/price.rb', line 251
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
152
|
# File 'lib/orb/models/price.rb', line 152
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
157
|
# File 'lib/orb/models/price.rb', line 157
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
162
|
# File 'lib/orb/models/price.rb', line 162
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
94
|
# File 'lib/orb/models/price.rb', line 94
required :id, String
|
#invoice_grouping_key ⇒ String?
167
|
# File 'lib/orb/models/price.rb', line 167
required :invoice_grouping_key, String, nil?: true
|
172
|
# File 'lib/orb/models/price.rb', line 172
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
179
|
# File 'lib/orb/models/price.rb', line 179
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
259
|
# File 'lib/orb/models/price.rb', line 259
optional :license_type, -> { Orb::Price::Unit::LicenseType }, nil?: true
|
185
|
# File 'lib/orb/models/price.rb', line 185
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
191
|
# File 'lib/orb/models/price.rb', line 191
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
200
|
# File 'lib/orb/models/price.rb', line 200
required :metadata, Orb::Internal::Type::HashOf[String]
|
206
|
# File 'lib/orb/models/price.rb', line 206
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
212
|
# File 'lib/orb/models/price.rb', line 212
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :unit
218
|
# File 'lib/orb/models/price.rb', line 218
required :model_type, const: :unit
|
#name ⇒ String
223
|
# File 'lib/orb/models/price.rb', line 223
required :name, String
|
#plan_phase_order ⇒ Integer?
228
|
# File 'lib/orb/models/price.rb', line 228
required :plan_phase_order, Integer, nil?: true
|
233
|
# File 'lib/orb/models/price.rb', line 233
required :price_type, enum: -> { Orb::Price::Unit::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
240
|
# File 'lib/orb/models/price.rb', line 240
required :replaces_price_id, String, nil?: true
|
Configuration for unit pricing
246
|
# File 'lib/orb/models/price.rb', line 246
required :unit_config, -> { Orb::UnitConfig }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 332
|
Instance Method Details
#to_hash ⇒ {
171
|
# File 'sig/orb/models/price.rbs', line 171
def to_hash: -> {
|