Class: Orb::Models::Price::UnitWithPercent
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, UnitWithPercentConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(percent:, unit_amount:) ⇒ Object
Configuration for unit_with_percent pricing
|
# File 'lib/orb/models/price.rb', line 5434
|
Instance Attribute Details
5272
|
# File 'lib/orb/models/price.rb', line 5272
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
5277
|
# File 'lib/orb/models/price.rb', line 5277
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
5282
|
# File 'lib/orb/models/price.rb', line 5282
required :billing_mode, enum: -> { Orb::Price::UnitWithPercent::BillingMode }
|
5287
|
# File 'lib/orb/models/price.rb', line 5287
required :cadence, enum: -> { Orb::Price::UnitWithPercent::Cadence }
|
5292
5293
5294
|
# File 'lib/orb/models/price.rb', line 5292
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::UnitWithPercent::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
5299
|
# File 'lib/orb/models/price.rb', line 5299
required :conversion_rate, Float, nil?: true
|
5304
|
# File 'lib/orb/models/price.rb', line 5304
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
5309
|
# File 'lib/orb/models/price.rb', line 5309
required :created_at, Time
|
5314
|
# File 'lib/orb/models/price.rb', line 5314
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
5319
|
# File 'lib/orb/models/price.rb', line 5319
required :currency, String
|
5424
|
# File 'lib/orb/models/price.rb', line 5424
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
5325
|
# File 'lib/orb/models/price.rb', line 5325
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
5330
|
# File 'lib/orb/models/price.rb', line 5330
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
5335
|
# File 'lib/orb/models/price.rb', line 5335
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
5267
|
# File 'lib/orb/models/price.rb', line 5267
required :id, String
|
#invoice_grouping_key ⇒ String?
5340
|
# File 'lib/orb/models/price.rb', line 5340
required :invoice_grouping_key, String, nil?: true
|
5345
|
# File 'lib/orb/models/price.rb', line 5345
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
5352
|
# File 'lib/orb/models/price.rb', line 5352
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
5432
|
# File 'lib/orb/models/price.rb', line 5432
optional :license_type, -> { Orb::Price::UnitWithPercent::LicenseType }, nil?: true
|
5358
|
# File 'lib/orb/models/price.rb', line 5358
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
5364
|
# File 'lib/orb/models/price.rb', line 5364
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
5373
|
# File 'lib/orb/models/price.rb', line 5373
required :metadata, Orb::Internal::Type::HashOf[String]
|
5379
|
# File 'lib/orb/models/price.rb', line 5379
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
5385
|
# File 'lib/orb/models/price.rb', line 5385
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :unit_with_percent
5391
|
# File 'lib/orb/models/price.rb', line 5391
required :model_type, const: :unit_with_percent
|
#name ⇒ String
5396
|
# File 'lib/orb/models/price.rb', line 5396
required :name, String
|
#plan_phase_order ⇒ Integer?
5401
|
# File 'lib/orb/models/price.rb', line 5401
required :plan_phase_order, Integer, nil?: true
|
5406
|
# File 'lib/orb/models/price.rb', line 5406
required :price_type, enum: -> { Orb::Price::UnitWithPercent::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
5413
|
# File 'lib/orb/models/price.rb', line 5413
required :replaces_price_id, String, nil?: true
|
Configuration for unit_with_percent pricing
5419
|
# File 'lib/orb/models/price.rb', line 5419
required :unit_with_percent_config, -> { Orb::Price::UnitWithPercent::UnitWithPercentConfig }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 5505
|
Instance Method Details
#to_hash ⇒ {
4048
|
# File 'sig/orb/models/price.rbs', line 4048
def to_hash: -> {
|