Class: Orb::Models::Price::UnitWithProration
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, UnitWithProrationConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(unit_amount:) ⇒ Object
Configuration for unit_with_proration pricing
|
# File 'lib/orb/models/price.rb', line 7082
|
Instance Attribute Details
6920
|
# File 'lib/orb/models/price.rb', line 6920
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
6925
|
# File 'lib/orb/models/price.rb', line 6925
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
6930
|
# File 'lib/orb/models/price.rb', line 6930
required :billing_mode, enum: -> { Orb::Price::UnitWithProration::BillingMode }
|
6935
|
# File 'lib/orb/models/price.rb', line 6935
required :cadence, enum: -> { Orb::Price::UnitWithProration::Cadence }
|
6940
6941
6942
|
# File 'lib/orb/models/price.rb', line 6940
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::UnitWithProration::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
6947
|
# File 'lib/orb/models/price.rb', line 6947
required :conversion_rate, Float, nil?: true
|
6952
|
# File 'lib/orb/models/price.rb', line 6952
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
6957
|
# File 'lib/orb/models/price.rb', line 6957
required :created_at, Time
|
6962
|
# File 'lib/orb/models/price.rb', line 6962
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
6967
|
# File 'lib/orb/models/price.rb', line 6967
required :currency, String
|
7072
|
# File 'lib/orb/models/price.rb', line 7072
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
6973
|
# File 'lib/orb/models/price.rb', line 6973
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
6978
|
# File 'lib/orb/models/price.rb', line 6978
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
6983
|
# File 'lib/orb/models/price.rb', line 6983
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
6915
|
# File 'lib/orb/models/price.rb', line 6915
required :id, String
|
#invoice_grouping_key ⇒ String?
6988
|
# File 'lib/orb/models/price.rb', line 6988
required :invoice_grouping_key, String, nil?: true
|
6993
|
# File 'lib/orb/models/price.rb', line 6993
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
7000
|
# File 'lib/orb/models/price.rb', line 7000
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
7080
|
# File 'lib/orb/models/price.rb', line 7080
optional :license_type, -> { Orb::Price::UnitWithProration::LicenseType }, nil?: true
|
7006
|
# File 'lib/orb/models/price.rb', line 7006
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
7012
|
# File 'lib/orb/models/price.rb', line 7012
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
7021
|
# File 'lib/orb/models/price.rb', line 7021
required :metadata, Orb::Internal::Type::HashOf[String]
|
7027
|
# File 'lib/orb/models/price.rb', line 7027
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
7033
|
# File 'lib/orb/models/price.rb', line 7033
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :unit_with_proration
7039
|
# File 'lib/orb/models/price.rb', line 7039
required :model_type, const: :unit_with_proration
|
#name ⇒ String
7044
|
# File 'lib/orb/models/price.rb', line 7044
required :name, String
|
#plan_phase_order ⇒ Integer?
7049
|
# File 'lib/orb/models/price.rb', line 7049
required :plan_phase_order, Integer, nil?: true
|
7054
|
# File 'lib/orb/models/price.rb', line 7054
required :price_type, enum: -> { Orb::Price::UnitWithProration::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
7061
|
# File 'lib/orb/models/price.rb', line 7061
required :replaces_price_id, String, nil?: true
|
Configuration for unit_with_proration pricing
7067
|
# File 'lib/orb/models/price.rb', line 7067
required :unit_with_proration_config, -> { Orb::Price::UnitWithProration::UnitWithProrationConfig }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 7153
|
Instance Method Details
#to_hash ⇒ {
5285
|
# File 'sig/orb/models/price.rbs', line 5285
def to_hash: -> {
|