Class: Orb::Models::Price::UnitWithProration
Defined Under Namespace
Modules: BillingMode, Cadence, PriceType
Classes: CompositePriceFilter, LicenseType, UnitWithProrationConfig
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(unit_amount:) ⇒ Object
Configuration for unit_with_proration pricing
|
# File 'lib/orb/models/price.rb', line 6650
|
Instance Attribute Details
6488
|
# File 'lib/orb/models/price.rb', line 6488
required :billable_metric, -> { Orb::BillableMetricTiny }, nil?: true
|
6493
|
# File 'lib/orb/models/price.rb', line 6493
required :billing_cycle_configuration, -> { Orb::BillingCycleConfiguration }
|
6498
|
# File 'lib/orb/models/price.rb', line 6498
required :billing_mode, enum: -> { Orb::Price::UnitWithProration::BillingMode }
|
6503
|
# File 'lib/orb/models/price.rb', line 6503
required :cadence, enum: -> { Orb::Price::UnitWithProration::Cadence }
|
6508
6509
6510
|
# File 'lib/orb/models/price.rb', line 6508
required :composite_price_filters,
-> { Orb::Internal::Type::ArrayOf[Orb::Price::UnitWithProration::CompositePriceFilter] },
nil?: true
|
#conversion_rate ⇒ Float?
6515
|
# File 'lib/orb/models/price.rb', line 6515
required :conversion_rate, Float, nil?: true
|
6520
|
# File 'lib/orb/models/price.rb', line 6520
required :conversion_rate_config, union: -> { Orb::ConversionRateConfig }, nil?: true
|
#created_at ⇒ Time
6525
|
# File 'lib/orb/models/price.rb', line 6525
required :created_at, Time
|
6530
|
# File 'lib/orb/models/price.rb', line 6530
required :credit_allocation, -> { Orb::Allocation }, nil?: true
|
#currency ⇒ String
6535
|
# File 'lib/orb/models/price.rb', line 6535
required :currency, String
|
6640
|
# File 'lib/orb/models/price.rb', line 6640
optional :dimensional_price_configuration, -> { Orb::DimensionalPriceConfiguration }, nil?: true
|
6541
|
# File 'lib/orb/models/price.rb', line 6541
required :discount, union: -> { Orb::Discount }, nil?: true
|
#external_price_id ⇒ String?
6546
|
# File 'lib/orb/models/price.rb', line 6546
required :external_price_id, String, nil?: true
|
#fixed_price_quantity ⇒ Float?
6551
|
# File 'lib/orb/models/price.rb', line 6551
required :fixed_price_quantity, Float, nil?: true
|
#id ⇒ String
6483
|
# File 'lib/orb/models/price.rb', line 6483
required :id, String
|
#invoice_grouping_key ⇒ String?
6556
|
# File 'lib/orb/models/price.rb', line 6556
required :invoice_grouping_key, String, nil?: true
|
6561
|
# File 'lib/orb/models/price.rb', line 6561
required :invoicing_cycle_configuration, -> { Orb::BillingCycleConfiguration }, nil?: true
|
A minimal representation of an Item containing only the essential identifying
information.
6568
|
# File 'lib/orb/models/price.rb', line 6568
required :item, -> { Orb::ItemSlim }
|
The LicenseType resource represents a type of license that can be assigned to
users. License types are used during billing by grouping metrics on the
configured grouping key.
6648
|
# File 'lib/orb/models/price.rb', line 6648
optional :license_type, -> { Orb::Price::UnitWithProration::LicenseType }, nil?: true
|
6574
|
# File 'lib/orb/models/price.rb', line 6574
required :maximum, -> { Orb::Maximum }, nil?: true
|
#maximum_amount ⇒ String?
6580
|
# File 'lib/orb/models/price.rb', line 6580
required :maximum_amount, String, nil?: true
|
User specified key-value pairs for the resource. If not present, this defaults
to an empty dictionary. Individual keys can be removed by setting the value to
null, and the entire metadata mapping can be cleared by setting metadata to
null.
6589
|
# File 'lib/orb/models/price.rb', line 6589
required :metadata, Orb::Internal::Type::HashOf[String]
|
6595
|
# File 'lib/orb/models/price.rb', line 6595
required :minimum, -> { Orb::Minimum }, nil?: true
|
#minimum_amount ⇒ String?
6601
|
# File 'lib/orb/models/price.rb', line 6601
required :minimum_amount, String, nil?: true
|
#model_type ⇒ Symbol, :unit_with_proration
6607
|
# File 'lib/orb/models/price.rb', line 6607
required :model_type, const: :unit_with_proration
|
#name ⇒ String
6612
|
# File 'lib/orb/models/price.rb', line 6612
required :name, String
|
#plan_phase_order ⇒ Integer?
6617
|
# File 'lib/orb/models/price.rb', line 6617
required :plan_phase_order, Integer, nil?: true
|
6622
|
# File 'lib/orb/models/price.rb', line 6622
required :price_type, enum: -> { Orb::Price::UnitWithProration::PriceType }
|
#replaces_price_id ⇒ String?
The price id this price replaces. This price will take the place of the replaced
price in plan version migrations.
6629
|
# File 'lib/orb/models/price.rb', line 6629
required :replaces_price_id, String, nil?: true
|
Configuration for unit_with_proration pricing
6635
|
# File 'lib/orb/models/price.rb', line 6635
required :unit_with_proration_config, -> { Orb::Price::UnitWithProration::UnitWithProrationConfig }
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/orb/models/price.rb', line 6721
|
Instance Method Details
#to_hash ⇒ {
4958
|
# File 'sig/orb/models/price.rbs', line 4958
def to_hash: -> {
|