Class: Orb::Models::PriceEditedWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::PriceEditedWebhookEvent
- Defined in:
- lib/orb/models/price_edited_webhook_event.rb,
sig/orb/models/price_edited_webhook_event.rbs
Defined Under Namespace
Modules: Type Classes: Properties
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The time at which this event was created, to the second.
-
#id ⇒ String
The ID of this webhook event.
-
#price ⇒ Orb::Models::Price::Unit, ...
The Price resource represents a price that can be billed on a subscription, resulting in a charge on an invoice in the form of an invoice line item.
- #properties ⇒ Orb::Models::PriceEditedWebhookEvent::Properties
-
#type ⇒ Symbol, Orb::Models::PriceEditedWebhookEvent::Type
The event this payload describes.
Instance Method Summary collapse
-
#initialize(metadata: nil) ⇒ Object
constructor
metadata values are non-null on the wire (deleting a key removes it from storage); the Optional values only exist on the new half of a metadata FieldChange.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(metadata: nil) ⇒ Object
metadata values are non-null on the wire (deleting a key removes it from storage); the Optional values only exist on the new half of a metadata FieldChange.
|
|
# File 'lib/orb/models/price_edited_webhook_event.rb', line 44
|
Instance Attribute Details
#created_at ⇒ Time
The time at which this event was created, to the second.
16 |
# File 'lib/orb/models/price_edited_webhook_event.rb', line 16 required :created_at, Time |
#id ⇒ String
The ID of this webhook event.
10 |
# File 'lib/orb/models/price_edited_webhook_event.rb', line 10 required :id, String |
#price ⇒ Orb::Models::Price::Unit, ...
The Price resource represents a price that can be billed on a subscription, resulting in a charge on an invoice in the form of an invoice line item. Prices take a quantity and determine an amount to bill.
Orb supports a few different pricing models out of the box. Each of these models is serialized differently in a given Price object. The model_type field determines the key for the configuration object that is present.
For more on the types of prices, see the core concepts documentation
31 |
# File 'lib/orb/models/price_edited_webhook_event.rb', line 31 required :price, union: -> { Orb::Price } |
#properties ⇒ Orb::Models::PriceEditedWebhookEvent::Properties
36 |
# File 'lib/orb/models/price_edited_webhook_event.rb', line 36 required :properties, -> { Orb::PriceEditedWebhookEvent::Properties } |
#type ⇒ Symbol, Orb::Models::PriceEditedWebhookEvent::Type
The event this payload describes.
42 |
# File 'lib/orb/models/price_edited_webhook_event.rb', line 42 required :type, enum: -> { Orb::PriceEditedWebhookEvent::Type } |
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/orb/models/price_edited_webhook_event.rbs', line 31
def to_hash: -> {
|