Class: Orb::Models::SubscriptionAlertDisabledWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionAlertDisabledWebhookEvent
- Defined in:
- lib/orb/models/subscription_alert_disabled_webhook_event.rb,
sig/orb/models/subscription_alert_disabled_webhook_event.rbs
Defined Under Namespace
Modules: Type Classes: Properties, Subscription
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The time at which this event was created, to the second.
-
#id ⇒ String
The ID of this webhook event.
-
#properties ⇒ Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties
Sent when the system disables an alert on its own, currently for cardinality-limit enforcement on grouped cost alerts.
-
#subscription ⇒ Orb::Models::SubscriptionAlertDisabledWebhookEvent::Subscription
A lightweight subscription representation for webhook payloads.
-
#type ⇒ Symbol, Orb::Models::SubscriptionAlertDisabledWebhookEvent::Type
The event this payload describes.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, created_at:, properties:, subscription:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see SubscriptionAlertDisabledWebhookEvent for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, properties:, subscription:, type:) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::SubscriptionAlertDisabledWebhookEvent for more details.
Issued when an alert is automatically disabled by the system.
|
|
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 40
|
Instance Attribute Details
#created_at ⇒ Time
The time at which this event was created, to the second.
16 |
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 16 required :created_at, Time |
#id ⇒ String
The ID of this webhook event.
10 |
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 10 required :id, String |
#properties ⇒ Orb::Models::SubscriptionAlertDisabledWebhookEvent::Properties
Sent when the system disables an alert on its own, currently for cardinality-limit enforcement on grouped cost alerts.
23 |
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 23 required :properties, -> { Orb::SubscriptionAlertDisabledWebhookEvent::Properties } |
#subscription ⇒ Orb::Models::SubscriptionAlertDisabledWebhookEvent::Subscription
A lightweight subscription representation for webhook payloads.
This avoids the expensive to_subscription_params() call required for full serialization.
32 |
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 32 required :subscription, -> { Orb::SubscriptionAlertDisabledWebhookEvent::Subscription } |
#type ⇒ Symbol, Orb::Models::SubscriptionAlertDisabledWebhookEvent::Type
The event this payload describes.
38 |
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 38 required :type, enum: -> { Orb::SubscriptionAlertDisabledWebhookEvent::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/subscription_alert_disabled_webhook_event.rb', line 516
|
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/orb/models/subscription_alert_disabled_webhook_event.rbs', line 31
def to_hash: -> {
|