Class: Orb::Models::SubscriptionChangeApplyParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionChangeApplyParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/orb/models/subscription_change_apply_params.rb,
sig/orb/models/subscription_change_apply_params.rbs
Overview
Instance Attribute Summary collapse
-
#description ⇒ String?
Description to apply to the balance transaction representing this credit.
-
#mark_as_paid ⇒ Boolean?
Mark all pending invoices that are payable as paid.
-
#payment_external_id ⇒ String?
An optional external ID to associate with the payment.
-
#payment_notes ⇒ String?
Optional notes about the payment.
-
#payment_received_date ⇒ Date?
A date string to specify the date the payment was received.
-
#previously_collected_amount ⇒ String?
Amount already collected to apply to the customer's balance.
- #subscription_change_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(subscription_change_id:, description: nil, mark_as_paid: nil, payment_external_id: nil, payment_notes: nil, payment_received_date: nil, previously_collected_amount: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see SubscriptionChangeApplyParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(subscription_change_id:, description: nil, mark_as_paid: nil, payment_external_id: nil, payment_notes: nil, payment_received_date: nil, previously_collected_amount: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::SubscriptionChangeApplyParams for more details.
|
|
# File 'lib/orb/models/subscription_change_apply_params.rb', line 55
|
Instance Attribute Details
#description ⇒ String?
Description to apply to the balance transaction representing this credit.
19 |
# File 'lib/orb/models/subscription_change_apply_params.rb', line 19 optional :description, String, nil?: true |
#mark_as_paid ⇒ Boolean?
Mark all pending invoices that are payable as paid. If amount is also provided, mark as paid and credit the difference to the customer's balance.
26 |
# File 'lib/orb/models/subscription_change_apply_params.rb', line 26 optional :mark_as_paid, Orb::Internal::Type::Boolean, nil?: true |
#payment_external_id ⇒ String?
An optional external ID to associate with the payment. Only applicable when mark_as_paid is true.
33 |
# File 'lib/orb/models/subscription_change_apply_params.rb', line 33 optional :payment_external_id, String, nil?: true |
#payment_notes ⇒ String?
Optional notes about the payment. Only applicable when mark_as_paid is true.
39 |
# File 'lib/orb/models/subscription_change_apply_params.rb', line 39 optional :payment_notes, String, nil?: true |
#payment_received_date ⇒ Date?
A date string to specify the date the payment was received. Only applicable when mark_as_paid is true. If not provided, defaults to the current date.
46 |
# File 'lib/orb/models/subscription_change_apply_params.rb', line 46 optional :payment_received_date, Date, nil?: true |
#previously_collected_amount ⇒ String?
Amount already collected to apply to the customer's balance. If mark_as_paid is also provided, credit the difference to the customer's balance.
53 |
# File 'lib/orb/models/subscription_change_apply_params.rb', line 53 optional :previously_collected_amount, String, nil?: true |
#subscription_change_id ⇒ String
13 |
# File 'lib/orb/models/subscription_change_apply_params.rb', line 13 required :subscription_change_id, String |
Instance Method Details
#to_hash ⇒ {
44 |
# File 'sig/orb/models/subscription_change_apply_params.rbs', line 44
def to_hash: -> {
|