Class: Orb::Models::SubscriptionChangeListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionChangeListResponse
- Defined in:
- lib/orb/models/subscription_change_list_response.rb,
sig/orb/models/subscription_change_list_response.rbs
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#applied_at ⇒ Time?
When this change was applied.
-
#cancelled_at ⇒ Time?
When this change was cancelled.
-
#expiration_time ⇒ Time
Subscription change will be cancelled at this time and can no longer be applied.
- #id ⇒ String
- #status ⇒ Symbol, Orb::Models::SubscriptionChangeListResponse::Status
- #subscription_id ⇒ String?
Instance Method Summary collapse
-
#initialize(id:, expiration_time:, status:, subscription_id:, applied_at: nil, cancelled_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see SubscriptionChangeListResponse for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, expiration_time:, status:, subscription_id:, applied_at: nil, cancelled_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::SubscriptionChangeListResponse for more details.
|
|
# File 'lib/orb/models/subscription_change_list_response.rb', line 40
|
Instance Attribute Details
#applied_at ⇒ Time?
When this change was applied.
32 |
# File 'lib/orb/models/subscription_change_list_response.rb', line 32 optional :applied_at, Time, nil?: true |
#cancelled_at ⇒ Time?
When this change was cancelled.
38 |
# File 'lib/orb/models/subscription_change_list_response.rb', line 38 optional :cancelled_at, Time, nil?: true |
#expiration_time ⇒ Time
Subscription change will be cancelled at this time and can no longer be applied.
16 |
# File 'lib/orb/models/subscription_change_list_response.rb', line 16 required :expiration_time, Time |
#id ⇒ String
10 |
# File 'lib/orb/models/subscription_change_list_response.rb', line 10 required :id, String |
#status ⇒ Symbol, Orb::Models::SubscriptionChangeListResponse::Status
21 |
# File 'lib/orb/models/subscription_change_list_response.rb', line 21 required :status, enum: -> { Orb::Models::SubscriptionChangeListResponse::Status } |
#subscription_id ⇒ String?
26 |
# File 'lib/orb/models/subscription_change_list_response.rb', line 26 required :subscription_id, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
35 |
# File 'sig/orb/models/subscription_change_list_response.rbs', line 35
def to_hash: -> {
|