Class: Orb::Models::SubscriptionCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/orb/models/subscription_create_params.rb,
sig/orb/models/subscription_create_params.rbs
Overview
Defined Under Namespace
Modules: ExternalMarketplace Classes: AddAdjustment, AddPrice, RemoveAdjustment, RemovePrice, ReplaceAdjustment, ReplacePrice
Instance Attribute Summary collapse
-
#add_adjustments ⇒ Array<Orb::Models::SubscriptionCreateParams::AddAdjustment>?
Additional adjustments to be added to the subscription.
-
#add_prices ⇒ Array<Orb::Models::SubscriptionCreateParams::AddPrice>?
Additional prices to be added to the subscription.
- #align_billing_with_subscription_start_date ⇒ Boolean?
-
#auto_collection ⇒ Boolean?
Determines whether issued invoices for this subscription will automatically be charged with the saved payment method on the due date.
-
#auto_issuance ⇒ Boolean?
Used to determine if invoices for this subscription will be automatically issued.
- #aws_region ⇒ String? deprecated Deprecated.
- #billing_cycle_anchor_configuration ⇒ Orb::Models::BillingCycleAnchorConfiguration?
-
#coupon_redemption_code ⇒ String?
Redemption code to be used for this subscription.
- #credits_overage_rate ⇒ Float? deprecated Deprecated.
-
#currency ⇒ String?
The currency to use for the subscription.
- #customer_id ⇒ String?
-
#default_invoice_memo ⇒ String?
Determines the default memo on this subscription's invoices.
- #end_date ⇒ Time?
- #external_customer_id ⇒ String?
- #external_marketplace ⇒ Symbol, ... deprecated Deprecated.
- #external_marketplace_reporting_id ⇒ String? deprecated Deprecated.
-
#external_plan_id ⇒ String?
The external_plan_id of the plan that the given subscription should be switched to.
-
#filter ⇒ String?
An additional filter to apply to usage queries.
-
#initial_phase_order ⇒ Integer?
The phase of the plan to start with.
-
#invoicing_threshold ⇒ String?
When this subscription's accrued usage reaches this threshold, an invoice will be issued for the subscription.
-
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource.
-
#name ⇒ String?
The name to use for the subscription.
-
#net_terms ⇒ Integer?
The net terms determines the difference between the invoice date and the issue date for the invoice.
- #per_credit_overage_amount ⇒ Float? deprecated Deprecated.
-
#plan_id ⇒ String?
The plan that the given subscription should be switched to.
-
#plan_version_number ⇒ Integer?
Specifies which version of the plan to subscribe to.
- #price_overrides ⇒ Array<Object>? deprecated Deprecated.
-
#remove_adjustments ⇒ Array<Orb::Models::SubscriptionCreateParams::RemoveAdjustment>?
Plan adjustments to be removed from the subscription.
-
#remove_prices ⇒ Array<Orb::Models::SubscriptionCreateParams::RemovePrice>?
Plan prices to be removed from the subscription.
-
#replace_adjustments ⇒ Array<Orb::Models::SubscriptionCreateParams::ReplaceAdjustment>?
Plan adjustments to be replaced with additional adjustments on the subscription.
-
#replace_prices ⇒ Array<Orb::Models::SubscriptionCreateParams::ReplacePrice>?
Plan prices to be replaced with additional prices on the subscription.
- #start_date ⇒ Time?
-
#trial_duration_days ⇒ Integer?
The duration of the trial period in days.
-
#usage_customer_ids ⇒ Array<String>?
A list of customer IDs whose usage events will be aggregated and billed under this subscription.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(Orb::Models::NewPercentageDiscount, Orb::Models::NewUsageDiscount, Orb::Models::NewAmountDiscount, Orb::Models::NewMinimum, Orb::Models::NewMaximum, Orb::Models::SubscriptionCreateParams::ReplaceAdjustment::Adjustment::TieredPercentageDiscount)
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(external_price_id: nil, price_id: nil) ⇒ Object
|
|
# File 'lib/orb/models/subscription_create_params.rb', line 3030
|
Instance Attribute Details
#add_adjustments ⇒ Array<Orb::Models::SubscriptionCreateParams::AddAdjustment>?
Additional adjustments to be added to the subscription. (Only available for accounts that have migrated off of legacy subscription overrides)
15 16 17 |
# File 'lib/orb/models/subscription_create_params.rb', line 15 optional :add_adjustments, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionCreateParams::AddAdjustment] }, nil?: true |
#add_prices ⇒ Array<Orb::Models::SubscriptionCreateParams::AddPrice>?
Additional prices to be added to the subscription. (Only available for accounts that have migrated off of legacy subscription overrides)
24 25 26 |
# File 'lib/orb/models/subscription_create_params.rb', line 24 optional :add_prices, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionCreateParams::AddPrice] }, nil?: true |
#align_billing_with_subscription_start_date ⇒ Boolean?
31 |
# File 'lib/orb/models/subscription_create_params.rb', line 31 optional :align_billing_with_subscription_start_date, Orb::Internal::Type::Boolean |
#auto_collection ⇒ Boolean?
Determines whether issued invoices for this subscription will automatically be charged with the saved payment method on the due date. If not specified, this defaults to the behavior configured for this customer.
39 |
# File 'lib/orb/models/subscription_create_params.rb', line 39 optional :auto_collection, Orb::Internal::Type::Boolean, nil?: true |
#auto_issuance ⇒ Boolean?
Used to determine if invoices for this subscription will be automatically
issued. If true, invoices will be automatically issued. If false, invoices will
require manual approval. If null is specified, this defaults to the behavior
configured for this customer.
48 |
# File 'lib/orb/models/subscription_create_params.rb', line 48 optional :auto_issuance, Orb::Internal::Type::Boolean, nil?: true |
#aws_region ⇒ String?
54 |
# File 'lib/orb/models/subscription_create_params.rb', line 54 optional :aws_region, String, nil?: true |
#billing_cycle_anchor_configuration ⇒ Orb::Models::BillingCycleAnchorConfiguration?
59 |
# File 'lib/orb/models/subscription_create_params.rb', line 59 optional :billing_cycle_anchor_configuration, -> { Orb::BillingCycleAnchorConfiguration }, nil?: true |
#coupon_redemption_code ⇒ String?
Redemption code to be used for this subscription. If the coupon cannot be found by its redemption code, or cannot be redeemed, an error response will be returned and the subscription creation or plan change will not be scheduled.
67 |
# File 'lib/orb/models/subscription_create_params.rb', line 67 optional :coupon_redemption_code, String, nil?: true |
#credits_overage_rate ⇒ Float?
73 |
# File 'lib/orb/models/subscription_create_params.rb', line 73 optional :credits_overage_rate, Float, nil?: true |
#currency ⇒ String?
The currency to use for the subscription. If not specified, the invoicing currency for the plan will be used.
80 |
# File 'lib/orb/models/subscription_create_params.rb', line 80 optional :currency, String, nil?: true |
#customer_id ⇒ String?
85 |
# File 'lib/orb/models/subscription_create_params.rb', line 85 optional :customer_id, String, nil?: true |
#default_invoice_memo ⇒ String?
Determines the default memo on this subscription's invoices. Note that if this is not provided, it is determined by the plan configuration.
92 |
# File 'lib/orb/models/subscription_create_params.rb', line 92 optional :default_invoice_memo, String, nil?: true |
#end_date ⇒ Time?
97 |
# File 'lib/orb/models/subscription_create_params.rb', line 97 optional :end_date, Time, nil?: true |
#external_customer_id ⇒ String?
102 |
# File 'lib/orb/models/subscription_create_params.rb', line 102 optional :external_customer_id, String, nil?: true |
#external_marketplace ⇒ Symbol, ...
108 109 110 |
# File 'lib/orb/models/subscription_create_params.rb', line 108 optional :external_marketplace, enum: -> { Orb::SubscriptionCreateParams::ExternalMarketplace }, nil?: true |
#external_marketplace_reporting_id ⇒ String?
116 |
# File 'lib/orb/models/subscription_create_params.rb', line 116 optional :external_marketplace_reporting_id, String, nil?: true |
#external_plan_id ⇒ String?
The external_plan_id of the plan that the given subscription should be switched
to. Note that either this property or plan_id must be specified.
123 |
# File 'lib/orb/models/subscription_create_params.rb', line 123 optional :external_plan_id, String, nil?: true |
#filter ⇒ String?
An additional filter to apply to usage queries. This filter must be expressed as a boolean computed property. If null, usage queries will not include any additional filter.
132 |
# File 'lib/orb/models/subscription_create_params.rb', line 132 optional :filter, String, nil?: true |
#initial_phase_order ⇒ Integer?
The phase of the plan to start with
138 |
# File 'lib/orb/models/subscription_create_params.rb', line 138 optional :initial_phase_order, Integer, nil?: true |
#invoicing_threshold ⇒ String?
When this subscription's accrued usage reaches this threshold, an invoice will be issued for the subscription. If not specified, invoices will only be issued at the end of the billing period.
146 |
# File 'lib/orb/models/subscription_create_params.rb', line 146 optional :invoicing_threshold, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource. Individual keys can be removed
by setting the value to null, and the entire metadata mapping can be cleared
by setting metadata to null.
154 |
# File 'lib/orb/models/subscription_create_params.rb', line 154 optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true |
#name ⇒ String?
The name to use for the subscription. If not specified, the plan name will be used.
161 |
# File 'lib/orb/models/subscription_create_params.rb', line 161 optional :name, String, nil?: true |
#net_terms ⇒ Integer?
The net terms determines the difference between the invoice date and the issue date for the invoice. If you intend the invoice to be due on issue, set this to 0. If not provided, this defaults to the value specified in the plan.
169 |
# File 'lib/orb/models/subscription_create_params.rb', line 169 optional :net_terms, Integer, nil?: true |
#per_credit_overage_amount ⇒ Float?
175 |
# File 'lib/orb/models/subscription_create_params.rb', line 175 optional :per_credit_overage_amount, Float, nil?: true |
#plan_id ⇒ String?
The plan that the given subscription should be switched to. Note that either
this property or external_plan_id must be specified.
182 |
# File 'lib/orb/models/subscription_create_params.rb', line 182 optional :plan_id, String, nil?: true |
#plan_version_number ⇒ Integer?
Specifies which version of the plan to subscribe to. If null, the default version will be used.
189 |
# File 'lib/orb/models/subscription_create_params.rb', line 189 optional :plan_version_number, Integer, nil?: true |
#price_overrides ⇒ Array<Object>?
Optionally provide a list of overrides for prices on the plan
197 |
# File 'lib/orb/models/subscription_create_params.rb', line 197 optional :price_overrides, Orb::Internal::Type::ArrayOf[Orb::Internal::Type::Unknown], nil?: true |
#remove_adjustments ⇒ Array<Orb::Models::SubscriptionCreateParams::RemoveAdjustment>?
Plan adjustments to be removed from the subscription. (Only available for accounts that have migrated off of legacy subscription overrides)
204 205 206 |
# File 'lib/orb/models/subscription_create_params.rb', line 204 optional :remove_adjustments, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionCreateParams::RemoveAdjustment] }, nil?: true |
#remove_prices ⇒ Array<Orb::Models::SubscriptionCreateParams::RemovePrice>?
Plan prices to be removed from the subscription. (Only available for accounts that have migrated off of legacy subscription overrides)
213 214 215 |
# File 'lib/orb/models/subscription_create_params.rb', line 213 optional :remove_prices, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionCreateParams::RemovePrice] }, nil?: true |
#replace_adjustments ⇒ Array<Orb::Models::SubscriptionCreateParams::ReplaceAdjustment>?
Plan adjustments to be replaced with additional adjustments on the subscription. (Only available for accounts that have migrated off of legacy subscription overrides)
223 224 225 |
# File 'lib/orb/models/subscription_create_params.rb', line 223 optional :replace_adjustments, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionCreateParams::ReplaceAdjustment] }, nil?: true |
#replace_prices ⇒ Array<Orb::Models::SubscriptionCreateParams::ReplacePrice>?
Plan prices to be replaced with additional prices on the subscription. (Only available for accounts that have migrated off of legacy subscription overrides)
232 233 234 |
# File 'lib/orb/models/subscription_create_params.rb', line 232 optional :replace_prices, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionCreateParams::ReplacePrice] }, nil?: true |
#start_date ⇒ Time?
239 |
# File 'lib/orb/models/subscription_create_params.rb', line 239 optional :start_date, Time, nil?: true |
#trial_duration_days ⇒ Integer?
The duration of the trial period in days. If not provided, this defaults to the
value specified in the plan. If 0 is provided, the trial on the plan will be
skipped.
247 |
# File 'lib/orb/models/subscription_create_params.rb', line 247 optional :trial_duration_days, Integer, nil?: true |
#usage_customer_ids ⇒ Array<String>?
A list of customer IDs whose usage events will be aggregated and billed under this subscription. By default, a subscription only considers usage events associated with its attached customer's customer_id. When usage_customer_ids is provided, the subscription includes usage events from the specified customers only. Provided usage_customer_ids must be either the customer for this subscription itself, or any of that customer's children.
258 |
# File 'lib/orb/models/subscription_create_params.rb', line 258 optional :usage_customer_ids, Orb::Internal::Type::ArrayOf[String], nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/subscription_create_params.rb', line 594
|
.variants ⇒ Array(Orb::Models::NewPercentageDiscount, Orb::Models::NewUsageDiscount, Orb::Models::NewAmountDiscount, Orb::Models::NewMinimum, Orb::Models::NewMaximum, Orb::Models::SubscriptionCreateParams::ReplaceAdjustment::Adjustment::TieredPercentageDiscount)
|
|
# File 'lib/orb/models/subscription_create_params.rb', line 599
|
Instance Method Details
#to_hash ⇒ {
154 |
# File 'sig/orb/models/subscription_create_params.rbs', line 154
def to_hash: -> {
|