Class: Orb::Models::SubscriptionCreateParams::AddPrice
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionCreateParams::AddPrice
- Defined in:
- lib/orb/models/subscription_create_params.rb,
sig/orb/models/subscription_create_params.rbs
Defined Under Namespace
Modules: Price
Constant Summary collapse
- Orb =
Instance Attribute Summary collapse
-
#allocation_price ⇒ Orb::Models::NewAllocationPrice?
The definition of a new allocation price to create and add to the subscription.
- #discounts ⇒ Array<Orb::Models::DiscountOverride>? deprecated Deprecated.
-
#end_date ⇒ Time?
The end date of the price interval.
-
#external_price_id ⇒ String?
The external price id of the price to add to the subscription.
- #maximum_amount ⇒ String? deprecated Deprecated.
-
#metric_parameter_overrides ⇒ Hash{Symbol=>Object}?
Override values for parameterized billable metric variables.
- #minimum_amount ⇒ String? deprecated Deprecated.
-
#plan_phase_order ⇒ Integer?
The phase to add this price to.
-
#price ⇒ Orb::Models::NewSubscriptionUnitPrice, ...
New subscription price request body params.
-
#price_id ⇒ String?
The id of the price to add to the subscription.
-
#start_date ⇒ Time?
The start date of the price interval.
Instance Method Summary collapse
-
#initialize(allocation_price: nil, discounts: nil, end_date: nil, external_price_id: nil, maximum_amount: nil, metric_parameter_overrides: nil, minimum_amount: nil, plan_phase_order: nil, price: nil, price_id: nil, start_date: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see AddPrice for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(allocation_price: nil, discounts: nil, end_date: nil, external_price_id: nil, maximum_amount: nil, metric_parameter_overrides: nil, minimum_amount: nil, plan_phase_order: nil, price: nil, price_id: nil, start_date: nil) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::SubscriptionCreateParams::AddPrice for more details.
|
|
# File 'lib/orb/models/subscription_create_params.rb', line 687
|
Instance Attribute Details
#allocation_price ⇒ Orb::Models::NewAllocationPrice?
The definition of a new allocation price to create and add to the subscription.
609 |
# File 'lib/orb/models/subscription_create_params.rb', line 609 optional :allocation_price, -> { Orb::NewAllocationPrice }, nil?: true |
#discounts ⇒ Array<Orb::Models::DiscountOverride>?
[DEPRECATED] Use add_adjustments instead. The subscription's discounts for this price.
618 |
# File 'lib/orb/models/subscription_create_params.rb', line 618 optional :discounts, -> { Orb::Internal::Type::ArrayOf[Orb::DiscountOverride] }, nil?: true |
#end_date ⇒ Time?
The end date of the price interval. This is the date that the price will stop billing on the subscription. If null, billing will end when the phase or subscription ends.
626 |
# File 'lib/orb/models/subscription_create_params.rb', line 626 optional :end_date, Time, nil?: true |
#external_price_id ⇒ String?
The external price id of the price to add to the subscription.
632 |
# File 'lib/orb/models/subscription_create_params.rb', line 632 optional :external_price_id, String, nil?: true |
#maximum_amount ⇒ String?
[DEPRECATED] Use add_adjustments instead. The subscription's maximum amount for this price.
641 |
# File 'lib/orb/models/subscription_create_params.rb', line 641 optional :maximum_amount, String, nil?: true |
#metric_parameter_overrides ⇒ Hash{Symbol=>Object}?
Override values for parameterized billable metric variables. Keys are parameter names, values are the override values.
648 649 650 |
# File 'lib/orb/models/subscription_create_params.rb', line 648 optional :metric_parameter_overrides, Orb::Internal::Type::HashOf[Orb::Internal::Type::Unknown], nil?: true |
#minimum_amount ⇒ String?
[DEPRECATED] Use add_adjustments instead. The subscription's minimum amount for this price.
659 |
# File 'lib/orb/models/subscription_create_params.rb', line 659 optional :minimum_amount, String, nil?: true |
#plan_phase_order ⇒ Integer?
The phase to add this price to.
665 |
# File 'lib/orb/models/subscription_create_params.rb', line 665 optional :plan_phase_order, Integer, nil?: true |
#price ⇒ Orb::Models::NewSubscriptionUnitPrice, ...
New subscription price request body params.
671 |
# File 'lib/orb/models/subscription_create_params.rb', line 671 optional :price, union: -> { Orb::SubscriptionCreateParams::AddPrice::Price }, nil?: true |
#price_id ⇒ String?
The id of the price to add to the subscription.
677 |
# File 'lib/orb/models/subscription_create_params.rb', line 677 optional :price_id, String, nil?: true |
#start_date ⇒ Time?
The start date of the price interval. This is the date that the price will start billing on the subscription. If null, billing will start when the phase or subscription starts.
685 |
# File 'lib/orb/models/subscription_create_params.rb', line 685 optional :start_date, Time, nil?: true |
Instance Method Details
#to_hash ⇒ {
458 |
# File 'sig/orb/models/subscription_create_params.rbs', line 458
def to_hash: -> {
|