Class: Orb::Models::SubscriptionLicenseAllocationResetWebhookEvent::Properties::ResetAllocation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionLicenseAllocationResetWebhookEvent::Properties::ResetAllocation
- Defined in:
- lib/orb/models/subscription_license_allocation_reset_webhook_event.rb,
sig/orb/models/subscription_license_allocation_reset_webhook_event.rbs
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(reset_allocations:, timeframe_end:, timeframe_start:) ⇒ Object
constructor
Fires at the start of a billing period when license allocations are replenished.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(reset_allocations:, timeframe_end:, timeframe_start:) ⇒ Object
Fires at the start of a billing period when license allocations are replenished. Allocations sharing a billing period are batched into one message.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/orb/models/subscription_license_allocation_reset_webhook_event.rb', line 82 class ResetAllocation < Orb::Internal::Type::BaseModel # @!attribute allocation_amount # # @return [String] required :allocation_amount, String # @!attribute license_type_id # # @return [String] required :license_type_id, String # @!attribute pricing_unit_id # # @return [String] required :pricing_unit_id, String # @!method initialize(allocation_amount:, license_type_id:, pricing_unit_id:) # A license allocation replenished at the start of a billing period. # # @param allocation_amount [String] # @param license_type_id [String] # @param pricing_unit_id [String] end |
Instance Attribute Details
#allocation_amount ⇒ String
86 |
# File 'lib/orb/models/subscription_license_allocation_reset_webhook_event.rb', line 86 required :allocation_amount, String |
#license_type_id ⇒ String
91 |
# File 'lib/orb/models/subscription_license_allocation_reset_webhook_event.rb', line 91 required :license_type_id, String |
#pricing_unit_id ⇒ String
96 |
# File 'lib/orb/models/subscription_license_allocation_reset_webhook_event.rb', line 96 required :pricing_unit_id, String |
Instance Method Details
#to_hash ⇒ {
85 |
# File 'sig/orb/models/subscription_license_allocation_reset_webhook_event.rbs', line 85
def to_hash: -> {
|