Class: Orb::Models::SubscriptionLicenseBalanceThresholdReachedWebhookEvent::Properties
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionLicenseBalanceThresholdReachedWebhookEvent::Properties
- Defined in:
- lib/orb/models/subscription_license_balance_threshold_reached_webhook_event.rb,
sig/orb/models/subscription_license_balance_threshold_reached_webhook_event.rbs
Overview
Defined Under Namespace
Classes: AlertConfiguration, License
Instance Attribute Summary collapse
-
#alert_configuration ⇒ Orb::Models::SubscriptionLicenseBalanceThresholdReachedWebhookEvent::Properties::AlertConfiguration
Alerts within Orb monitor spending, usage, or credit balance and trigger webhooks when a threshold is exceeded.
- #licenses ⇒ Array<Orb::Models::SubscriptionLicenseBalanceThresholdReachedWebhookEvent::Properties::License>
- #timeframe_end ⇒ Time
- #timeframe_start ⇒ Time
Instance Method Summary collapse
-
#initialize(value:) ⇒ Object
constructor
Some parameter documentations has been truncated, see AlertConfiguration::ThresholdOverride::Threshold for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(value:) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::SubscriptionLicenseBalanceThresholdReachedWebhookEvent::Properties::AlertConfiguration::ThresholdOverride::Threshold for more details.
Thresholds are used to define the conditions under which an alert will be triggered.
|
|
# File 'lib/orb/models/subscription_license_balance_threshold_reached_webhook_event.rb', line 86
|
Instance Attribute Details
#alert_configuration ⇒ Orb::Models::SubscriptionLicenseBalanceThresholdReachedWebhookEvent::Properties::AlertConfiguration
Alerts within Orb monitor spending, usage, or credit balance and trigger webhooks when a threshold is exceeded.
Alerts created through the API can be scoped to either customers or subscriptions.
67 68 |
# File 'lib/orb/models/subscription_license_balance_threshold_reached_webhook_event.rb', line 67 required :alert_configuration, -> { Orb::SubscriptionLicenseBalanceThresholdReachedWebhookEvent::Properties::AlertConfiguration } |
#licenses ⇒ Array<Orb::Models::SubscriptionLicenseBalanceThresholdReachedWebhookEvent::Properties::License>
73 74 |
# File 'lib/orb/models/subscription_license_balance_threshold_reached_webhook_event.rb', line 73 required :licenses, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionLicenseBalanceThresholdReachedWebhookEvent::Properties::License] } |
#timeframe_end ⇒ Time
79 |
# File 'lib/orb/models/subscription_license_balance_threshold_reached_webhook_event.rb', line 79 required :timeframe_end, Time |
#timeframe_start ⇒ Time
84 |
# File 'lib/orb/models/subscription_license_balance_threshold_reached_webhook_event.rb', line 84 required :timeframe_start, Time |
Instance Method Details
#to_hash ⇒ {
63 |
# File 'sig/orb/models/subscription_license_balance_threshold_reached_webhook_event.rbs', line 63 def to_hash: -> { |