Class: Orb::Models::SubscriptionPriceIntervalsParams::AddAdjustment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/subscription_price_intervals_params.rb,
sig/orb/models/subscription_price_intervals_params.rbs

Defined Under Namespace

Modules: Adjustment, EndDate, StartDate

Constant Summary collapse

Orb =

Returns:

  • (:NewPercentageDiscount)

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(start_date:, adjustment: nil, adjustment_id: nil, end_date: nil) ⇒ Object

Some parameter documentations has been truncated, see Orb::Models::SubscriptionPriceIntervalsParams::AddAdjustment for more details.

Parameters:



# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2657

Instance Attribute Details

#adjustmentOrb::Models::NewPercentageDiscount, ...

The definition of a new adjustment to create and add to the subscription.



2634
2635
2636
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2634

optional :adjustment,
union: -> { Orb::SubscriptionPriceIntervalsParams::AddAdjustment::Adjustment },
nil?: true

#adjustment_idString?

The ID of the adjustment to add to the subscription. Adjustment IDs can be re-used from existing subscriptions or plans, but adjustments associated with coupon redemptions cannot be re-used.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2644
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2644

optional :adjustment_id, String, nil?: true

#end_dateTime, ...

The end date of the adjustment interval. This is the date that the adjustment will stop affecting prices on the subscription. The adjustment will apply to invoice dates that overlap with this end_date.This end_date is treated as exclusive for in-advance prices, and inclusive for in-arrears prices.

Parameters:

  • value (Orb::Models::SubscriptionPriceIntervalsParams::AddAdjustment::end_date, nil)

Returns:



2653
2654
2655
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2653

optional :end_date,
union: -> { Orb::SubscriptionPriceIntervalsParams::AddAdjustment::EndDate },
nil?: true

#start_dateTime, ...

The start date of the adjustment interval. This is the date that the adjustment will start affecting prices on the subscription. The adjustment will apply to invoice dates that overlap with this start_date. This start_date is treated as inclusive for in-advance prices, and exclusive for in-arrears prices.

Parameters:

  • value (Orb::Models::SubscriptionPriceIntervalsParams::AddAdjustment::start_date)

Returns:



2628
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2628

required :start_date, union: -> { Orb::SubscriptionPriceIntervalsParams::AddAdjustment::StartDate }

Instance Method Details

#to_hash{

Returns:

  • ({)


1857
# File 'sig/orb/models/subscription_price_intervals_params.rbs', line 1857

def to_hash: -> {