Class: Orb::Models::SubscriptionPriceIntervalsParams::AddAdjustment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionPriceIntervalsParams::AddAdjustment
- Defined in:
- lib/orb/models/subscription_price_intervals_params.rb,
sig/orb/models/subscription_price_intervals_params.rbs
Defined Under Namespace
Modules: Adjustment, EndDate, StartDate
Constant Summary collapse
- Orb =
Instance Attribute Summary collapse
-
#adjustment ⇒ Orb::Models::NewPercentageDiscount, ...
The definition of a new adjustment to create and add to the subscription.
-
#adjustment_id ⇒ String?
The ID of the adjustment to add to the subscription.
-
#end_date ⇒ Time, ...
The end date of the adjustment interval.
-
#start_date ⇒ Time, ...
The start date of the adjustment interval.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(Orb::Models::NewPercentageDiscount, Orb::Models::NewUsageDiscount, Orb::Models::NewAmountDiscount, Orb::Models::NewMinimum, Orb::Models::NewMaximum, Orb::Models::SubscriptionPriceIntervalsParams::AddAdjustment::Adjustment::TieredPercentageDiscount)
Instance Method Summary collapse
-
#initialize(start_date:, adjustment: nil, adjustment_id: nil, end_date: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see AddAdjustment for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(start_date:, adjustment: nil, adjustment_id: nil, end_date: nil) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::SubscriptionPriceIntervalsParams::AddAdjustment for more details.
|
|
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2657
|
Instance Attribute Details
#adjustment ⇒ Orb::Models::NewPercentageDiscount, ...
The definition of a new adjustment to create and add to the subscription.
2634 2635 2636 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2634 optional :adjustment, union: -> { Orb::SubscriptionPriceIntervalsParams::AddAdjustment::Adjustment }, nil?: true |
#adjustment_id ⇒ String?
The ID of the adjustment to add to the subscription. Adjustment IDs can be re-used from existing subscriptions or plans, but adjustments associated with coupon redemptions cannot be re-used.
2644 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2644 optional :adjustment_id, String, nil?: true |
#end_date ⇒ Time, ...
The end date of the adjustment interval. This is the date that the adjustment
will stop affecting prices on the subscription. The adjustment will apply to
invoice dates that overlap with this end_date.This end_date is treated as
exclusive for in-advance prices, and inclusive for in-arrears prices.
2653 2654 2655 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2653 optional :end_date, union: -> { Orb::SubscriptionPriceIntervalsParams::AddAdjustment::EndDate }, nil?: true |
#start_date ⇒ Time, ...
The start date of the adjustment interval. This is the date that the adjustment
will start affecting prices on the subscription. The adjustment will apply to
invoice dates that overlap with this start_date. This start_date is treated
as inclusive for in-advance prices, and exclusive for in-arrears prices.
2628 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2628 required :start_date, union: -> { Orb::SubscriptionPriceIntervalsParams::AddAdjustment::StartDate } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2906
|
.variants ⇒ Array(Orb::Models::NewPercentageDiscount, Orb::Models::NewUsageDiscount, Orb::Models::NewAmountDiscount, Orb::Models::NewMinimum, Orb::Models::NewMaximum, Orb::Models::SubscriptionPriceIntervalsParams::AddAdjustment::Adjustment::TieredPercentageDiscount)
|
|
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2682
|
Instance Method Details
#to_hash ⇒ {
1857 |
# File 'sig/orb/models/subscription_price_intervals_params.rbs', line 1857
def to_hash: -> {
|