Class: Orb::Models::SubscriptionPriceIntervalsParams::Edit
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionPriceIntervalsParams::Edit
- Defined in:
- lib/orb/models/subscription_price_intervals_params.rb,
sig/orb/models/subscription_price_intervals_params.rbs
Defined Under Namespace
Modules: EndDate, StartDate Classes: FixedFeeQuantityTransition
Instance Attribute Summary collapse
-
#billing_cycle_day ⇒ Integer?
The updated billing cycle day for this price interval.
-
#can_defer_billing ⇒ Boolean?
If true, an in-arrears price interval ending mid-cycle will defer billing the final line item until the next scheduled invoice.
-
#end_date ⇒ Time, ...
The updated end date of this price interval.
-
#filter ⇒ String?
An additional filter to apply to usage queries.
-
#fixed_fee_quantity_transitions ⇒ Array<Orb::Models::SubscriptionPriceIntervalsParams::Edit::FixedFeeQuantityTransition>?
A list of fixed fee quantity transitions to use for this price interval.
-
#metric_parameter_overrides ⇒ Hash{Symbol=>Object}?
Override values for parameterized billable metric variables.
-
#price_interval_id ⇒ String
The id of the price interval to edit.
-
#start_date ⇒ Time, ...
The updated start date of this price interval.
-
#usage_customer_ids ⇒ Array<String>?
A list of customer IDs whose usage events will be aggregated and billed under this subscription.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(effective_date:, quantity:) ⇒ Object
|
|
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 3047
|
Instance Attribute Details
#billing_cycle_day ⇒ Integer?
The updated billing cycle day for this price interval. If not specified, the billing cycle day will not be updated. Note that overlapping price intervals must have the same billing cycle day.
2982 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2982 optional :billing_cycle_day, Integer, nil?: true |
#can_defer_billing ⇒ Boolean?
If true, an in-arrears price interval ending mid-cycle will defer billing the final line item until the next scheduled invoice. If false, it will be billed on its end date.
2990 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2990 optional :can_defer_billing, Orb::Internal::Type::Boolean, nil?: true |
#end_date ⇒ Time, ...
The updated end date of this price interval. If not specified, the end date will not be updated.
2997 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2997 optional :end_date, union: -> { Orb::SubscriptionPriceIntervalsParams::Edit::EndDate }, nil?: true |
#filter ⇒ String?
An additional filter to apply to usage queries. This filter must be expressed as a boolean computed property. If null, usage queries will not include any additional filter.
3006 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 3006 optional :filter, String, nil?: true |
#fixed_fee_quantity_transitions ⇒ Array<Orb::Models::SubscriptionPriceIntervalsParams::Edit::FixedFeeQuantityTransition>?
A list of fixed fee quantity transitions to use for this price interval. Note that this list will overwrite all existing fixed fee quantity transitions on the price interval.
3014 3015 3016 3017 3018 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 3014 optional :fixed_fee_quantity_transitions, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionPriceIntervalsParams::Edit::FixedFeeQuantityTransition] }, nil?: true |
#metric_parameter_overrides ⇒ Hash{Symbol=>Object}?
Override values for parameterized billable metric variables. Keys are parameter names, values are the override values (number or string).
3025 3026 3027 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 3025 optional :metric_parameter_overrides, Orb::Internal::Type::HashOf[Orb::Internal::Type::Unknown], nil?: true |
#price_interval_id ⇒ String
The id of the price interval to edit.
2974 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2974 required :price_interval_id, String |
#start_date ⇒ Time, ...
The updated start date of this price interval. If not specified, the start date will not be updated.
3034 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 3034 optional :start_date, union: -> { Orb::SubscriptionPriceIntervalsParams::Edit::StartDate } |
#usage_customer_ids ⇒ Array<String>?
A list of customer IDs whose usage events will be aggregated and billed under this subscription. By default, a subscription only considers usage events associated with its attached customer's customer_id. When usage_customer_ids is provided, the subscription includes usage events from the specified customers only. Provided usage_customer_ids must be either the customer for this subscription itself, or any of that customer's children.
3045 |
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 3045 optional :usage_customer_ids, Orb::Internal::Type::ArrayOf[String], nil?: true |
Class Method Details
.variants ⇒ Array(Time, Symbol, Orb::Models::BillingCycleRelativeDate)
|
|
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 3080
|
Instance Method Details
#to_hash ⇒ {
2111 |
# File 'sig/orb/models/subscription_price_intervals_params.rbs', line 2111
def to_hash: -> {
|