Class: Orb::Models::SubscriptionPriceIntervalsParams::Edit

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/orb/models/subscription_price_intervals_params.rb,
sig/orb/models/subscription_price_intervals_params.rbs

Defined Under Namespace

Modules: EndDate, StartDate Classes: FixedFeeQuantityTransition

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(effective_date:, quantity:) ⇒ Object

Parameters:

  • effective_date (Time)

    The date that the fixed fee quantity transition should take effect.

  • quantity (Integer)

    The quantity of the fixed fee quantity transition.



# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2763

Instance Attribute Details

#billing_cycle_dayInteger?

The updated billing cycle day for this price interval. If not specified, the billing cycle day will not be updated. Note that overlapping price intervals must have the same billing cycle day.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


2698
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2698

optional :billing_cycle_day, Integer, nil?: true

#can_defer_billingBoolean?

If true, an in-arrears price interval ending mid-cycle will defer billing the final line item until the next scheduled invoice. If false, it will be billed on its end date.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


2706
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2706

optional :can_defer_billing, Orb::Internal::Type::Boolean, nil?: true

#end_dateTime, ...

The updated end date of this price interval. If not specified, the end date will not be updated.

Parameters:

  • value (Orb::Models::SubscriptionPriceIntervalsParams::Edit::end_date, nil)

Returns:



2713
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2713

optional :end_date, union: -> { Orb::SubscriptionPriceIntervalsParams::Edit::EndDate }, nil?: true

#filterString?

An additional filter to apply to usage queries. This filter must be expressed as a boolean computed property. If null, usage queries will not include any additional filter.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2722
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2722

optional :filter, String, nil?: true

#fixed_fee_quantity_transitionsArray<Orb::Models::SubscriptionPriceIntervalsParams::Edit::FixedFeeQuantityTransition>?

A list of fixed fee quantity transitions to use for this price interval. Note that this list will overwrite all existing fixed fee quantity transitions on the price interval.

Parameters:

  • value (::Array[Orb::SubscriptionPriceIntervalsParams::Edit::FixedFeeQuantityTransition], nil)

Returns:



2730
2731
2732
2733
2734
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2730

optional :fixed_fee_quantity_transitions,
-> {
  Orb::Internal::Type::ArrayOf[Orb::SubscriptionPriceIntervalsParams::Edit::FixedFeeQuantityTransition]
},
nil?: true

#metric_parameter_overridesHash{Symbol=>Object}?

Override values for parameterized billable metric variables. Keys are parameter names, values are the override values (number or string).

Parameters:

  • value (::Hash[Symbol, top], nil)

Returns:

  • (Hash{Symbol=>Object}, nil)


2741
2742
2743
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2741

optional :metric_parameter_overrides,
Orb::Internal::Type::HashOf[Orb::Internal::Type::Unknown],
nil?: true

#price_interval_idString

The id of the price interval to edit.

Parameters:

  • value (String)

Returns:

  • (String)


2690
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2690

required :price_interval_id, String

#start_dateTime, ...

The updated start date of this price interval. If not specified, the start date will not be updated.

Returns:



2750
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2750

optional :start_date, union: -> { Orb::SubscriptionPriceIntervalsParams::Edit::StartDate }

#usage_customer_idsArray<String>?

A list of customer IDs whose usage events will be aggregated and billed under this subscription. By default, a subscription only considers usage events associated with its attached customer's customer_id. When usage_customer_ids is provided, the subscription includes usage events from the specified customers only. Provided usage_customer_ids must be either the customer for this subscription itself, or any of that customer's children.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


2761
# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2761

optional :usage_customer_ids, Orb::Internal::Type::ArrayOf[String], nil?: true

Class Method Details

.variantsArray(Time, Symbol, Orb::Models::BillingCycleRelativeDate)

Returns:



# File 'lib/orb/models/subscription_price_intervals_params.rb', line 2796

Instance Method Details

#to_hash{

Returns:

  • ({)


1933
# File 'sig/orb/models/subscription_price_intervals_params.rbs', line 1933

def to_hash: -> {