Class: Orb::Models::SubscriptionSchedulePlanChangeParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionSchedulePlanChangeParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/orb/models/subscription_schedule_plan_change_params.rb,
sig/orb/models/subscription_schedule_plan_change_params.rbs
Overview
Defined Under Namespace
Modules: BillingCycleAlignment, ChangeOption Classes: AddAdjustment, AddPrice, RemoveAdjustment, RemovePrice, ReplaceAdjustment, ReplacePrice
Instance Attribute Summary collapse
-
#add_adjustments ⇒ Array<Orb::Models::SubscriptionSchedulePlanChangeParams::AddAdjustment>?
Additional adjustments to be added to the subscription.
-
#add_prices ⇒ Array<Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice>?
Additional prices to be added to the subscription.
-
#align_billing_with_plan_change_date ⇒ Boolean?
[DEPRECATED] Use billing_cycle_alignment instead.
-
#auto_collection ⇒ Boolean?
Determines whether issued invoices for this subscription will automatically be charged with the saved payment method on the due date.
-
#auto_issuance ⇒ Boolean?
Used to determine if invoices for this subscription will be automatically issued.
-
#billing_cycle_alignment ⇒ Symbol, ...
Reset billing periods to be aligned with the plan change's effective date or start of the month.
- #billing_cycle_anchor_configuration ⇒ Orb::Models::BillingCycleAnchorConfiguration?
-
#change_date ⇒ Time?
The date that the plan change should take effect.
- #change_option ⇒ Symbol, Orb::Models::SubscriptionSchedulePlanChangeParams::ChangeOption
-
#coupon_redemption_code ⇒ String?
Redemption code to be used for this subscription.
- #credits_overage_rate ⇒ Float? deprecated Deprecated.
-
#default_invoice_memo ⇒ String?
Determines the default memo on this subscription's invoices.
-
#external_plan_id ⇒ String?
The external_plan_id of the plan that the given subscription should be switched to.
-
#filter ⇒ String?
An additional filter to apply to usage queries.
-
#initial_phase_order ⇒ Integer?
The phase of the plan to start with.
-
#invoicing_threshold ⇒ String?
When this subscription's accrued usage reaches this threshold, an invoice will be issued for the subscription.
-
#net_terms ⇒ Integer?
The net terms determines the difference between the invoice date and the issue date for the invoice.
- #per_credit_overage_amount ⇒ Float? deprecated Deprecated.
-
#plan_id ⇒ String?
The plan that the given subscription should be switched to.
-
#plan_version_number ⇒ Integer?
Specifies which version of the plan to change to.
- #price_overrides ⇒ Array<Object>? deprecated Deprecated.
-
#remove_adjustments ⇒ Array<Orb::Models::SubscriptionSchedulePlanChangeParams::RemoveAdjustment>?
Plan adjustments to be removed from the subscription.
-
#remove_prices ⇒ Array<Orb::Models::SubscriptionSchedulePlanChangeParams::RemovePrice>?
Plan prices to be removed from the subscription.
-
#replace_adjustments ⇒ Array<Orb::Models::SubscriptionSchedulePlanChangeParams::ReplaceAdjustment>?
Plan adjustments to be replaced with additional adjustments on the subscription.
-
#replace_prices ⇒ Array<Orb::Models::SubscriptionSchedulePlanChangeParams::ReplacePrice>?
Plan prices to be replaced with additional prices on the subscription.
- #subscription_id ⇒ String
-
#trial_duration_days ⇒ Integer?
The duration of the trial period in days.
-
#usage_customer_ids ⇒ Array<String>?
A list of customer IDs whose usage events will be aggregated and billed under this subscription.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(Orb::Models::NewPercentageDiscount, Orb::Models::NewUsageDiscount, Orb::Models::NewAmountDiscount, Orb::Models::NewMinimum, Orb::Models::NewMaximum, Orb::Models::SubscriptionSchedulePlanChangeParams::ReplaceAdjustment::Adjustment::TieredPercentageDiscount)
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(external_price_id: nil, price_id: nil) ⇒ Object
|
|
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3014
|
Instance Attribute Details
#add_adjustments ⇒ Array<Orb::Models::SubscriptionSchedulePlanChangeParams::AddAdjustment>?
Additional adjustments to be added to the subscription. (Only available for accounts that have migrated off of legacy subscription overrides)
25 26 27 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 25 optional :add_adjustments, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionSchedulePlanChangeParams::AddAdjustment] }, nil?: true |
#add_prices ⇒ Array<Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice>?
Additional prices to be added to the subscription. (Only available for accounts that have migrated off of legacy subscription overrides)
34 35 36 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 34 optional :add_prices, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionSchedulePlanChangeParams::AddPrice] }, nil?: true |
#align_billing_with_plan_change_date ⇒ Boolean?
[DEPRECATED] Use billing_cycle_alignment instead. Reset billing periods to be aligned with the plan change's effective date.
43 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 43 optional :align_billing_with_plan_change_date, Orb::Internal::Type::Boolean, nil?: true |
#auto_collection ⇒ Boolean?
Determines whether issued invoices for this subscription will automatically be charged with the saved payment method on the due date. If not specified, this defaults to the behavior configured for this customer.
51 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 51 optional :auto_collection, Orb::Internal::Type::Boolean, nil?: true |
#auto_issuance ⇒ Boolean?
Used to determine if invoices for this subscription will be automatically
issued. If true, invoices will be automatically issued. If false, invoices will
require manual approval. If null is specified, this defaults to the behavior
configured for this customer.
60 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 60 optional :auto_issuance, Orb::Internal::Type::Boolean, nil?: true |
#billing_cycle_alignment ⇒ Symbol, ...
Reset billing periods to be aligned with the plan change's effective date or
start of the month. Defaults to unchanged which keeps subscription's existing
billing cycle alignment.
68 69 70 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 68 optional :billing_cycle_alignment, enum: -> { Orb::SubscriptionSchedulePlanChangeParams::BillingCycleAlignment }, nil?: true |
#billing_cycle_anchor_configuration ⇒ Orb::Models::BillingCycleAnchorConfiguration?
75 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 75 optional :billing_cycle_anchor_configuration, -> { Orb::BillingCycleAnchorConfiguration }, nil?: true |
#change_date ⇒ Time?
The date that the plan change should take effect. This parameter can only be
passed if the change_option is requested_date. If a date with no time is
passed, the plan change will happen at midnight in the customer's timezone.
83 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 83 optional :change_date, Time, nil?: true |
#change_option ⇒ Symbol, Orb::Models::SubscriptionSchedulePlanChangeParams::ChangeOption
18 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 18 required :change_option, enum: -> { Orb::SubscriptionSchedulePlanChangeParams::ChangeOption } |
#coupon_redemption_code ⇒ String?
Redemption code to be used for this subscription. If the coupon cannot be found by its redemption code, or cannot be redeemed, an error response will be returned and the subscription creation or plan change will not be scheduled.
91 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 91 optional :coupon_redemption_code, String, nil?: true |
#credits_overage_rate ⇒ Float?
97 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 97 optional :credits_overage_rate, Float, nil?: true |
#default_invoice_memo ⇒ String?
Determines the default memo on this subscription's invoices. Note that if this is not provided, it is determined by the plan configuration.
104 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 104 optional :default_invoice_memo, String, nil?: true |
#external_plan_id ⇒ String?
The external_plan_id of the plan that the given subscription should be switched
to. Note that either this property or plan_id must be specified.
111 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 111 optional :external_plan_id, String, nil?: true |
#filter ⇒ String?
An additional filter to apply to usage queries. This filter must be expressed as a boolean computed property. If null, usage queries will not include any additional filter.
120 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 120 optional :filter, String, nil?: true |
#initial_phase_order ⇒ Integer?
The phase of the plan to start with
126 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 126 optional :initial_phase_order, Integer, nil?: true |
#invoicing_threshold ⇒ String?
When this subscription's accrued usage reaches this threshold, an invoice will be issued for the subscription. If not specified, invoices will only be issued at the end of the billing period.
134 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 134 optional :invoicing_threshold, String, nil?: true |
#net_terms ⇒ Integer?
The net terms determines the difference between the invoice date and the issue date for the invoice. If you intend the invoice to be due on issue, set this to 0. If not provided, this defaults to the value specified in the plan.
142 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 142 optional :net_terms, Integer, nil?: true |
#per_credit_overage_amount ⇒ Float?
148 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 148 optional :per_credit_overage_amount, Float, nil?: true |
#plan_id ⇒ String?
The plan that the given subscription should be switched to. Note that either
this property or external_plan_id must be specified.
155 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 155 optional :plan_id, String, nil?: true |
#plan_version_number ⇒ Integer?
Specifies which version of the plan to change to. If null, the default version will be used.
162 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 162 optional :plan_version_number, Integer, nil?: true |
#price_overrides ⇒ Array<Object>?
Optionally provide a list of overrides for prices on the plan
170 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 170 optional :price_overrides, Orb::Internal::Type::ArrayOf[Orb::Internal::Type::Unknown], nil?: true |
#remove_adjustments ⇒ Array<Orb::Models::SubscriptionSchedulePlanChangeParams::RemoveAdjustment>?
Plan adjustments to be removed from the subscription. (Only available for accounts that have migrated off of legacy subscription overrides)
177 178 179 180 181 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 177 optional :remove_adjustments, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionSchedulePlanChangeParams::RemoveAdjustment] }, nil?: true |
#remove_prices ⇒ Array<Orb::Models::SubscriptionSchedulePlanChangeParams::RemovePrice>?
Plan prices to be removed from the subscription. (Only available for accounts that have migrated off of legacy subscription overrides)
188 189 190 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 188 optional :remove_prices, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionSchedulePlanChangeParams::RemovePrice] }, nil?: true |
#replace_adjustments ⇒ Array<Orb::Models::SubscriptionSchedulePlanChangeParams::ReplaceAdjustment>?
Plan adjustments to be replaced with additional adjustments on the subscription. (Only available for accounts that have migrated off of legacy subscription overrides)
198 199 200 201 202 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 198 optional :replace_adjustments, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionSchedulePlanChangeParams::ReplaceAdjustment] }, nil?: true |
#replace_prices ⇒ Array<Orb::Models::SubscriptionSchedulePlanChangeParams::ReplacePrice>?
Plan prices to be replaced with additional prices on the subscription. (Only available for accounts that have migrated off of legacy subscription overrides)
209 210 211 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 209 optional :replace_prices, -> { Orb::Internal::Type::ArrayOf[Orb::SubscriptionSchedulePlanChangeParams::ReplacePrice] }, nil?: true |
#subscription_id ⇒ String
13 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 13 required :subscription_id, String |
#trial_duration_days ⇒ Integer?
The duration of the trial period in days. If not provided, this defaults to the
value specified in the plan. If 0 is provided, the trial on the plan will be
skipped.
219 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 219 optional :trial_duration_days, Integer, nil?: true |
#usage_customer_ids ⇒ Array<String>?
A list of customer IDs whose usage events will be aggregated and billed under this subscription. By default, a subscription only considers usage events associated with its attached customer's customer_id. When usage_customer_ids is provided, the subscription includes usage events from the specified customers only. Provided usage_customer_ids must be either the customer for this subscription itself, or any of that customer's children.
230 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 230 optional :usage_customer_ids, Orb::Internal::Type::ArrayOf[String], nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 301
|
.variants ⇒ Array(Orb::Models::NewPercentageDiscount, Orb::Models::NewUsageDiscount, Orb::Models::NewAmountDiscount, Orb::Models::NewMinimum, Orb::Models::NewMaximum, Orb::Models::SubscriptionSchedulePlanChangeParams::ReplaceAdjustment::Adjustment::TieredPercentageDiscount)
|
|
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 571
|
Instance Method Details
#to_hash ⇒ {
128 |
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 128
def to_hash: -> {
|