Class: Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier
- Defined in:
- lib/orb/models/subscription_schedule_plan_change_params.rb,
sig/orb/models/subscription_schedule_plan_change_params.rbs
Instance Attribute Summary collapse
-
#dimension_values ⇒ Array<String>
The matrix cell this tier applies to, as one or two dimension values.
-
#tier_lower_bound ⇒ String
Exclusive tier starting value.
-
#unit_amount ⇒ String
Per unit amount.
Instance Method Summary collapse
-
#initialize(allocation:, default_unit_amount:, dimensions:, tiers:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(allocation:, default_unit_amount:, dimensions:, tiers:) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig for more details.
Configuration for tiered_matrix_with_allocation pricing
1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 1540 class Tier < Orb::Internal::Type::BaseModel # @!attribute dimension_values # The matrix cell this tier applies to, as one or two dimension values # # @return [Array<String>] required :dimension_values, Orb::Internal::Type::ArrayOf[String] # @!attribute tier_lower_bound # Exclusive tier starting value. The tier runs up to and including the next bound # configured for the same matrix cell. # # @return [String] required :tier_lower_bound, String # @!attribute unit_amount # Per unit amount # # @return [String] required :unit_amount, String # @!method initialize(dimension_values:, tier_lower_bound:, unit_amount:) # Some parameter documentations has been truncated, see # {Orb::Models::SubscriptionSchedulePlanChangeParams::AddPrice::Price::TieredMatrixWithAllocation::TieredMatrixWithAllocationConfig::Tier} # for more details. # # Configuration for a single tier scoped to one matrix cell # # @param dimension_values [Array<String>] The matrix cell this tier applies to, as one or two dimension values # # @param tier_lower_bound [String] Exclusive tier starting value. The tier runs up to and including the next bound # # @param unit_amount [String] Per unit amount end |
Instance Attribute Details
#dimension_values ⇒ Array<String>
The matrix cell this tier applies to, as one or two dimension values
1545 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 1545 required :dimension_values, Orb::Internal::Type::ArrayOf[String] |
#tier_lower_bound ⇒ String
Exclusive tier starting value. The tier runs up to and including the next bound configured for the same matrix cell.
1552 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 1552 required :tier_lower_bound, String |
#unit_amount ⇒ String
Per unit amount
1558 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 1558 required :unit_amount, String |
Instance Method Details
#to_hash ⇒ {
1037 |
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 1037 def to_hash: -> { |