Class: Orb::Models::SubscriptionSchedulePlanChangeParams::ReplacePrice
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionSchedulePlanChangeParams::ReplacePrice
- Defined in:
- lib/orb/models/subscription_schedule_plan_change_params.rb,
sig/orb/models/subscription_schedule_plan_change_params.rbs
Defined Under Namespace
Modules: Price
Constant Summary collapse
- Orb =
Instance Attribute Summary collapse
-
#allocation_price ⇒ Orb::Models::NewAllocationPrice?
The definition of a new allocation price to create and add to the subscription.
- #discounts ⇒ Array<Orb::Models::DiscountOverride>? deprecated Deprecated.
-
#external_price_id ⇒ String?
The external price id of the price to add to the subscription.
-
#fixed_price_quantity ⇒ Float?
The new quantity of the price, if the price is a fixed price.
- #maximum_amount ⇒ String? deprecated Deprecated.
-
#metric_parameter_overrides ⇒ Hash{Symbol=>Object}?
Override values for parameterized billable metric variables.
- #minimum_amount ⇒ String? deprecated Deprecated.
-
#price ⇒ Orb::Models::NewSubscriptionUnitPrice, ...
New subscription price request body params.
-
#price_id ⇒ String?
The id of the price to add to the subscription.
-
#replaces_price_id ⇒ String
The id of the price on the plan to replace in the subscription.
Instance Method Summary collapse
-
#initialize(replaces_price_id:, allocation_price: nil, discounts: nil, external_price_id: nil, fixed_price_quantity: nil, maximum_amount: nil, metric_parameter_overrides: nil, minimum_amount: nil, price: nil, price_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ReplacePrice for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(replaces_price_id:, allocation_price: nil, discounts: nil, external_price_id: nil, fixed_price_quantity: nil, maximum_amount: nil, metric_parameter_overrides: nil, minimum_amount: nil, price: nil, price_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::SubscriptionSchedulePlanChangeParams::ReplacePrice for more details.
|
|
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3404
|
Instance Attribute Details
#allocation_price ⇒ Orb::Models::NewAllocationPrice?
The definition of a new allocation price to create and add to the subscription.
3338 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3338 optional :allocation_price, -> { Orb::NewAllocationPrice }, nil?: true |
#discounts ⇒ Array<Orb::Models::DiscountOverride>?
[DEPRECATED] Use add_adjustments instead. The subscription's discounts for the replacement price.
3347 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3347 optional :discounts, -> { Orb::Internal::Type::ArrayOf[Orb::DiscountOverride] }, nil?: true |
#external_price_id ⇒ String?
The external price id of the price to add to the subscription.
3353 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3353 optional :external_price_id, String, nil?: true |
#fixed_price_quantity ⇒ Float?
The new quantity of the price, if the price is a fixed price.
3359 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3359 optional :fixed_price_quantity, Float, nil?: true |
#maximum_amount ⇒ String?
[DEPRECATED] Use add_adjustments instead. The subscription's maximum amount for the replacement price.
3368 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3368 optional :maximum_amount, String, nil?: true |
#metric_parameter_overrides ⇒ Hash{Symbol=>Object}?
Override values for parameterized billable metric variables. Keys are parameter names, values are the override values.
3375 3376 3377 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3375 optional :metric_parameter_overrides, Orb::Internal::Type::HashOf[Orb::Internal::Type::Unknown], nil?: true |
#minimum_amount ⇒ String?
[DEPRECATED] Use add_adjustments instead. The subscription's minimum amount for the replacement price.
3386 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3386 optional :minimum_amount, String, nil?: true |
#price ⇒ Orb::Models::NewSubscriptionUnitPrice, ...
New subscription price request body params.
3392 3393 3394 3395 3396 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3392 optional :price, union: -> { Orb::SubscriptionSchedulePlanChangeParams::ReplacePrice::Price }, nil?: true |
#price_id ⇒ String?
The id of the price to add to the subscription.
3402 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3402 optional :price_id, String, nil?: true |
#replaces_price_id ⇒ String
The id of the price on the plan to replace in the subscription.
3332 |
# File 'lib/orb/models/subscription_schedule_plan_change_params.rb', line 3332 required :replaces_price_id, String |
Instance Method Details
#to_hash ⇒ {
2360 |
# File 'sig/orb/models/subscription_schedule_plan_change_params.rbs', line 2360
def to_hash: -> {
|