Class: Orb::Models::SubscriptionUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Orb::Models::SubscriptionUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/orb/models/subscription_update_params.rb,
sig/orb/models/subscription_update_params.rbs
Overview
Instance Attribute Summary collapse
-
#auto_collection ⇒ Boolean?
Determines whether issued invoices for this subscription will automatically be charged with the saved payment method on the due date.
-
#auto_issuance ⇒ Boolean?
Used to determine if invoices for this subscription will be automatically issued.
-
#default_invoice_memo ⇒ String?
Determines the default memo on this subscription's invoices.
-
#invoicing_threshold ⇒ String?
When this subscription's accrued usage reaches this threshold, an invoice will be issued for the subscription.
-
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource.
-
#net_terms ⇒ Integer?
Determines the difference between the invoice issue date for subscription invoices as the date that they are due.
- #subscription_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(subscription_id:, auto_collection: nil, auto_issuance: nil, default_invoice_memo: nil, invoicing_threshold: nil, metadata: nil, net_terms: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see SubscriptionUpdateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(subscription_id:, auto_collection: nil, auto_issuance: nil, default_invoice_memo: nil, invoicing_threshold: nil, metadata: nil, net_terms: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Orb::Models::SubscriptionUpdateParams for more details.
|
|
# File 'lib/orb/models/subscription_update_params.rb', line 64
|
Instance Attribute Details
#auto_collection ⇒ Boolean?
Determines whether issued invoices for this subscription will automatically be charged with the saved payment method on the due date. This property defaults to the plan's behavior.
21 |
# File 'lib/orb/models/subscription_update_params.rb', line 21 optional :auto_collection, Orb::Internal::Type::Boolean, nil?: true |
#auto_issuance ⇒ Boolean?
Used to determine if invoices for this subscription will be automatically
issued. If true, invoices will be automatically issued. If false, invoices will
require manual approval. If null is specified, this defaults to the behavior
configured for this customer.
30 |
# File 'lib/orb/models/subscription_update_params.rb', line 30 optional :auto_issuance, Orb::Internal::Type::Boolean, nil?: true |
#default_invoice_memo ⇒ String?
Determines the default memo on this subscription's invoices. Note that if this is not provided, it is determined by the plan configuration.
37 |
# File 'lib/orb/models/subscription_update_params.rb', line 37 optional :default_invoice_memo, String, nil?: true |
#invoicing_threshold ⇒ String?
When this subscription's accrued usage reaches this threshold, an invoice will be issued for the subscription. If not specified, invoices will only be issued at the end of the billing period.
45 |
# File 'lib/orb/models/subscription_update_params.rb', line 45 optional :invoicing_threshold, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String, nil}?
User-specified key/value pairs for the resource. Individual keys can be removed
by setting the value to null, and the entire metadata mapping can be cleared
by setting metadata to null.
53 |
# File 'lib/orb/models/subscription_update_params.rb', line 53 optional :metadata, Orb::Internal::Type::HashOf[String, nil?: true], nil?: true |
#net_terms ⇒ Integer?
Determines the difference between the invoice issue date for subscription
invoices as the date that they are due. A value of 0 here represents that the
invoice is due on issue, whereas a value of 30 represents that the customer
has a month to pay the invoice.
62 |
# File 'lib/orb/models/subscription_update_params.rb', line 62 optional :net_terms, Integer, nil?: true |
#subscription_id ⇒ String
13 |
# File 'lib/orb/models/subscription_update_params.rb', line 13 required :subscription_id, String |
Instance Method Details
#to_hash ⇒ {
44 |
# File 'sig/orb/models/subscription_update_params.rbs', line 44
def to_hash: -> {
|